@@ -7,34 +7,37 @@
 Module implementing a code metrics dialog.
 """
 
-import sys
 import os
-import types
+import fnmatch
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot, Qt, QLocale, qVersion
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
+    QTreeWidgetItem, QApplication
+
+from .Ui_CodeMetricsDialog import Ui_CodeMetricsDialog
+from . import CodeMetrics
 
-from Ui_CodeMetricsDialog import Ui_CodeMetricsDialog
-import CodeMetrics
 import Utilities
 
+
 class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
     """
     Class implementing a dialog to display the code metrics.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.summaryList.headerItem().setText(self.summaryList.columnCount(), "")
+        self.summaryList.headerItem().setText(
+            self.summaryList.columnCount(), "")
         self.summaryList.header().resizeSection(0, 200)
         self.summaryList.header().resizeSection(1, 100)
         
@@ -43,12 +46,16 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         self.cancelled = False
         
         self.__menu = QMenu(self)
-        self.__menu.addAction(self.trUtf8("Collapse all"), self.__resultCollapse)
+        self.__menu.addAction(self.trUtf8("Collapse all"),
+                              self.__resultCollapse)
         self.__menu.addAction(self.trUtf8("Expand all"), self.__resultExpand)
         self.resultList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.resultList, 
-                     SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.resultList.customContextMenuRequested.connect(
+            self.__showContextMenu)
+        
+        self.__fileList = []
+        self.__project = None
+        self.filterFrame.setVisible(False)
         
     def __resizeResultColumns(self):
         """
@@ -83,21 +90,48 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         """
         Private slot to create a new item in the summary list.
         
-        @param col0 string for column 0 (string or QString)
-        @param col1 string for column 1 (string or QString)
+        @param col0 string for column 0 (string)
+        @param col1 string for column 1 (string)
         """
-        itm = QTreeWidgetItem(self.summaryList, QStringList() << col0 << col1)
+        itm = QTreeWidgetItem(self.summaryList, [col0, col1])
         itm.setTextAlignment(1, Qt.Alignment(Qt.AlignRight))
         
+    def prepare(self, fileList, project):
+        """
+        Public method to prepare the dialog with a list of filenames.
+        
+        @param fileList list of filenames (list of strings)
+        @param project reference to the project object (Project)
+        """
+        self.__fileList = fileList[:]
+        self.__project = project
+        
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
+        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        
+        self.filterFrame.setVisible(True)
+        
+        self.__data = self.__project.getData("OTHERTOOLSPARMS", "CodeMetrics")
+        if self.__data is None or "ExcludeFiles" not in self.__data:
+            self.__data = {"ExcludeFiles": ""}
+        self.excludeFilesEdit.setText(self.__data["ExcludeFiles"])
+        
     def start(self, fn):
         """
         Public slot to start the code metrics determination.
         
-        @param fn file or list of files or directory to be show
+        @param fn file or list of files or directory to show
                 the code metrics for (string or list of strings)
         """
+        self.cancelled = False
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
+        QApplication.processEvents()
+        
         loc = QLocale()
-        if type(fn) is types.ListType:
+        if isinstance(fn, list):
             files = fn
         elif os.path.isdir(fn):
             files = Utilities.direntries(fn, True, '*.py', False)
@@ -150,16 +184,20 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         
         # now do the summary stuff
         docstrings = total['lines'] - total['comments'] - \
-                     total['empty lines'] - total['non-commentary lines']
-        self.__createSummaryItem(self.trUtf8("files"), loc.toString(total['files']))
-        self.__createSummaryItem(self.trUtf8("lines"), loc.toString(total['lines']))
-        self.__createSummaryItem(self.trUtf8("bytes"), loc.toString(total['bytes']))
-        self.__createSummaryItem(self.trUtf8("comments"), loc.toString(total['comments']))
-        self.__createSummaryItem(self.trUtf8("empty lines"), 
+            total['empty lines'] - total['non-commentary lines']
+        self.__createSummaryItem(self.trUtf8("files"),
+                                 loc.toString(total['files']))
+        self.__createSummaryItem(self.trUtf8("lines"),
+                                 loc.toString(total['lines']))
+        self.__createSummaryItem(self.trUtf8("bytes"),
+                                 loc.toString(total['bytes']))
+        self.__createSummaryItem(self.trUtf8("comments"),
+                                 loc.toString(total['comments']))
+        self.__createSummaryItem(self.trUtf8("empty lines"),
                                  loc.toString(total['empty lines']))
-        self.__createSummaryItem(self.trUtf8("non-commentary lines"), 
+        self.__createSummaryItem(self.trUtf8("non-commentary lines"),
                                  loc.toString(total['non-commentary lines']))
-        self.__createSummaryItem(self.trUtf8("documentation lines"), 
+        self.__createSummaryItem(self.trUtf8("documentation lines"),
                                  loc.toString(docstrings))
         self.__resizeSummaryColumns()
         self.__finish()
@@ -171,7 +209,7 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         @param loc reference to the locale object (QLocale)
         @param stats reference to the code metric statistics object
         @param identifier identifier to get values for
-        @return list of values suitable for display (QStringList)
+        @return list of values suitable for display (list of strings)
         """
         counters = stats.counters.get(identifier, {})
         v = []
@@ -184,15 +222,22 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         
     def __finish(self):
         """
-        Private slot called when the action finished or the user pressed the button.
+        Private slot called when the action finished or the user pressed the
+        button.
         """
         self.cancelled = True
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
-        self.resultList.header().setResizeMode(QHeaderView.Interactive)
-        self.summaryList.header().setResizeMode(QHeaderView.Interactive)
+        if qVersion() >= "5.0.0":
+            self.resultList.header().setSectionResizeMode(
+                QHeaderView.Interactive)
+            self.summaryList.header().setSectionResizeMode(
+                QHeaderView.Interactive)
+        else:
+            self.resultList.header().setResizeMode(QHeaderView.Interactive)
+            self.summaryList.header().setResizeMode(QHeaderView.Interactive)
         
     def on_buttonBox_clicked(self, button):
         """
@@ -205,6 +250,29 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         elif button == self.buttonBox.button(QDialogButtonBox.Cancel):
             self.__finish()
         
+    @pyqtSlot()
+    def on_startButton_clicked(self):
+        """
+        Private slot to start a code metrics run.
+        """
+        fileList = self.__fileList[:]
+        
+        filterString = self.excludeFilesEdit.text()
+        if "ExcludeFiles" not in self.__data or \
+           filterString != self.__data["ExcludeFiles"]:
+            self.__data["ExcludeFiles"] = filterString
+            self.__project.setData("OTHERTOOLSPARMS", "CodeMetrics",
+                                   self.__data)
+        filterList = filterString.split(",")
+        if filterList:
+            for filter in filterList:
+                fileList = [f for f in fileList
+                            if not fnmatch.fnmatch(f, filter.strip())]
+        
+        self.resultList.clear()
+        self.summaryList.clear()
+        self.start(fileList)
+        
     def __showContextMenu(self, coord):
         """
         Private slot to show the context menu of the listview.
