@@ -7,66 +7,69 @@
 Module implementing a Python code coverage dialog.
 """
 
-import sys
 import os
-import types
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot, Qt
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
+    QTreeWidgetItem, QApplication
 
-from KdeQt.KQApplication import e4App
-from KdeQt.KQProgressDialog import KQProgressDialog
+from E5Gui import E5MessageBox
+from E5Gui.E5Application import e5App
+from E5Gui.E5ProgressDialog import E5ProgressDialog
 
-from Ui_PyCoverageDialog import Ui_PyCoverageDialog
+from .Ui_PyCoverageDialog import Ui_PyCoverageDialog
 
 import Utilities
-from DebugClients.Python.coverage import coverage
+from DebugClients.Python3.coverage import coverage
+from DebugClients.Python3.coverage.misc import CoverageException
+
 
 class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
     """
     Class implementing a dialog to display the collected code coverage data.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.summaryList.headerItem().setText(self.summaryList.columnCount(), "")
+        self.summaryList.headerItem().setText(
+            self.summaryList.columnCount(), "")
         self.resultList.headerItem().setText(self.resultList.columnCount(), "")
         
         self.cancelled = False
         self.path = '.'
         self.reload = False
         
-        self.excludeList = QStringList('# *pragma[: ]*[nN][oO] *[cC][oO][vV][eE][rR]')
+        self.excludeList = ['# *pragma[: ]*[nN][oO] *[cC][oO][vV][eE][rR]']
         
         self.__menu = QMenu(self)
         self.__menu.addSeparator()
-        self.openAct = self.__menu.addAction(self.trUtf8("Open"),
-            self.__openFile)
+        self.openAct = self.__menu.addAction(
+            self.trUtf8("Open"), self.__openFile)
         self.__menu.addSeparator()
-        self.annotate = self.__menu.addAction(self.trUtf8('Annotate'), 
-            self.__annotate)
+        self.annotate = self.__menu.addAction(
+            self.trUtf8('Annotate'), self.__annotate)
         self.__menu.addAction(self.trUtf8('Annotate all'), self.__annotateAll)
-        self.__menu.addAction(self.trUtf8('Delete annotated files'), 
-            self.__deleteAnnotated)
+        self.__menu.addAction(
+            self.trUtf8('Delete annotated files'), self.__deleteAnnotated)
         self.__menu.addSeparator()
         self.__menu.addAction(self.trUtf8('Erase Coverage Info'), self.__erase)
         self.resultList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.resultList, 
-                     SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.resultList.customContextMenuRequested.connect(
+            self.__showContextMenu)
     
     def __format_lines(self, lines):
         """
-        Private method to format a list of integers into string by coalescing groups.
+        Private method to format a list of integers into string by coalescing
+        groups.
         
         @param lines list of integers
         @return string representing the list
@@ -89,39 +92,46 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
                 start = None
                 if ind + 1 >= len(lines):
                     break
-                i = lines[ind+1]
+                i = lines[ind + 1]
         if start:
             pairs.append((start, end))
         
         def stringify(pair):
             """
-            Private helper function to generate a string representation of a pair
+            Private helper function to generate a string representation of a
+            pair.
             
             @param pair pair of integers
             """
             start, end = pair
             if start == end:
-                return "%d" % start
+                return "{0:d}".format(start)
             else:
-                return "%d-%d" % (start, end)
+                return "{0:d}-{1:d}".format(start, end)
         
         return ", ".join(map(stringify, pairs))
     
-    def __createResultItem(self, file, statements, executed, coverage, excluded, missing):
+    def __createResultItem(self, file, statements, executed, coverage,
+                           excluded, missing):
         """
         Private method to create an entry in the result list.
         
-        @param file filename of file (string or QString)
+        @param file filename of file (string)
         @param statements amount of statements (integer)
         @param executed amount of executed statements (integer)
         @param coverage percent of coverage (integer)
         @param excluded list of excluded lines (string)
         @param missing list of lines without coverage (string)
         """
-        itm = QTreeWidgetItem(self.resultList, QStringList() \
-            << file << str(statements) << str(executed) << "%d%%" % coverage \
-            << excluded << missing)
-        for col in range(1,4):
+        itm = QTreeWidgetItem(self.resultList, [
+            file,
+            str(statements),
+            str(executed),
+            "{0:.0f}%".format(coverage),
+            excluded,
+            missing
+        ])
+        for col in range(1, 4):
             itm.setTextAlignment(col, Qt.AlignRight)
         if statements != executed:
             font = itm.font(0)
@@ -142,9 +152,9 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         
         self.basename = os.path.splitext(cfn)[0]
         
-        self.cfn = "%s.coverage" % self.basename
+        self.cfn = "{0}.coverage".format(self.basename)
         
-        if type(fn) is types.ListType:
+        if isinstance(fn, list):
             files = fn
             self.path = os.path.dirname(cfn)
         elif os.path.isdir(fn):
@@ -155,7 +165,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
             self.path = os.path.dirname(cfn)
         files.sort()
         
-        cover = coverage(data_file = self.cfn)
+        cover = coverage(data_file=self.cfn)
         cover.use_cache(True)
         cover.load()
         
@@ -168,8 +178,9 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         
         total_statements = 0
         total_executed = 0
+        total_exceptions = 0
         
-        cover.exclude(unicode(self.excludeList[0]))
+        cover.exclude(self.excludeList[0])
         progress = 0
         
         try:
@@ -182,18 +193,24 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
                 if self.cancelled:
                     return
                 
-                statements, excluded, missing, readable  = cover.analysis2(file)[1:]
-                readableEx = excluded and self.__format_lines(excluded) or ''
-                n = len(statements)
-                m = n - len(missing)
-                if n > 0:
-                    pc = 100.0 * m / n
-                else:
-                    pc = 100.0
-                self.__createResultItem(file, str(n), str(m), pc, readableEx, readable)
-                
-                total_statements = total_statements + n
-                total_executed = total_executed + m
+                try:
+                    statements, excluded, missing, readable = \
+                        cover.analysis2(file)[1:]
+                    readableEx = (excluded and self.__format_lines(excluded)
+                                  or '')
+                    n = len(statements)
+                    m = n - len(missing)
+                    if n > 0:
+                        pc = 100.0 * m / n
+                    else:
+                        pc = 100.0
+                    self.__createResultItem(
+                        file, str(n), str(m), pc, readableEx, readable)
+                    
+                    total_statements = total_statements + n
+                    total_executed = total_executed + m
+                except CoverageException:
+                    total_exceptions += 1
                 
                 progress += 1
                 self.checkProgress.setValue(progress)
@@ -210,16 +227,30 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
                 pc = 100.0 * total_executed / total_statements
             else:
                 pc = 100.0
-            itm = QTreeWidgetItem(self.summaryList, QStringList() \
-                << str(total_statements) << str(total_executed) << "%d%%" % pc)
+            itm = QTreeWidgetItem(self.summaryList, [
+                str(total_statements),
+                str(total_executed),
+                "{0:.0f}%".format(pc)
+            ])
             for col in range(0, 3):
                 itm.setTextAlignment(col, Qt.AlignRight)
+        else:
+            self.summaryGroup.hide()
+        
+        if total_exceptions:
+            E5MessageBox.warning(
+                self,
+                self.trUtf8("Parse Error"),
+                self.trUtf8("""%n file(s) could not be parsed. Coverage"""
+                            """ info for these is not available.""", "",
+                            total_exceptions))
         
         self.__finish()
         
     def __finish(self):
         """
-        Private slot called when the action finished or the user pressed the button.
+        Private slot called when the action finished or the user pressed the
+        button.
         """
         self.cancelled = True
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
@@ -265,9 +296,9 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         """
         if itm is None:
             itm = self.resultList.currentItem()
-        fn = unicode(itm.text(0))
+        fn = itm.text(0)
         
-        vm = e4App().getObject("ViewManager")
+        vm = e5App().getObject("ViewManager")
         vm.openSourceFile(fn)
         editor = vm.getOpenEditor(fn)
         editor.codeCoverageShowAnnotations()
@@ -280,11 +311,11 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         selected file.
         """
         itm = self.resultList.currentItem()
-        fn = unicode(itm.text(0))
+        fn = itm.text(0)
         
-        cover = coverage(data_file = self.cfn)
+        cover = coverage(data_file=self.cfn)
         cover.use_cache(True)
-        cover.exclude(unicode(self.excludeList[0]))
+        cover.exclude(self.excludeList[0])
         cover.load()
         cover.annotate([fn], None, True)
         
@@ -303,16 +334,17 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         files = []
         for index in range(amount):
             itm = self.resultList.topLevelItem(index)
-            files.append(unicode(itm.text(0)))
+            files.append(itm.text(0))
         
-        cover = coverage(data_file = self.cfn)
+        cover = coverage(data_file=self.cfn)
         cover.use_cache(True)
-        cover.exclude(unicode(self.excludeList[0]))
+        cover.exclude(self.excludeList[0])
         cover.load()
         
         # now process them
-        progress = KQProgressDialog(self.trUtf8("Annotating files..."), 
-            self.trUtf8("Abort"), 0, len(files), self)
+        progress = E5ProgressDialog(
+            self.trUtf8("Annotating files..."), self.trUtf8("Abort"),
+            0, len(files), self.trUtf8("%v/%m Files"), self)
         progress.setMinimumDuration(0)
         count = 0
         
@@ -320,7 +352,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
             progress.setValue(count)
             if progress.wasCanceled():
                 break
-            cover.annotate([file], None)#, True)
+            cover.annotate([file], None)  # , True)
             count += 1
         
         progress.setValue(len(files))
@@ -332,7 +364,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         This method erases the collected coverage data that is
         stored in the .coverage file.
         """
-        cover = coverage(data_file = self.cfn)
+        cover = coverage(data_file=self.cfn)
         cover.use_cache(True)
         cover.load()
         cover.erase()
@@ -355,7 +387,7 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
             except EnvironmentError:
                 pass
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_reloadButton_clicked(self):
         """
         Private slot to reload the coverage info.
@@ -364,15 +396,16 @@ class PyCoverageDialog(QDialog, Ui_PyCoverageDialog):
         self.summaryList.clear()
         self.reload = True
         excludePattern = self.excludeCombo.currentText()
-        self.excludeList.removeAll(excludePattern)
-        self.excludeList.prepend(excludePattern)
+        if excludePattern in self.excludeList:
+            self.excludeList.remove(excludePattern)
+        self.excludeList.insert(0, excludePattern)
         self.cancelled = False
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         self.start(self.__cfn, self.__fn)
     
-    @pyqtSignature("QTreeWidgetItem*, int")
+    @pyqtSlot(QTreeWidgetItem, int)
     def on_resultList_itemActivated(self, item, column):
         """
         Private slot to handle the activation of an item.
