@@ -7,56 +7,61 @@
 Module implementing a dialog to display profile data.
 """
 
-import sys
 import os
 import pickle
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QMenu, QHeaderView, \
+    QTreeWidgetItem, QApplication
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from Ui_PyProfileDialog import Ui_PyProfileDialog
+from .Ui_PyProfileDialog import Ui_PyProfileDialog
 import Utilities
 
+
 class ProfileTreeWidgetItem(QTreeWidgetItem):
     """
-    Class implementing a custom QTreeWidgetItem to allow sorting on numeric values.
+    Class implementing a custom QTreeWidgetItem to allow sorting on numeric
+    values.
     """
     def __getNC(self, itm):
         """
         Private method to get the value to compare on for the first column.
         
         @param itm item to operate on (ProfileTreeWidgetItem)
+        @return comparison value for the first column (integer)
         """
-        s = str(itm.text(0))
+        s = itm.text(0)
         return int(s.split('/')[0])
         
     def __lt__(self, other):
         """
         Public method to check, if the item is less than the other one.
         
-        @param other reference to item to compare against (ProfileTreeWidgetItem)
+        @param other reference to item to compare against
+            (ProfileTreeWidgetItem)
         @return true, if this item is less than other (boolean)
         """
         column = self.treeWidget().sortColumn()
         if column == 0:
             return self.__getNC(self) < self.__getNC(other)
         if column == 6:
-            return int(str(self.text(column))) < int(str(other.text(column)))
+            return int(self.text(column)) < int(other.text(column))
         return self.text(column) < other.text(column)
         
+
 class PyProfileDialog(QDialog, Ui_PyProfileDialog):
     """
     Class implementing a dialog to display the results of a syntax check run.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
@@ -64,33 +69,36 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         
         self.cancelled = False
         self.exclude = True
-        self.ericpath = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+        self.ericpath = os.path.dirname(
+            os.path.dirname(os.path.abspath(__file__)))
         self.pyLibPath = Utilities.getPythonLibPath()
         
-        self.summaryList.headerItem().setText(self.summaryList.columnCount(), "")
+        self.summaryList.headerItem().setText(
+            self.summaryList.columnCount(), "")
         self.resultList.headerItem().setText(self.resultList.columnCount(), "")
         self.resultList.header().setSortIndicator(0, Qt.DescendingOrder)
         
         self.__menu = QMenu(self)
-        self.filterItm = self.__menu.addAction(self.trUtf8('Exclude Python Library'), 
+        self.filterItm = self.__menu.addAction(
+            self.trUtf8('Exclude Python Library'),
             self.__filter)
         self.__menu.addSeparator()
-        self.__menu.addAction(self.trUtf8('Erase Profiling Info'), 
-            self.__eraseProfile)
-        self.__menu.addAction(self.trUtf8('Erase Timing Info'), self.__eraseTiming)
+        self.__menu.addAction(
+            self.trUtf8('Erase Profiling Info'), self.__eraseProfile)
+        self.__menu.addAction(
+            self.trUtf8('Erase Timing Info'), self.__eraseTiming)
         self.__menu.addSeparator()
         self.__menu.addAction(self.trUtf8('Erase All Infos'), self.__eraseAll)
         self.resultList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.resultList, 
-                     SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.resultList.customContextMenuRequested.connect(
+            self.__showContextMenu)
         self.summaryList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.summaryList, 
-                     SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.summaryList.customContextMenuRequested.connect(
+            self.__showContextMenu)
         
-    def __createResultItem(self, calls, totalTime, totalTimePerCall, cumulativeTime, 
-                           cumulativeTimePerCall, file, line, functionName):
+    def __createResultItem(self, calls, totalTime, totalTimePerCall,
+                           cumulativeTime, cumulativeTimePerCall, file, line,
+                           functionName):
         """
         Private method to create an entry in the result list.
         
@@ -99,14 +107,20 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         @param totalTimePerCall total time per call (double)
         @param cumulativeTime cumulative time (double)
         @param cumulativeTimePerCall cumulative time per call (double)
-        @param file filename of file (string or QString)
+        @param file filename of file (string)
         @param line linenumber (integer)
-        @param functionName function name (string or QString)
+        @param functionName function name (string)
         """
-        itm = ProfileTreeWidgetItem(self.resultList, QStringList() \
-            << calls << "% 8.3f" % totalTime << totalTimePerCall \
-            << "% 8.3f" % cumulativeTime << cumulativeTimePerCall \
-            << file << str(line) << functionName)
+        itm = ProfileTreeWidgetItem(self.resultList, [
+            calls,
+            "{0: 8.3f}".format(totalTime),
+            totalTimePerCall,
+            "{0: 8.3f}".format(cumulativeTime),
+            cumulativeTimePerCall,
+            file,
+            str(line),
+            functionName
+        ])
         for col in [0, 1, 2, 3, 4, 6]:
             itm.setTextAlignment(col, Qt.AlignRight)
         
@@ -114,20 +128,21 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         """
         Private method to create an entry in the summary list.
         
-        @param label text of the first column (string or QString)
-        @param contents text of the second column (string or QString)
+        @param label text of the first column (string)
+        @param contents text of the second column (string)
         """
-        itm = QTreeWidgetItem(self.summaryList, QStringList() << label << contents)
+        itm = QTreeWidgetItem(self.summaryList, [label, contents])
         itm.setTextAlignment(1, Qt.AlignRight)
         
     def __resortResultList(self):
         """
         Private method to resort the tree.
         """
-        self.resultList.sortItems(self.resultList.sortColumn(), 
-                                  self.resultList.header().sortIndicatorOrder())
+        self.resultList.sortItems(self.resultList.sortColumn(),
+                                  self.resultList.header()
+                                  .sortIndicatorOrder())
         
-    def __populateLists(self, exclude = False):
+    def __populateLists(self, exclude=False):
         """
         Private method used to populate the listviews.
         
@@ -142,8 +157,8 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         
         progress = 0
         total_calls = 0
-        prim_calls  = 0
-        total_tt    = 0
+        prim_calls = 0
+        total_tt = 0
         
         try:
             # disable updates of the list for speed
@@ -151,11 +166,12 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
             self.resultList.setSortingEnabled(False)
             
             # now go through all the files
-            for func, (cc, nc, tt, ct, callers) in self.stats.items():
+            for func, (cc, nc, tt, ct, callers) in list(self.stats.items()):
                 if self.cancelled:
                     return
                 
-                if not (self.ericpath and func[0].startswith(self.ericpath)) and \
+                if not (self.ericpath and
+                        func[0].startswith(self.ericpath)) and \
                    not func[0].startswith("DebugClients") and \
                    func[0] != "profile" and \
                    not (exclude and (
@@ -164,22 +180,22 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
                        func[0].startswith(self.pyLibPath):
                         # calculate the totals
                         total_calls += nc
-                        prim_calls  += cc
-                        total_tt    += tt
+                        prim_calls += cc
+                        total_tt += tt
                         
                         if nc != cc:
-                            c = "%d/%d" % (nc, cc)
+                            c = "{0:d}/{1:d}".format(nc, cc)
                         else:
                             c = str(nc)
                         if nc == 0:
-                            tpc = "% 8.3f" % 0.0
+                            tpc = "{0: 8.3f}".format(0.0)
                         else:
-                            tpc = "% 8.3f" % (tt/nc,)
+                            tpc = "{0: 8.3f}".format(tt / nc)
                         if cc == 0:
-                            cpc = "% 8.3f" % 0.0
+                            cpc = "{0: 8.3f}".format(0.0)
                         else:
-                            cpc = "% 8.3f" % (ct/cc,)
-                        self.__createResultItem(c, tt, tpc, ct, cpc, func[0], 
+                            cpc = "{0: 8.3f}".format(ct / cc)
+                        self.__createResultItem(c, tt, tpc, ct, cpc, func[0],
                                                 func[1], func[2])
                     
                 progress += 1
@@ -192,10 +208,13 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         self.__resortResultList()
         
         # now do the summary stuff
-        self.__createSummaryItem(self.trUtf8("function calls"), str(total_calls))
+        self.__createSummaryItem(self.trUtf8("function calls"),
+                                 str(total_calls))
         if total_calls != prim_calls:
-            self.__createSummaryItem(self.trUtf8("primitive calls"), str(prim_calls))
-        self.__createSummaryItem(self.trUtf8("CPU seconds"), "%.3f" % total_tt)
+            self.__createSummaryItem(self.trUtf8("primitive calls"),
+                                     str(prim_calls))
+        self.__createSummaryItem(self.trUtf8("CPU seconds"),
+                                 "{0:.3f}".format(total_tt))
         
     def start(self, pfn, fn=None):
         """
@@ -206,13 +225,14 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         """
         self.basename = os.path.splitext(pfn)[0]
         
-        fname = "%s.profile" % self.basename
+        fname = "{0}.profile".format(self.basename)
         if not os.path.exists(fname):
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                self,
                 self.trUtf8("Profile Results"),
                 self.trUtf8("""<p>There is no profiling data"""
-                            """ available for <b>%1</b>.</p>""")
-                    .arg(pfn))
+                            """ available for <b>{0}</b>.</p>""")
+                .format(pfn))
             self.close()
             return
         try:
@@ -220,11 +240,12 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
             self.stats = pickle.load(f)
             f.close()
         except (EnvironmentError, pickle.PickleError, EOFError):
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Loading Profiling Data"),
                 self.trUtf8("""<p>The profiling data could not be"""
-                            """ read from file <b>%1</b>.</p>""")
-                    .arg(fname))
+                            """ read from file <b>{0}</b>.</p>""")
+                .format(fname))
             self.close()
             return
         
@@ -234,7 +255,8 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         
     def __finish(self):
         """
-        Private slot called when the action finished or the user pressed the button.
+        Private slot called when the action finished or the user pressed the
+        button.
         """
         self.cancelled = True
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
@@ -278,7 +300,7 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         """
         Private slot to handle the Erase Profile context menu action.
         """
-        fname = "%s.profile" % self.basename
+        fname = "{0}.profile".format(self.basename)
         if os.path.exists(fname):
             os.remove(fname)
         
@@ -286,7 +308,7 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         """
         Private slot to handle the Erase Timing context menu action.
         """
-        fname = "%s.timings" % self.basename
+        fname = "{0}.timings".format(self.basename)
         if os.path.exists(fname):
             os.remove(fname)
         
@@ -299,7 +321,8 @@ class PyProfileDialog(QDialog, Ui_PyProfileDialog):
         
     def __filter(self):
         """
-        Private slot to handle the Exclude/Include Python Library context menu action.
+        Private slot to handle the Exclude/Include Python Library context menu
+        action.
         """
         self.__unfinish()
         if self.exclude:
