@@ -4,13 +4,13 @@
 #
 
 """
-Module implementing an asynchronous file like socket interface for the debugger.
+Module implementing an asynchronous file like socket interface for the
+debugger.
 """
 
 import socket
-import sys
 
-from DebugProtocol import EOT, RequestOK
+from DebugProtocol import EOT
 
 
 def AsyncPendingWrite(file):
@@ -35,7 +35,7 @@ class AsyncFile(object):
     maxtries = 10
     maxbuffersize = 1024 * 1024 * 4
     
-    def __init__(self,sock,mode,name):
+    def __init__(self, sock, mode, name):
         """
         Constructor
         
@@ -53,7 +53,7 @@ class AsyncFile(object):
 
         self.wpending = u''
 
-    def __checkMode(self,mode):
+    def __checkMode(self, mode):
         """
         Private method to check the mode.
         
@@ -61,18 +61,19 @@ class AsyncFile(object):
         the mode of the file. If it is not, an IOError is raised.
         
         @param mode the mode to be checked (string)
+        @exception IOError raised to indicate a bad file descriptor
         """
         if mode != self.mode:
-            raise IOError, '[Errno 9] Bad file descriptor'
+            raise IOError('[Errno 9] Bad file descriptor')
 
-    def __nWrite(self,n):
+    def __nWrite(self, n):
         """
         Private method to write a specific number of pending bytes.
         
         @param n the number of bytes to be written (int)
         """
         if n:
-            try :
+            try:
                 buf = "%s%s" % (self.wpending[:n], EOT)
                 try:
                     buf = buf.encode('utf-8')
@@ -84,7 +85,7 @@ class AsyncFile(object):
             except socket.error:
                 self.nWriteErrors += 1
                 if self.nWriteErrors > self.maxtries:
-                    self.wpending = u'' # delete all output
+                    self.wpending = u''  # delete all output
 
     def pendingWrite(self):
         """
@@ -98,7 +99,8 @@ class AsyncFile(object):
         """
         Public method to close the file.
         
-        @param closeit flag to indicate a close ordered by the debugger code (boolean)
+        @param closeit flag to indicate a close ordered by the debugger code
+            (boolean)
         """
         if closeit and not self.closed:
             self.flush()
@@ -130,7 +132,7 @@ class AsyncFile(object):
         except socket.error:
             return -1
 
-    def read_p(self,size=-1):
+    def read_p(self, size=-1):
         """
         Public method to read bytes from this file.
         
@@ -144,7 +146,7 @@ class AsyncFile(object):
 
         return self.sock.recv(size).decode('utf8')
 
-    def read(self,size=-1):
+    def read(self, size=-1):
         """
         Public method to read bytes from this file.
         
@@ -158,7 +160,7 @@ class AsyncFile(object):
             buf = buf[:size]
         return buf
 
-    def readline_p(self,size=-1):
+    def readline_p(self, size=-1):
         """
         Public method to read a line from this file.
         
@@ -189,7 +191,7 @@ class AsyncFile(object):
         # Now we know how big the line is, read it for real.
         return self.sock.recv(size).decode('utf8')
 
-    def readlines(self,sizehint=-1):
+    def readlines(self, sizehint=-1):
         """
         Public method to read all lines from this file.
         
@@ -232,14 +234,16 @@ class AsyncFile(object):
             line = line[:sizehint]
         return line
         
-    def seek(self,offset,whence=0):
+    def seek(self, offset, whence=0):
         """
         Public method to move the filepointer.
         
+        @param offset offset to seek for
+        @param whence where to seek from
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError, '[Errno 29] Illegal seek'
+        raise IOError('[Errno 29] Illegal seek')
 
     def tell(self):
         """
@@ -248,33 +252,36 @@ class AsyncFile(object):
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError, '[Errno 29] Illegal seek'
+        raise IOError('[Errno 29] Illegal seek')
 
-    def truncate(self,size=-1):
+    def truncate(self, size=-1):
         """
         Public method to truncate the file.
         
+        @param size size to truncate to (integer)
         @exception IOError This method is not supported and always raises an
         IOError.
         """
-        raise IOError, '[Errno 29] Illegal seek'
+        raise IOError('[Errno 29] Illegal seek')
 
-    def write(self,s):
+    def write(self, s):
         """
         Public method to write a string to the file.
         
         @param s bytes to be written (string)
+        @exception socket.error raised to indicate too many send attempts
         """
         self.__checkMode('w')
         tries = 0
         if not self.wpending:
             self.wpending = s
         elif type(self.wpending) != type(s) or \
-             len(self.wpending) + len(s) > self.maxbuffersize:
-            # flush wpending so that different string types are not concatenated
+                len(self.wpending) + len(s) > self.maxbuffersize:
+            # flush wpending so that different string types are not
+            # concatenated
             while self.wpending:
-                # if we have a persistent error in sending the data, an exception
-                # will be raised in __nWrite
+                # if we have a persistent error in sending the data, an
+                # exception will be raised in __nWrite
                 self.flush()
                 tries += 1
                 if tries > self.maxtries:
@@ -284,10 +291,13 @@ class AsyncFile(object):
             self.wpending += s
         self.__nWrite(self.pendingWrite())
 
-    def writelines(self,list):
+    def writelines(self, list):
         """
         Public method to write a list of strings to the file.
         
         @param list the list to be written (list of string)
         """
-        map(self.write,list)
+        map(self.write, list)
+
+#
+# eflag: FileType = Python2
