@@ -15,8 +15,6 @@ class AsyncIO(object):
     def __init__(self):
         """
         Constructor
-        
-        @param parent the optional parent of this object (QObject) (ignored)
         """
         # There is no connection yet.
         self.disconnect()
@@ -28,7 +26,7 @@ class AsyncIO(object):
         self.readfd = None
         self.writefd = None
 
-    def setDescriptors(self,rfd,wfd):
+    def setDescriptors(self, rfd, wfd):
         """
         Public method called to set the descriptors for the connection.
         
@@ -41,7 +39,7 @@ class AsyncIO(object):
         self.wbuf = ''
         self.writefd = wfd
 
-    def readReady(self,fd):
+    def readReady(self, fd):
         """
         Public method called when there is data ready to be read.
         
@@ -67,7 +65,7 @@ class AsyncIO(object):
             self.handleLine(s)
             eol = self.rbuf.find('\n')
 
-    def writeReady(self,fd):
+    def writeReady(self, fd):
         """
         Public method called when we are ready to write data.
         
@@ -77,10 +75,13 @@ class AsyncIO(object):
         self.writefd.flush()
         self.wbuf = ''
 
-    def write(self,s):
+    def write(self, s):
         """
         Public method to write a string.
         
         @param s the data to be written (string)
         """
         self.wbuf = self.wbuf + s
+
+#
+# eflag: FileType = Python2
