@@ -8,27 +8,28 @@ Module implementing the debug base class.
 """
 
 import sys
-import traceback
 import bdb
 import os
 import types
 import atexit
 import inspect
 
-from DebugProtocol import *
+from DebugProtocol import ResponseClearWatch, ResponseClearBreak, \
+    ResponseLine, ResponseSyntax, ResponseException, CallTrace
 
 gRecursionLimit = 64
 
+
 def printerr(s):
     """
     Module function used for debugging the debug client.
     
     @param s data to be printed
     """
-    import sys
     sys.__stderr__.write('%s\n' % unicode(s))
     sys.__stderr__.flush()
 
+
 def setRecursionLimit(limit):
     """
     Module function to set the recursion limit.
@@ -38,6 +39,7 @@ def setRecursionLimit(limit):
     global gRecursionLimit
     gRecursionLimit = limit
 
+
 class DebugBase(bdb.Bdb):
     """
     Class implementing base class of the debugger.
@@ -86,7 +88,7 @@ class DebugBase(bdb.Bdb):
         
         @return the current frame
         """
-        return self.currentFrame        
+        return self.currentFrame
     
     def getCurrentFrameLocals(self):
         """
@@ -94,7 +96,7 @@ class DebugBase(bdb.Bdb):
         
         @return locals dictionary of the current frame
         """
-        return self.currentFrameLocals        
+        return self.currentFrameLocals
     
     def step(self, traceMode):
         """
@@ -142,23 +144,51 @@ class DebugBase(bdb.Bdb):
     
     def profile(self, frame, event, arg):
         """
-        Public method used to trace some stuff independent of the debugger 
+        Public method used to trace some stuff independent of the debugger
         trace function.
         
-        @param frame The current stack frame.
-        @param event The trace event (string)
-        @param arg The arguments
+        @param frame current stack frame.
+        @param event trace event (string)
+        @param arg arguments
+        @exception RuntimeError raised to indicate too many recursions
         """
-        if event == 'return':  
+        if event == 'return':
             self.cFrame = frame.f_back
             self.__recursionDepth -= 1
+            self.__sendCallTrace(event, frame, self.cFrame)
         elif event == 'call':
+            self.__sendCallTrace(event, self.cFrame, frame)
             self.cFrame = frame
             self.__recursionDepth += 1
             if self.__recursionDepth > gRecursionLimit:
-                raise RuntimeError('maximum recursion depth exceeded\n'
+                raise RuntimeError(
+                    'maximum recursion depth exceeded\n'
                     '(offending frame is two down the stack)')
     
+    def __sendCallTrace(self, event, fromFrame, toFrame):
+        """
+        Private method to send a call/return trace.
+        
+        @param event trace event (string)
+        @param fromFrame originating frame (frame)
+        @param toFrame destination frame (frame)
+        """
+        if self._dbgClient.callTraceEnabled:
+            if not self.__skip_it(fromFrame) and not self.__skip_it(toFrame):
+                if event in ["call", "return"]:
+                    fr = fromFrame
+                    fromStr = "%s:%s:%s" % (
+                        self._dbgClient.absPath(self.fix_frame_filename(fr)),
+                        fr.f_lineno,
+                        fr.f_code.co_name)
+                    fr = toFrame
+                    toStr = "%s:%s:%s" % (
+                        self._dbgClient.absPath(self.fix_frame_filename(fr)),
+                        fr.f_lineno,
+                        fr.f_code.co_name)
+                    self._dbgClient.write("%s%s@@%s@@%s\n" % (
+                        CallTrace, event[0], fromStr, toStr))
+    
     def trace_dispatch(self, frame, event, arg):
         """
         Reimplemented from bdb.py to do some special things.
@@ -173,7 +203,7 @@ class DebugBase(bdb.Bdb):
         @return local trace function
         """
         if self.quitting:
-            return # None
+            return  # None
         
         # give the client a chance to push through new break points.
         self._dbgClient.eventPoll()
@@ -195,7 +225,7 @@ class DebugBase(bdb.Bdb):
             return self.trace_dispatch
         if event == 'c_return':
             return self.trace_dispatch
-        print 'DebugBase.trace_dispatch: unknown debugging event:', `event`
+        print 'DebugBase.trace_dispatch: unknown debugging event:', repr(event)
         return self.trace_dispatch
 
     def dispatch_line(self, frame):
@@ -208,10 +238,12 @@ class DebugBase(bdb.Bdb):
         
         @param frame The current stack frame.
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if self.stop_here(frame) or self.break_here(frame):
             self.user_line(frame)
-            if self.quitting: raise bdb.BdbQuit
+            if self.quitting:
+                raise bdb.BdbQuit
         return self.trace_dispatch
 
     def dispatch_return(self, frame, arg):
@@ -221,6 +253,7 @@ class DebugBase(bdb.Bdb):
         @param frame The current stack frame.
         @param arg The arguments
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if self.stop_here(frame) or frame == self.returnframe:
             self.user_return(frame, arg)
@@ -235,13 +268,15 @@ class DebugBase(bdb.Bdb):
         @param frame The current stack frame.
         @param arg The arguments
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if not self.__skip_it(frame):
             self.user_exception(frame, arg)
-            if self.quitting: raise bdb.BdbQuit
+            if self.quitting:
+                raise bdb.BdbQuit
         return self.trace_dispatch
 
-    def set_trace(self, frame = None):
+    def set_trace(self, frame=None):
         """
         Overridden method of bdb.py to do some special setup.
         
@@ -265,7 +300,7 @@ class DebugBase(bdb.Bdb):
 
     def set_quit(self):
         """
-        Public method to quit. 
+        Public method to quit.
         
         It wraps call to bdb to clear the current frame properly.
         """
@@ -289,9 +324,10 @@ class DebugBase(bdb.Bdb):
         code over a network... This logic deals with that.
         
         @param frame the frame object
+        @return fixed up file name (string)
         """
         # get module name from __file__
-        if frame.f_globals.has_key('__file__') and \
+        if '__file__' in frame.f_globals and \
            frame.f_globals['__file__'] and \
            frame.f_globals['__file__'] == frame.f_code.co_filename:
             root, ext = os.path.splitext(frame.f_globals['__file__'])
@@ -316,7 +352,7 @@ class DebugBase(bdb.Bdb):
             bp.condition = cond
             bp.special = ""
         bp.values = {}
-        if not self.breaks.has_key("Watch"):
+        if "Watch" not in self.breaks:
             self.breaks["Watch"] = 1
         else:
             self.breaks["Watch"] += 1
@@ -327,7 +363,7 @@ class DebugBase(bdb.Bdb):
         
         @param cond expression of the watch expression to be cleared (string)
         """
-        try: 
+        try:
             possibles = bdb.Breakpoint.bplist["Watch", 0]
             for i in range(0, len(possibles)):
                 b = possibles[i]
@@ -345,6 +381,7 @@ class DebugBase(bdb.Bdb):
         Public method to get a watch expression.
         
         @param cond expression of the watch expression to be cleared (string)
+        @return reference to the watch point
         """
         possibles = bdb.Breakpoint.bplist["Watch", 0]
         for i in range(0, len(possibles)):
@@ -366,8 +403,8 @@ class DebugBase(bdb.Bdb):
         Private method to determine, if a watch expression is effective.
         
         @param frame the current execution frame
-        @return tuple of watch expression and a flag to indicate, that a temporary
-            watch expression may be deleted (bdb.Breakpoint, boolean)
+        @return tuple of watch expression and a flag to indicate, that a
+            temporary watch expression may be deleted (bdb.Breakpoint, boolean)
         """
         possibles = bdb.Breakpoint.bplist["Watch", 0]
         for i in range(0, len(possibles)):
@@ -375,7 +412,8 @@ class DebugBase(bdb.Bdb):
             if b.enabled == 0:
                 continue
             if not b.cond:
-                # watch expression without expression shouldn't occur, just ignore it
+                # watch expression without expression shouldn't occur,
+                # just ignore it
                 continue
             try:
                 val = eval(b.condition, frame.f_globals, frame.f_locals)
@@ -416,7 +454,7 @@ class DebugBase(bdb.Bdb):
     
     def break_here(self, frame):
         """
-        Reimplemented from bdb.py to fix the filename from the frame. 
+        Reimplemented from bdb.py to fix the filename from the frame.
         
         See fix_frame_filename for more info.
         
@@ -424,10 +462,10 @@ class DebugBase(bdb.Bdb):
         @return flag indicating the break status (boolean)
         """
         filename = self.canonic(self.fix_frame_filename(frame))
-        if not self.breaks.has_key(filename) and not self.breaks.has_key("Watch"):
+        if filename not in self.breaks and "Watch" not in self.breaks:
             return 0
         
-        if self.breaks.has_key(filename):
+        if filename in self.breaks:
             lineno = frame.f_lineno
             if lineno in self.breaks[filename]:
                 # flag says ok to delete temp. bp
@@ -438,7 +476,7 @@ class DebugBase(bdb.Bdb):
                         self.__do_clear(filename, lineno)
                     return 1
         
-        if self.breaks.has_key("Watch"):
+        if "Watch" in self.breaks:
             # flag says ok to delete temp. bp
             (bp, flag) = self.__effective(frame)
             if bp:
@@ -459,23 +497,24 @@ class DebugBase(bdb.Bdb):
         @param frame the frame object
         @return flag indicating the break status (boolean)
         """
-        return self.breaks.has_key(
-            self.canonic(self.fix_frame_filename(frame))) or \
-            (self.breaks.has_key("Watch") and self.breaks["Watch"])
+        return \
+            self.canonic(self.fix_frame_filename(frame)) in self.breaks or \
+            ("Watch" in self.breaks and self.breaks["Watch"])
 
     def get_break(self, filename, lineno):
         """
-        Reimplemented from bdb.py to get the first breakpoint of a particular line.
+        Reimplemented from bdb.py to get the first breakpoint of a particular
+        line.
         
-        Because eric4 supports only one breakpoint per line, this overwritten
+        Because eric5 supports only one breakpoint per line, this overwritten
         method will return this one and only breakpoint.
         
-        @param filename the filename of the bp to retrieve (string)
-        @param ineno the linenumber of the bp to retrieve (integer)
+        @param filename filename of the bp to retrieve (string)
+        @param lineno linenumber of the bp to retrieve (integer)
         @return breakpoint or None, if there is no bp
         """
         filename = self.canonic(filename)
-        return self.breaks.has_key(filename) and \
+        return filename in self.breaks and \
             lineno in self.breaks[filename] and \
             bdb.Breakpoint.bplist[filename, lineno][0] or None
     
@@ -487,7 +526,8 @@ class DebugBase(bdb.Bdb):
         @param lineno linenumber of the bp
         """
         self.clear_break(filename, lineno)
-        self._dbgClient.write('%s%s,%d\n' % (ResponseClearBreak, filename, lineno))
+        self._dbgClient.write('%s%s,%d\n' % (ResponseClearBreak, filename,
+                                             lineno))
 
     def getStack(self):
         """
@@ -500,13 +540,21 @@ class DebugBase(bdb.Bdb):
         stack = []
         while fr is not None:
             fname = self._dbgClient.absPath(self.fix_frame_filename(fr))
-            fline = fr.f_lineno
-            ffunc = fr.f_code.co_name
+            if not fname.startswith("<"):
+                fline = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
             
-            if ffunc == '?':
-                ffunc = ''
-            
-            stack.append([fname, fline, ffunc])
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(argInfo[0], argInfo[1],
+                                                    argInfo[2], argInfo[3])
+                else:
+                    fargs = ""
+                
+            stack.append([fname, fline, ffunc, fargs])
             
             if fr == self._dbgClient.mainFrame:
                 fr = None
@@ -549,13 +597,21 @@ class DebugBase(bdb.Bdb):
             # return from dispatch_call
             fr.f_trace = self.trace_dispatch
             fname = self._dbgClient.absPath(self.fix_frame_filename(fr))
-            fline = fr.f_lineno
-            ffunc = fr.f_code.co_name
-            
-            if ffunc == '?':
-                ffunc = ''
-            
-            stack.append([fname, fline, ffunc])
+            if not fname.startswith("<"):
+                fline = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
+                
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(argInfo[0], argInfo[1],
+                                                    argInfo[2], argInfo[3])
+                else:
+                    fargs = ""
+                
+            stack.append([fname, fline, ffunc, fargs])
             
             if fr == self._dbgClient.mainFrame:
                 fr = None
@@ -567,7 +623,7 @@ class DebugBase(bdb.Bdb):
         self._dbgClient.write('%s%s\n' % (ResponseLine, unicode(stack)))
         self._dbgClient.eventLoop()
 
-    def user_exception(self,frame,(exctype,excval,exctb),unhandled=0):
+    def user_exception(self, frame, (exctype, excval, exctb), unhandled=0):
         """
         Reimplemented to report an exception to the debug server.
         
@@ -601,7 +657,8 @@ class DebugBase(bdb.Bdb):
                 realSyntaxError = os.path.exists(filename)
             
             if realSyntaxError:
-                self._dbgClient.write("%s%s\n" % (ResponseSyntax, unicode(exclist)))
+                self._dbgClient.write("%s%s\n" % (ResponseSyntax,
+                                                  unicode(exclist)))
                 self._dbgClient.eventLoop()
                 return
         
@@ -617,7 +674,7 @@ class DebugBase(bdb.Bdb):
         else:
             exctypetxt = unicode(exctype)
         try:
-            exclist = [exctypetxt, 
+            exclist = [exctypetxt,
                        unicode(excval).encode(self._dbgClient.getCoding())]
         except TypeError:
             exclist = [exctypetxt, str(excval)]
@@ -632,13 +689,25 @@ class DebugBase(bdb.Bdb):
             
             for fr in frlist:
                 filename = self._dbgClient.absPath(self.fix_frame_filename(fr))
-                linenr = fr.f_lineno
                 
                 if os.path.basename(filename).startswith("DebugClient") or \
                    os.path.basename(filename) == "bdb.py":
                     break
                 
-                exclist.append([filename, linenr])
+                linenr = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
+                
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(argInfo[0], argInfo[1],
+                                                    argInfo[2], argInfo[3])
+                else:
+                    fargs = ""
+                
+                exclist.append([filename, linenr, ffunc, fargs])
         
         self._dbgClient.write("%s%s\n" % (ResponseException, unicode(exclist)))
         
@@ -662,7 +731,7 @@ class DebugBase(bdb.Bdb):
         tb = None
         return stack
 
-    def user_return(self,frame,retval):
+    def user_return(self, frame, retval):
         """
         Reimplemented to report program termination to the debug server.
         
@@ -671,14 +740,14 @@ class DebugBase(bdb.Bdb):
         """
         # The program has finished if we have just left the first frame.
         if frame == self._dbgClient.mainFrame and \
-            self._mainThread:
+                self._mainThread:
             atexit._run_exitfuncs()
             self._dbgClient.progTerminated(retval)
         elif frame is not self.stepFrame:
             self.stepFrame = None
             self.user_line(frame)
 
-    def stop_here(self,frame):
+    def stop_here(self, frame):
         """
         Reimplemented to filter out debugger files.
         
@@ -690,7 +759,7 @@ class DebugBase(bdb.Bdb):
         """
         if self.__skip_it(frame):
             return 0
-        return bdb.Bdb.stop_here(self,frame)
+        return bdb.Bdb.stop_here(self, frame)
 
     def __skip_it(self, frame):
         """
@@ -702,6 +771,9 @@ class DebugBase(bdb.Bdb):
         @param frame the frame object
         @return flag indicating whether the debugger should skip this frame
         """
+        if frame is None:
+            return 1
+        
         fn = self.fix_frame_filename(frame)
 
         # Eliminate things like <string> and <stdin>.
@@ -711,11 +783,11 @@ class DebugBase(bdb.Bdb):
         #XXX - think of a better way to do this.  It's only a convience for
         #debugging the debugger - when the debugger code is in the current
         #directory.
-        if os.path.basename(fn) in [\
+        if os.path.basename(fn) in [
             'AsyncFile.py', 'AsyncIO.py',
             'DebugConfig.py', 'DCTestResult.py',
-            'DebugBase.py', 'DebugClientBase.py', 
-            'DebugClientCapabilities.py', 'DebugClient.py', 
+            'DebugBase.py', 'DebugClientBase.py',
+            'DebugClientCapabilities.py', 'DebugClient.py',
             'DebugClientThreads.py', 'DebugProtocol.py',
             'DebugThread.py', 'FlexCompleter.py',
             'PyProfile.py'] or \
@@ -742,3 +814,6 @@ class DebugBase(bdb.Bdb):
         @return last debugger event (string)
         """
         return self.__event
+
+#
+# eflag: FileType = Python2
