@@ -7,8 +7,8 @@
 Module implementing a Qt free version of the debug client.
 """
 
-from AsyncIO import *
-from DebugBase import *
+from AsyncIO import AsyncIO
+from DebugBase import DebugBase
 import DebugClientBase
 
 
@@ -36,3 +36,6 @@ class DebugClient(DebugClientBase.DebugClientBase, AsyncIO, DebugBase):
 if __name__ == '__main__':
     debugClient = DebugClient()
     debugClient.main()
+
+#
+# eflag: FileType = Python2
