@@ -8,10 +8,10 @@ Module implementing the multithreaded version of the debug client.
 """
 
 import thread
+import sys
 
-from AsyncIO import *
-from DebugThread import *
-from DebugBase import *
+from AsyncIO import AsyncIO
+from DebugThread import DebugThread
 import DebugClientBase
 
 
@@ -19,14 +19,14 @@ def _debugclient_start_new_thread(target, args, kwargs={}):
     """
     Module function used to allow for debugging of multiple threads.
     
-    The way it works is that below, we reset thread._start_new_thread to 
+    The way it works is that below, we reset thread._start_new_thread to
     this function object. Thus, providing a hook for us to see when
-    threads are started. From here we forward the request onto the 
+    threads are started. From here we forward the request onto the
     DebugClient which will create a DebugThread object to allow tracing
     of the thread then start up the thread. These actions are always
     performed in order to allow dropping into debug mode.
     
-    See DebugClientThreads.attachThread and DebugThread.DebugThread in 
+    See DebugClientThreads.attachThread and DebugThread.DebugThread in
     DebugThread.py
     
     @param target the start function of the target thread (i.e. the user code)
@@ -35,18 +35,20 @@ def _debugclient_start_new_thread(target, args, kwargs={}):
     @return The identifier of the created thread
     """
     if DebugClientBase.DebugClientInstance is not None:
-        return DebugClientBase.DebugClientInstance.attachThread(target, args, kwargs)
+        return DebugClientBase.DebugClientInstance.attachThread(
+            target, args, kwargs)
     else:
         return _original_start_thread(target, args, kwargs)
     
-# make thread hooks available to system    
+# make thread hooks available to system
 _original_start_thread = thread.start_new_thread
 thread.start_new_thread = _debugclient_start_new_thread
 
-# NOTE: import threading here AFTER above hook, as threading cache's 
-# thread._start_new_thread.
+# Note: import threading here AFTER above hook, as threading cache's
+#       thread._start_new_thread.
 from threading import RLock
 
+
 class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
     """
     Class implementing the client side of the debugger.
@@ -65,7 +67,8 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
         # protection lock for synchronization
         self.clientLock = RLock()
         
-        # the "current" thread, basically the thread we are at a breakpoint for.
+        # the "current" thread, basically the thread we are at a breakpoint
+        # for.
         self.currentThread = None
         
         # special objects representing the main scripts thread and frame
@@ -74,17 +77,18 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
         
         self.variant = 'Threaded'
 
-    def attachThread(self, target = None, args = None, kwargs = None, mainThread = 0):
+    def attachThread(self, target=None, args=None, kwargs=None, mainThread=0):
         """
         Public method to setup a thread for DebugClient to debug.
         
-        If mainThread is non-zero, then we are attaching to the already 
+        If mainThread is non-zero, then we are attaching to the already
         started mainthread of the app and the rest of the args are ignored.
         
-        @param target the start function of the target thread (i.e. the user code)
+        @param target the start function of the target thread (i.e. the
+            user code)
         @param args arguments to pass to target
         @param kwargs keyword arguments to pass to target
-        @param mainThread non-zero, if we are attaching to the already 
+        @param mainThread non-zero, if we are attaching to the already
               started mainthread of the app
         @return The identifier of the created thread
         """
@@ -120,7 +124,7 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
         finally:
             self.unlockClient()
             
-    def lockClient(self, blocking = 1):
+    def lockClient(self, blocking=1):
         """
         Public method to acquire the lock for this client.
         
@@ -156,7 +160,7 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
         finally:
             self.unlockClient()
     
-    def eventLoop(self, disablePolling = False):
+    def eventLoop(self, disablePolling=False):
         """
         Public method implementing our event loop.
         
@@ -191,3 +195,6 @@ class DebugClientThreads(DebugClientBase.DebugClientBase, AsyncIO):
 if __name__ == '__main__':
     debugClient = DebugClientThreads()
     debugClient.main()
+
+#
+# eflag: FileType = Python2
