@@ -8,10 +8,10 @@ Module implementing the debug thread.
 """
 
 import bdb
-import os
 import sys
 
-from DebugBase import *
+from DebugBase import DebugBase
+
 
 class DebugThread(DebugBase):
     """
@@ -22,8 +22,8 @@ class DebugThread(DebugBase):
     Provides simple wrapper methods around bdb for the 'owning' client to
     call to step etc.
     """
-    def __init__(self, dbgClient, targ = None, args = None, kwargs = None, 
-                 mainThread = 0):
+    def __init__(self, dbgClient, targ=None, args=None, kwargs=None,
+                 mainThread=0):
         """
         Constructor
         
@@ -35,16 +35,16 @@ class DebugThread(DebugBase):
         """
         DebugBase.__init__(self, dbgClient)
         
-        self._target = targ 
+        self._target = targ
         self._args = args
         self._kwargs = kwargs
         self._mainThread = mainThread
         # thread running tracks execution state of client code
         # it will always be 0 for main thread as that is tracked
         # by DebugClientThreads and Bdb...
-        self._threadRunning = 0 
+        self._threadRunning = 0
         
-        self.__ident = None # id of this thread.
+        self.__ident = None  # id of this thread.
         self.__name = ""
     
     def set_ident(self, id):
@@ -83,7 +83,7 @@ class DebugThread(DebugBase):
         """
         Private method to bootstrap the thread.
         
-        It wraps the call to the user function to enable tracing 
+        It wraps the call to the user function to enable tracing
         before hand.
         """
         try:
@@ -115,8 +115,8 @@ class DebugThread(DebugBase):
         """
         try:
             self._dbgClient.lockClient()
-            # if this thread came out of a lock, and we are quitting 
-            # and we are still running, then get rid of tracing for this thread 
+            # if this thread came out of a lock, and we are quitting
+            # and we are still running, then get rid of tracing for this thread
             if self.quitting and self._threadRunning:
                 sys.settrace(None)
                 sys.setprofile(None)
@@ -127,3 +127,6 @@ class DebugThread(DebugBase):
             self._dbgClient.unlockClient()
         
         return retval
+
+#
+# eflag: FileType = Python2
