@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 
 """
-Word completion for the eric4 shell
+Word completion for the eric5 shell.
 
-<h4>NOTE for eric4 variant</h4>
+<h4>NOTE for eric5 variant</h4>
 
-    This version is a re-implementation of FlexCompleter 
-    as found in the PyQwt package. It is modified to work with the eric4 debug 
+    This version is a re-implementation of FlexCompleter
+    as found in the PyQwt package. It is modified to work with the eric5 debug
     clients.
 
 
@@ -20,16 +20,16 @@ Word completion for the eric4 shell
 
 <h4>NOTE for FlexCompleter</h4>
 
-    This version is a re-implementation of rlcompleter with 
+    This version is a re-implementation of rlcompleter with
     selectable namespace.
 
     The problem with rlcompleter is that it's hardwired to work with
-    __main__.__dict__, and in some cases one may have 'sandboxed' namespaces. So
-    this class is a ripoff of rlcompleter, with the namespace to work in as an
-    optional parameter.
+    __main__.__dict__, and in some cases one may have 'sandboxed' namespaces.
+    So this class is a ripoff of rlcompleter, with the namespace to work in as
+    an optional parameter.
     
-    This class can be used just like rlcompleter, but the Completer class now has
-    a constructor with the optional 'namespace' parameter.
+    This class can be used just like rlcompleter, but the Completer class now
+    has a constructor with the optional 'namespace' parameter.
     
     A patch has been submitted to Python@sourceforge for these changes to go in
     the standard Python distribution.
@@ -103,11 +103,12 @@ import __main__
 
 __all__ = ["Completer"]
 
+
 class Completer(object):
     """
     Class implementing the command line completer object.
     """
-    def __init__(self, namespace = None):
+    def __init__(self, namespace=None):
         """
         Create a new completer for the command line.
 
@@ -122,11 +123,11 @@ class Completer(object):
 
         readline.set_completer(Completer(my_namespace).complete)
         
-        @param namespace The namespace for the completer.
+        @param namespace namespace for the completer
+        @exception TypeError raised to indicate a wrong namespace structure
         """
-        
-        if namespace and type(namespace) != type({}):
-            raise TypeError,'namespace must be a dictionary'
+        if namespace and not isinstance(namespace, dict):
+            raise TypeError('namespace must be a dictionary')
 
         # Don't bind to namespace quite yet, but flag whether the user wants a
         # specific namespace or to use __main__.__dict__. This will allow us
@@ -176,7 +177,9 @@ class Completer(object):
                      __builtin__.__dict__.keys(),
                      self.namespace.keys()]:
             for word in list:
-                if word[:n] == text and word != "__builtins__" and not word in matches:
+                if word[:n] == text and \
+                   word != "__builtins__" and \
+                   not word in matches:
                     matches.append(word)
         return matches
 
@@ -211,7 +214,7 @@ class Completer(object):
         expr, attr = m.group(1, 3)
         object = eval(expr, self.namespace)
         words = dir(object)
-        if hasattr(object,'__class__'):
+        if hasattr(object, '__class__'):
             words.append('__class__')
             words = words + get_class_members(object.__class__)
         matches = []
@@ -229,6 +232,7 @@ class Completer(object):
                 pass
         return matches
 
+
 def get_class_members(klass):
     """
     Module function to retrieve the class members.
@@ -241,7 +245,10 @@ def get_class_members(klass):
         return klass.getLazyNames()
     # vanilla Python stuff
     ret = dir(klass)
-    if hasattr(klass,'__bases__'):
+    if hasattr(klass, '__bases__'):
         for base in klass.__bases__:
             ret = ret + get_class_members(base)
     return ret
+
+#
+# eflag: FileType = Python2
