@@ -8,18 +8,18 @@ Module defining additions to the standard Python profile.py.
 
 import os
 import marshal
-import types
 import profile
 import atexit
 import pickle
 
+
 class PyProfile(profile.Profile):
     """
     Class extending the standard Python profiler with additional methods.
     
     This class extends the standard Python profiler by the functionality to
     save the collected timing data in a timing cache, to restore these data
-    on subsequent calls, to store a profile dump to a standard filename and 
+    on subsequent calls, to store a profile dump to a standard filename and
     to erase these caches.
     """
     def __init__(self, basename, timer=None, bias=None):
@@ -111,10 +111,11 @@ class PyProfile(profile.Profile):
         code over a network... This logic deals with that.
         
         @param frame the frame object
+        @return fixed up file name (string)
         """
         # get module name from __file__
         if not isinstance(frame, profile.Profile.fake_frame) and \
-            frame.f_globals.has_key('__file__'):
+                '__file__' in frame.f_globals:
             root, ext = os.path.splitext(frame.f_globals['__file__'])
             if ext == '.pyc' or ext == '.py':
                 fixedName = root + '.py'
@@ -129,6 +130,10 @@ class PyProfile(profile.Profile):
         
         This is a variant of the one found in the standard Python
         profile.py calling fix_frame_filename above.
+        
+        @param frame reference to the call frame
+        @param t arguments of the call
+        @return flag indicating a handled call
         """
         if self.cur and frame.f_back is not self.cur[-2]:
             rpt, rit, ret, rfn, rframe, rcur = self.cur
@@ -137,15 +142,15 @@ class PyProfile(profile.Profile):
                                                        rframe, rframe.f_back,
                                                        frame, frame.f_back)
                 self.trace_dispatch_return(rframe, 0)
-                assert (self.cur is None or \
+                assert (self.cur is None or
                         frame.f_back is self.cur[-2]), ("Bad call",
                                                         self.cur[-3])
         fcode = frame.f_code
         fn = (self.fix_frame_filename(frame),
-            fcode.co_firstlineno, fcode.co_name)
+              fcode.co_firstlineno, fcode.co_name)
         self.cur = (t, 0, 0, fn, frame, self.cur)
         timings = self.timings
-        if timings.has_key(fn):
+        if fn in timings:
             cc, ns, tt, ct, callers = timings[fn]
             timings[fn] = cc, ns + 1, tt, ct, callers
         else:
@@ -157,6 +162,10 @@ class PyProfile(profile.Profile):
         "exception": profile.Profile.trace_dispatch_exception,
         "return": profile.Profile.trace_dispatch_return,
         "c_call": profile.Profile.trace_dispatch_c_call,
-        "c_exception": profile.Profile.trace_dispatch_return,  # the C function returned
+        "c_exception": profile.Profile.trace_dispatch_return,
+        # the C function returned
         "c_return": profile.Profile.trace_dispatch_return,
-        }
+    }
+
+#
+# eflag: FileType = Python2
