@@ -13,9 +13,8 @@ This module is a replacement for the one found in the Python distribution. It
 is to provide a debugger compatible variant of the a.m. functions.
 """
 
-import sys
+__all__ = ["getpass", "getuser"]
 
-__all__ = ["getpass","getuser"]
 
 def getuser():
     """
@@ -39,6 +38,7 @@ def getuser():
     import pwd
     return pwd.getpwuid(os.getuid())[0]
 
+
 def getpass(prompt='Password: '):
     """
     Function to prompt for a password, with echo turned off.
@@ -51,3 +51,6 @@ def getpass(prompt='Password: '):
 unix_getpass = getpass
 win_getpass = getpass
 default_getpass = getpass
+
+#
+# eflag: FileType = Python2
