@@ -8,27 +8,27 @@ Module implementing the debug base class.
 """
 
 import sys
-import traceback
 import bdb
 import os
-import types
 import atexit
 import inspect
 
-from DebugProtocol import *
+from DebugProtocol import ResponseClearWatch, ResponseClearBreak, \
+    ResponseLine, ResponseSyntax, ResponseException, CallTrace
 
 gRecursionLimit = 64
 
+
 def printerr(s):
     """
     Module function used for debugging the debug client.
     
     @param s data to be printed
     """
-    import sys
     sys.__stderr__.write('{0!s}\n'.format(s))
     sys.__stderr__.flush()
 
+
 def setRecursionLimit(limit):
     """
     Module function to set the recursion limit.
@@ -38,6 +38,7 @@ def setRecursionLimit(limit):
     global gRecursionLimit
     gRecursionLimit = limit
 
+
 class DebugBase(bdb.Bdb):
     """
     Class implementing base class of the debugger.
@@ -86,7 +87,7 @@ class DebugBase(bdb.Bdb):
         
         @return the current frame
         """
-        return self.currentFrame        
+        return self.currentFrame
     
     def getCurrentFrameLocals(self):
         """
@@ -94,7 +95,7 @@ class DebugBase(bdb.Bdb):
         
         @return locals dictionary of the current frame
         """
-        return self.currentFrameLocals        
+        return self.currentFrameLocals
     
     def step(self, traceMode):
         """
@@ -142,23 +143,51 @@ class DebugBase(bdb.Bdb):
     
     def profile(self, frame, event, arg):
         """
-        Public method used to trace some stuff independent of the debugger 
+        Public method used to trace some stuff independent of the debugger
         trace function.
         
-        @param frame The current stack frame.
-        @param event The trace event (string)
-        @param arg The arguments
+        @param frame current stack frame.
+        @param event trace event (string)
+        @param arg arguments
+        @exception RuntimeError raised to indicate too many recursions
         """
-        if event == 'return':  
+        if event == 'return':
             self.cFrame = frame.f_back
             self.__recursionDepth -= 1
+            self.__sendCallTrace(event, frame, self.cFrame)
         elif event == 'call':
+            self.__sendCallTrace(event, self.cFrame, frame)
             self.cFrame = frame
             self.__recursionDepth += 1
             if self.__recursionDepth > gRecursionLimit:
-                raise RuntimeError('maximum recursion depth exceeded\n'
+                raise RuntimeError(
+                    'maximum recursion depth exceeded\n'
                     '(offending frame is two down the stack)')
     
+    def __sendCallTrace(self, event, fromFrame, toFrame):
+        """
+        Private method to send a call/return trace.
+        
+        @param event trace event (string)
+        @param fromFrame originating frame (frame)
+        @param toFrame destination frame (frame)
+        """
+        if self._dbgClient.callTraceEnabled:
+            if not self.__skip_it(fromFrame) and not self.__skip_it(toFrame):
+                if event in ["call", "return"]:
+                    fr = fromFrame
+                    fromStr = "{0}:{1}:{2}".format(
+                        self._dbgClient.absPath(self.fix_frame_filename(fr)),
+                        fr.f_lineno,
+                        fr.f_code.co_name)
+                    fr = toFrame
+                    toStr = "{0}:{1}:{2}".format(
+                        self._dbgClient.absPath(self.fix_frame_filename(fr)),
+                        fr.f_lineno,
+                        fr.f_code.co_name)
+                    self._dbgClient.write("{0}{1}@@{2}@@{3}\n".format(
+                        CallTrace, event[0], fromStr, toStr))
+    
     def trace_dispatch(self, frame, event, arg):
         """
         Reimplemented from bdb.py to do some special things.
@@ -173,7 +202,7 @@ class DebugBase(bdb.Bdb):
         @return local trace function
         """
         if self.quitting:
-            return # None
+            return  # None
         
         # give the client a chance to push through new break points.
         self._dbgClient.eventPoll()
@@ -208,10 +237,12 @@ class DebugBase(bdb.Bdb):
         
         @param frame The current stack frame.
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if self.stop_here(frame) or self.break_here(frame):
             self.user_line(frame)
-            if self.quitting: raise bdb.BdbQuit
+            if self.quitting:
+                raise bdb.BdbQuit
         return self.trace_dispatch
 
     def dispatch_return(self, frame, arg):
@@ -221,6 +252,7 @@ class DebugBase(bdb.Bdb):
         @param frame The current stack frame.
         @param arg The arguments
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if self.stop_here(frame) or frame == self.returnframe:
             self.user_return(frame, arg)
@@ -235,13 +267,15 @@ class DebugBase(bdb.Bdb):
         @param frame The current stack frame.
         @param arg The arguments
         @return local trace function
+        @exception bdb.BdbQuit raised to indicate the end of the debug session
         """
         if not self.__skip_it(frame):
             self.user_exception(frame, arg)
-            if self.quitting: raise bdb.BdbQuit
+            if self.quitting:
+                raise bdb.BdbQuit
         return self.trace_dispatch
 
-    def set_trace(self, frame = None):
+    def set_trace(self, frame=None):
         """
         Overridden method of bdb.py to do some special setup.
         
@@ -265,7 +299,7 @@ class DebugBase(bdb.Bdb):
 
     def set_quit(self):
         """
-        Public method to quit. 
+        Public method to quit.
         
         It wraps call to bdb to clear the current frame properly.
         """
@@ -289,6 +323,7 @@ class DebugBase(bdb.Bdb):
         code over a network... This logic deals with that.
         
         @param frame the frame object
+        @return fixed up file name (string)
         """
         # get module name from __file__
         if '__file__' in frame.f_globals and \
@@ -306,7 +341,7 @@ class DebugBase(bdb.Bdb):
 
         return frame.f_code.co_filename
 
-    def set_watch(self, cond, temporary = False):
+    def set_watch(self, cond, temporary=False):
         """
         Public method to set a watch expression.
         
@@ -331,7 +366,7 @@ class DebugBase(bdb.Bdb):
         
         @param cond expression of the watch expression to be cleared (string)
         """
-        try: 
+        try:
             possibles = bdb.Breakpoint.bplist["Watch", 0]
             for i in range(0, len(possibles)):
                 b = possibles[i]
@@ -349,6 +384,7 @@ class DebugBase(bdb.Bdb):
         Public method to get a watch expression.
         
         @param cond expression of the watch expression to be cleared (string)
+        @return reference to the watch point
         """
         possibles = bdb.Breakpoint.bplist["Watch", 0]
         for i in range(0, len(possibles)):
@@ -370,8 +406,8 @@ class DebugBase(bdb.Bdb):
         Private method to determine, if a watch expression is effective.
         
         @param frame the current execution frame
-        @return tuple of watch expression and a flag to indicate, that a temporary
-            watch expression may be deleted (bdb.Breakpoint, boolean)
+        @return tuple of watch expression and a flag to indicate, that a
+            temporary watch expression may be deleted (bdb.Breakpoint, boolean)
         """
         possibles = bdb.Breakpoint.bplist["Watch", 0]
         for i in range(0, len(possibles)):
@@ -379,7 +415,8 @@ class DebugBase(bdb.Bdb):
             if not b.enabled:
                 continue
             if not b.cond:
-                # watch expression without expression shouldn't occur, just ignore it
+                # watch expression without expression shouldn't occur,
+                # just ignore it
                 continue
             try:
                 val = eval(b.condition, frame.f_globals, frame.f_locals)
@@ -421,7 +458,7 @@ class DebugBase(bdb.Bdb):
     
     def break_here(self, frame):
         """
-        Reimplemented from bdb.py to fix the filename from the frame. 
+        Reimplemented from bdb.py to fix the filename from the frame.
         
         See fix_frame_filename for more info.
         
@@ -436,7 +473,8 @@ class DebugBase(bdb.Bdb):
             lineno = frame.f_lineno
             if lineno not in self.breaks[filename]:
                 # The line itself has no breakpoint, but maybe the line is the
-                # first line of a function with breakpoint set by function name.
+                # first line of a function with breakpoint set by function
+                # name.
                 lineno = frame.f_code.co_firstlineno
             if lineno in self.breaks[filename]:
                 # flag says ok to delete temp. bp
@@ -474,9 +512,10 @@ class DebugBase(bdb.Bdb):
 
     def get_break(self, filename, lineno):
         """
-        Reimplemented from bdb.py to get the first breakpoint of a particular line.
+        Reimplemented from bdb.py to get the first breakpoint of a particular
+        line.
         
-        Because eric4 supports only one breakpoint per line, this overwritten
+        Because eric5 supports only one breakpoint per line, this overwritten
         method will return this one and only breakpoint.
         
         @param filename the filename of the bp to retrieve (string)
@@ -510,13 +549,22 @@ class DebugBase(bdb.Bdb):
         stack = []
         while fr is not None:
             fname = self._dbgClient.absPath(self.fix_frame_filename(fr))
-            fline = fr.f_lineno
-            ffunc = fr.f_code.co_name
-            
-            if ffunc == '?':
-                ffunc = ''
-            
-            stack.append([fname, fline, ffunc])
+            if not fname.startswith("<"):
+                fline = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
+                
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(
+                        argInfo.args, argInfo.varargs,
+                        argInfo.keywords, argInfo.locals)
+                else:
+                    fargs = ""
+                
+                stack.append([fname, fline, ffunc, fargs])
             
             if fr == self._dbgClient.mainFrame:
                 fr = None
@@ -548,7 +596,7 @@ class DebugBase(bdb.Bdb):
         self.currentFrame = frame
         self.currentFrameLocals = frame.f_locals
         # remember the locals because it is reinitialized when accessed
-
+        
         fr = frame
         stack = []
         while fr is not None:
@@ -559,13 +607,22 @@ class DebugBase(bdb.Bdb):
             # return from dispatch_call
             fr.f_trace = self.trace_dispatch
             fname = self._dbgClient.absPath(self.fix_frame_filename(fr))
-            fline = fr.f_lineno
-            ffunc = fr.f_code.co_name
-            
-            if ffunc == '?':
-                ffunc = ''
-            
-            stack.append([fname, fline, ffunc])
+            if not fname.startswith("<"):
+                fline = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
+                
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(
+                        argInfo.args, argInfo.varargs,
+                        argInfo.keywords, argInfo.locals)
+                else:
+                    fargs = ""
+                
+                stack.append([fname, fline, ffunc, fargs])
             
             if fr == self._dbgClient.mainFrame:
                 fr = None
@@ -577,7 +634,7 @@ class DebugBase(bdb.Bdb):
         self._dbgClient.write('{0}{1}\n'.format(ResponseLine, str(stack)))
         self._dbgClient.eventLoop()
 
-    def user_exception(self, frame, excinfo, unhandled = False):
+    def user_exception(self, frame, excinfo, unhandled=False):
         """
         Reimplemented to report an exception to the debug server.
         
@@ -604,8 +661,11 @@ class DebugBase(bdb.Bdb):
         
         if exctype in [SyntaxError, IndentationError]:
             try:
-                message, (filename, linenr, charnr, text) = excval[0], excval[1]
-            except ValueError:
+                message = str(excval)
+                filename = excval.filename
+                linenr = excval.lineno
+                charnr = excval.offset
+            except (AttributeError, ValueError):
                 exclist = []
                 realSyntaxError = True
             else:
@@ -613,7 +673,8 @@ class DebugBase(bdb.Bdb):
                 realSyntaxError = os.path.exists(filename)
             
             if realSyntaxError:
-                self._dbgClient.write("{0}{1}\n".format(ResponseSyntax, str(exclist)))
+                self._dbgClient.write("{0}{1}\n".format(
+                    ResponseSyntax, str(exclist)))
                 self._dbgClient.eventLoop()
                 return
         
@@ -627,9 +688,7 @@ class DebugBase(bdb.Bdb):
         else:
             exctypetxt = str(exctype)
         try:
-            exclist = [exctypetxt, 
-                       str(excval).encode(
-                            self._dbgClient.getCoding(), 'backslashreplace')]
+            exclist = [exctypetxt, str(excval)]
         except TypeError:
             exclist = [exctypetxt, str(excval)]
         
@@ -643,15 +702,29 @@ class DebugBase(bdb.Bdb):
             
             for fr in frlist:
                 filename = self._dbgClient.absPath(self.fix_frame_filename(fr))
-                linenr = fr.f_lineno
                 
                 if os.path.basename(filename).startswith("DebugClient") or \
                    os.path.basename(filename) == "bdb.py":
                     break
                 
-                exclist.append([filename, linenr])
+                linenr = fr.f_lineno
+                ffunc = fr.f_code.co_name
+                
+                if ffunc == '?':
+                    ffunc = ''
+                
+                if ffunc and not ffunc.startswith("<"):
+                    argInfo = inspect.getargvalues(fr)
+                    fargs = inspect.formatargvalues(
+                        argInfo.args, argInfo.varargs,
+                        argInfo.keywords, argInfo.locals)
+                else:
+                    fargs = ""
+                
+                exclist.append([filename, linenr, ffunc, fargs])
         
-        self._dbgClient.write("{0}{1}\n".format(ResponseException, str(exclist)))
+        self._dbgClient.write("{0}{1}\n".format(
+            ResponseException, str(exclist)))
         
         if exctb is None:
             return
@@ -664,6 +737,7 @@ class DebugBase(bdb.Bdb):
         type object.
         
         @param exctype type of the exception
+        @return exception name (string)
         """
         return str(exctype).replace("<class '", "").replace("'>", "")
     
@@ -691,7 +765,7 @@ class DebugBase(bdb.Bdb):
         """
         # The program has finished if we have just left the first frame.
         if frame == self._dbgClient.mainFrame and \
-            self._mainThread:
+                self._mainThread:
             atexit._run_exitfuncs()
             self._dbgClient.progTerminated(retval)
         elif frame is not self.stepFrame:
@@ -711,7 +785,7 @@ class DebugBase(bdb.Bdb):
         if self.__skip_it(frame):
             return False
         
-        return bdb.Bdb.stop_here(self,frame)
+        return bdb.Bdb.stop_here(self, frame)
 
     def __skip_it(self, frame):
         """
@@ -723,20 +797,23 @@ class DebugBase(bdb.Bdb):
         @param frame the frame object
         @return flag indicating whether the debugger should skip this frame
         """
+        if frame is None:
+            return True
+        
         fn = self.fix_frame_filename(frame)
 
         # Eliminate things like <string> and <stdin>.
         if fn[0] == '<':
-            return 1
+            return True
 
         #XXX - think of a better way to do this.  It's only a convience for
         #debugging the debugger - when the debugger code is in the current
         #directory.
-        if os.path.basename(fn) in [\
+        if os.path.basename(fn) in [
             'AsyncFile.py', 'AsyncIO.py',
             'DebugConfig.py', 'DCTestResult.py',
-            'DebugBase.py', 'DebugClientBase.py', 
-            'DebugClientCapabilities.py', 'DebugClient.py', 
+            'DebugBase.py', 'DebugClientBase.py',
+            'DebugClientCapabilities.py', 'DebugClient.py',
             'DebugClientThreads.py', 'DebugProtocol.py',
             'DebugThread.py', 'FlexCompleter.py',
             'PyProfile.py'] or \
