@@ -13,10 +13,9 @@ This module is a replacement for the one found in the Python distribution. It
 is to provide a debugger compatible variant of the a.m. functions.
 """
 
-import sys
-
 __all__ = ["getpass", "getuser"]
 
+
 def getuser():
     """
     Function to get the username from the environment or password database.
@@ -39,14 +38,15 @@ def getuser():
     import pwd
     return pwd.getpwuid(os.getuid())[0]
 
-def getpass(prompt = 'Password: '):
+
+def getpass(prompt='Password: '):
     """
     Function to prompt for a password, with echo turned off.
     
     @param prompt Prompt to be shown to the user (string)
     @return Password entered by the user (string)
     """
-    return raw_input(prompt, 0)
+    return input(prompt, False)
     
 unix_getpass = getpass
 win_getpass = getpass
