@@ -7,11 +7,6 @@
 File implementing an asynchronous file like socket interface for the debugger.
 =end
 
-if RUBY_VERSION < "1.9"
-    $KCODE = 'UTF8'
-    require 'jcode'
-end
-
 require 'socket'
 
 require 'DebugProtocol'
@@ -89,7 +84,8 @@ Private method to write a specific number of pending bytes.
             rescue IOError
                 @nWriteErrors += 1
                 if @nWriteErrors > self.maxtries
-                    raise   # assume that an error that occurs 10 times wont go away
+                    raise
+                    # assume that an error that occurs 10 times wont go away
                 end
             end
         end
@@ -238,7 +234,14 @@ Public method to read all lines from this file.
         return lines
     end
     
-    def seek(offset, whence=IO::SEEK_SET)
+    def gets()
+=begin edoc
+ Public method to read a line from this file.
+=end
+        readline()
+    end
+
+   def seek(offset, whence=IO::SEEK_SET)
 =begin edoc
 Public method to move the filepointer.
 
@@ -281,8 +284,8 @@ Public method to write a string to the file.
         elsif @wpending.length + s.length > @@maxbuffersize
             # flush wpending if too big
             while @wpending.length > 0
-                # if we have a persistent error in sending the data, an exception
-                # will be raised in nWrite
+                # if we have a persistent error in sending the data, an
+                # exception will be raised in nWrite
                 flush
                 tries += 1
                 if tries > @@maxtries
