@@ -7,50 +7,55 @@
 Module implementing the Breakpoint model.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
+
 
 class BreakPointModel(QAbstractItemModel):
     """
     Class implementing a custom model for breakpoints.
     """
-    def __init__(self, parent = None):
+    dataAboutToBeChanged = pyqtSignal(QModelIndex, QModelIndex)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
-        @param reference to the parent widget (QObject)
+        @param parent reference to the parent widget (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.breakpoints = []
         self.header = [
-            QVariant(self.trUtf8("Filename")),
-            QVariant(self.trUtf8("Line")),
-            QVariant(self.trUtf8('Condition')),
-            QVariant(self.trUtf8('Temporary')),
-            QVariant(self.trUtf8('Enabled')),
-            QVariant(self.trUtf8('Ignore Count')),
-        ]
-        self.alignments = [QVariant(Qt.Alignment(Qt.AlignLeft)),
-                           QVariant(Qt.Alignment(Qt.AlignRight)),
-                           QVariant(Qt.Alignment(Qt.AlignLeft)),
-                           QVariant(Qt.Alignment(Qt.AlignHCenter)),
-                           QVariant(Qt.Alignment(Qt.AlignHCenter)),
-                           QVariant(Qt.Alignment(Qt.AlignRight)),
-                           QVariant(Qt.Alignment(Qt.AlignHCenter)),
+            self.trUtf8("Filename"),
+            self.trUtf8("Line"),
+            self.trUtf8('Condition'),
+            self.trUtf8('Temporary'),
+            self.trUtf8('Enabled'),
+            self.trUtf8('Ignore Count'),
         ]
+        self.alignments = [Qt.Alignment(Qt.AlignLeft),
+                           Qt.Alignment(Qt.AlignRight),
+                           Qt.Alignment(Qt.AlignLeft),
+                           Qt.Alignment(Qt.AlignHCenter),
+                           Qt.Alignment(Qt.AlignHCenter),
+                           Qt.Alignment(Qt.AlignRight),
+                           Qt.Alignment(Qt.AlignHCenter),
+                           ]
 
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the current column count.
         
+        @param parent reference to parent index (QModelIndex)
         @return column count (integer)
         """
-        return len(self.header) + 1
+        return len(self.header)
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to get the current row count.
         
+        @param parent reference to parent index (QModelIndex)
         @return row count (integer)
         """
         # we do not have a tree, parent should always be invalid
@@ -59,26 +64,53 @@ class BreakPointModel(QAbstractItemModel):
         else:
             return 0
     
-    def data(self, index, role):
+    def data(self, index, role=Qt.DisplayRole):
         """
         Public method to get the requested data.
         
         @param index index of the requested data (QModelIndex)
         @param role role of the requested data (Qt.ItemDataRole)
-        @return the requested data (QVariant)
+        @return the requested data
         """
         if not index.isValid():
-            return QVariant()
+            return None
         
-        if role == Qt.DisplayRole or role == Qt.ToolTipRole:
-            if index.column() < len(self.header):
-                return QVariant(self.breakpoints[index.row()][index.column()])
+        if role == Qt.DisplayRole:
+            if index.column() in [0, 1, 2, 5]:
+                return self.breakpoints[index.row()][index.column()]
+        
+        if role == Qt.CheckStateRole:
+            if index.column() in [3, 4]:
+                return self.breakpoints[index.row()][index.column()]
+        
+        if role == Qt.ToolTipRole:
+            if index.column() in [0, 2]:
+                return self.breakpoints[index.row()][index.column()]
         
         if role == Qt.TextAlignmentRole:
             if index.column() < len(self.alignments):
                 return self.alignments[index.column()]
         
-        return QVariant()
+        return None
+    
+    def setData(self, index, value, role=Qt.EditRole):
+        """
+        Public method to change data in the model.
+        
+        @param index index of the changed data (QModelIndex)
+        @param value value of the changed data
+        @param role role of the changed data (Qt.ItemDataRole)
+        @return flag indicating success (boolean)
+        """
+        if not index.isValid() or \
+           index.column() >= len(self.header) or \
+           index.row() >= len(self.breakpoints):
+            return False
+        
+        self.dataAboutToBeChanged.emit(index, index)
+        self.breakpoints[index.row()][index.column()] = value
+        self.dataChanged.emit(index, index)
+        return True
     
     def flags(self, index):
         """
@@ -92,24 +124,24 @@ class BreakPointModel(QAbstractItemModel):
         
         return Qt.ItemIsEnabled | Qt.ItemIsSelectable
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get header data.
         
         @param section section number of the requested header data (integer)
         @param orientation orientation of the header (Qt.Orientation)
         @param role role of the requested data (Qt.ItemDataRole)
-        @return header data (QVariant)
+        @return header data
         """
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             if section >= len(self.header):
-                return QVariant("")
+                return ""
             else:
                 return self.header[section]
         
-        return QVariant()
+        return None
     
-    def index(self, row, column, parent = QModelIndex()):
+    def index(self, row, column, parent=QModelIndex()):
         """
         Public method to create an index.
         
@@ -134,7 +166,7 @@ class BreakPointModel(QAbstractItemModel):
         """
         return QModelIndex()
     
-    def hasChildren(self, parent = QModelIndex()):
+    def hasChildren(self, parent=QModelIndex()):
         """
         Public method to check for the presence of child items.
         
@@ -146,19 +178,19 @@ class BreakPointModel(QAbstractItemModel):
         else:
             return False
     
-    ############################################################################
+    ###########################################################################
     
     def addBreakPoint(self, fn, line, properties):
         """
         Public method to add a new breakpoint to the list.
         
-        @param fn filename of the breakpoint (string or QString)
+        @param fn filename of the breakpoint (string)
         @param line line number of the breakpoint (integer)
         @param properties properties of the breakpoint
-            (tuple of condition (string or QString), temporary flag (bool), 
+            (tuple of condition (string), temporary flag (bool),
              enabled flag (bool), ignore count (integer))
         """
-        bp = [unicode(fn), line] + list(properties)
+        bp = [fn, line] + list(properties)
         cnt = len(self.breakpoints)
         self.beginInsertRows(QModelIndex(), cnt, cnt)
         self.breakpoints.append(bp)
@@ -169,26 +201,20 @@ class BreakPointModel(QAbstractItemModel):
         Public method to set the values of a breakpoint given by index.
         
         @param index index of the breakpoint (QModelIndex)
-        @param fn filename of the breakpoint (string or QString)
+        @param fn filename of the breakpoint (string)
         @param line line number of the breakpoint (integer)
         @param properties properties of the breakpoint
-            (tuple of condition (string or QString), temporary flag (bool), 
+            (tuple of condition (string), temporary flag (bool),
              enabled flag (bool), ignore count (integer))
         """
         if index.isValid():
             row = index.row()
             index1 = self.createIndex(row, 0, self.breakpoints[row])
-            index2 = self.createIndex(row, len(self.breakpoints[row]), 
-                     self.breakpoints[row])
-            self.emit(\
-                SIGNAL("dataAboutToBeChanged(const QModelIndex &, const QModelIndex &)"),
-                index1, index2)
-            i = 0
-            for value in [unicode(fn), line] + list(properties):
-                self.breakpoints[row][i] = value
-                i += 1
-            self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                      index1, index2)
+            index2 = self.createIndex(
+                row, len(self.breakpoints[row]), self.breakpoints[row])
+            self.dataAboutToBeChanged.emit(index1, index2)
+            self.breakpoints[row] = [fn, line] + list(properties)
+            self.dataChanged.emit(index1, index2)
 
     def setBreakPointEnabledByIndex(self, index, enabled):
         """
@@ -201,12 +227,9 @@ class BreakPointModel(QAbstractItemModel):
             row = index.row()
             col = 4
             index1 = self.createIndex(row, col, self.breakpoints[row])
-            self.emit(\
-                SIGNAL("dataAboutToBeChanged(const QModelIndex &, const QModelIndex &)"),
-                index1, index1)
+            self.dataAboutToBeChanged.emit(index1, index1)
             self.breakpoints[row][col] = enabled
-            self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                      index1, index1)
+            self.dataChanged.emit(index1, index1)
     
     def deleteBreakPointByIndex(self, index):
         """
@@ -230,7 +253,7 @@ class BreakPointModel(QAbstractItemModel):
         for index in idxList:
             if index.isValid():
                 rows.append(index.row())
-        rows.sort(reverse = True)
+        rows.sort(reverse=True)
         for row in rows:
             self.beginRemoveRows(QModelIndex(), row, row)
             del self.breakpoints[row]
@@ -254,34 +277,34 @@ class BreakPointModel(QAbstractItemModel):
             condition, temporary flag, enabled flag, ignore count))
         """
         if index.isValid():
-            return self.breakpoints[index.row()][:] # return a copy
+            return self.breakpoints[index.row()][:]  # return a copy
         else:
             return []
 
     def getBreakPointIndex(self, fn, lineno):
         """
-        Public method to get the index of a breakpoint given by filename and line number.
+        Public method to get the index of a breakpoint given by filename and
+        line number.
         
-        @param fn filename of the breakpoint (string or QString)
-        @param line line number of the breakpoint (integer)
+        @param fn filename of the breakpoint (string)
+        @param lineno line number of the breakpoint (integer)
         @return index (QModelIndex)
         """
-        fn = unicode(fn)
         for row in range(len(self.breakpoints)):
             bp = self.breakpoints[row]
-            if unicode(bp[0]) == fn and bp[1] == lineno:
+            if bp[0] == fn and bp[1] == lineno:
                 return self.createIndex(row, 0, self.breakpoints[row])
         
         return QModelIndex()
     
     def isBreakPointTemporaryByIndex(self, index):
         """
-        Public method to test, if a breakpoint given by it's index is temporary.
+        Public method to test, if a breakpoint given by its index is temporary.
         
         @param index index of the breakpoint to test (QModelIndex)
         @return flag indicating a temporary breakpoint (boolean)
         """
-        if index.isValid(): 
+        if index.isValid():
             return self.breakpoints[index.row()][3]
         else:
             return False
