@@ -7,29 +7,31 @@
 Module implementing the Breakpoint viewer widget.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, Qt, qVersion
+from PyQt4.QtGui import QTreeView, QAbstractItemView, QSortFilterProxyModel, \
+    QHeaderView, QItemSelectionModel, QMenu, QDialog
 
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
-from EditBreakpointDialog import EditBreakpointDialog
 
 class BreakPointViewer(QTreeView):
     """
     Class implementing the Breakpoint viewer widget.
     
-    Breakpoints will be shown with all their details. They can be modified through
-    the context menu of this widget.
+    Breakpoints will be shown with all their details. They can be modified
+    through the context menu of this widget.
     
-    @signal sourceFile(string, int) emitted to show the source of a breakpoint
+    @signal sourceFile(str, int) emitted to show the source of a breakpoint
     """
-    def __init__(self, parent = None):
+    sourceFile = pyqtSignal(str, int)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent the parent (QWidget)
         """
-        QTreeView.__init__(self, parent)
+        super().__init__(parent)
         self.setObjectName("BreakPointViewer")
         
         self.__model = None
@@ -43,33 +45,35 @@ class BreakPointViewer(QTreeView):
         self.setWindowTitle(self.trUtf8("Breakpoints"))
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self,SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
-        self.connect(self,SIGNAL('doubleClicked(const QModelIndex &)'),
-                     self.__doubleClicked)
+        self.customContextMenuRequested.connect(self.__showContextMenu)
+        self.doubleClicked.connect(self.__doubleClicked)
         
         self.__createPopupMenus()
         
-        self.condHistory = QStringList()
-        self.fnHistory = QStringList()
+        self.condHistory = []
+        self.fnHistory = []
         self.fnHistory.append('')
         
     def setModel(self, model):
         """
         Public slot to set the breakpoint model.
         
-        @param reference to the breakpoint model (BreakPointModel)
+        @param model reference to the breakpoint model (BreakPointModel)
         """
         self.__model = model
         
         self.sortingModel = QSortFilterProxyModel()
+        self.sortingModel.setDynamicSortFilter(True)
         self.sortingModel.setSourceModel(self.__model)
-        QTreeView.setModel(self, self.sortingModel)
+        super().setModel(self.sortingModel)
         
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        header.setClickable(True)
+        if qVersion() >= "5.0.0":
+            header.setSectionsClickable(True)
+        else:
+            header.setClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -84,7 +88,8 @@ class BreakPointViewer(QTreeView):
         
     def __resizeColumns(self):
         """
-        Private slot to resize the view when items get added, edited or deleted.
+        Private slot to resize the view when items get added, edited or
+        deleted.
         """
         self.header().resizeSections(QHeaderView.ResizeToContents)
         self.header().setStretchLastSection(True)
@@ -93,7 +98,7 @@ class BreakPointViewer(QTreeView):
         """
         Private slot to resort the tree.
         """
-        self.model().sort(self.header().sortIndicatorSection(), 
+        self.model().sort(self.header().sortIndicatorSection(),
                           self.header().sortIndicatorOrder())
         
     def __toSourceIndex(self, index):
@@ -101,6 +106,7 @@ class BreakPointViewer(QTreeView):
         Private slot to convert an index to a source index.
         
         @param index index to be converted (QModelIndex)
+        @return mapped index (QModelIndex)
         """
         return self.sortingModel.mapToSource(index)
         
@@ -109,10 +115,11 @@ class BreakPointViewer(QTreeView):
         Private slot to convert a source index to an index.
         
         @param sindex source index to be converted (QModelIndex)
+        @return mapped index (QModelIndex)
         """
         return self.sortingModel.mapFromSource(sindex)
         
-    def __setRowSelected(self, index, selected = True):
+    def __setRowSelected(self, index, selected=True):
         """
         Private slot to select a complete row.
         
@@ -123,10 +130,10 @@ class BreakPointViewer(QTreeView):
             return
         
         if selected:
-            flags = QItemSelectionModel.SelectionFlags(\
+            flags = QItemSelectionModel.SelectionFlags(
                 QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
         else:
-            flags = QItemSelectionModel.SelectionFlags(\
+            flags = QItemSelectionModel.SelectionFlags(
                 QItemSelectionModel.Deselect | QItemSelectionModel.Rows)
         self.selectionModel().select(index, flags)
         
@@ -142,7 +149,8 @@ class BreakPointViewer(QTreeView):
         self.menu.addAction(self.trUtf8("Enable all"), self.__enableAllBreaks)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Disable"), self.__disableBreak)
-        self.menu.addAction(self.trUtf8("Disable all"), self.__disableAllBreaks)
+        self.menu.addAction(self.trUtf8("Disable all"),
+                            self.__disableAllBreaks)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Delete"), self.__deleteBreak)
         self.menu.addAction(self.trUtf8("Delete all"), self.__deleteAllBreaks)
@@ -155,29 +163,35 @@ class BreakPointViewer(QTreeView):
         self.backMenu = QMenu()
         self.backMenu.addAction(self.trUtf8("Add"), self.__addBreak)
         self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Enable all"), self.__enableAllBreaks)
+            self.backMenu.addAction(self.trUtf8("Enable all"),
+                                    self.__enableAllBreaks)
         self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Disable all"), self.__disableAllBreaks)
+            self.backMenu.addAction(self.trUtf8("Disable all"),
+                                    self.__disableAllBreaks)
         self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.trUtf8("Delete all"), self.__deleteAllBreaks)
-        self.connect(self.backMenu, SIGNAL('aboutToShow()'), self.__showBackMenu)
+            self.backMenu.addAction(self.trUtf8("Delete all"),
+                                    self.__deleteAllBreaks)
+        self.backMenu.aboutToShow.connect(self.__showBackMenu)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
 
         self.multiMenu = QMenu()
         self.multiMenu.addAction(self.trUtf8("Add"), self.__addBreak)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Enable selected"), 
-            self.__enableSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Enable all"), self.__enableAllBreaks)
+        self.multiMenu.addAction(self.trUtf8("Enable selected"),
+                                 self.__enableSelectedBreaks)
+        self.multiMenu.addAction(self.trUtf8("Enable all"),
+                                 self.__enableAllBreaks)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Disable selected"), 
-            self.__disableSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Disable all"), self.__disableAllBreaks)
+        self.multiMenu.addAction(self.trUtf8("Disable selected"),
+                                 self.__disableSelectedBreaks)
+        self.multiMenu.addAction(self.trUtf8("Disable all"),
+                                 self.__disableAllBreaks)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Delete selected"), 
-            self.__deleteSelectedBreaks)
-        self.multiMenu.addAction(self.trUtf8("Delete all"), self.__deleteAllBreaks)
+        self.multiMenu.addAction(self.trUtf8("Delete selected"),
+                                 self.__deleteSelectedBreaks)
+        self.multiMenu.addAction(self.trUtf8("Delete all"),
+                                 self.__deleteAllBreaks)
         self.multiMenu.addSeparator()
         self.multiMenu.addAction(self.trUtf8("Configure..."), self.__configure)
     
@@ -212,20 +226,24 @@ class BreakPointViewer(QTreeView):
         """
         Private slot to handle the add breakpoint context menu entry.
         """
+        from .EditBreakpointDialog import EditBreakpointDialog
+        
         dlg = EditBreakpointDialog((self.fnHistory[0], None), None,
-            self.condHistory, self, modal = 1, addMode = 1,
-            filenameHistory = self.fnHistory)
+                                   self.condHistory, self, modal=1,
+                                   addMode=1, filenameHistory=self.fnHistory)
         if dlg.exec_() == QDialog.Accepted:
             fn, line, cond, temp, enabled, count = dlg.getAddData()
             if fn is not None:
-                self.fnHistory.removeAll(fn)
-                self.fnHistory.prepend(fn)
+                if fn in self.fnHistory:
+                    self.fnHistory.remove(fn)
+                self.fnHistory.insert(0, fn)
             
-            if not cond.isEmpty():
-                self.condHistory.removeAll(cond)
-                self.condHistory.prepend(cond)
+            if cond:
+                if cond in self.condHistory:
+                    self.condHistory.remove(cond)
+                self.condHistory.insert(0, cond)
             
-            self.__model.addBreakPoint(fn, line, (unicode(cond), temp, enabled, count))
+            self.__model.addBreakPoint(fn, line, (cond, temp, enabled, count))
             self.__resizeColumns()
             self.__resort()
     
@@ -260,16 +278,19 @@ class BreakPointViewer(QTreeView):
             
             fn, line, cond, temp, enabled, count = bp[:6]
             
-            dlg = EditBreakpointDialog((fn, line), (cond, temp, enabled, count),
-                self.condHistory, self, modal = True)
+            from .EditBreakpointDialog import EditBreakpointDialog
+            dlg = EditBreakpointDialog(
+                (fn, line), (cond, temp, enabled, count),
+                self.condHistory, self, modal=True)
             if dlg.exec_() == QDialog.Accepted:
                 cond, temp, enabled, count = dlg.getData()
-                if not cond.isEmpty():
-                    self.condHistory.removeAll(cond)
-                    self.condHistory.prepend(cond)
+                if cond:
+                    if cond in self.condHistory:
+                        self.condHistory.remove(cond)
+                    self.condHistory.insert(0, cond)
                 
-                self.__model.setBreakPointByIndex(sindex, 
-                    fn, line, (unicode(cond), temp, enabled, count))
+                self.__model.setBreakPointByIndex(
+                    sindex, fn, line, (cond, temp, enabled, count))
                 self.__resizeColumns()
                 self.__resort()
 
@@ -306,7 +327,8 @@ class BreakPointViewer(QTreeView):
 
     def __enableSelectedBreaks(self):
         """
-        Private slot to handle the enable selected breakpoints context menu entry.
+        Private slot to handle the enable selected breakpoints context menu
+        entry.
         """
         for index in self.selectedIndexes():
             if index.column() == 0:
@@ -336,7 +358,8 @@ class BreakPointViewer(QTreeView):
 
     def __disableSelectedBreaks(self):
         """
-        Private slot to handle the disable selected breakpoints context menu entry.
+        Private slot to handle the disable selected breakpoints context menu
+        entry.
         """
         for index in self.selectedIndexes():
             if index.column() == 0:
@@ -361,7 +384,8 @@ class BreakPointViewer(QTreeView):
 
     def __deleteSelectedBreaks(self):
         """
-        Private slot to handle the delete selected breakpoints context menu entry.
+        Private slot to handle the delete selected breakpoints context menu
+        entry.
         """
         idxList = []
         for index in self.selectedIndexes():
@@ -381,13 +405,13 @@ class BreakPointViewer(QTreeView):
             return
         
         fn, line = bp[:2]
-        self.emit(SIGNAL("sourceFile"), fn, line)
+        self.sourceFile.emit(fn, line)
     
     def highlightBreakpoint(self, fn, lineno):
         """
         Public slot to handle the clientLine signal.
         
-        @param fn filename of the breakpoint (QString)
+        @param fn filename of the breakpoint (string)
         @param lineno line number of the breakpoint (integer)
         """
         sindex = self.__model.getBreakPointIndex(fn, lineno)
@@ -424,7 +448,7 @@ class BreakPointViewer(QTreeView):
         
         @return count of items selected (integer)
         """
-        count = len(self.selectedIndexes()) / (self.__model.columnCount()-1)
+        count = len(self.selectedIndexes()) // (self.__model.columnCount() - 1)
         # column count is 1 greater than selectable
         return count
     
@@ -432,4 +456,5 @@ class BreakPointViewer(QTreeView):
         """
         Private method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("debuggerGeneralPage")
+        e5App().getObject("UserInterface").showPreferences(
+            "debuggerGeneralPage")
