@@ -10,6 +10,7 @@ The views avaliable are:
 <ul>
   <li>variables viewer for global variables</li>
   <li>variables viewer for local variables</li>
+  <li>call trace viewer</li>
   <li>viewer for breakpoints</li>
   <li>viewer for watch expressions</li>
   <li>viewer for exceptions</li>
@@ -21,34 +22,32 @@ The views avaliable are:
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal
+from PyQt4.QtGui import QWidget, QVBoxLayout, QHBoxLayout, QLineEdit, \
+    QSizePolicy, QPushButton, QComboBox, QLabel, QTreeWidget, \
+    QTreeWidgetItem, QHeaderView
 
-from QScintilla.Shell import Shell
-from VariablesViewer import VariablesViewer
-from ExceptionLogger import ExceptionLogger
-from BreakPointViewer import BreakPointViewer
-from WatchPointViewer import WatchPointViewer
-
-import Preferences
-import Utilities
 import UI.PixmapCache
+import Preferences
+
+from E5Gui.E5TabWidget import E5TabWidget
 
-from E4Gui.E4TabWidget import E4TabWidget
 
 class DebugViewer(QWidget):
     """
     Class implementing a widget conatining various debug related views.
     
-    The individual tabs contain the interpreter shell (optional), 
-    the filesystem browser (optional), the two variables viewers (global and local),
-    a breakpoint viewer, a watch expression viewer and the exception logger. Additionally
-    a list of all threads is shown.
+    The individual tabs contain the interpreter shell (optional),
+    the filesystem browser (optional), the two variables viewers
+    (global and local), a breakpoint viewer, a watch expression viewer and
+    the exception logger. Additionally a list of all threads is shown.
     
     @signal sourceFile(string, int) emitted to open a source file at a line
     """
-    def __init__(self, debugServer, docked, vm, parent = None, 
-                 embeddedShell = True, embeddedBrowser = True):
+    sourceFile = pyqtSignal(str, int)
+    
+    def __init__(self, debugServer, docked, vm, parent=None,
+                 embeddedShell=True, embeddedBrowser=True):
         """
         Constructor
         
@@ -56,15 +55,15 @@ class DebugViewer(QWidget):
         @param docked flag indicating a dock window
         @param vm reference to the viewmanager object
         @param parent parent widget (QWidget)
-        @param embeddedShell flag indicating whether the shell should be included.
-                This flag is set to False by those layouts, that have the interpreter
-                shell in a separate window.
+        @param embeddedShell flag indicating whether the shell should be
+            included. This flag is set to False by those layouts, that have
+            the interpreter shell in a separate window.
         @param embeddedBrowser flag indicating whether the file browser should
-                be included. This flag is set to False by those layouts, that
-                have the file browser in a separate window or embedded
-                in the project browser instead.
+            be included. This flag is set to False by those layouts, that
+            have the file browser in a separate window or embedded
+            in the project browser instead.
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         
         self.debugServer = debugServer
         self.debugUI = None
@@ -72,17 +71,20 @@ class DebugViewer(QWidget):
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         
         self.__mainLayout = QVBoxLayout()
-        self.__mainLayout.setMargin(0)
+        self.__mainLayout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(self.__mainLayout)
         
-        self.__tabWidget = E4TabWidget()
+        self.__tabWidget = E5TabWidget()
         self.__mainLayout.addWidget(self.__tabWidget)
         
         self.embeddedShell = embeddedShell
         if embeddedShell:
+            from QScintilla.Shell import ShellAssembly
             # add the interpreter shell
-            self.shell = Shell(debugServer, vm)
-            index = self.__tabWidget.addTab(self.shell, 
+            self.shellAssembly = ShellAssembly(debugServer, vm, False)
+            self.shell = self.shellAssembly.shell()
+            index = self.__tabWidget.addTab(
+                self.shellAssembly,
                 UI.PixmapCache.getIcon("shell.png"), '')
             self.__tabWidget.setTabToolTip(index, self.shell.windowTitle())
         
@@ -91,14 +93,16 @@ class DebugViewer(QWidget):
             from UI.Browser import Browser
             # add the browser
             self.browser = Browser()
-            index = self.__tabWidget.addTab(self.browser, 
+            index = self.__tabWidget.addTab(
+                self.browser,
                 UI.PixmapCache.getIcon("browser.png"), '')
             self.__tabWidget.setTabToolTip(index, self.browser.windowTitle())
         
+        from .VariablesViewer import VariablesViewer
         # add the global variables viewer
         self.glvWidget = QWidget()
         self.glvWidgetVLayout = QVBoxLayout(self.glvWidget)
-        self.glvWidgetVLayout.setMargin(0)
+        self.glvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
         self.glvWidgetVLayout.setSpacing(3)
         self.glvWidget.setLayout(self.glvWidgetVLayout)
         
@@ -106,44 +110,48 @@ class DebugViewer(QWidget):
         self.glvWidgetVLayout.addWidget(self.globalsViewer)
         
         self.glvWidgetHLayout = QHBoxLayout()
-        self.glvWidgetHLayout.setMargin(3)
+        self.glvWidgetHLayout.setContentsMargins(3, 3, 3, 3)
         
         self.globalsFilterEdit = QLineEdit(self.glvWidget)
-        self.globalsFilterEdit.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.globalsFilterEdit.setSizePolicy(
+            QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.glvWidgetHLayout.addWidget(self.globalsFilterEdit)
-        self.globalsFilterEdit.setToolTip(\
-            self.trUtf8("Enter regular expression patterns separated by ';' to define "
-                "variable filters. "))
-        self.globalsFilterEdit.setWhatsThis(\
-            self.trUtf8("Enter regular expression patterns separated by ';' to define "
-                "variable filters. All variables and class attributes matched by one of "
-                "the expressions are not shown in the list above."))
+        self.globalsFilterEdit.setToolTip(
+            self.trUtf8("Enter regular expression patterns separated by ';'"
+                        " to define variable filters. "))
+        self.globalsFilterEdit.setWhatsThis(
+            self.trUtf8("Enter regular expression patterns separated by ';'"
+                        " to define variable filters. All variables and"
+                        " class attributes matched by one of the expressions"
+                        " are not shown in the list above."))
         
-        self.setGlobalsFilterButton = QPushButton(self.trUtf8('Set'), self.glvWidget)
+        self.setGlobalsFilterButton = QPushButton(
+            self.trUtf8('Set'), self.glvWidget)
         self.glvWidgetHLayout.addWidget(self.setGlobalsFilterButton)
         self.glvWidgetVLayout.addLayout(self.glvWidgetHLayout)
         
-        index = self.__tabWidget.addTab(self.glvWidget,
+        index = self.__tabWidget.addTab(
+            self.glvWidget,
             UI.PixmapCache.getIcon("globalVariables.png"), '')
         self.__tabWidget.setTabToolTip(index, self.globalsViewer.windowTitle())
         
-        self.connect(self.setGlobalsFilterButton, SIGNAL('clicked()'),
-                     self.__setGlobalsFilter)
-        self.connect(self.globalsFilterEdit, SIGNAL('returnPressed()'),
-                     self.__setGlobalsFilter)
+        self.setGlobalsFilterButton.clicked[()].connect(
+            self.__setGlobalsFilter)
+        self.globalsFilterEdit.returnPressed.connect(self.__setGlobalsFilter)
         
         # add the local variables viewer
         self.lvWidget = QWidget()
         self.lvWidgetVLayout = QVBoxLayout(self.lvWidget)
-        self.lvWidgetVLayout.setMargin(0)
+        self.lvWidgetVLayout.setContentsMargins(0, 0, 0, 0)
         self.lvWidgetVLayout.setSpacing(3)
         self.lvWidget.setLayout(self.lvWidgetVLayout)
         
         self.lvWidgetHLayout1 = QHBoxLayout()
-        self.lvWidgetHLayout1.setMargin(3)
+        self.lvWidgetHLayout1.setContentsMargins(3, 3, 3, 3)
         
         self.stackComboBox = QComboBox(self.lvWidget)
-        self.stackComboBox.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.stackComboBox.setSizePolicy(
+            QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.lvWidgetHLayout1.addWidget(self.stackComboBox)
 
         self.sourceButton = QPushButton(self.trUtf8('Source'), self.lvWidget)
@@ -155,60 +163,92 @@ class DebugViewer(QWidget):
         self.lvWidgetVLayout.addWidget(self.localsViewer)
         
         self.lvWidgetHLayout2 = QHBoxLayout()
-        self.lvWidgetHLayout2.setMargin(3)
+        self.lvWidgetHLayout2.setContentsMargins(3, 3, 3, 3)
         
         self.localsFilterEdit = QLineEdit(self.lvWidget)
-        self.localsFilterEdit.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.localsFilterEdit.setSizePolicy(
+            QSizePolicy.Expanding, QSizePolicy.Fixed)
         self.lvWidgetHLayout2.addWidget(self.localsFilterEdit)
-        self.localsFilterEdit.setToolTip(\
-            self.trUtf8("Enter regular expression patterns separated by ';' to define "
+        self.localsFilterEdit.setToolTip(
+            self.trUtf8(
+                "Enter regular expression patterns separated by ';' to define "
                 "variable filters. "))
-        self.localsFilterEdit.setWhatsThis(\
-            self.trUtf8("Enter regular expression patterns separated by ';' to define "
-                "variable filters. All variables and class attributes matched by one of "
-                "the expressions are not shown in the list above."))
+        self.localsFilterEdit.setWhatsThis(
+            self.trUtf8(
+                "Enter regular expression patterns separated by ';' to define "
+                "variable filters. All variables and class attributes matched"
+                " by one of the expressions are not shown in the list above."))
         
-        self.setLocalsFilterButton = QPushButton(self.trUtf8('Set'), self.lvWidget)
+        self.setLocalsFilterButton = QPushButton(
+            self.trUtf8('Set'), self.lvWidget)
         self.lvWidgetHLayout2.addWidget(self.setLocalsFilterButton)
         self.lvWidgetVLayout.addLayout(self.lvWidgetHLayout2)
         
-        index = self.__tabWidget.addTab(self.lvWidget,
+        index = self.__tabWidget.addTab(
+            self.lvWidget,
             UI.PixmapCache.getIcon("localVariables.png"), '')
         self.__tabWidget.setTabToolTip(index, self.localsViewer.windowTitle())
         
-        self.connect(self.sourceButton, SIGNAL('clicked()'), 
-                     self.__showSource)
-        self.connect(self.stackComboBox, SIGNAL('activated(int)'), 
-                     self.__frameSelected)
-        self.connect(self.setLocalsFilterButton, SIGNAL('clicked()'),
-                     self.__setLocalsFilter)
-        self.connect(self.localsFilterEdit, SIGNAL('returnPressed()'),
-                     self.__setLocalsFilter)
+        self.sourceButton.clicked[()].connect(self.__showSource)
+        self.stackComboBox.currentIndexChanged[int].connect(
+            self.__frameSelected)
+        self.setLocalsFilterButton.clicked[()].connect(self.__setLocalsFilter)
+        self.localsFilterEdit.returnPressed.connect(self.__setLocalsFilter)
         
+        from .CallStackViewer import CallStackViewer
+        # add the call stack viewer
+        self.callStackViewer = CallStackViewer(self.debugServer)
+        index = self.__tabWidget.addTab(
+            self.callStackViewer,
+            UI.PixmapCache.getIcon("step.png"), "")
+        self.__tabWidget.setTabToolTip(
+            index, self.callStackViewer.windowTitle())
+        self.callStackViewer.sourceFile.connect(self.sourceFile)
+        self.callStackViewer.frameSelected.connect(
+            self.__callStackFrameSelected)
+        
+        from .CallTraceViewer import CallTraceViewer
+        # add the call trace viewer
+        self.callTraceViewer = CallTraceViewer(self.debugServer)
+        index = self.__tabWidget.addTab(
+            self.callTraceViewer,
+            UI.PixmapCache.getIcon("callTrace.png"), "")
+        self.__tabWidget.setTabToolTip(
+            index, self.callTraceViewer.windowTitle())
+        self.callTraceViewer.sourceFile.connect(self.sourceFile)
+        
+        from .BreakPointViewer import BreakPointViewer
         # add the breakpoint viewer
         self.breakpointViewer = BreakPointViewer()
         self.breakpointViewer.setModel(self.debugServer.getBreakPointModel())
-        index = self.__tabWidget.addTab(self.breakpointViewer,
+        index = self.__tabWidget.addTab(
+            self.breakpointViewer,
             UI.PixmapCache.getIcon("breakpoints.png"), '')
-        self.__tabWidget.setTabToolTip(index, self.breakpointViewer.windowTitle())
-        self.connect(self.breakpointViewer, SIGNAL("sourceFile"),
-                     self, SIGNAL("sourceFile"))
+        self.__tabWidget.setTabToolTip(
+            index, self.breakpointViewer.windowTitle())
+        self.breakpointViewer.sourceFile.connect(self.sourceFile)
         
+        from .WatchPointViewer import WatchPointViewer
         # add the watch expression viewer
         self.watchpointViewer = WatchPointViewer()
         self.watchpointViewer.setModel(self.debugServer.getWatchPointModel())
-        index = self.__tabWidget.addTab(self.watchpointViewer,
+        index = self.__tabWidget.addTab(
+            self.watchpointViewer,
             UI.PixmapCache.getIcon("watchpoints.png"), '')
-        self.__tabWidget.setTabToolTip(index, self.watchpointViewer.windowTitle())
+        self.__tabWidget.setTabToolTip(
+            index, self.watchpointViewer.windowTitle())
         
+        from .ExceptionLogger import ExceptionLogger
         # add the exception logger
         self.exceptionLogger = ExceptionLogger()
-        index = self.__tabWidget.addTab(self.exceptionLogger, 
+        index = self.__tabWidget.addTab(
+            self.exceptionLogger,
             UI.PixmapCache.getIcon("exceptions.png"), '')
-        self.__tabWidget.setTabToolTip(index, self.exceptionLogger.windowTitle())
+        self.__tabWidget.setTabToolTip(
+            index, self.exceptionLogger.windowTitle())
         
         if self.embeddedShell:
-            self.__tabWidget.setCurrentWidget(self.shell)
+            self.__tabWidget.setCurrentWidget(self.shellAssembly)
         else:
             if self.embeddedBrowser:
                 self.__tabWidget.setCurrentWidget(self.browser)
@@ -218,16 +258,15 @@ class DebugViewer(QWidget):
         # add the threads viewer
         self.__mainLayout.addWidget(QLabel(self.trUtf8("Threads:")))
         self.__threadList = QTreeWidget()
-        self.__threadList.setHeaderLabels([self.trUtf8("ID"), self.trUtf8("Name"), 
-                                           self.trUtf8("State"), ""])
+        self.__threadList.setHeaderLabels(
+            [self.trUtf8("ID"), self.trUtf8("Name"),
+             self.trUtf8("State"), ""])
         self.__threadList.setSortingEnabled(True)
         self.__mainLayout.addWidget(self.__threadList)
         
         self.__doThreadListUpdate = True
         
-        self.connect(self.__threadList, 
-                     SIGNAL('currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)'), 
-                     self.__threadSelected)
+        self.__threadList.currentItemChanged.connect(self.__threadSelected)
         
         self.__mainLayout.setStretchFactor(self.__tabWidget, 5)
         self.__mainLayout.setStretchFactor(self.__threadList, 1)
@@ -236,7 +275,7 @@ class DebugViewer(QWidget):
         self.currentStack = None
         self.framenr = 0
         
-        self.connect(self.debugServer, SIGNAL('clientStack'), self.handleClientStack)
+        self.debugServer.clientStack.connect(self.handleClientStack)
         
         self.__autoViewSource = Preferences.getDebugger("AutoViewSourceCode")
         self.sourceButton.setVisible(not self.__autoViewSource)
@@ -252,10 +291,11 @@ class DebugViewer(QWidget):
         """
         Public method to set a reference to the Debug UI.
         
-        @param debugUI reference to the DebugUI objectTrees
+        @param debugUI reference to the DebugUI object (DebugUI)
         """
         self.debugUI = debugUI
-        self.connect(self.debugUI, SIGNAL('clientStack'), self.handleClientStack)
+        self.debugUI.clientStack.connect(self.handleClientStack)
+        self.callStackViewer.setDebugger(debugUI)
         
     def handleResetUI(self):
         """
@@ -263,12 +303,12 @@ class DebugViewer(QWidget):
         """
         self.globalsViewer.handleResetUI()
         self.localsViewer.handleResetUI()
-        self.stackComboBox.clear()
         self.sourceButton.setEnabled(False)
         self.currentStack = None
+        self.stackComboBox.clear()
         self.__threadList.clear()
         if self.embeddedShell:
-            self.__tabWidget.setCurrentWidget(self.shell)
+            self.__tabWidget.setCurrentWidget(self.shellAssembly)
         else:
             if self.embeddedBrowser:
                 self.__tabWidget.setCurrentWidget(self.browser)
@@ -282,8 +322,42 @@ class DebugViewer(QWidget):
         """
         if self.embeddedShell:
             self.saveCurrentPage()
-            self.__tabWidget.setCurrentWidget(self.shell)
-            
+            self.__tabWidget.setCurrentWidget(self.shellAssembly)
+        
+    def initCallStackViewer(self, projectMode):
+        """
+        Public method to initialize the call stack viewer.
+        
+        @param projectMode flag indicating to enable the project mode (boolean)
+        """
+        self.callStackViewer.clear()
+        self.callStackViewer.setProjectMode(projectMode)
+        
+    def isCallTraceEnabled(self):
+        """
+        Public method to get the state of the call trace function.
+        
+        @return flag indicating the state of the call trace function (boolean)
+        """
+        return self.callTraceViewer.isCallTraceEnabled()
+        
+    def clearCallTrace(self):
+        """
+        Public method to clear the recorded call trace.
+        """
+        self.callTraceViewer.clear()
+        
+    def setCallTraceToProjectMode(self, enabled):
+        """
+        Public slot to set the call trace viewer to project mode.
+        
+        In project mode the call trace info is shown with project relative
+        path names.
+        
+        @param enabled flag indicating to enable the project mode (boolean)
+        """
+        self.callTraceViewer.setProjectMode(enabled)
+        
     def showVariables(self, vlist, globals):
         """
         Public method to show the variables in the respective window.
@@ -335,7 +409,11 @@ class DebugViewer(QWidget):
     def handleClientStack(self, stack):
         """
         Public slot to show the call stack of the program being debugged.
+        
+        @param stack list of tuples with call stack data (file name,
+            line number, function name, formatted argument/values list)
         """
+        block = self.stackComboBox.blockSignals(True)
         self.framenr = 0
         self.stackComboBox.clear()
         self.currentStack = stack
@@ -343,13 +421,15 @@ class DebugViewer(QWidget):
         for s in stack:
             # just show base filename to make it readable
             s = (os.path.basename(s[0]), s[1], s[2])
-            self.stackComboBox.addItem('%s:%s:%s' % s)
+            self.stackComboBox.addItem('{0}:{1}:{2}'.format(*s))
+        self.stackComboBox.blockSignals(block)
         
     def setVariablesFilter(self, globalsFilter, localsFilter):
         """
         Public slot to set the local variables filter.
         
-        @param globalsFilter filter list for global variable types (list of int)
+        @param globalsFilter filter list for global variable types
+            (list of int)
         @param localsFilter filter list for local variable types (list of int)
         """
         self.globalsFilter = globalsFilter
@@ -357,10 +437,13 @@ class DebugViewer(QWidget):
         
     def __showSource(self):
         """
-        Private slot to handle the source button press to show the selected file.
+        Private slot to handle the source button press to show the selected
+        file.
         """
-        s = self.currentStack[self.stackComboBox.currentIndex()]
-        self.emit(SIGNAL('sourceFile'), s[0], int(s[1]))
+        index = self.stackComboBox.currentIndex()
+        if index > -1 and self.currentStack:
+            s = self.currentStack[index]
+            self.sourceFile.emit(s[0], int(s[1]))
         
     def __frameSelected(self, frmnr):
         """
@@ -376,21 +459,22 @@ class DebugViewer(QWidget):
         
     def __setGlobalsFilter(self):
         """
-        Private slot to set the global variable filter
+        Private slot to set the global variable filter.
         """
-        filter = unicode(self.globalsFilterEdit.text())
+        filter = self.globalsFilterEdit.text()
         self.debugServer.remoteClientSetFilter(1, filter)
         if self.currentStack:
             self.debugServer.remoteClientVariables(2, self.globalsFilter)
         
     def __setLocalsFilter(self):
         """
-        Private slot to set the local variable filter
+        Private slot to set the local variable filter.
         """
-        filter = unicode(self.localsFilterEdit.text())
+        filter = self.localsFilterEdit.text()
         self.debugServer.remoteClientSetFilter(0, filter)
         if self.currentStack:
-            self.debugServer.remoteClientVariables(0, self.localsFilter, self.framenr)
+            self.debugServer.remoteClientVariables(
+                0, self.localsFilter, self.framenr)
         
     def handleDebuggingStarted(self):
         """
@@ -433,8 +517,9 @@ class DebugViewer(QWidget):
                 state = self.trUtf8("waiting at breakpoint")
             else:
                 state = self.trUtf8("running")
-            itm = QTreeWidgetItem(self.__threadList, 
-                                  ["%d" % thread['id'], thread['name'], state])
+            itm = QTreeWidgetItem(self.__threadList,
+                                  ["{0:d}".format(thread['id']),
+                                   thread['name'], state])
             if thread['id'] == currentID:
                 citm = itm
         
@@ -451,9 +536,19 @@ class DebugViewer(QWidget):
         Private slot to handle the selection of a thread in the thread list.
         
         @param current reference to the new current item (QTreeWidgetItem)
-        @param previous reference to the previous current item (QTreeWidgetItem)
+        @param previous reference to the previous current item
+            (QTreeWidgetItem)
         """
         if current is not None and self.__doThreadListUpdate:
-            tid, ok = current.text(0).toLong()
-            if ok:
-                self.debugServer.remoteSetThread(tid)
+            tid = int(current.text(0))
+            self.debugServer.remoteSetThread(tid)
+    
+    def __callStackFrameSelected(self, frameNo):
+        """
+        Private slot to handle the selection of a call stack entry of the
+        call stack viewer.
+        
+        @param frameNo frame number (index) of the selected entry (integer)
+        """
+        if frameNo >= 0:
+            self.stackComboBox.setCurrentIndex(frameNo)
