@@ -9,23 +9,23 @@ Module implementing a dialog to edit breakpoint properties.
 
 import os.path
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from Ui_EditBreakpointDialog import Ui_EditBreakpointDialog
+from .Ui_EditBreakpointDialog import Ui_EditBreakpointDialog
 
 import Utilities
 
+
 class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
     """
     Class implementing a dialog to edit breakpoint properties.
     """
-    def __init__(self, id, properties, condHistory, parent = None, name = None, 
-                 modal = False, addMode = False, filenameHistory = None):
+    def __init__(self, id, properties, condHistory, parent=None, name=None,
+                 modal=False, addMode=False, filenameHistory=None):
         """
         Constructor
         
@@ -33,19 +33,22 @@ class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
                 (filename, linenumber)
         @param properties properties for the breakpoint (tuple)
                 (condition, temporary flag, enabled flag, ignore count)
-        @param condHistory the list of conditionals history (QStringList)
-        @param parent the parent of this dialog
-        @param name the widget name of this dialog
-        @param modal flag indicating a modal dialog
+        @param condHistory the list of conditionals history (list of strings)
+        @param parent the parent of this dialog (QWidget)
+        @param name the widget name of this dialog (string)
+        @param modal flag indicating a modal dialog (boolean)
+        @param addMode flag indicating the add mode (boolean)
+        @param filenameHistory list of recently used file names
+            (list of strings)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         if name:
             self.setObjectName(name)
         self.setModal(modal)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
-        self.filenameCompleter = E4FileCompleter(self.filenameCombo)
+        self.filenameCompleter = E5FileCompleter(self.filenameCombo)
         
         fn, lineno = id
         
@@ -62,9 +65,10 @@ class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
             # set the condition
             if cond is None:
                 cond = ''
-            curr = condHistory.indexOf(cond)
-            if curr == -1:
-                condHistory.prepend(cond)
+            try:
+                curr = condHistory.index(cond)
+            except ValueError:
+                condHistory.insert(0, cond)
                 curr = 0
             self.conditionCombo.addItems(condHistory)
             self.conditionCombo.setCurrentIndex(curr)
@@ -84,47 +88,49 @@ class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
             self.setWindowTitle(self.trUtf8("Add Breakpoint"))
             # set the filename
             if fn is None:
-                fn = QString('')
-            curr = filenameHistory.indexOf(fn)
-            if curr == -1:
-                filenameHistory.prepend(fn)
+                fn = ""
+            try:
+                curr = filenameHistory.index(fn)
+            except ValueError:
+                filenameHistory.insert(0, fn)
                 curr = 0
             self.filenameCombo.addItems(filenameHistory)
             self.filenameCombo.setCurrentIndex(curr)
             
             # set the condition
             cond = ''
-            curr = condHistory.indexOf(cond)
-            if curr == -1:
-                condHistory.prepend(cond)
+            try:
+                curr = condHistory.index(cond)
+            except ValueError:
+                condHistory.insert(0, cond)
                 curr = 0
             self.conditionCombo.addItems(condHistory)
             self.conditionCombo.setCurrentIndex(curr)
             
-            if QString(fn).isEmpty():
+            if not fn:
                 self.okButton.setEnabled(False)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fileButton_clicked(self):
         """
         Private slot to select a file via a file selection dialog.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select filename of the breakpoint"),
             self.filenameCombo.currentText(),
-            QString())
+            "")
             
-        if not file.isNull():
+        if file:
             self.filenameCombo.setEditText(Utilities.toNativeSeparators(file))
         
     def on_filenameCombo_editTextChanged(self, fn):
         """
         Private slot to handle the change of the filename.
         
-        @param fn text of the filename edit (QString)
+        @param fn text of the filename edit (string)
         """
-        if fn.isEmpty():
+        if not fn:
             self.okButton.setEnabled(False)
         else:
             self.okButton.setEnabled(True)
@@ -136,7 +142,7 @@ class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
         @return a tuple containing the breakpoints new properties
             (condition, temporary flag, enabled flag, ignore count)
         """
-        return (self.conditionCombo.currentText(), 
+        return (self.conditionCombo.currentText(),
                 self.temporaryCheckBox.isChecked(),
                 self.enabledCheckBox.isChecked(), self.ignoreSpinBox.value())
         
@@ -145,15 +151,17 @@ class EditBreakpointDialog(QDialog, Ui_EditBreakpointDialog):
         Public method to retrieve the entered data for an add.
         
         @return a tuple containing the new breakpoints properties
-            (filename, lineno, condition, temporary flag, enabled flag, ignore count)
+            (filename, lineno, condition, temporary flag, enabled flag,
+            ignore count)
         """
         fn = self.filenameCombo.currentText()
-        if fn.isEmpty():
-            fn  =  None
+        if not fn:
+            fn = None
         else:
-            fn = os.path.expanduser(os.path.expandvars(unicode(fn)))
+            fn = os.path.expanduser(os.path.expandvars(fn))
         
-        return (fn, self.linenoSpinBox.value(), 
+        return (fn, self.linenoSpinBox.value(),
                 self.conditionCombo.currentText(),
-                self.temporaryCheckBox.isChecked(), self.enabledCheckBox.isChecked(),
+                self.temporaryCheckBox.isChecked(),
+                self.enabledCheckBox.isChecked(),
                 self.ignoreSpinBox.value())
