@@ -7,27 +7,27 @@
 Module implementing a dialog to edit watch expression properties.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from Ui_EditWatchpointDialog import Ui_EditWatchpointDialog
+from .Ui_EditWatchpointDialog import Ui_EditWatchpointDialog
 
 
 class EditWatchpointDialog(QDialog, Ui_EditWatchpointDialog):
     """
     Class implementing a dialog to edit watch expression properties.
     """
-    def __init__(self, properties, parent = None, name = None, modal = False):
+    def __init__(self, properties, parent=None, name=None, modal=False):
         """
         Constructor
         
         @param properties properties for the watch expression (tuple)
-            (expression, temporary flag, enabled flag, ignore count, special condition)
+            (expression, temporary flag, enabled flag, ignore count,
+            special condition)
         @param parent the parent of this dialog
         @param name the widget name of this dialog
         @param modal flag indicating a modal dialog
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         if name:
             self.setObjectName(name)
@@ -36,15 +36,13 @@ class EditWatchpointDialog(QDialog, Ui_EditWatchpointDialog):
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
         
         # connect our widgets
-        self.connect(self.conditionEdit, SIGNAL("textChanged(const QString &)"),
-            self.__textChanged)
-        self.connect(self.specialEdit, SIGNAL("textChanged(const QString &)"),
-            self.__textChanged)
+        self.conditionEdit.textChanged.connect(self.__textChanged)
+        self.specialEdit.textChanged.connect(self.__textChanged)
         
         cond, temp, enabled, count, special = properties
         
         # set the condition
-        if special.isEmpty():
+        if not special:
             self.conditionButton.setChecked(True)
             self.conditionEdit.setText(cond)
         else:
@@ -62,47 +60,48 @@ class EditWatchpointDialog(QDialog, Ui_EditWatchpointDialog):
         self.temporaryCheckBox.setChecked(temp)
         self.enabledCheckBox.setChecked(enabled)
         
-        if special.isEmpty():
+        if not special:
             self.conditionEdit.setFocus()
         else:
             self.specialEdit.setFocus()
         
     def __textChanged(self, txt):
         """
-        Private slot to handle the text changed signal of the condition line edit.
+        Private slot to handle the text changed signal of the condition line
+        edit.
         
-        @param txt text of the line edit (QString)
+        @param txt text of the line edit (string)
         """
         if self.conditionButton.isChecked():
             self.buttonBox.button(QDialogButtonBox.Ok)\
-                .setEnabled(not self.conditionEdit.text().isEmpty())
+                .setEnabled(self.conditionEdit.text() != "")
         elif self.specialButton.isChecked():
             self.buttonBox.button(QDialogButtonBox.Ok)\
-                .setEnabled(not self.specialEdit.text().isEmpty())
+                .setEnabled(self.specialEdit.text() != "")
         else:
             # should not happen
             self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
         
-        
     def getData(self):
         """
         Public method to retrieve the entered data.
         
         @return a tuple containing the watch expressions new properties
-            (expression, temporary flag, enabled flag, ignore count, special condition)
+            (expression, temporary flag, enabled flag, ignore count,
+            special condition)
         """
         if self.conditionButton.isChecked():
-            return (self.conditionEdit.text(), 
+            return (self.conditionEdit.text(),
                     self.temporaryCheckBox.isChecked(),
-                    self.enabledCheckBox.isChecked(), 
+                    self.enabledCheckBox.isChecked(),
                     self.ignoreSpinBox.value(),
-                    QString(""))
+                    "")
         elif self.specialButton.isChecked():
-            return (self.specialEdit.text(), 
+            return (self.specialEdit.text(),
                     self.temporaryCheckBox.isChecked(),
-                    self.enabledCheckBox.isChecked(), 
+                    self.enabledCheckBox.isChecked(),
                     self.ignoreSpinBox.value(),
                     self.specialCombo.currentText())
         else:
             # should not happen
-            return (QString(""), False, False,  0, QString(""))
+            return ("", False, False, 0, "")
