@@ -7,10 +7,11 @@
 Module implementing the exceptions filter dialog.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
+
+from .Ui_ExceptionsFilterDialog import Ui_ExceptionsFilterDialog
 
-from Ui_ExceptionsFilterDialog import Ui_ExceptionsFilterDialog
 
 class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
     """
@@ -20,11 +21,11 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         """
         Constructor
         
-        @param excList list of exceptions to be edited (QStringList)
+        @param excList list of exceptions to be edited (list of strings)
         @param ignore flag indicating the ignore exceptions mode (boolean)
         @param parent the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         self.setModal(True)
         
@@ -32,18 +33,20 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         
         if ignore:
             self.setWindowTitle(self.trUtf8("Ignored Exceptions"))
-            self.exceptionList.setToolTip(self.trUtf8("List of ignored exceptions"))
+            self.exceptionList.setToolTip(
+                self.trUtf8("List of ignored exceptions"))
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_exceptionList_itemSelectionChanged(self):
         """
         Private slot to handle the change of the selection.
         """
-        self.deleteButton.setEnabled(len(self.exceptionList.selectedItems()) > 0)
+        self.deleteButton.setEnabled(
+            len(self.exceptionList.selectedItems()) > 0)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteButton_clicked(self):
         """
         Private slot to delete the currently selected exception of the listbox.
@@ -51,7 +54,7 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         itm = self.exceptionList.takeItem(self.exceptionList.currentRow())
         del itm
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteAllButton_clicked(self):
         """
         Private slot to delete all exceptions of the listbox.
@@ -60,13 +63,13 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
             itm = self.exceptionList.takeItem(0)
             del itm
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to handle the Add button press.
         """
         exception = self.exceptionEdit.text()
-        if not exception.isEmpty():
+        if exception:
             self.exceptionList.addItem(exception)
             self.exceptionEdit.clear()
         
@@ -77,9 +80,9 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         This slot sets the enabled status of the add button and sets the forms
         default button.
         
-        @param txt the text entered into exceptionEdit (QString)
+        @param txt the text entered into exceptionEdit (string)
         """
-        if txt.isEmpty():
+        if not txt:
             self.okButton.setDefault(True)
             self.addButton.setDefault(False)
             self.addButton.setEnabled(False)
@@ -94,7 +97,7 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         
         @return list of exception types (list of strings)
         """
-        excList = QStringList()
+        excList = []
         for row in range(0, self.exceptionList.count()):
             itm = self.exceptionList.item(row)
             excList.append(itm.text())
