@@ -7,10 +7,10 @@
 Module implementing the variable detail dialog.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog
+
+from .Ui_VariableDetailDialog import Ui_VariableDetailDialog
 
-from Ui_VariableDetailDialog import Ui_VariableDetailDialog
 
 class VariableDetailDialog(QDialog, Ui_VariableDetailDialog):
     """
@@ -24,11 +24,11 @@ class VariableDetailDialog(QDialog, Ui_VariableDetailDialog):
         """
         Constructor
         
-        @param var the variables name (string or QString)
-        @param vtype the variables type (string or QString)
-        @param value the variables value (string or QString)
+        @param var the variables name (string)
+        @param vtype the variables type (string)
+        @param value the variables value (string)
         """
-        QDialog.__init__(self)
+        super().__init__()
         self.setupUi(self)
         
         # set the different fields
