@@ -7,13 +7,12 @@
 Module implementing the variables filter dialog.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
 from Debugger.Config import ConfigVarTypeDispStrings
 import Preferences
 
-from Ui_VariablesFilterDialog import Ui_VariablesFilterDialog
+from .Ui_VariablesFilterDialog import Ui_VariablesFilterDialog
 
 
 class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
@@ -23,21 +22,21 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
     It opens a dialog window for the configuration of the variables type
     filter to be applied during a debugging session.
     """
-    def __init__(self, parent = None, name = None, modal = False):
+    def __init__(self, parent=None, name=None, modal=False):
         """
         Constructor
         
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
         @param modal flag to indicate a modal dialog (boolean)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setModal(modal)
         self.setupUi(self)
 
-        self.defaultButton = self.buttonBox.addButton(\
+        self.defaultButton = self.buttonBox.addButton(
             self.trUtf8("Save Default"), QDialogButtonBox.ActionRole)
         
         lDefaultFilter, gDefaultFilter = Preferences.getVarFilters()
@@ -58,8 +57,8 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
         """
         Public slot to retrieve the current selections.
         
-        @return A tuple of lists of integer values. The first list is the locals variables
-            filter, the second the globals variables filter.
+        @return A tuple of lists of integer values. The first list is the
+            locals variables filter, the second the globals variables filter.
         """
         lList = []
         gList = []
@@ -75,7 +74,7 @@ class VariablesFilterDialog(QDialog, Ui_VariablesFilterDialog):
         
     def setSelection(self, lList, gList):
         """
-        Public slot to set the current selection. 
+        Public slot to set the current selection.
         
         @param lList local variables filter (list of int)
         @param gList global variables filter (list of int)
