@@ -7,20 +7,19 @@
 Module implementing the variables viewer widget.
 """
 
-import types
-from math import log10
-import sys
+from PyQt4.QtCore import Qt, QRegExp, qVersion
+from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem, QApplication, \
+    QAbstractItemView, QMenu
+from PyQt4.QtGui import QTextDocument   # __IGNORE_WARNING__
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from E5Gui.E5Application import e5App
 
-from KdeQt.KQApplication import e4App
-
-from Config import ConfigVarTypeDispStrings, ConfigVarTypeStrings
-from VariableDetailDialog import VariableDetailDialog
-from Utilities import toUnicode
+from DebugClients.Python3.DebugConfig import ConfigVarTypeStrings
+    
+from .Config import ConfigVarTypeDispStrings
 
 import Preferences
+import Utilities
 
 
 class VariableItem(QTreeWidgetItem):
@@ -32,36 +31,36 @@ class VariableItem(QTreeWidgetItem):
         Constructor.
         
         @param parent reference to the parent item
-        @param dvar variable name (string or QString)
-        @param dvalue value string (string or QString)
-        @param dtype type string (string or QString)
+        @param dvar variable name (string)
+        @param dvalue value string (string)
+        @param dtype type string (string)
         """
-        self.__value = QString(dvalue)
+        self.__value = dvalue
         if len(dvalue) > 2048:     # 1024 * 2
-            dvalue = QApplication.translate("VariableItem", 
+            dvalue = QApplication.translate("VariableItem",
                                             "<double click to show value>")
-            self.__tooltip = QString(dvalue)
+            self.__tooltip = dvalue
         else:
             if Qt.mightBeRichText(dvalue):
-                self.__tooltip = Qt.escape(dvalue)
+                self.__tooltip = Utilities.html_encode(dvalue)
             else:
                 self.__tooltip = dvalue
-            lines = QString(dvalue).split(QRegExp(r"\r\n|\r|\n"))
+            lines = dvalue.splitlines()
             if len(lines) > 1:
                 # only show the first non-empty line;
                 # indicate skipped lines by <...> at the
                 # beginning and/or end
                 index = 0
-                while index < len(lines) - 1 and lines[index].isEmpty():
+                while index < len(lines) - 1 and lines[index] == "":
                     index += 1
-                dvalue = QString("")
+                dvalue = ""
                 if index > 0:
-                    dvalue += QString("<...>")
+                    dvalue += "<...>"
                 dvalue += lines[index]
                 if index < len(lines) - 1:
-                    dvalue += QString("<...>")
+                    dvalue += "<...>"
         
-        QTreeWidgetItem.__init__(self, parent, QStringList() << dvar << dvalue << dtype)
+        super().__init__(parent, [dvar, dvalue, dtype])
         
         self.populated = True
         
@@ -69,7 +68,7 @@ class VariableItem(QTreeWidgetItem):
         """
         Public method to return the value of the item.
         
-        @return value of the item (QString)
+        @return value of the item (string)
         """
         return self.__value
         
@@ -77,22 +76,22 @@ class VariableItem(QTreeWidgetItem):
         """
         Public method to return the data for the requested role.
         
-        This implementation changes the original behavior in a way, that the display
-        data is returned as the tooltip for column 1.
+        This implementation changes the original behavior in a way, that the
+        display data is returned as the tooltip for column 1.
         
         @param column column number (integer)
         @param role data role (Qt.ItemDataRole)
-        @return requested data (QVariant)
+        @return requested data
         """
         if column == 1 and role == Qt.ToolTipRole:
             return self.__tooltip
-        return QTreeWidgetItem.data(self, column, role)
+        return super().data(column, role)
         
     def attachDummy(self):
         """
         Public method to attach a dummy sub item to allow for lazy population.
         """
-        QTreeWidgetItem(self, QStringList("DUMMY"))
+        QTreeWidgetItem(self, ["DUMMY"])
         
     def deleteChildren(self):
         """
@@ -106,6 +105,7 @@ class VariableItem(QTreeWidgetItem):
         Public method generating the key for this item.
         
         @param column the column to sort on (integer)
+        @return text of the column (string)
         """
         return self.text(column)
         
@@ -135,11 +135,12 @@ class VariableItem(QTreeWidgetItem):
         """
         return
 
+
 class SpecialVarItem(VariableItem):
     """
     Class implementing a VariableItem that represents a special variable node.
     
-    These special variable nodes are generated for classes, lists, 
+    These special variable nodes are generated for classes, lists,
     tuples and dictionaries.
     """
     def __init__(self, parent, dvar, dvalue, dtype, frmnr, scope):
@@ -147,9 +148,9 @@ class SpecialVarItem(VariableItem):
         Constructor
         
         @param parent parent of this item
-        @param dvar variable name (string or QString)
-        @param dvalue value string (string or QString)
-        @param dtype type string (string or QString)
+        @param dvar variable name (string)
+        @param dvalue value string (string)
+        @param dtype type string (string)
         @param frmnr frame number (0 is the current frame) (int)
         @param scope flag indicating global (1) or local (0) variables
         """
@@ -167,19 +168,20 @@ class SpecialVarItem(VariableItem):
         self.deleteChildren()
         self.populated = True
         
-        pathlist = [str(self.text(0))]
+        pathlist = [self.text(0)]
         par = self.parent()
         
         # step 1: get a pathlist up to the requested variable
         while par is not None:
-            pathlist.insert(0, str(par.text(0)))
+            pathlist.insert(0, par.text(0))
             par = par.parent()
         
         # step 2: request the variable from the debugger
-        filter = e4App().getObject("DebugUI").variablesFilter(self.scope)
-        e4App().getObject("DebugServer").remoteClientVariable(\
+        filter = e5App().getObject("DebugUI").variablesFilter(self.scope)
+        e5App().getObject("DebugServer").remoteClientVariable(
             self.scope, filter, pathlist, self.framenr)
 
+
 class ArrayElementVarItem(VariableItem):
     """
     Class implementing a VariableItem that represents an array element.
@@ -189,76 +191,82 @@ class ArrayElementVarItem(VariableItem):
         Constructor
         
         @param parent parent of this item
-        @param dvar variable name (string or QString)
-        @param dvalue value string (string or QString)
-        @param dtype type string (string or QString)
+        @param dvar variable name (string)
+        @param dvalue value string (string)
+        @param dtype type string (string)
         """
         VariableItem.__init__(self, parent, dvar, dvalue, dtype)
         
         """
         Array elements have numbers as names, but the key must be
-        right justified and zero filled to 6 decimal places. Then 
-        element 2 will have a key of '000002' and appear before 
+        right justified and zero filled to 6 decimal places. Then
+        element 2 will have a key of '000002' and appear before
         element 10 with a key of '000010'
         """
-        keyStr = str(self.text(0))
-        self.arrayElementKey = QString("%.6d" % int(keyStr))
+        keyStr = self.text(0)
+        self.arrayElementKey = "{0:6d}".format(int(keyStr))
 
     def key(self, column):
         """
         Public method generating the key for this item.
         
         @param column the column to sort on (integer)
+        @return key of the item (string)
         """
         if column == 0:
             return self.arrayElementKey
         else:
             return VariableItem.key(self, column)
 
+
 class SpecialArrayElementVarItem(SpecialVarItem):
     """
-    Class implementing a QTreeWidgetItem that represents a special array variable node.
+    Class implementing a QTreeWidgetItem that represents a special array
+    variable node.
     """
     def __init__(self, parent, dvar, dvalue, dtype, frmnr, scope):
         """
         Constructor
         
         @param parent parent of this item
-        @param dvar variable name (string or QString)
-        @param dvalue value string (string or QString)
-        @param dtype type string (string or QString)
+        @param dvar variable name (string)
+        @param dvalue value string (string)
+        @param dtype type string (string)
         @param frmnr frame number (0 is the current frame) (int)
         @param scope flag indicating global (1) or local (0) variables
         """
-        SpecialVarItem.__init__(self, parent, dvar, dvalue, dtype, frmnr, scope)
+        SpecialVarItem.__init__(self, parent, dvar, dvalue, dtype, frmnr,
+                                scope)
         
         """
         Array elements have numbers as names, but the key must be
-        right justified and zero filled to 6 decimal places. Then 
-        element 2 will have a key of '000002' and appear before 
+        right justified and zero filled to 6 decimal places. Then
+        element 2 will have a key of '000002' and appear before
         element 10 with a key of '000010'
         """
-        keyStr = str(self.text(0))[:-2] # strip off [], () or {}
-        self.arrayElementKey = QString("%.6d" % int(keyStr))
+        keyStr = self.text(0)[:-2]  # strip off [], () or {}
+        self.arrayElementKey = "{0:6d}".format(int(keyStr))
 
     def key(self, column):
         """
         Public method generating the key for this item.
         
         @param column the column to sort on (integer)
+        @return key of the item (string)
         """
         if column == 0:
             return self.arrayElementKey
         else:
             return SpecialVarItem.key(self, column)
 
+
 class VariablesViewer(QTreeWidget):
     """
     Class implementing the variables viewer widget.
     
     This widget is used to display the variables of the program being
     debugged in a tree. Compound types will be shown with
-    their main entry first. Once the subtree has been expanded, the 
+    their main entry first. Once the subtree has been expanded, the
     individual entries will be shown. Double clicking an entry will
     popup a dialog showing the variables parameters in a more readable
     form. This is especially useful for lengthy strings.
@@ -273,15 +281,18 @@ class VariablesViewer(QTreeWidget):
         @param parent the parent (QWidget)
         @param scope flag indicating global (1) or local (0) variables
         """
-        QTreeWidget.__init__(self, parent)
+        super().__init__(parent)
         
-        self.indicators = {'list' : '[]', 'tuple' : '()', 'dict' : '{}', # Python types
-                           'Array' : '[]', 'Hash' : '{}'}                # Ruby types
+        self.indicators = {'list': '[]', 'tuple': '()', 'dict': '{}',
+                           # Python types
+                           'Array': '[]', 'Hash': '{}'}
+                           # Ruby types
         
         self.rx_class = QRegExp('<.*(instance|object) at 0x.*>')
         self.rx_class2 = QRegExp('class .*')
         self.rx_class3 = QRegExp('<class .* at 0x.*>')
-        self.dvar_rx_class1 = QRegExp(r'<.*(instance|object) at 0x.*>(\[\]|\{\}|\(\))')
+        self.dvar_rx_class1 = QRegExp(
+            r'<.*(instance|object) at 0x.*>(\[\]|\{\}|\(\))')
         self.dvar_rx_class2 = QRegExp(r'<class .* at 0x.*>(\[\]|\{\}|\(\))')
         self.dvar_rx_array_element = QRegExp(r'^\d+$')
         self.dvar_rx_special_array_element = QRegExp(r'^\d+(\[\]|\{\}|\(\))$')
@@ -300,10 +311,10 @@ class VariablesViewer(QTreeWidget):
         self.scope = scope
         if scope:
             self.setWindowTitle(self.trUtf8("Global Variables"))
-            self.setHeaderLabels(QStringList() << \
-                self.trUtf8("Globals") << \
-                self.trUtf8("Value") << \
-                self.trUtf8("Type"))
+            self.setHeaderLabels([
+                self.trUtf8("Globals"),
+                self.trUtf8("Value"),
+                self.trUtf8("Type")])
             self.setWhatsThis(self.trUtf8(
                 """<b>The Global Variables Viewer Window</b>"""
                 """<p>This window displays the global variables"""
@@ -311,10 +322,10 @@ class VariablesViewer(QTreeWidget):
             ))
         else:
             self.setWindowTitle(self.trUtf8("Local Variables"))
-            self.setHeaderLabels(QStringList() << \
-                self.trUtf8("Locals") << \
-                self.trUtf8("Value") << \
-                self.trUtf8("Type"))
+            self.setHeaderLabels([
+                self.trUtf8("Locals"),
+                self.trUtf8("Value"),
+                self.trUtf8("Type")])
             self.setWhatsThis(self.trUtf8(
                 """<b>The Local Variables Viewer Window</b>"""
                 """<p>This window displays the local variables"""
@@ -324,19 +335,19 @@ class VariablesViewer(QTreeWidget):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        header.setClickable(True)
+        if qVersion() >= "5.0.0":
+            header.setSectionsClickable(True)
+        else:
+            header.setClickable(True)
         header.resizeSection(0, 120)    # variable column
         header.resizeSection(1, 150)    # value column
         
         self.__createPopupMenus()
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self,SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.customContextMenuRequested.connect(self.__showContextMenu)
         
-        self.connect(self, SIGNAL("itemExpanded(QTreeWidgetItem *)"), 
-            self.__expandItemSignal)
-        self.connect(self, SIGNAL("itemCollapsed(QTreeWidgetItem *)"), 
-            self.collapseItem)
+        self.itemExpanded.connect(self.__expandItemSignal)
+        self.itemCollapsed.connect(self.collapseItem)
         
         self.resortEnabled = True
         
@@ -372,7 +383,7 @@ class VariablesViewer(QTreeWidget):
         that is a child of node. If node is None, a child of the
         QTreeWidget is searched.
         
-        @param slist searchlist (list of strings or QStrings)
+        @param slist searchlist (list of strings)
         @param column index of column to search in (int)
         @param node start point of the search
         @return the found item or None
@@ -387,7 +398,7 @@ class VariablesViewer(QTreeWidget):
                 itm = self.topLevelItem(index)
             else:
                 itm = node.child(index)
-            if QString.compare(itm.text(column), slist[0]) == 0:
+            if itm.text(column) == slist[0]:
                 if len(slist) > 1:
                     itm = self.__findItem(slist[1:], column, itm)
                 return itm
@@ -420,8 +431,7 @@ class VariablesViewer(QTreeWidget):
                 self.__addItem(None, vtype, var, value)
             
             # reexpand tree
-            openItems = self.openItems[:]
-            openItems.sort()
+            openItems = sorted(self.openItems[:])
             self.openItems = []
             for itemPath in openItems:
                 itm = self.__findItem(itemPath, 0)
@@ -445,9 +455,9 @@ class VariablesViewer(QTreeWidget):
         """
         Public method to show variables in a list.
         
-        @param vlist the list of subitems to be displayed. 
+        @param vlist the list of subitems to be displayed.
                 The first element gives the path of the
-                parent variable. Each other listentry is 
+                parent variable. Each other listentry is
                 a tuple of three values.
                 <ul>
                 <li>the variable name (string)</li>
@@ -462,16 +472,13 @@ class VariablesViewer(QTreeWidget):
             if self.current:
                 self.curpathlist = self.__buildTreePath(self.current)
         
-        subelementsAdded = False
         if vlist:
             itm = self.__findItem(vlist[0], 0)
             for var, vtype, value in vlist[1:]:
                 self.__addItem(itm, vtype, var, value)
-            subelementsAdded = True
 
         # reexpand tree
-        openItems = self.openItems[:]
-        openItems.sort()
+        openItems = sorted(self.openItems[:])
         self.openItems = []
         for itemPath in openItems:
             itm = self.__findItem(itemPath, 0)
@@ -490,76 +497,59 @@ class VariablesViewer(QTreeWidget):
                 self.setCurrentItem(citm)
                 self.setItemSelected(citm, True)
                 if self.__scrollToItem:
-                    self.scrollToItem(self.__scrollToItem, 
+                    self.scrollToItem(self.__scrollToItem,
                                       QAbstractItemView.PositionAtTop)
                 else:
                     self.scrollToItem(citm, QAbstractItemView.PositionAtTop)
                 self.current = None
         elif self.__scrollToItem:
-            self.scrollToItem(self.__scrollToItem, QAbstractItemView.PositionAtTop)
+            self.scrollToItem(self.__scrollToItem,
+                              QAbstractItemView.PositionAtTop)
         
         self.resortEnabled = resortEnabled
         self.__resort()
 
-    def __generateItem(self, parent, dvar, dvalue, dtype, isSpecial = False):
+    def __generateItem(self, parent, dvar, dvalue, dtype, isSpecial=False):
         """
         Private method used to generate a VariableItem.
         
         @param parent parent of the item to be generated
-        @param dvar variable name (string or QString)
-        @param dvalue value string (string or QString)
-        @param dtype type string (string or QString)
-        @param isSpecial flag indicating that a special node should be generated (boolean)
+        @param dvar variable name (string)
+        @param dvalue value string (string)
+        @param dtype type string (string)
+        @param isSpecial flag indicating that a special node should be
+            generated (boolean)
         @return The item that was generated (VariableItem).
         """
         if isSpecial and \
-           (self.dvar_rx_class1.exactMatch(dvar) or \
-            self.dvar_rx_class2.exactMatch(dvar)):
+           (self.dvar_rx_class1.exactMatch(dvar) or
+                self.dvar_rx_class2.exactMatch(dvar)):
             isSpecial = False
         
         if self.rx_class2.exactMatch(dtype):
-            return SpecialVarItem(parent, dvar, dvalue, dtype[7:-1], 
+            return SpecialVarItem(parent, dvar, dvalue, dtype[7:-1],
                                   self.framenr, self.scope)
         elif dtype != "void *" and \
-             (self.rx_class.exactMatch(dvalue) or \
-              self.rx_class3.exactMatch(dvalue) or \
-              isSpecial):
+            (self.rx_class.exactMatch(dvalue) or
+             self.rx_class3.exactMatch(dvalue) or
+             isSpecial):
             if self.dvar_rx_special_array_element.exactMatch(dvar):
-                return SpecialArrayElementVarItem(parent, dvar, dvalue, dtype, 
+                return SpecialArrayElementVarItem(parent, dvar, dvalue, dtype,
                                                   self.framenr, self.scope)
             else:
-                return SpecialVarItem(parent, dvar, dvalue, dtype, 
+                return SpecialVarItem(parent, dvar, dvalue, dtype,
                                       self.framenr, self.scope)
         else:
-            if isinstance(dvalue, str):
-                dvalue = QString.fromLocal8Bit( dvalue )
             if self.dvar_rx_array_element.exactMatch(dvar):
                 return ArrayElementVarItem(parent, dvar, dvalue, dtype)
             else:
                 return VariableItem(parent, dvar, dvalue, dtype)
         
-    def __unicode(self, s):
-        """
-        Private method to convert a string to unicode.
-        
-        @param s the string to be converted (string)
-        @return unicode representation of s (unicode object)
-        """
-        if type(s) is type(u""):
-            return s
-        try:
-            u = unicode(s, self.loc)
-        except TypeError:
-            u = str(s)
-        except UnicodeError:
-            u = toUnicode(s)
-        return u
-        
     def __addItem(self, parent, vtype, var, value):
         """
         Private method used to add an item to the list.
         
-        If the item is of a type with subelements (i.e. list, dictionary, 
+        If the item is of a type with subelements (i.e. list, dictionary,
         tuple), these subelements are added by calling this method recursively.
         
         @param parent the parent of the item to be added
@@ -573,14 +563,15 @@ class VariablesViewer(QTreeWidget):
         if parent is None:
             parent = self
         try:
-            dvar = '%s%s' % (var, self.indicators[vtype])
+            dvar = '{0}{1}'.format(var, self.indicators[vtype])
         except KeyError:
             dvar = var
         dvtype = self.__getDispType(vtype)
         
         if vtype in ['list', 'Array', 'tuple', 'dict', 'Hash']:
-            itm = self.__generateItem(parent, dvar, self.trUtf8("%1 items").arg(value), 
-                                    dvtype, True)
+            itm = self.__generateItem(parent, dvar,
+                                      self.trUtf8("{0} items").format(value),
+                                      dvtype, True)
         elif vtype in ['unicode', 'str']:
             if self.rx_nonprintable.indexIn(value) != -1:
                 sval = value
@@ -589,7 +580,7 @@ class VariablesViewer(QTreeWidget):
                     sval = eval(value)
                 except:
                     sval = value
-            itm = self.__generateItem(parent, dvar, self.__unicode(sval), dvtype)
+            itm = self.__generateItem(parent, dvar, str(sval), dvtype)
         
         else:
             itm = self.__generateItem(parent, dvar, value, dvtype)
@@ -602,26 +593,25 @@ class VariablesViewer(QTreeWidget):
         
         @param vtype the type, the display string should be looked up for
               (string)
-        @return displaystring (string or QString)
+        @return displaystring (string)
         """
         try:
             i = ConfigVarTypeStrings.index(vtype)
             dvtype = self.trUtf8(ConfigVarTypeDispStrings[i])
         except ValueError:
             if vtype == 'classobj':
-                dvtype = self.trUtf8(\
-                    ConfigVarTypeDispStrings[ConfigVarTypeStrings.index('instance')]\
-                )
+                dvtype = self.trUtf8(ConfigVarTypeDispStrings[
+                    ConfigVarTypeStrings.index('instance')])
             else:
                 dvtype = vtype
         return dvtype
 
     def mouseDoubleClickEvent(self, mouseEvent):
         """
-        Protected method of QAbstractItemView. 
+        Protected method of QAbstractItemView.
         
-        Reimplemented to disable expanding/collapsing
-        of items when double-clicking. Instead the double-clicked entry is opened.
+        Reimplemented to disable expanding/collapsing of items when
+        double-clicking. Instead the double-clicked entry is opened.
         
         @param mouseEvent the mouse event object (QMouseEvent)
         """
@@ -646,11 +636,11 @@ class VariablesViewer(QTreeWidget):
         
         val = itm.getValue()
         
-        if val.isEmpty():
+        if not val:
             return  # do not display anything, if the variable has no value
             
         vtype = itm.text(2)
-        name = unicode(itm.text(0))
+        name = itm.text(0)
         if name[-2:] in ['[]', '{}', '()']:
             name = name[:-2]
         
@@ -658,19 +648,20 @@ class VariablesViewer(QTreeWidget):
         nlist = [name]
         # build up the fully qualified name
         while par is not None:
-            pname = unicode(par.text(0))
+            pname = par.text(0)
             if pname[-2:] in ['[]', '{}', '()']:
                 if nlist[0].endswith("."):
-                    nlist[0] = '[%s].' % nlist[0][:-1]
+                    nlist[0] = '[{0}].'.format(nlist[0][:-1])
                 else:
-                    nlist[0] = '[%s]' % nlist[0]
+                    nlist[0] = '[{0}]'.format(nlist[0])
                 nlist.insert(0, pname[:-2])
             else:
-                nlist.insert(0, '%s.' % pname)
+                nlist.insert(0, '{0}.'.format(pname))
             par = par.parent()
             
         name = ''.join(nlist)
         # now show the dialog
+        from .VariableDetailDialog import VariableDetailDialog
         dlg = VariableDetailDialog(name, vtype, val)
         dlg.exec_()
     
@@ -681,13 +672,13 @@ class VariablesViewer(QTreeWidget):
         @param itm item to build the path for (QTreeWidgetItem)
         @return list of names denoting the path from the top (list of strings)
         """
-        name = unicode(itm.text(0))
+        name = itm.text(0)
         pathlist = [name]
         
         par = itm.parent()
         # build up a path from the top to the item
         while par is not None:
-            pname = unicode(par.text(0))
+            pname = par.text(0)
             pathlist.insert(0, pname)
             par = par.parent()
         
@@ -697,7 +688,8 @@ class VariablesViewer(QTreeWidget):
         """
         Private slot to handle the expanded signal.
         
-        @param parentItem reference to the item being expanded (QTreeWidgetItem)
+        @param parentItem reference to the item being expanded
+            (QTreeWidgetItem)
         """
         self.expandItem(parentItem)
         self.__scrollToItem = parentItem
@@ -706,7 +698,8 @@ class VariablesViewer(QTreeWidget):
         """
         Public slot to handle the expanded signal.
         
-        @param parentItem reference to the item being expanded (QTreeWidgetItem)
+        @param parentItem reference to the item being expanded
+            (QTreeWidgetItem)
         """
         pathlist = self.__buildTreePath(parentItem)
         self.openItems.append(pathlist)
@@ -717,13 +710,14 @@ class VariablesViewer(QTreeWidget):
             parentItem.expand()
             self.__resort()
         except AttributeError:
-            QTreeWidget.expandItem(self, parentItem)
+            super().expandItem(parentItem)
 
     def collapseItem(self, parentItem):
         """
         Public slot to handle the collapsed signal.
         
-        @param parentItem reference to the item being collapsed (QTreeWidgetItem)
+        @param parentItem reference to the item being collapsed
+            (QTreeWidgetItem)
         """
         pathlist = self.__buildTreePath(parentItem)
         self.openItems.remove(pathlist)
@@ -731,14 +725,15 @@ class VariablesViewer(QTreeWidget):
         try:
             parentItem.collapse()
         except AttributeError:
-            QTreeWidget.collapseItem(self, parentItem)
+            super().collapseItem(parentItem)
 
     def __resort(self):
         """
         Private method to resort the tree.
         """
         if self.resortEnabled:
-            self.sortItems(self.sortColumn(), self.header().sortIndicatorOrder())
+            self.sortItems(self.sortColumn(),
+                           self.header().sortIndicatorOrder())
     
     def handleResetUI(self):
         """
@@ -751,4 +746,5 @@ class VariablesViewer(QTreeWidget):
         """
         Private method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("debuggerGeneralPage")
+        e5App().getObject("UserInterface")\
+            .showPreferences("debuggerGeneralPage")
