@@ -7,47 +7,52 @@
 Module implementing the Watch expression model.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
+
 
 class WatchPointModel(QAbstractItemModel):
     """
     Class implementing a custom model for watch expressions.
     """
-    def __init__(self, parent = None):
+    dataAboutToBeChanged = pyqtSignal(QModelIndex, QModelIndex)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
-        @param reference to the parent widget (QObject)
+        @param parent reference to the parent widget (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.watchpoints = []
         self.header = [
-            QVariant(self.trUtf8("Condition")),
-            QVariant(self.trUtf8("Special")),
-            QVariant(self.trUtf8('Temporary')),
-            QVariant(self.trUtf8('Enabled')),
-            QVariant(self.trUtf8('Ignore Count')),
-        ]
-        self.alignments = [QVariant(Qt.Alignment(Qt.AlignLeft)),
-                           QVariant(Qt.Alignment(Qt.AlignLeft)),
-                           QVariant(Qt.Alignment(Qt.AlignHCenter)),
-                           QVariant(Qt.Alignment(Qt.AlignHCenter)),
-                           QVariant(Qt.Alignment(Qt.AlignRight)),
+            self.trUtf8("Condition"),
+            self.trUtf8("Special"),
+            self.trUtf8('Temporary'),
+            self.trUtf8('Enabled'),
+            self.trUtf8('Ignore Count'),
         ]
+        self.alignments = [Qt.Alignment(Qt.AlignLeft),
+                           Qt.Alignment(Qt.AlignLeft),
+                           Qt.Alignment(Qt.AlignHCenter),
+                           Qt.Alignment(Qt.AlignHCenter),
+                           Qt.Alignment(Qt.AlignRight),
+                           ]
         
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the current column count.
         
+        @param parent index of the parent item (QModelIndex)
         @return column count (integer)
         """
-        return len(self.header) + 1
+        return len(self.header)
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to get the current row count.
         
+        @param parent index of the parent item (QModelIndex)
         @return row count (integer)
         """
         # we do not have a tree, parent should always be invalid
@@ -62,20 +67,28 @@ class WatchPointModel(QAbstractItemModel):
         
         @param index index of the requested data (QModelIndex)
         @param role role of the requested data (Qt.ItemDataRole)
-        @return the requested data (QVariant)
+        @return the requested data
         """
         if not index.isValid():
-            return QVariant()
+            return None
         
-        if role == Qt.DisplayRole or role == Qt.ToolTipRole:
-            if index.column() < len(self.header):
-                return QVariant(self.watchpoints[index.row()][index.column()])
+        if role == Qt.DisplayRole:
+            if index.column() in [0, 1, 4]:
+                return self.watchpoints[index.row()][index.column()]
+        
+        if role == Qt.CheckStateRole:
+            if index.column() in [2, 3]:
+                return self.watchpoints[index.row()][index.column()]
+        
+        if role == Qt.ToolTipRole:
+            if index.column() in [0, 1]:
+                return self.watchpoints[index.row()][index.column()]
         
         if role == Qt.TextAlignmentRole:
             if index.column() < len(self.alignments):
                 return self.alignments[index.column()]
         
-        return QVariant()
+        return None
     
     def flags(self, index):
         """
@@ -89,24 +102,24 @@ class WatchPointModel(QAbstractItemModel):
         
         return Qt.ItemIsEnabled | Qt.ItemIsSelectable
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get header data.
         
         @param section section number of the requested header data (integer)
         @param orientation orientation of the header (Qt.Orientation)
         @param role role of the requested data (Qt.ItemDataRole)
-        @return header data (QVariant)
+        @return header data
         """
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             if section >= len(self.header):
-                return QVariant("")
+                return ""
             else:
                 return self.header[section]
         
-        return QVariant()
+        return None
     
-    def index(self, row, column, parent = QModelIndex()):
+    def index(self, row, column, parent=QModelIndex()):
         """
         Public method to create an index.
         
@@ -131,7 +144,7 @@ class WatchPointModel(QAbstractItemModel):
         """
         return QModelIndex()
     
-    def hasChildren(self, parent = QModelIndex()):
+    def hasChildren(self, parent=QModelIndex()):
         """
         Public method to check for the presence of child items.
         
@@ -143,18 +156,19 @@ class WatchPointModel(QAbstractItemModel):
         else:
             return False
     
-    ############################################################################
+    ###########################################################################
     
     def addWatchPoint(self, cond, special, properties):
         """
         Public method to add a new watch expression to the list.
         
-        @param cond expression of the watch expression (string or QString)
-        @param special special condition of the watch expression (string or QString)
+        @param cond expression of the watch expression (string)
+        @param special special condition of the watch expression (string)
         @param properties properties of the watch expression
-            (tuple of temporary flag (bool), enabled flag (bool), ignore count (integer))
+            (tuple of temporary flag (bool), enabled flag (bool),
+            ignore count (integer))
         """
-        wp = [unicode(cond), unicode(special)] + list(properties)
+        wp = [cond, special] + list(properties)
         cnt = len(self.watchpoints)
         self.beginInsertRows(QModelIndex(), cnt, cnt)
         self.watchpoints.append(wp)
@@ -165,29 +179,28 @@ class WatchPointModel(QAbstractItemModel):
         Public method to set the values of a watch expression given by index.
         
         @param index index of the watch expression (QModelIndex)
-        @param cond expression of the watch expression (string or QString)
-        @param special special condition of the watch expression (string or QString)
+        @param cond expression of the watch expression (string)
+        @param special special condition of the watch expression (string)
         @param properties properties of the watch expression
-            (tuple of temporary flag (bool), enabled flag (bool), ignore count (integer))
+            (tuple of temporary flag (bool), enabled flag (bool),
+            ignore count (integer))
         """
         if index.isValid():
             row = index.row()
             index1 = self.createIndex(row, 0, self.watchpoints[row])
-            index2 = self.createIndex(row, len(self.watchpoints[row]), 
-                     self.watchpoints[row])
-            self.emit(\
-                SIGNAL("dataAboutToBeChanged(const QModelIndex &, const QModelIndex &)"),
-                index1, index2)
+            index2 = self.createIndex(
+                row, len(self.watchpoints[row]), self.watchpoints[row])
+            self.dataAboutToBeChanged.emit(index1, index2)
             i = 0
-            for value in [unicode(cond), unicode(special)] + list(properties):
+            for value in [cond, special] + list(properties):
                 self.watchpoints[row][i] = value
                 i += 1
-            self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                      index1, index2)
+            self.dataChanged.emit(index1, index2)
 
     def setWatchPointEnabledByIndex(self, index, enabled):
         """
-        Public method to set the enabled state of a watch expression given by index.
+        Public method to set the enabled state of a watch expression given by
+        index.
         
         @param index index of the watch expression (QModelIndex)
         @param enabled flag giving the enabled state (boolean)
@@ -196,12 +209,9 @@ class WatchPointModel(QAbstractItemModel):
             row = index.row()
             col = 3
             index1 = self.createIndex(row, col, self.watchpoints[row])
-            self.emit(\
-                SIGNAL("dataAboutToBeChanged(const QModelIndex &, const QModelIndex &)"),
-                index1, index1)
+            self.dataAboutToBeChanged.emit(index1, index1)
             self.watchpoints[row][col] = enabled
-            self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                      index1, index1)
+            self.dataChanged.emit(index1, index1)
     
     def deleteWatchPointByIndex(self, index):
         """
@@ -217,7 +227,8 @@ class WatchPointModel(QAbstractItemModel):
 
     def deleteWatchPoints(self, idxList):
         """
-        Public method to delete a list of watch expressions given by their indexes.
+        Public method to delete a list of watch expressions given by their
+        indexes.
         
         @param idxList list of watch expression indexes (list of QModelIndex)
         """
@@ -225,7 +236,7 @@ class WatchPointModel(QAbstractItemModel):
         for index in idxList:
             if index.isValid():
                 rows.append(index.row())
-        rows.sort(reverse = True)
+        rows.sort(reverse=True)
         for row in rows:
             self.beginRemoveRows(QModelIndex(), row, row)
             del self.watchpoints[row]
@@ -245,28 +256,28 @@ class WatchPointModel(QAbstractItemModel):
         Public method to get the values of a watch expression given by index.
         
         @param index index of the watch expression (QModelIndex)
-        @return watch expression (list of six values (expression, special condition,
-            temporary flag, enabled flag, ignore count, index))
+        @return watch expression (list of six values (expression,
+            special condition, temporary flag, enabled flag, ignore count,
+            index))
         """
         if index.isValid():
-            return self.watchpoints[index.row()][:] # return a copy
+            return self.watchpoints[index.row()][:]  # return a copy
         else:
             return []
 
-    def getWatchPointIndex(self, cond, special = ""):
+    def getWatchPointIndex(self, cond, special=""):
         """
-        Public method to get the index of a watch expression given by expression.
+        Public method to get the index of a watch expression given by
+        expression.
         
-        @param cond expression of the watch expression (string or QString)
-        @param special special condition of the watch expression (string or QString)
+        @param cond expression of the watch expression (string)
+        @param special special condition of the watch expression (string)
         @return index (QModelIndex)
         """
-        cond = unicode(cond)
-        special = unicode(special)
         for row in range(len(self.watchpoints)):
             wp = self.watchpoints[row]
-            if unicode(wp[0]) == cond:
-                if special and unicode(wp[1]) != special:
+            if wp[0] == cond:
+                if special and wp[1] != special:
                     continue
                 return self.createIndex(row, 0, self.watchpoints[row])
         
