@@ -7,30 +7,30 @@
 Module implementing the watch expression viewer widget.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt, QModelIndex, qVersion
+from PyQt4.QtGui import QTreeView, QAbstractItemView, QMenu, \
+    QSortFilterProxyModel, QHeaderView, QItemSelectionModel, QDialog
 
-from KdeQt import KQMessageBox
-from KdeQt.KQApplication import e4App
-
-from EditWatchpointDialog import EditWatchpointDialog
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox
 
 import Utilities
 
+
 class WatchPointViewer(QTreeView):
     """
     Class implementing the watch expression viewer widget.
     
-    Watch expressions will be shown with all their details. They can be modified through
-    the context menu of this widget.
+    Watch expressions will be shown with all their details. They can be
+    modified through the context menu of this widget.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent the parent (QWidget)
         """
-        QTreeView.__init__(self,parent)
+        super().__init__(parent)
         self.setObjectName("WatchExpressionViewer")
         
         self.__model = None
@@ -44,10 +44,8 @@ class WatchPointViewer(QTreeView):
         self.setWindowTitle(self.trUtf8("Watchpoints"))
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self,SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
-        self.connect(self,SIGNAL('doubleClicked(const QModelIndex &)'),
-                     self.__doubleClicked)
+        self.customContextMenuRequested.connect(self.__showContextMenu)
+        self.doubleClicked.connect(self.__doubleClicked)
         
         self.__createPopupMenus()
         
@@ -55,18 +53,22 @@ class WatchPointViewer(QTreeView):
         """
         Public slot to set the watch expression model.
         
-        @param reference to the watch expression model (WatchPointModel)
+        @param model reference to the watch expression model (WatchPointModel)
         """
         self.__model = model
         
         self.sortingModel = QSortFilterProxyModel()
+        self.sortingModel.setDynamicSortFilter(True)
         self.sortingModel.setSourceModel(self.__model)
-        QTreeView.setModel(self, self.sortingModel)
+        super().setModel(self.sortingModel)
         
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        header.setClickable(True)
+        if qVersion() >= "5.0.0":
+            header.setSectionsClickable(True)
+        else:
+            header.setClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -81,7 +83,8 @@ class WatchPointViewer(QTreeView):
         
     def __resizeColumns(self):
         """
-        Private slot to resize the view when items get added, edited or deleted.
+        Private slot to resize the view when items get added, edited or
+        deleted.
         """
         self.header().resizeSections(QHeaderView.ResizeToContents)
         self.header().setStretchLastSection(True)
@@ -90,7 +93,7 @@ class WatchPointViewer(QTreeView):
         """
         Private slot to resort the tree.
         """
-        self.model().sort(self.header().sortIndicatorSection(), 
+        self.model().sort(self.header().sortIndicatorSection(),
                           self.header().sortIndicatorOrder())
         
     def __toSourceIndex(self, index):
@@ -98,6 +101,7 @@ class WatchPointViewer(QTreeView):
         Private slot to convert an index to a source index.
         
         @param index index to be converted (QModelIndex)
+        @return mapped index (QModelIndex)
         """
         return self.sortingModel.mapToSource(index)
         
@@ -106,10 +110,11 @@ class WatchPointViewer(QTreeView):
         Private slot to convert a source index to an index.
         
         @param sindex source index to be converted (QModelIndex)
+        @return mapped index (QModelIndex)
         """
         return self.sortingModel.mapFromSource(sindex)
         
-    def __setRowSelected(self, index, selected = True):
+    def __setRowSelected(self, index, selected=True):
         """
         Private slot to select a complete row.
         
@@ -120,10 +125,10 @@ class WatchPointViewer(QTreeView):
             return
         
         if selected:
-            flags = QItemSelectionModel.SelectionFlags(\
+            flags = QItemSelectionModel.SelectionFlags(
                 QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
         else:
-            flags = QItemSelectionModel.SelectionFlags(\
+            flags = QItemSelectionModel.SelectionFlags(
                 QItemSelectionModel.Deselect | QItemSelectionModel.Rows)
         self.selectionModel().select(index, flags)
         
@@ -136,13 +141,16 @@ class WatchPointViewer(QTreeView):
         self.menu.addAction(self.trUtf8("Edit..."), self.__editWatchPoint)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Enable"), self.__enableWatchPoint)
-        self.menu.addAction(self.trUtf8("Enable all"), self.__enableAllWatchPoints)
+        self.menu.addAction(self.trUtf8("Enable all"),
+                            self.__enableAllWatchPoints)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Disable"), self.__disableWatchPoint)
-        self.menu.addAction(self.trUtf8("Disable all"), self.__disableAllWatchPoints)
+        self.menu.addAction(self.trUtf8("Disable all"),
+                            self.__disableAllWatchPoints)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Delete"), self.__deleteWatchPoint)
-        self.menu.addAction(self.trUtf8("Delete all"), self.__deleteAllWatchPoints)
+        self.menu.addAction(self.trUtf8("Delete all"),
+                            self.__deleteAllWatchPoints)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8("Configure..."), self.__configure)
 
@@ -150,32 +158,35 @@ class WatchPointViewer(QTreeView):
         self.backMenu = QMenu()
         self.backMenu.addAction(self.trUtf8("Add"), self.__addWatchPoint)
         self.backMenuActions["EnableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Enable all"), 
-                self.__enableAllWatchPoints)
+            self.backMenu.addAction(self.trUtf8("Enable all"),
+                                    self.__enableAllWatchPoints)
         self.backMenuActions["DisableAll"] = \
-            self.backMenu.addAction(self.trUtf8("Disable all"), 
-                self.__disableAllWatchPoints)
+            self.backMenu.addAction(self.trUtf8("Disable all"),
+                                    self.__disableAllWatchPoints)
         self.backMenuActions["DeleteAll"] = \
-            self.backMenu.addAction(self.trUtf8("Delete all"), 
-                self.__deleteAllWatchPoints)
+            self.backMenu.addAction(self.trUtf8("Delete all"),
+                                    self.__deleteAllWatchPoints)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
-        self.connect(self.backMenu, SIGNAL('aboutToShow()'), self.__showBackMenu)
+        self.backMenu.aboutToShow.connect(self.__showBackMenu)
 
         self.multiMenu = QMenu()
         self.multiMenu.addAction(self.trUtf8("Add"), self.__addWatchPoint)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Enable selected"), 
-            self.__enableSelectedWatchPoints)
-        self.multiMenu.addAction(self.trUtf8("Enable all"), self.__enableAllWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Enable selected"),
+                                 self.__enableSelectedWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Enable all"),
+                                 self.__enableAllWatchPoints)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Disable selected"), 
-            self.__disableSelectedWatchPoints)
-        self.multiMenu.addAction(self.trUtf8("Disable all"), self.__disableAllWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Disable selected"),
+                                 self.__disableSelectedWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Disable all"),
+                                 self.__disableAllWatchPoints)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8("Delete selected"), 
-            self.__deleteSelectedWatchPoints)
-        self.multiMenu.addAction(self.trUtf8("Delete all"), self.__deleteAllWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Delete selected"),
+                                 self.__deleteSelectedWatchPoints)
+        self.multiMenu.addAction(self.trUtf8("Delete all"),
+                                 self.__deleteAllWatchPoints)
         self.multiMenu.addSeparator()
         self.multiMenu.addAction(self.trUtf8("Configure..."), self.__configure)
     
@@ -205,54 +216,51 @@ class WatchPointViewer(QTreeView):
         """
         for index in self.selectedIndexes():
             self.__setRowSelected(index, False)
-            
-    def __findDuplicates(self, cond, special, showMessage = False, index = QModelIndex()):
+    
+    def __findDuplicates(self, cond, special, showMessage=False,
+                         index=QModelIndex()):
         """
         Private method to check, if an entry already exists.
         
-        @param cond condition to check (string or QString)
-        @param special special condition to check (string or QString)
+        @param cond condition to check (string)
+        @param special special condition to check (string)
         @param showMessage flag indicating a message should be shown,
             if a duplicate entry is found (boolean)
-        @param index index that should not be considered duplicate (QModelIndex)
+        @param index index that should not be considered duplicate
+            (QModelIndex)
         @return flag indicating a duplicate entry (boolean)
         """
-        cond = unicode(cond)
-        special = unicode(special)
         idx = self.__model.getWatchPointIndex(cond, special)
-        duplicate = idx.isValid() and idx.internalPointer() != index.internalPointer()
+        duplicate = idx.isValid() and \
+            idx.internalPointer() != index.internalPointer()
         if showMessage and duplicate:
             if not special:
-                msg = self.trUtf8("""<p>A watch expression '<b>%1</b>'"""
+                msg = self.trUtf8("""<p>A watch expression '<b>{0}</b>'"""
                                   """ already exists.</p>""")\
-                        .arg(Utilities.html_encode(unicode(cond)))
+                    .format(Utilities.html_encode(cond))
             else:
-                msg = self.trUtf8("""<p>A watch expression '<b>%1</b>'"""
-                                  """ for the variable <b>%2</b> already exists.</p>""")\
-                        .arg(special)\
-                        .arg(Utilities.html_encode(unicode(cond)))
-            KQMessageBox.warning(None,
+                msg = self.trUtf8(
+                    """<p>A watch expression '<b>{0}</b>'"""
+                    """ for the variable <b>{1}</b> already exists.</p>""")\
+                    .format(special, Utilities.html_encode(cond))
+            E5MessageBox.warning(
+                self,
                 self.trUtf8("Watch expression already exists"),
                 msg)
         
         return duplicate
     
-    def __clearSelection(self):
-        """
-        Private slot to clear the selection.
-        """
-        for index in self.selectedIndexes():
-            self.__setRowSelected(index, False)
-            
     def __addWatchPoint(self):
         """
         Private slot to handle the add watch expression context menu entry.
         """
-        dlg = EditWatchpointDialog((QString(""), False, True, 0, QString("")), self)
+        from .EditWatchpointDialog import EditWatchpointDialog
+        dlg = EditWatchpointDialog(("", False, True, 0, ""), self)
         if dlg.exec_() == QDialog.Accepted:
             cond, temp, enabled, ignorecount, special = dlg.getData()
             if not self.__findDuplicates(cond, special, True):
-                self.__model.addWatchPoint(cond, special, (temp, enabled, ignorecount))
+                self.__model.addWatchPoint(cond, special,
+                                           (temp, enabled, ignorecount))
                 self.__resizeColumns()
                 self.__resort()
 
@@ -287,13 +295,14 @@ class WatchPointViewer(QTreeView):
             
             cond, special, temp, enabled, count = wp[:5]
             
-            dlg = EditWatchpointDialog(\
-                (QString(cond), temp, enabled, count, QString(special)), self)
+            from .EditWatchpointDialog import EditWatchpointDialog
+            dlg = EditWatchpointDialog(
+                (cond, temp, enabled, count, special), self)
             if dlg.exec_() == QDialog.Accepted:
                 cond, temp, enabled, count, special = dlg.getData()
                 if not self.__findDuplicates(cond, special, True, sindex):
-                    self.__model.setWatchPointByIndex(sindex, 
-                        unicode(cond), unicode(special), (temp, enabled, count))
+                    self.__model.setWatchPointByIndex(
+                        sindex, cond, special, (temp, enabled, count))
                     self.__resizeColumns()
                     self.__resort()
 
@@ -301,7 +310,8 @@ class WatchPointViewer(QTreeView):
         """
         Private method to set the enabled status of a watch expression.
         
-        @param index index of watch expression to be enabled/disabled (QModelIndex)
+        @param index index of watch expression to be enabled/disabled
+            (QModelIndex)
         @param enabled flag indicating the enabled status to be set (boolean)
         """
         sindex = self.__toSourceIndex(index)
@@ -319,7 +329,8 @@ class WatchPointViewer(QTreeView):
 
     def __enableAllWatchPoints(self):
         """
-        Private slot to handle the enable all watch expressions context menu entry.
+        Private slot to handle the enable all watch expressions context menu
+        entry.
         """
         index = self.model().index(0, 0)
         while index.isValid():
@@ -330,7 +341,8 @@ class WatchPointViewer(QTreeView):
 
     def __enableSelectedWatchPoints(self):
         """
-        Private slot to handle the enable selected watch expressions context menu entry.
+        Private slot to handle the enable selected watch expressions context
+        menu entry.
         """
         for index in self.selectedIndexes():
             if index.column() == 0:
@@ -349,7 +361,8 @@ class WatchPointViewer(QTreeView):
 
     def __disableAllWatchPoints(self):
         """
-        Private slot to handle the disable all watch expressions context menu entry.
+        Private slot to handle the disable all watch expressions context menu
+        entry.
         """
         index = self.model().index(0, 0)
         while index.isValid():
@@ -360,7 +373,8 @@ class WatchPointViewer(QTreeView):
 
     def __disableSelectedWatchPoints(self):
         """
-        Private slot to handle the disable selected watch expressions context menu entry.
+        Private slot to handle the disable selected watch expressions context
+        menu entry.
         """
         for index in self.selectedIndexes():
             if index.column() == 0:
@@ -379,19 +393,20 @@ class WatchPointViewer(QTreeView):
         
     def __deleteAllWatchPoints(self):
         """
-        Private slot to handle the delete all watch expressions context menu entry.
+        Private slot to handle the delete all watch expressions context menu
+        entry.
         """
         self.__model.deleteAll()
 
     def __deleteSelectedWatchPoints(self):
         """
-        Private slot to handle the delete selected watch expressions context menu entry.
+        Private slot to handle the delete selected watch expressions context
+        menu entry.
         """
         idxList = []
         for index in self.selectedIndexes():
             sindex = self.__toSourceIndex(index)
             if sindex.isValid() and index.column() == 0:
-                lastrow = index.row()
                 idxList.append(sindex)
         self.__model.deleteWatchPoints(idxList)
 
@@ -414,7 +429,7 @@ class WatchPointViewer(QTreeView):
         
         @return count of items selected (integer)
         """
-        count = len(self.selectedIndexes()) / (self.__model.columnCount()-1)
+        count = len(self.selectedIndexes()) // (self.__model.columnCount() - 1)
         # column count is 1 greater than selectable
         return count
     
@@ -422,4 +437,5 @@ class WatchPointViewer(QTreeView):
         """
         Private method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("debuggerGeneralPage")
+        e5App().getObject("UserInterface")\
+            .showPreferences("debuggerGeneralPage")
