@@ -5,12 +5,8 @@
 
 """
 Module implementing the builtin API generator.
-
 """
 
-import sys
-
-from QScintilla.Editor import Editor
 
 class APIGenerator(object):
     """
@@ -26,32 +22,47 @@ class APIGenerator(object):
         
     def genAPI(self, newStyle, basePackage, includePrivate):
         """
-        Method to generate the source code documentation.
+        Public method to generate the API information.
         
-        @param newStyle flag indicating the api generation for QScintilla 1.7 and 
-            newer (boolean)
+        @param newStyle flag indicating the api generation for QScintilla 1.7
+            and newer (boolean) (ignored)
         @param basePackage name of the base package (string)
-        @param includePrivate flag indicating to include 
+        @param includePrivate flag indicating to include
             private methods/functions (boolean)
-        @return The API information. (string)
+        @return API information (list of strings)
         """
         self.includePrivate = includePrivate
-        self.newStyle = newStyle
-        if self.newStyle:
-            modulePath = self.module.name.split('.')
-            if modulePath[-1] == '__init__':
-                del modulePath[-1]
-            if basePackage:
-                modulePath[0] = basePackage
-            self.moduleName = "%s." % '.'.join(modulePath)
-        else:
-            self.moduleName = ""
+        modulePath = self.module.name.split('.')
+        if modulePath[-1] == '__init__':
+            del modulePath[-1]
+        if basePackage:
+            modulePath[0] = basePackage
+        self.moduleName = "{0}.".format('.'.join(modulePath))
         self.api = []
         self.__addGlobalsAPI()
         self.__addClassesAPI()
         self.__addFunctionsAPI()
         return self.api
         
+    def genBases(self, includePrivate):
+        """
+        Public method to generate the base classes information.
+        
+        @param includePrivate flag indicating to include private classes
+            (boolean)
+        @return base classes information (dictionary of list of strings)
+        """
+        bases = {}
+        self.includePrivate = includePrivate
+        classNames = sorted(list(self.module.classes.keys()))
+        for className in classNames:
+            if not self.__isPrivate(self.module.classes[className]):
+                if className not in bases:
+                    bases[className] = [
+                        b for b in self.module.classes[className].super
+                        if b != "object"]
+        return bases
+        
     def __isPrivate(self, obj):
         """
         Private method to check, if an object is considered private.
@@ -64,12 +75,11 @@ class APIGenerator(object):
         
     def __addGlobalsAPI(self):
         """
-        Private method to generate the api section for global variables. 
+        Private method to generate the api section for global variables.
         """
-        if self.newStyle:
-            moduleNameStr = "%s" % self.moduleName
-        else:
-            moduleNameStr = ""
+        from QScintilla.Editor import Editor
+        
+        moduleNameStr = "{0}".format(self.moduleName)
         
         for globalName in sorted(self.module.globals.keys()):
             if not self.__isPrivate(self.module.globals[globalName]):
@@ -79,14 +89,14 @@ class APIGenerator(object):
                     id = Editor.AttributeProtectedID
                 else:
                     id = Editor.AttributePrivateID
-                self.api.append("%s%s?%d" % (moduleNameStr, globalName, id))
+                self.api.append("{0}{1}?{2:d}".format(
+                    moduleNameStr, globalName, id))
         
     def __addClassesAPI(self):
         """
         Private method to generate the api section for classes.
         """
-        classNames = self.module.classes.keys()
-        classNames.sort()
+        classNames = sorted(list(self.module.classes.keys()))
         for className in classNames:
             if not self.__isPrivate(self.module.classes[className]):
                 self.__addClassVariablesAPI(className)
@@ -96,13 +106,12 @@ class APIGenerator(object):
         """
         Private method to generate the api section for class methods.
         
-        @param classname Name of the class containing the method. (string)
+        @param className name of the class containing the method (string)
         """
-        _class = self.module.classes[className]
-        methods = _class.methods.keys()
-        methods.sort()
+        from QScintilla.Editor import Editor
         
-        # first do the constructor
+        _class = self.module.classes[className]
+        methods = sorted(list(_class.methods.keys()))
         if '__init__' in methods:
             methods.remove('__init__')
             if _class.isPublic():
@@ -111,61 +120,64 @@ class APIGenerator(object):
                 id = Editor.ClassProtectedID
             else:
                 id = Editor.ClassPrivateID
-            self.api.append('%s%s?%d(%s)' % \
-                (self.moduleName, _class.name, id, 
-                 ', '.join(_class.methods['__init__'].parameters[1:])))
+            self.api.append(
+                '{0}{1}?{2:d}({3})'.format(
+                    self.moduleName, _class.name, id,
+                    ', '.join(_class.methods['__init__'].parameters[1:])))
             
-        if self.newStyle:
-            classNameStr = "%s%s." % (self.moduleName, className)
-        else:
-            classNameStr = ""
+        classNameStr = "{0}{1}.".format(self.moduleName, className)
         for method in methods:
-            if not self.__isPrivate(_class.methods[method]): 
+            if not self.__isPrivate(_class.methods[method]):
                 if _class.methods[method].isPublic():
                     id = Editor.MethodID
                 elif _class.methods[method].isProtected():
                     id = Editor.MethodProtectedID
                 else:
                     id = Editor.MethodPrivateID
-                self.api.append('%s%s?%d(%s)' % \
-                    (classNameStr, method, id, 
-                     ', '.join(_class.methods[method].parameters[1:])))
+                self.api.append(
+                    '{0}{1}?{2:d}({3})'.format(
+                        classNameStr, method, id,
+                        ', '.join(_class.methods[method].parameters[1:])))
         
     def __addClassVariablesAPI(self, className):
         """
         Private method to generate class api section for class variables.
         
-        @param classname Name of the class containing the class variables. (string)
+        @param className name of the class containing the class variables
+            (string)
         """
+        from QScintilla.Editor import Editor
+        
         _class = self.module.classes[className]
-        if self.newStyle:
-            classNameStr = "%s%s." % (self.moduleName, className)
-        else:
-            classNameStr = ""
+        classNameStr = "{0}{1}.".format(self.moduleName, className)
         for variable in sorted(_class.globals.keys()):
-            if not self.__isPrivate(_class.globals[variable]): 
+            if not self.__isPrivate(_class.globals[variable]):
                 if _class.globals[variable].isPublic():
                     id = Editor.AttributeID
                 elif _class.globals[variable].isProtected():
                     id = Editor.AttributeProtectedID
                 else:
                     id = Editor.AttributePrivateID
-                self.api.append('%s%s?%d' % (classNameStr, variable, id))
+                self.api.append('{0}{1}?{2:d}'.format(
+                    classNameStr, variable, id))
         
     def __addFunctionsAPI(self):
         """
         Private method to generate the api section for functions.
         """
-        funcNames = self.module.functions.keys()
-        funcNames.sort()
+        from QScintilla.Editor import Editor
+        
+        funcNames = sorted(list(self.module.functions.keys()))
         for funcName in funcNames:
-            if not self.__isPrivate(self.module.functions[funcName]): 
+            if not self.__isPrivate(self.module.functions[funcName]):
                 if self.module.functions[funcName].isPublic():
                     id = Editor.MethodID
                 elif self.module.functions[funcName].isProtected():
                     id = Editor.MethodProtectedID
                 else:
                     id = Editor.MethodPrivateID
-                self.api.append('%s%s?%d(%s)' % \
-                    (self.moduleName, self.module.functions[funcName].name, id, 
-                     ', '.join(self.module.functions[funcName].parameters)))
+                self.api.append(
+                    '{0}{1}?{2:d}({3})'.format(
+                        self.moduleName, self.module.functions[funcName].name,
+                        id,
+                        ', '.join(self.module.functions[funcName].parameters)))
