@@ -4,22 +4,22 @@
 #
 
 """
-Module implementing the index generator for the builtin documentation generator.
+Module implementing the index generator for the builtin documentation
+generator.
 """
 
 import sys
 import os
 
-import TemplatesListsStyle
-import TemplatesListsStyleCSS
-
 from Utilities import joinext
 
+
 class IndexGenerator(object):
     """
-    Class implementing the index generator for the builtin documentation generator.
+    Class implementing the index generator for the builtin documentation
+    generator.
     """
-    def __init__(self, outputDir, colors, stylesheet = None):
+    def __init__(self, outputDir, colors, stylesheet=None):
         """
         Constructor
         
@@ -30,10 +30,10 @@ class IndexGenerator(object):
         """
         self.outputDir = outputDir
         self.packages = {
-            "00index" : {
-                "description" : "",
-                "subpackages" : {},
-                "modules" : {}
+            "00index": {
+                "description": "",
+                "subpackages": {},
+                "modules": {}
             }
         }
         self.remembered = False
@@ -41,6 +41,7 @@ class IndexGenerator(object):
         self.stylesheet = stylesheet
         
         if self.stylesheet:
+            from . import TemplatesListsStyleCSS
             self.headerTemplate = TemplatesListsStyleCSS.headerTemplate
             self.footerTemplate = TemplatesListsStyleCSS.footerTemplate
             self.indexBodyTemplate = TemplatesListsStyleCSS.indexBodyTemplate
@@ -48,24 +49,29 @@ class IndexGenerator(object):
                 TemplatesListsStyleCSS.indexListPackagesTemplate
             self.indexListModulesTemplate = \
                 TemplatesListsStyleCSS.indexListModulesTemplate
-            self.indexListEntryTemplate = TemplatesListsStyleCSS.indexListEntryTemplate
-        else:
-            self.headerTemplate = TemplatesListsStyle.headerTemplate % colors
-            self.footerTemplate = TemplatesListsStyle.footerTemplate % colors
-            self.indexBodyTemplate = TemplatesListsStyle.indexBodyTemplate % colors
-            self.indexListPackagesTemplate = \
-                TemplatesListsStyle.indexListPackagesTemplate % colors
-            self.indexListModulesTemplate = \
-                TemplatesListsStyle.indexListModulesTemplate % colors
             self.indexListEntryTemplate = \
-                TemplatesListsStyle.indexListEntryTemplate % colors
+                TemplatesListsStyleCSS.indexListEntryTemplate
+        else:
+            from . import TemplatesListsStyle
+            self.headerTemplate = \
+                TemplatesListsStyle.headerTemplate.format(**colors)
+            self.footerTemplate = \
+                TemplatesListsStyle.footerTemplate.format(**colors)
+            self.indexBodyTemplate = \
+                TemplatesListsStyle.indexBodyTemplate.format(**colors)
+            self.indexListPackagesTemplate = \
+                TemplatesListsStyle.indexListPackagesTemplate.format(**colors)
+            self.indexListModulesTemplate = \
+                TemplatesListsStyle.indexListModulesTemplate.format(**colors)
+            self.indexListEntryTemplate = \
+                TemplatesListsStyle.indexListEntryTemplate.format(**colors)
         
     def remember(self, file, moduleDocument, basename=""):
         """
         Public method to remember a documentation file.
         
         @param file The filename to be remembered. (string)
-        @param moduleDocument The ModuleDocument object containing the 
+        @param moduleDocument The ModuleDocument object containing the
             information for the file.
         @param basename The basename of the file hierarchy to be documented.
             The basename is stripped off the filename if it starts with
@@ -78,7 +84,6 @@ class IndexGenerator(object):
         if "__init__" in file:
             dir = os.path.dirname(file)
             udir = os.path.dirname(dir)
-            base = os.path.basename(dir)
             if udir:
                 upackage = udir.replace(os.sep, ".")
                 try:
@@ -91,16 +96,15 @@ class IndexGenerator(object):
             elt["subpackages"][package] = moduleDocument.shortDescription()
                 
             self.packages[package] = {
-                "description" : moduleDocument.description(),
-                "subpackages" : {},
-                "modules" : {}
+                "description": moduleDocument.description(),
+                "subpackages": {},
+                "modules": {}
             }
             
             if moduleDocument.isEmpty():
                 return
-            
+        
         package = os.path.dirname(file).replace(os.sep, ".")
-        name = os.path.splitext(file)[0].replace(os.sep, ".")
         try:
             elt = self.packages[package]
         except KeyError:
@@ -108,19 +112,20 @@ class IndexGenerator(object):
         elt["modules"][moduleDocument.name()] = \
             moduleDocument.shortDescription()
     
-    def __writeIndex(self, packagename, package):
+    def __writeIndex(self, packagename, package, newline=None):
         """
         Private method to generate an index file for a package.
         
         @param packagename The name of the package. (string)
         @param package A dictionary with information about the package.
+        @param newline newline character to be used (string)
         @return The name of the generated index file.
         """
         if packagename == "00index":
             f = os.path.join(self.outputDir, "index")
             title = "Table of contents"
         else:
-            f = os.path.join(self.outputDir, "index-%s" % packagename)
+            f = os.path.join(self.outputDir, "index-{0}".format(packagename))
             title = packagename
         
         filename = joinext(f, ".html")
@@ -131,64 +136,62 @@ class IndexGenerator(object):
         # 1) subpackages
         if package["subpackages"]:
             subpacks = package["subpackages"]
-            names = subpacks.keys()
-            names.sort()
+            names = sorted(list(subpacks.keys()))
             lst = []
             for name in names:
-                link = joinext("index-%s" % name, ".html")
-                lst.append(self.indexListEntryTemplate % {
-                    "Description" : subpacks[name],
-                    "Name" : name.split(".")[-1],
-                    "Link" : link,
-                })
-            subpackages = self.indexListPackagesTemplate % {
-                "Entries" : "".join(lst),
-            }
+                link = joinext("index-{0}".format(name), ".html")
+                lst.append(self.indexListEntryTemplate.format(**{
+                    "Description": subpacks[name],
+                    "Name": name.split(".")[-1],
+                    "Link": link,
+                }))
+            subpackages = self.indexListPackagesTemplate.format(**{
+                "Entries": "".join(lst),
+            })
             
         # 2) modules
         if package["modules"]:
             mods = package["modules"]
-            names = mods.keys()
-            names.sort()
+            names = sorted(list(mods.keys()))
             lst = []
             for name in names:
                 link = joinext(name, ".html")
                 nam = name.split(".")[-1]
                 if nam == "__init__":
                     nam = name.split(".")[-2]
-                lst.append(self.indexListEntryTemplate % {
-                    "Description" : mods[name],
-                    "Name" : nam,
-                    "Link" : link,
-                })
-            modules = self.indexListModulesTemplate % {
-                "Entries" : "".join(lst),
-            }
+                lst.append(self.indexListEntryTemplate.format(**{
+                    "Description": mods[name],
+                    "Name": nam,
+                    "Link": link,
+                }))
+            modules = self.indexListModulesTemplate.format(**{
+                "Entries": "".join(lst),
+            })
             
-        doc = self.headerTemplate % { \
-                "Title" : title,
-                "Style" : self.stylesheet} + \
-              self.indexBodyTemplate % { \
-                "Title" : title,
-                "Description" : package["description"],
-                "Subpackages" : subpackages,
-                "Modules" : modules,
-              } + \
-              self.footerTemplate
+        doc = self.headerTemplate.format(
+            **{"Title": title,
+               "Style": self.stylesheet}) + \
+            self.indexBodyTemplate.format(
+                **{"Title": title,
+                   "Description": package["description"],
+                   "Subpackages": subpackages,
+                   "Modules": modules}) + \
+            self.footerTemplate
     
-        f = open(filename, "wb")
+        f = open(filename, "w", encoding="utf-8", newline=newline)
         f.write(doc)
         f.close()
     
         return filename
     
-    def writeIndices(self, basename = ""):
+    def writeIndices(self, basename="", newline=None):
         """
         Public method to generate all index files.
         
         @param basename The basename of the file hierarchy to be documented.
             The basename is stripped off the filename if it starts with
             the basename.
+        @param newline newline character to be used (string)
         """
         if not self.remembered:
             sys.stderr.write("No index to generate.\n")
@@ -197,17 +200,17 @@ class IndexGenerator(object):
         if basename:
             basename = basename.replace(os.sep, ".")
             if not basename.endswith("."):
-                basename = "%s." % basename
-        for package, element in self.packages.items():
+                basename = "{0}.".format(basename)
+        for package, element in list(self.packages.items()):
             try:
                 if basename:
-                    package = package.replace(basename,"")
-                out = self.__writeIndex(package, element)
-            except IOError, v:
-                sys.stderr.write("%s error: %s\n" % (package, v[1]))
+                    package = package.replace(basename, "")
+                out = self.__writeIndex(package, element, newline)
+            except IOError as v:
+                sys.stderr.write("{0} error: {1}\n".format(package, v[1]))
             else:
                 if out:
-                    sys.stdout.write("%s ok\n" % out)
+                    sys.stdout.write("{0} ok\n".format(out))
     
         sys.stdout.write("Indices written.\n")
         sys.stdout.flush()
