@@ -7,15 +7,19 @@
 Module implementing a graphics item for an association between two items.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QPointF, QRectF, QLineF
+from PyQt4.QtGui import QGraphicsItem
+
+from E5Graphics.E5ArrowItem import E5ArrowItem, NormalArrow, WideArrow
+
+import Utilities
 
-from E4Graphics.E4ArrowItem import E4ArrowItem, NormalArrow, WideArrow
 
 Normal = 0
 Generalisation = 1
 Imports = 2
 
+
 NoRegion = 0
 West = 1
 North = 2
@@ -27,14 +31,16 @@ SouthEast = 7
 SouthWest = 8
 Center = 9
 
-class AssociationItem(E4ArrowItem):
+
+class AssociationItem(E5ArrowItem):
     """
     Class implementing a graphics item for an association between two items.
     
     The association is drawn as an arrow starting at the first items and
     ending at the second.
     """
-    def __init__(self, itemA, itemB, type = Normal, parent = None):
+    def __init__(self, itemA, itemB, type=Normal, topToBottom=False,
+                 parent=None):
         """
         Constructor
         
@@ -46,6 +52,8 @@ class AssociationItem(E4ArrowItem):
             <li>Generalisation</li>
             <li>Imports</li>
             </ul>
+        @keyparam topToBottom flag indicating to draw the association
+            from item A top to item B bottom (boolean)
         @keyparam parent reference to the parent object (QGraphicsItem)
         """
         if type == Normal:
@@ -58,18 +66,23 @@ class AssociationItem(E4ArrowItem):
             arrowType = WideArrow
             arrowFilled = False
         
-        E4ArrowItem.__init__(self, QPointF(0, 0), QPointF(100, 100), 
-            arrowFilled, arrowType, parent)
+        E5ArrowItem.__init__(self, QPointF(0, 0), QPointF(100, 100),
+                             arrowFilled, arrowType, parent)
         
         self.setFlag(QGraphicsItem.ItemIsMovable, False)
         self.setFlag(QGraphicsItem.ItemIsSelectable, False)
         
-##        self.calculateEndingPoints = self.__calculateEndingPoints_center
-        self.calculateEndingPoints = self.__calculateEndingPoints_rectangle
+        if topToBottom:
+            self.calculateEndingPoints = \
+                self.__calculateEndingPoints_topToBottom
+        else:
+##            self.calculateEndingPoints = self.__calculateEndingPoints_center
+            self.calculateEndingPoints = self.__calculateEndingPoints_rectangle
         
         self.itemA = itemA
         self.itemB = itemB
         self.assocType = type
+        self.topToBottom = topToBottom
         
         self.regionA = NoRegion
         self.regionB = NoRegion
@@ -81,7 +94,8 @@ class AssociationItem(E4ArrowItem):
         
     def __mapRectFromItem(self, item):
         """
-        Private method to map item's rectangle to this item's coordinate system.
+        Private method to map item's rectangle to this item's coordinate
+        system.
         
         @param item reference to the item to be mapped (QGraphicsRectItem)
         @return item's rectangle in local coordinates (QRectF)
@@ -90,6 +104,34 @@ class AssociationItem(E4ArrowItem):
         tl = self.mapFromItem(item, rect.topLeft())
         return QRectF(tl.x(), tl.y(), rect.width(), rect.height())
         
+    def __calculateEndingPoints_topToBottom(self):
+        """
+        Private method to calculate the ending points of the association item.
+        
+        The ending points are calculated from the top center of the lower item
+        to the bottom center of the upper item.
+        """
+        if self.itemA is None or self.itemB is None:
+            return
+        
+        self.prepareGeometryChange()
+        
+        rectA = self.__mapRectFromItem(self.itemA)
+        rectB = self.__mapRectFromItem(self.itemB)
+        midA = QPointF(rectA.x() + rectA.width() / 2.0,
+                       rectA.y() + rectA.height() / 2.0)
+        midB = QPointF(rectB.x() + rectB.width() / 2.0,
+                       rectB.y() + rectB.height() / 2.0)
+        if midA.y() > midB.y():
+            startP = QPointF(rectA.x() + rectA.width() / 2.0, rectA.y())
+            endP = QPointF(rectB.x() + rectB.width() / 2.0,
+                           rectB.y() + rectB.height())
+        else:
+            startP = QPointF(rectA.x() + rectA.width() / 2.0,
+                             rectA.y() + rectA.height())
+            endP = QPointF(rectB.x() + rectB.width() / 2.0, rectB.y())
+        self.setPoints(startP.x(), startP.y(), endP.x(), endP.y())
+    
     def __calculateEndingPoints_center(self):
         """
         Private method to calculate the ending points of the association item.
@@ -116,7 +158,7 @@ class AssociationItem(E4ArrowItem):
             self.setPoints(startP.x(), startP.y(), endP.x(), endP.y())
         
     def __calculateEndingPoints_rectangle(self):
-        """
+        r"""
         Private method to calculate the ending points of the association item.
         
         The ending points are calculated by the following method.
@@ -141,12 +183,12 @@ class AssociationItem(E4ArrowItem):
         Each diagonal is defined by two corners of the bounding rectangle
         
         To calculate the start point  we have to find out in which
-        region (defined by itemA's diagonals) is itemB's TopLeft corner 
+        region (defined by itemA's diagonals) is itemB's TopLeft corner
         (lets call it region M). After that the start point will be
         the middle point of rectangle's side contained in region M.
         
-        To calculate the end point we repeat the above but in the opposite direction
-        (from itemB to itemA)
+        To calculate the end point we repeat the above but in the opposite
+        direction (from itemB to itemA)
         """
         if self.itemA is None or self.itemB is None:
             return
@@ -163,7 +205,6 @@ class AssociationItem(E4ArrowItem):
         
         # find itemA region
         rc = QRectF(xA, yA, rectA.width(), rectA.height())
-        oldRegionA = self.regionA
         self.regionA = self.__findPointRegion(rc, xB, yB)
         # move some regions to the standard ones
         if self.regionA == NorthWest:
@@ -181,7 +222,6 @@ class AssociationItem(E4ArrowItem):
         
         # now do the same for itemB
         rc = QRectF(xB, yB, rectB.width(), rectB.height())
-        oldRegionB = self.regionB
         self.regionB = self.__findPointRegion(rc, xA, yA)
         # move some regions to the standard ones
         if self.regionB == NorthWest:
@@ -199,8 +239,8 @@ class AssociationItem(E4ArrowItem):
         
     def __findPointRegion(self, rect, posX, posY):
         """
-        Private method to find out, which region of rectangle rect contains the point 
-        (PosX, PosY) and returns the region number.
+        Private method to find out, which region of rectangle rect contains
+        the point (PosX, PosY) and returns the region number.
         
         @param rect rectangle to calculate the region for (QRectF)
         @param posX x position of point (float)
@@ -312,7 +352,8 @@ class AssociationItem(E4ArrowItem):
         
     def __findRectIntersectionPoint(self, item, p1, p2):
         """
-        Private method to find the intersetion point of a line with a rectangle.
+        Private method to find the intersetion point of a line with a
+        rectangle.
         
         @param item item to check against
         @param p1 first point of the line (QPointF)
@@ -441,19 +482,23 @@ class AssociationItem(E4ArrowItem):
         pt.setX(slope1 * pt.y() + b1)
         # the intersection point must be inside the segment (x1, y1) (x2, y2)
         if x2 >= x1 and y2 >= y1:
-            if not ((x1 <= pt.y() and pt.y() <= x2) and (y1 <= pt.x() and pt.x() <= y2)):
+            if not ((x1 <= pt.y() and pt.y() <= x2) and
+                    (y1 <= pt.x() and pt.x() <= y2)):
                 pt.setX(-1.0)
                 pt.setY(-1.0)
         elif x2 < x1 and y2 >= y1:
-            if not ((x2 <= pt.y() and pt.y() <= x1) and (y1 <= pt.x() and pt.x() <= y2)):
+            if not ((x2 <= pt.y() and pt.y() <= x1) and
+                    (y1 <= pt.x() and pt.x() <= y2)):
                 pt.setX(-1.0)
                 pt.setY(-1.0)
         elif x2 >= x1 and y2 < y1:
-            if not ((x1 <= pt.y() and pt.y() <= x2) and (y2 <= pt.x() and pt.x() <= y1)):
+            if not ((x1 <= pt.y() and pt.y() <= x2) and
+                    (y2 <= pt.x() and pt.x() <= y1)):
                 pt.setX(-1.0)
                 pt.setY(-1.0)
         else:
-            if not ((x2 <= pt.y() and pt.y() <= x1) and (y2 <= pt.x() and pt.x() <= y1)):
+            if not ((x2 <= pt.y() and pt.y() <= x1) and
+                    (y2 <= pt.x() and pt.x() <= y1)):
                 pt.setX(-1.0)
                 pt.setY(-1.0)
         
@@ -471,3 +516,48 @@ class AssociationItem(E4ArrowItem):
         """
         self.itemA.removeAssociation(self)
         self.itemB.removeAssociation(self)
+    
+    def buildAssociationItemDataString(self):
+        """
+        Public method to build a string to persist the specific item data.
+        
+        This string should be built like "attribute=value" with pairs separated
+        by ", ". value must not contain ", " or newlines.
+        
+        @return persistence data (string)
+        """
+        entries = [
+            "src={0}".format(self.itemA.getId()),
+            "dst={0}".format(self.itemB.getId()),
+            "type={0}".format(self.assocType),
+            "topToBottom={0}".format(self.topToBottom)
+        ]
+        return ", ".join(entries)
+    
+    @classmethod
+    def parseAssociationItemDataString(cls, data):
+        """
+        Class method to parse the given persistence data.
+        
+        @param data persisted data to be parsed (string)
+        @return tuple with the IDs of the source and destination items,
+            the association type and a flag indicating to associate from top
+            to bottom (integer, integer, integer, boolean)
+        """
+        src = -1
+        dst = -1
+        assocType = Normal
+        topToBottom = False
+        for entry in data.split(", "):
+            if "=" in entry:
+                key, value = entry.split("=", 1)
+                if key == "src":
+                    src = int(value)
+                elif key == "dst":
+                    dst = int(value)
+                elif key == "type":
+                    assocType = int(value)
+                elif key == "topToBottom":
+                    topToBottom = Utilities.toBool(value)
+        
+        return src, dst, assocType, topToBottom
