@@ -7,16 +7,18 @@
 Module implementing an UML like class item.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QFont, QGraphicsSimpleTextItem, QStyle
 
-from UMLItem import UMLItem
+from .UMLItem import UMLModel, UMLItem
 
-class ClassModel(object):
+import Utilities
+
+
+class ClassModel(UMLModel):
     """
     Class implementing the class model.
     """
-    def __init__(self, name, methods = [], attributes = []):
+    def __init__(self, name, methods=[], attributes=[]):
         """
         Constructor
         
@@ -26,10 +28,11 @@ class ClassModel(object):
         @param attributes list of attribute names of the class
             (list of strings)
         """
-        self.name = name
+        super().__init__(name)
+        
         self.methods = methods
         self.attributes = attributes
-        
+    
     def addMethod(self, method):
         """
         Method to add a method to the class model.
@@ -37,7 +40,7 @@ class ClassModel(object):
         @param method method name to be added (string)
         """
         self.methods.append(method)
-        
+    
     def addAttribute(self, attribute):
         """
         Method to add an attribute to the class model.
@@ -45,7 +48,7 @@ class ClassModel(object):
         @param attribute attribute name to be added (string)
         """
         self.attributes.append(attribute)
-        
+    
     def getMethods(self):
         """
         Method to retrieve the methods of the class.
@@ -53,7 +56,7 @@ class ClassModel(object):
         @return list of class methods (list of strings)
         """
         return self.methods[:]
-        
+    
     def getAttributes(self):
         """
         Method to retrieve the attributes of the class.
@@ -61,35 +64,32 @@ class ClassModel(object):
         @return list of class attributes (list of strings)
         """
         return self.attributes[:]
-        
-    def getName(self):
-        """
-        Method to retrieve the class name.
-        
-        @return class name (string)
-        """
-        return self.name
     
+
 class ClassItem(UMLItem):
     """
     Class implementing an UML like class item.
     """
-    def __init__(self, model = None, external = False, x = 0, y = 0, 
-                 rounded = False, noAttrs = False, parent = None, scene = None):
+    ItemType = "class"
+    
+    def __init__(self, model=None, external=False, x=0, y=0,
+                 rounded=False, noAttrs=False, parent=None, scene=None):
         """
         Constructor
         
         @param model class model containing the class data (ClassModel)
-        @param external flag indicating a class defined outside our scope (boolean)
+        @param external flag indicating a class defined outside our scope
+            (boolean)
         @param x x-coordinate (integer)
         @param y y-coordinate (integer)
         @keyparam rounded flag indicating a rounded corner (boolean)
-        @keyparam noAttrs flag indicating, that no attributes should be shown (boolean)
+        @keyparam noAttrs flag indicating, that no attributes should be shown
+            (boolean)
         @keyparam parent reference to the parent object (QGraphicsItem)
         @keyparam scene reference to the scene object (QGraphicsScene)
         """
-        UMLItem.__init__(self, x, y, rounded, parent)
-        self.model = model
+        UMLItem.__init__(self, model, x, y, rounded, parent)
+        
         self.external = external
         self.noAttrs = noAttrs
         
@@ -175,7 +175,7 @@ class ClassItem(UMLItem):
         self.__createTexts()
         self.__calculateSize()
         
-    def paint(self, painter, option, widget = None):
+    def paint(self, painter, option, widget=None):
         """
         Public method to paint the item in local coordinates.
         
@@ -184,7 +184,8 @@ class ClassItem(UMLItem):
         @param widget optional reference to the widget painted on (QWidget)
         """
         pen = self.pen()
-        if (option.state & QStyle.State_Selected) == QStyle.State(QStyle.State_Selected):
+        if (option.state & QStyle.State_Selected) == \
+                QStyle.State(QStyle.State_Selected):
             pen.setWidth(2)
         else:
             pen.setWidth(1)
@@ -203,7 +204,8 @@ class ClassItem(UMLItem):
         painter.drawLine(offsetX, offsetY + y, offsetX + w - 1, offsetY + y)
         if self.attrs:
             y += self.margin + self.attrs.boundingRect().height()
-            painter.drawLine(offsetX, offsetY + y, offsetX + w - 1, offsetY + y)
+            painter.drawLine(offsetX, offsetY + y,
+                             offsetX + w - 1, offsetY + y)
         
         self.adjustAssociations()
         
@@ -214,3 +216,64 @@ class ClassItem(UMLItem):
         @return external state (boolean)
         """
         return self.external
+    
+    def buildItemDataString(self):
+        """
+        Public method to build a string to persist the specific item data.
+        
+        This string must start with ", " and should be built like
+        "attribute=value" with pairs separated by ", ". value must not
+        contain ", " or newlines.
+        
+        @return persistence data (string)
+        """
+        entries = [
+            "is_external={0}".format(self.external),
+            "no_attributes={0}".format(self.noAttrs),
+            "name={0}".format(self.model.getName()),
+        ]
+        attributes = self.model.getAttributes()
+        if attributes:
+            entries.append("attributes={0}".format("||".join(attributes)))
+        methods = self.model.getMethods()
+        if methods:
+            entries.append("methods={0}".format("||".join(methods)))
+        
+        return ", " + ", ".join(entries)
+    
+    def parseItemDataString(self, version, data):
+        """
+        Public method to parse the given persistence data.
+        
+        @param version version of the data (string)
+        @param data persisted data to be parsed (string)
+        @return flag indicating success (boolean)
+        """
+        parts = data.split(", ")
+        if len(parts) < 3:
+            return False
+        
+        name = ""
+        attributes = []
+        methods = []
+        
+        for part in parts:
+            key, value = part.split("=", 1)
+            if key == "is_external":
+                self.external = Utilities.toBool(value.strip())
+            elif key == "no_attributes":
+                self.noAttrs = Utilities.toBool(value.strip())
+            elif key == "name":
+                name = value.strip()
+            elif key == "attributes":
+                attributes = value.strip().split("||")
+            elif key == "methods":
+                methods = value.strip().split("||")
+            else:
+                return False
+        
+        self.model = ClassModel(name, methods, attributes)
+        self.__createTexts()
+        self.__calculateSize()
+        
+        return True
