@@ -7,12 +7,12 @@
 Module implementing a module item.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QFont, QGraphicsSimpleTextItem, QStyle
 
-from UMLItem import UMLItem
+from .UMLItem import UMLModel, UMLItem
 
-class ModuleModel(object):
+
+class ModuleModel(UMLModel):
     """
     Class implementing the module model.
     """
@@ -23,9 +23,10 @@ class ModuleModel(object):
         @param name the module name (string)
         @param classlist list of class names (list of strings)
         """
-        self.name = name
-        self.classlist = classlist
+        super().__init__(name)
         
+        self.classlist = classlist
+    
     def addClass(self, classname):
         """
         Method to add a class to the module model.
@@ -33,7 +34,7 @@ class ModuleModel(object):
         @param classname class name to be added (string)
         """
         self.classlist.append(classname)
-        
+    
     def getClasses(self):
         """
         Method to retrieve the classes of the module.
@@ -41,21 +42,16 @@ class ModuleModel(object):
         @return list of class names (list of strings)
         """
         return self.classlist[:]
-        
-    def getName(self):
-        """
-        Method to retrieve the module name.
-        
-        @return module name (string)
-        """
-        return self.name
-        
+
+
 class ModuleItem(UMLItem):
     """
     Class implementing a module item.
     """
-    def __init__(self, model = None, x = 0, y = 0, rounded = False,
-                 parent = None, scene = None):
+    ItemType = "module"
+    
+    def __init__(self, model=None, x=0, y=0, rounded=False,
+                 parent=None, scene=None):
         """
         Constructor
         
@@ -66,8 +62,7 @@ class ModuleItem(UMLItem):
         @keyparam parent reference to the parent object (QGraphicsItem)
         @keyparam scene reference to the scene object (QGraphicsScene)
         """
-        UMLItem.__init__(self, x, y, rounded, parent)
-        self.model = model
+        UMLItem.__init__(self, model, x, y, rounded, parent)
         
         scene.addItem(self)
         
@@ -132,7 +127,7 @@ class ModuleItem(UMLItem):
         self.__createTexts()
         self.__calculateSize()
         
-    def paint(self, painter, option, widget = None):
+    def paint(self, painter, option, widget=None):
         """
         Public method to paint the item in local coordinates.
         
@@ -141,7 +136,8 @@ class ModuleItem(UMLItem):
         @param widget optional reference to the widget painted on (QWidget)
         """
         pen = self.pen()
-        if (option.state & QStyle.State_Selected) == QStyle.State(QStyle.State_Selected):
+        if (option.state & QStyle.State_Selected) == \
+                QStyle.State(QStyle.State_Selected):
             pen.setWidth(2)
         else:
             pen.setWidth(1)
@@ -160,3 +156,52 @@ class ModuleItem(UMLItem):
         painter.drawLine(offsetX, offsetY + y, offsetX + w - 1, offsetY + y)
         
         self.adjustAssociations()
+    
+    def buildItemDataString(self):
+        """
+        Public method to build a string to persist the specific item data.
+        
+        This string must start with ", " and should be built like
+        "attribute=value" with pairs separated by ", ". value must not
+        contain ", " or newlines.
+        
+        @return persistence data (string)
+        """
+        entries = [
+            "name={0}".format(self.model.getName()),
+        ]
+        classes = self.model.getClasses()
+        if classes:
+            entries.append("classes={0}".format("||".join(classes)))
+        
+        return ", " + ", ".join(entries)
+    
+    def parseItemDataString(self, version, data):
+        """
+        Public method to parse the given persistence data.
+        
+        @param version version of the data (string)
+        @param data persisted data to be parsed (string)
+        @return flag indicating success (boolean)
+        """
+        parts = data.split(", ")
+        if len(parts) < 1:
+            return False
+        
+        name = ""
+        classes = []
+        
+        for part in parts:
+            key, value = part.split("=", 1)
+            if key == "name":
+                name = value.strip()
+            elif key == "classes":
+                classes = value.strip().split("||")
+            else:
+                return False
+        
+        self.model = ModuleModel(name, classes)
+        self.__createTexts()
+        self.__calculateSize()
+        
+        return True
