@@ -7,25 +7,28 @@
 Module implementing a package item.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QFont, QGraphicsSimpleTextItem, QStyle
 
-from UMLItem import UMLItem
+from .UMLItem import UMLModel, UMLItem
 
-class PackageModel(object):
+import Utilities
+
+
+class PackageModel(UMLModel):
     """
     Class implementing the package model.
     """
-    def __init__(self, name, moduleslist = []):
+    def __init__(self, name, moduleslist=[]):
         """
         Constructor
         
         @param name package name (string)
         @param moduleslist list of module names (list of strings)
         """
-        self.name = name
-        self.moduleslist = moduleslist
+        super().__init__(name)
         
+        self.moduleslist = moduleslist
+    
     def addModule(self, modulename):
         """
         Method to add a module to the package model.
@@ -33,7 +36,7 @@ class PackageModel(object):
         @param modulename module name to be added (string)
         """
         self.moduleslist.append(modulename)
-        
+    
     def getModules(self):
         """
         Method to retrieve the modules of the package.
@@ -41,35 +44,29 @@ class PackageModel(object):
         @return list of module names (list of strings)
         """
         return self.moduleslist[:]
-        
-    def getName(self):
-        """
-        Method to retrieve the package name.
-        
-        @return package name (string)
-        """
-        return self.name
-        
+
+
 class PackageItem(UMLItem):
     """
     Class implementing a package item.
     """
-    def __init__(self, model = None, x = 0, y = 0, rounded = False, 
-                 noModules = False, parent = None, scene = None):
+    ItemType = "package"
+    
+    def __init__(self, model=None, x=0, y=0, rounded=False,
+                 noModules=False, parent=None, scene=None):
         """
         Constructor
         
-        @param model module model containing the module data (ModuleModel)
+        @param model package model containing the package data (PackageModel)
         @param x x-coordinate (integer)
         @param y y-coordinate (integer)
         @param rounded flag indicating a rounded corner (boolean)
-        @keyparam noModules flag indicating, that no module names should be 
+        @keyparam noModules flag indicating, that no module names should be
             shown (boolean)
         @keyparam parent reference to the parent object (QGraphicsItem)
         @keyparam scene reference to the scene object (QGraphicsScene)
         """
-        UMLItem.__init__(self, x, y, rounded, parent)
-        self.model = model
+        UMLItem.__init__(self, model, x, y, rounded, parent)
         self.noModules = noModules
         
         scene.addItem(self)
@@ -124,7 +121,8 @@ class PackageItem(UMLItem):
             height = height + self.modules.boundingRect().height()
         latchW = width / 3.0
         latchH = min(15.0, latchW)
-        self.setSize(width + 2 * self.margin, height + latchH + 2 * self.margin)
+        self.setSize(width + 2 * self.margin,
+                     height + latchH + 2 * self.margin)
         
         x = self.margin + self.rect().x()
         y = self.margin + self.rect().y() + latchH
@@ -148,7 +146,7 @@ class PackageItem(UMLItem):
         self.__createTexts()
         self.__calculateSize()
         
-    def paint(self, painter, option, widget = None):
+    def paint(self, painter, option, widget=None):
         """
         Public method to paint the item in local coordinates.
         
@@ -157,7 +155,8 @@ class PackageItem(UMLItem):
         @param widget optional reference to the widget painted on (QWidget)
         """
         pen = self.pen()
-        if (option.state & QStyle.State_Selected) == QStyle.State(QStyle.State_Selected):
+        if (option.state & QStyle.State_Selected) == \
+                QStyle.State(QStyle.State_Selected):
             pen.setWidth(2)
         else:
             pen.setWidth(1)
@@ -179,3 +178,55 @@ class PackageItem(UMLItem):
         painter.drawLine(offsetX, offsetY + y, offsetX + w - 1, offsetY + y)
         
         self.adjustAssociations()
+    
+    def buildItemDataString(self):
+        """
+        Public method to build a string to persist the specific item data.
+        
+        This string must start with ", " and should be built like
+        "attribute=value" with pairs separated by ", ". value must not
+        contain ", " or newlines.
+        
+        @return persistence data (string)
+        """
+        entries = [
+            "no_modules={0}".format(self.noModules),
+            "name={0}".format(self.model.getName()),
+        ]
+        modules = self.model.getModules()
+        if modules:
+            entries.append("modules={0}".format("||".join(modules)))
+        
+        return ", " + ", ".join(entries)
+    
+    def parseItemDataString(self, version, data):
+        """
+        Public method to parse the given persistence data.
+        
+        @param version version of the data (string)
+        @param data persisted data to be parsed (string)
+        @return flag indicating success (boolean)
+        """
+        parts = data.split(", ")
+        if len(parts) < 2:
+            return False
+        
+        name = ""
+        modules = []
+        
+        for part in parts:
+            key, value = part.split("=", 1)
+            if key == "no_modules":
+                self.external = Utilities.toBool(value.strip())
+            elif key == "name":
+                name = value.strip()
+            elif key == "modules":
+                modules = value.strip().split("||")
+            else:
+                return False
+        
+        self.model = PackageModel(name, modules)
+        self.__createTexts()
+        self.__calculateSize()
+        
+        return True
