@@ -7,33 +7,41 @@
 Module implementing a dialog showing a SVG graphic.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt, QSize, QEvent
+from PyQt4.QtGui import QPalette, QSizePolicy, QScrollArea, QAction, QMenu, \
+    QToolBar, QPrinter, QPrintDialog, QPainter, QFont, QColor
 from PyQt4.QtSvg import QSvgWidget
 
-import KdeQt.KQPrinter
-from KdeQt.KQMainWindow import KQMainWindow
-from KdeQt.KQPrintDialog import KQPrintDialog
-
-from ZoomDialog import ZoomDialog
+from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5ZoomWidget import E5ZoomWidget
 
 import UI.Config
 
 import Preferences
 
-class SvgDiagram(KQMainWindow):
+
+class SvgDiagram(E5MainWindow):
     """
     Class implementing a dialog showing a SVG graphic.
     """
-    def __init__(self, svgFile, parent = None, name = None):
+    ZoomLevels = [
+        1, 3, 5, 7, 9,
+        10, 20, 30, 50, 67, 80, 90,
+        100,
+        110, 120, 133, 150, 170, 200, 240, 300, 400,
+        500, 600, 700, 800, 900, 1000,
+    ]
+    ZoomLevelDefault = 100
+    
+    def __init__(self, svgFile, parent=None, name=None):
         """
         Constructor
         
-        @param svgFile filename of a SVG graphics file to show (QString or string)
+        @param svgFile filename of a SVG graphics file to show (string)
         @param parent parent widget of the view (QWidget)
-        @param name name of the view widget (QString or string)
+        @param name name of the view widget (string)
         """
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         else:
@@ -52,6 +60,15 @@ class SvgDiagram(KQMainWindow):
         
         self.setCentralWidget(self.svgView)
         
+        self.__zoomWidget = E5ZoomWidget(
+            UI.PixmapCache.getPixmap("zoomOut.png"),
+            UI.PixmapCache.getPixmap("zoomIn.png"),
+            UI.PixmapCache.getPixmap("zoomReset.png"), self)
+        self.statusBar().addPermanentWidget(self.__zoomWidget)
+        self.__zoomWidget.setMapping(
+            SvgDiagram.ZoomLevels, SvgDiagram.ZoomLevelDefault)
+        self.__zoomWidget.valueChanged.connect(self.__doZoom)
+        
         # polish up the dialog
         self.resize(QSize(800, 600).expandedTo(self.minimumSizeHint()))
         
@@ -64,6 +81,8 @@ class SvgDiagram(KQMainWindow):
         self.__initContextMenu()
         self.__initToolBars()
         
+        self.grabGesture(Qt.PinchGesture)
+        
     def __initActions(self):
         """
         Private method to initialize the view actions.
@@ -71,38 +90,17 @@ class SvgDiagram(KQMainWindow):
         self.closeAct = \
             QAction(UI.PixmapCache.getIcon("close.png"),
                     self.trUtf8("Close"), self)
-        self.connect(self.closeAct, SIGNAL("triggered()"), self.close)
+        self.closeAct.triggered[()].connect(self.close)
         
         self.printAct = \
             QAction(UI.PixmapCache.getIcon("print.png"),
                     self.trUtf8("Print"), self)
-        self.connect(self.printAct, SIGNAL("triggered()"), self.__printDiagram)
+        self.printAct.triggered[()].connect(self.__printDiagram)
         
         self.printPreviewAct = \
             QAction(UI.PixmapCache.getIcon("printPreview.png"),
                     self.trUtf8("Print Preview"), self)
-        self.connect(self.printPreviewAct, SIGNAL("triggered()"), 
-            self.__printPreviewDiagram)
-        
-        self.zoomInAct = \
-            QAction(UI.PixmapCache.getIcon("zoomIn.png"),
-                    self.trUtf8("Zoom in"), self)
-        self.connect(self.zoomInAct, SIGNAL("triggered()"), self.__zoomIn)
-        
-        self.zoomOutAct = \
-            QAction(UI.PixmapCache.getIcon("zoomOut.png"),
-                    self.trUtf8("Zoom out"), self)
-        self.connect(self.zoomOutAct, SIGNAL("triggered()"), self.__zoomOut)
-        
-        self.zoomAct = \
-            QAction(UI.PixmapCache.getIcon("zoomTo.png"),
-                    self.trUtf8("Zoom..."), self)
-        self.connect(self.zoomAct, SIGNAL("triggered()"), self.__zoom)
-        
-        self.zoomResetAct = \
-            QAction(UI.PixmapCache.getIcon("zoomReset.png"),
-                    self.trUtf8("Zoom reset"), self)
-        self.connect(self.zoomResetAct, SIGNAL("triggered()"), self.__zoomReset)
+        self.printPreviewAct.triggered[()].connect(self.__printPreviewDiagram)
         
     def __initContextMenu(self):
         """
@@ -113,15 +111,9 @@ class SvgDiagram(KQMainWindow):
         self.__menu.addSeparator()
         self.__menu.addAction(self.printPreviewAct)
         self.__menu.addAction(self.printAct)
-        self.__menu.addSeparator()
-        self.__menu.addAction(self.zoomInAct)
-        self.__menu.addAction(self.zoomOutAct)
-        self.__menu.addAction(self.zoomAct)
-        self.__menu.addAction(self.zoomResetAct)
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.customContextMenuRequested.connect(self.__showContextMenu)
         
     def __showContextMenu(self, coord):
         """
@@ -143,11 +135,6 @@ class SvgDiagram(KQMainWindow):
         self.graphicsToolBar.setIconSize(UI.Config.ToolBarIconSize)
         self.graphicsToolBar.addAction(self.printPreviewAct)
         self.graphicsToolBar.addAction(self.printAct)
-        self.graphicsToolBar.addSeparator()
-        self.graphicsToolBar.addAction(self.zoomInAct)
-        self.graphicsToolBar.addAction(self.zoomOutAct)
-        self.graphicsToolBar.addAction(self.zoomAct)
-        self.graphicsToolBar.addAction(self.zoomResetAct)
         
         self.addToolBar(Qt.TopToolBarArea, self.windowToolBar)
         self.addToolBar(Qt.TopToolBarArea, self.graphicsToolBar)
@@ -160,9 +147,52 @@ class SvgDiagram(KQMainWindow):
         """
         return self.svgFile
     
-    ############################################################################
+    def wheelEvent(self, evt):
+        """
+        Protected method to handle wheel events.
+        
+        @param evt reference to the wheel event (QWheelEvent)
+        """
+        if evt.modifiers() & Qt.ControlModifier:
+            if evt.delta() < 0:
+                self.__zoomOut()
+            else:
+                self.__zoomIn()
+            evt.accept()
+            return
+        
+        super().wheelEvent(evt)
+    
+    def event(self, evt):
+        """
+        Protected method handling events.
+        
+        @param evt reference to the event (QEvent)
+        @return flag indicating, if the event was handled (boolean)
+        """
+        if evt.type() == QEvent.Gesture:
+            self.gestureEvent(evt)
+            return True
+        
+        return super().event(evt)
+    
+    def gestureEvent(self, evt):
+        """
+        Protected method handling gesture events.
+        
+        @param evt reference to the gesture event (QGestureEvent
+        """
+        pinch = evt.gesture(Qt.PinchGesture)
+        if pinch:
+            if pinch.state() == Qt.GestureStarted:
+                pinch.setScaleFactor(self.__zoom() / 100)
+            else:
+                self.__doZoom(int(pinch.scaleFactor() * 100))
+            evt.accept()
+    
+    ###########################################################################
     ## Private menu handling methods below.
-    ############################################################################
+    ###########################################################################
     
     def __adjustScrollBar(self, scrollBar, factor):
         """
@@ -171,67 +201,91 @@ class SvgDiagram(KQMainWindow):
         @param scrollBar reference to the scrollbar object (QScrollBar)
         @param factor factor to adjust by (float)
         """
-        scrollBar.setValue(int(factor * scrollBar.value()
-                                + ((factor - 1) * scrollBar.pageStep()/2)))
+        scrollBar.setValue(
+            int(factor * scrollBar.value() +
+                ((factor - 1) * scrollBar.pageStep() / 2)))
         
-    def __doZoom(self, factor):
+    def __levelForZoom(self, zoom):
         """
-        Private method to perform the zooming.
+        Private method determining the zoom level index given a zoom factor.
         
-        @param factor zoom factor (float)
+        @param zoom zoom factor (integer)
+        @return index of zoom factor (integer)
         """
-        self.zoom *= factor
-        self.svgWidget.resize(self.zoom * self.svgWidget.sizeHint())
+        try:
+            index = SvgDiagram.ZoomLevels.index(zoom)
+        except ValueError:
+            for index in range(len(SvgDiagram.ZoomLevels)):
+                if zoom <= SvgDiagram.ZoomLevels[index]:
+                    break
+        return index
+    
+    def __doZoom(self, value):
+        """
+        Public method to set the zoom value in percent.
         
-        self.__adjustScrollBar(self.svgView.horizontalScrollBar(), factor)
-        self.__adjustScrollBar(self.svgView.verticalScrollBar(), factor)
+        @param value zoom value in percent (integer)
+        """
+        oldValue = self.__zoom()
+        if value != oldValue:
+            self.svgWidget.resize(value / 100 * self.svgWidget.sizeHint())
+            
+            factor = value / oldValue
+            self.__adjustScrollBar(self.svgView.horizontalScrollBar(), factor)
+            self.__adjustScrollBar(self.svgView.verticalScrollBar(), factor)
+            
+            self.__zoomWidget.setValue(value)
         
     def __zoomIn(self):
         """
-        Private method to handle the zoom in context menu entry.
+        Private method to zoom into the SVG.
         """
-        self.__doZoom(1.25)
+        index = self.__levelForZoom(self.__zoom())
+        if index < len(SvgDiagram.ZoomLevels) - 1:
+            self.__doZoom(SvgDiagram.ZoomLevels[index + 1])
         
     def __zoomOut(self):
         """
-        Private method to handle the zoom out context menu entry.
+        Private method to zoom out of the SVG.
         """
-        self.__doZoom(0.8)
+        index = self.__levelForZoom(self.__zoom())
+        if index > 0:
+            self.__doZoom(SvgDiagram.ZoomLevels[index - 1])
         
     def __zoomReset(self):
         """
-        Private method to handle the reset zoom context menu entry.
+        Private method to reset the zoom value.
         """
-        self.zoom = 1.0
-        self.svgWidget.adjustSize()
+        self.__doZoom(SvgDiagram.ZoomLevels[SvgDiagram.ZoomLevelDefault])
         
     def __zoom(self):
         """
-        Private method to handle the zoom context menu action.
+        Public method to get the current zoom factor in percent.
+        
+        @return current zoom factor in percent (integer)
         """
-        dlg = ZoomDialog(self.zoom, self)
-        if dlg.exec_() == QDialog.Accepted:
-            zoom = dlg.getZoomSize()
-            factor = zoom / self.zoom
-            self.__doZoom(factor)
+        return int(self.svgWidget.width() /
+                   self.svgWidget.sizeHint().width() * 100.0)
         
     def __printDiagram(self):
         """
         Private slot called to print the diagram.
         """
-        printer = KdeQt.KQPrinter.KQPrinter(mode = QPrinter.ScreenResolution)
+        printer = QPrinter(mode=QPrinter.ScreenResolution)
         printer.setFullPage(True)
         if Preferences.getPrinter("ColorMode"):
-            printer.setColorMode(KdeQt.KQPrinter.Color)
+            printer.setColorMode(QPrinter.Color)
         else:
-            printer.setColorMode(KdeQt.KQPrinter.GrayScale)
+            printer.setColorMode(QPrinter.GrayScale)
         if Preferences.getPrinter("FirstPageFirst"):
-            printer.setPageOrder(KdeQt.KQPrinter.FirstPageFirst)
+            printer.setPageOrder(QPrinter.FirstPageFirst)
         else:
-            printer.setPageOrder(KdeQt.KQPrinter.LastPageFirst)
-        printer.setPrinterName(Preferences.getPrinter("PrinterName"))
+            printer.setPageOrder(QPrinter.LastPageFirst)
+        printerName = Preferences.getPrinter("PrinterName")
+        if printerName:
+            printer.setPrinterName(printerName)
         
-        printDialog = KQPrintDialog(printer, self)
+        printDialog = QPrintDialog(printer, self)
         if printDialog.exec_():
             self.__print(printer)
         
@@ -241,16 +295,16 @@ class SvgDiagram(KQMainWindow):
         """
         from PyQt4.QtGui import QPrintPreviewDialog
         
-        printer = KdeQt.KQPrinter.KQPrinter(mode = QPrinter.ScreenResolution)
+        printer = QPrinter(mode=QPrinter.ScreenResolution)
         printer.setFullPage(True)
         if Preferences.getPrinter("ColorMode"):
-            printer.setColorMode(KdeQt.KQPrinter.Color)
+            printer.setColorMode(QPrinter.Color)
         else:
-            printer.setColorMode(KdeQt.KQPrinter.GrayScale)
+            printer.setColorMode(QPrinter.GrayScale)
         if Preferences.getPrinter("FirstPageFirst"):
-            printer.setPageOrder(KdeQt.KQPrinter.FirstPageFirst)
+            printer.setPageOrder(QPrinter.FirstPageFirst)
         else:
-            printer.setPageOrder(KdeQt.KQPrinter.LastPageFirst)
+            printer.setPageOrder(QPrinter.LastPageFirst)
         printer.setPageMargins(
             Preferences.getPrinter("LeftMargin") * 10,
             Preferences.getPrinter("TopMargin") * 10,
@@ -258,10 +312,12 @@ class SvgDiagram(KQMainWindow):
             Preferences.getPrinter("BottomMargin") * 10,
             QPrinter.Millimeter
         )
-        printer.setPrinterName(Preferences.getPrinter("PrinterName"))
+        printerName = Preferences.getPrinter("PrinterName")
+        if printerName:
+            printer.setPrinterName(printerName)
         
         preview = QPrintPreviewDialog(printer, self)
-        self.connect(preview, SIGNAL("paintRequested(QPrinter*)"), self.__print)
+        preview.paintRequested[QPrinter].connect(self.__print)
         preview.exec_()
         
     def __print(self, printer):
@@ -279,29 +335,29 @@ class SvgDiagram(KQMainWindow):
         fm = painter.fontMetrics()
         fontHeight = fm.lineSpacing()
         marginX = printer.pageRect().x() - printer.paperRect().x()
-        marginX = \
-            Preferences.getPrinter("LeftMargin") * int(printer.resolution() / 2.54) \
-            - marginX
+        marginX = Preferences.getPrinter("LeftMargin") * \
+            int(printer.resolution() / 2.54) - marginX
         marginY = printer.pageRect().y() - printer.paperRect().y()
-        marginY = \
-            Preferences.getPrinter("TopMargin") * int(printer.resolution() / 2.54) \
-            - marginY
+        marginY = Preferences.getPrinter("TopMargin") * \
+            int(printer.resolution() / 2.54) - marginY
 
-        width = printer.width() - marginX \
-            - Preferences.getPrinter("RightMargin") * int(printer.resolution() / 2.54)
-        height = printer.height() - fontHeight - 4 - marginY \
-            - Preferences.getPrinter("BottomMargin") * int(printer.resolution() / 2.54)
+        width = printer.width() - marginX - \
+            Preferences.getPrinter("RightMargin") * \
+            int(printer.resolution() / 2.54)
+        height = printer.height() - fontHeight - 4 - marginY - \
+            Preferences.getPrinter("BottomMargin") * \
+            int(printer.resolution() / 2.54)
 
         # write a foot note
-        s = QString(self.trUtf8("Diagram: %1").arg(self.getDiagramName()))
+        s = self.trUtf8("Diagram: {0}").format(self.getDiagramName())
         tc = QColor(50, 50, 50)
         painter.setPen(tc)
         painter.drawRect(marginX, marginY, width, height)
-        painter.drawLine(marginX, marginY + height + 2, 
-                   marginX + width, marginY + height + 2)
+        painter.drawLine(marginX, marginY + height + 2,
+                         marginX + width, marginY + height + 2)
         painter.setFont(font)
         painter.drawText(marginX, marginY + height + 4, width,
-                   fontHeight, Qt.AlignRight, s)
+                         fontHeight, Qt.AlignRight, s)
 
         # render the diagram
         painter.setViewport(marginX, marginY, width, height)
