@@ -7,29 +7,57 @@
 Module implementing the UMLItem base class.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt, QSizeF
+from PyQt4.QtGui import QGraphicsItem, QGraphicsRectItem, QStyle
 
 import Preferences
 
+
+class UMLModel(object):
+    """
+    Class implementing the UMLModel base class.
+    """
+    def __init__(self, name):
+        """
+        Constructor
+        
+        @param name package name (string)
+        """
+        self.name = name
+    
+    def getName(self):
+        """
+        Method to retrieve the model name.
+        
+        @return model name (string)
+        """
+        return self.name
+
+
 class UMLItem(QGraphicsRectItem):
     """
     Class implementing the UMLItem base class.
     """
-    def __init__(self, x = 0, y = 0, rounded = False, parent = None):
+    ItemType = "UMLItem"
+    
+    def __init__(self, model=None, x=0, y=0, rounded=False, parent=None):
         """
         Constructor
         
+        @param model UML model containing the item data (UMLModel)
         @param x x-coordinate (integer)
         @param y y-coordinate (integer)
         @param rounded flag indicating a rounded corner (boolean)
         @keyparam parent reference to the parent object (QGraphicsItem)
         """
-        QGraphicsRectItem.__init__(self, parent)
+        super().__init__(parent)
+        self.model = model
+        
         self.font = Preferences.getGraphics("Font")
         self.margin = 5
         self.associations = []
         self.shouldAdjustAssociations = False
+        self.__id = -1
         
         self.setRect(x, y, 60, 30)
         
@@ -45,7 +73,18 @@ class UMLItem(QGraphicsRectItem):
         except AttributeError:
             # only available for Qt 4.6.0 and newer
             pass
+    
+    def getName(self):
+        """
+        Method to retrieve the item name.
         
+        @return item name (string)
+        """
+        if self.model:
+            return self.model.name
+        else:
+            return ""
+    
     def setSize(self, width, height):
         """
         Public method to set the rectangles size.
@@ -56,7 +95,7 @@ class UMLItem(QGraphicsRectItem):
         rect = self.rect()
         rect.setSize(QSizeF(width, height))
         self.setRect(rect)
-        
+    
     def addAssociation(self, assoc):
         """
         Method to add an association to this widget.
@@ -65,7 +104,7 @@ class UMLItem(QGraphicsRectItem):
         """
         if assoc and not assoc in self.associations:
             self.associations.append(assoc)
-        
+    
     def removeAssociation(self, assoc):
         """
         Method to remove an association to this widget.
@@ -74,7 +113,7 @@ class UMLItem(QGraphicsRectItem):
         """
         if assoc and assoc in self.associations:
             self.associations.remove(assoc)
-        
+    
     def removeAssociations(self):
         """
         Method to remove all associations of this widget.
@@ -83,7 +122,7 @@ class UMLItem(QGraphicsRectItem):
             assoc.unassociate()
             assoc.hide()
             del assoc
-        
+    
     def adjustAssociations(self):
         """
         Method to adjust the associations to widget movements.
@@ -92,7 +131,7 @@ class UMLItem(QGraphicsRectItem):
             for assoc in self.associations:
                 assoc.widgetMoved()
             self.shouldAdjustAssociations = False
-        
+    
     def moveBy(self, dx, dy):
         """
         Overriden method to move the widget relative.
@@ -100,9 +139,9 @@ class UMLItem(QGraphicsRectItem):
         @param dx relative movement in x-direction (float)
         @param dy relative movement in y-direction (float)
         """
-        QGraphicsRectItem.moveBy(self, dx, dy)
+        super().moveBy(dx, dy)
         self.adjustAssociations()
-        
+    
     def setPos(self, x, y):
         """
         Overriden method to set the items position.
@@ -110,22 +149,32 @@ class UMLItem(QGraphicsRectItem):
         @param x absolute x-position (float)
         @param y absolute y-position (float)
         """
-        QGraphicsRectItem.setPos(self, x, y)
+        super().setPos(x, y)
         self.adjustAssociations()
-        
+    
     def itemChange(self, change, value):
         """
         Protected method called when an items state changes.
         
         @param change the item's change (QGraphicsItem.GraphicsItemChange)
-        @param value the value of the change (QVariant)
-        @return adjusted values (QVariant)
+        @param value the value of the change
+        @return adjusted values
         """
         if change == QGraphicsItem.ItemPositionChange:
+            # 1. remember to adjust associations
             self.shouldAdjustAssociations = True
+            
+            # 2. ensure the new position is inside the scene
+            rect = self.scene().sceneRect()
+            if not rect.contains(value):
+                # keep the item inside the scene
+                value.setX(min(rect.right(), max(value.x(), rect.left())))
+                value.setY(min(rect.bottom(), max(value.y(), rect.top())))
+                return value
+            
         return QGraphicsItem.itemChange(self, change, value)
-        
-    def paint(self, painter, option, widget = None):
+    
+    def paint(self, painter, option, widget=None):
         """
         Public method to paint the item in local coordinates.
         
@@ -134,7 +183,8 @@ class UMLItem(QGraphicsRectItem):
         @param widget optional reference to the widget painted on (QWidget)
         """
         pen = self.pen()
-        if (option.state & QStyle.State_Selected) == QStyle.State(QStyle.State_Selected):
+        if (option.state & QStyle.State_Selected) == \
+                QStyle.State(QStyle.State_Selected):
             pen.setWidth(2)
         else:
             pen.setWidth(1)
@@ -143,3 +193,49 @@ class UMLItem(QGraphicsRectItem):
         painter.setBrush(self.brush())
         painter.drawRect(self.rect())
         self.adjustAssociations()
+    
+    def setId(self, id):
+        """
+        Public method to assign an ID to the item.
+        
+        @param id assigned ID (integer)
+        """
+        self.__id = id
+    
+    def getId(self):
+        """
+        Public method to get the item ID.
+        
+        @return ID of the item (integer)
+        """
+        return self.__id
+    
+    def getItemType(self):
+        """
+        Public method to get the item's type.
+        
+        @return item type (string)
+        """
+        return self.ItemType
+    
+    def buildItemDataString(self):
+        """
+        Public method to build a string to persist the specific item data.
+        
+        This string must start with ", " and should be built like
+        "attribute=value" with pairs separated by ", ". value must not
+        contain ", " or newlines.
+        
+        @return persistence data (string)
+        """
+        return ""
+    
+    def parseItemDataString(self, version, data):
+        """
+        Public method to parse the given persistence data.
+        
+        @param version version of the data (string)
+        @param data persisted data to be parsed (string)
+        @return flag indicating success (boolean)
+        """
+        return True
