@@ -7,26 +7,25 @@
 Module implementing a scheme access handler for AdBlock URLs.
 """
 
-from PyQt4.QtGui import QMessageBox
+from PyQt4.QtCore import QUrl
 from PyQt4.QtNetwork import QNetworkAccessManager
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from AdBlockSubscription import AdBlockSubscription
-
-import Helpviewer.HelpWindow
 from Helpviewer.Network.SchemeAccessHandler import SchemeAccessHandler
 from Helpviewer.Network.EmptyNetworkReply import EmptyNetworkReply
 
+
 class AdBlockAccessHandler(SchemeAccessHandler):
     """
     Class implementing a scheme access handler for AdBlock URLs.
     """
-    def createRequest(self, op, request, outgoingData = None):
+    def createRequest(self, op, request, outgoingData=None):
         """
         Protected method to create a request.
         
-        @param op the operation to be performed (QNetworkAccessManager.Operation)
+        @param op the operation to be performed
+            (QNetworkAccessManager.Operation)
         @param request reference to the request object (QNetworkRequest)
         @param outgoingData reference to an IODevice containing data to be sent
             (QIODevice)
@@ -35,25 +34,32 @@ class AdBlockAccessHandler(SchemeAccessHandler):
         if op != QNetworkAccessManager.GetOperation:
             return None
         
-        if request.url().path() != "subscribe":
+        url = request.url()
+        if url.path() != "subscribe":
             return None
         
-        subscription = AdBlockSubscription(request.url(), 
-                            Helpviewer.HelpWindow.HelpWindow.adblockManager())
-        
-        res = KQMessageBox.question(None,
+        title = QUrl.fromPercentEncoding(url.encodedQueryItemValue("title"))
+        if not title:
+            return None
+        res = E5MessageBox.yesNo(
+            None,
             self.trUtf8("Subscribe?"),
-            self.trUtf8("""<p>Subscribe to this AdBlock subscription?</p><p>%1</p>""")\
-                .arg(subscription.title()),
-            QMessageBox.StandardButtons(\
-                QMessageBox.No | \
-                QMessageBox.Yes))
-        if res == QMessageBox.Yes:
-            Helpviewer.HelpWindow.HelpWindow.adblockManager()\
+            self.trUtf8(
+                """<p>Subscribe to this AdBlock subscription?</p>"""
+                """<p>{0}</p>""").format(title))
+        if res:
+            from .AdBlockSubscription import AdBlockSubscription
+            import Helpviewer.HelpWindow
+            
+            dlg = Helpviewer.HelpWindow.HelpWindow.adBlockManager()\
+                .showDialog()
+            subscription = AdBlockSubscription(
+                url, False,
+                Helpviewer.HelpWindow.HelpWindow.adBlockManager())
+            Helpviewer.HelpWindow.HelpWindow.adBlockManager()\
                 .addSubscription(subscription)
-            dlg = Helpviewer.HelpWindow.HelpWindow.adblockManager().showDialog()
-            model = dlg.model()
-            dlg.setCurrentIndex(model.index(model.rowCount() - 1, 0))
+            dlg.addSubscription(subscription, False)
             dlg.setFocus()
+            dlg.raise_()
         
         return EmptyNetworkReply(self.parent())
