@@ -7,26 +7,23 @@
 Module implementing a dialog to add a bookmark or a bookmark folder.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QModelIndex
+from PyQt4.QtGui import QSortFilterProxyModel, QDialog, QTreeView
 
-import Helpviewer.HelpWindow
+from .Ui_AddBookmarkDialog import Ui_AddBookmarkDialog
 
-from BookmarkNode import BookmarkNode
-
-from Ui_AddBookmarkDialog import Ui_AddBookmarkDialog
 
 class AddBookmarkProxyModel(QSortFilterProxyModel):
     """
     Class implementing a proxy model used by the AddBookmarkDialog dialog.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QSortFilterProxyModel.__init__(self, parent)
+        super().__init__(parent)
     
     def columnCount(self, parent):
         """
@@ -58,7 +55,7 @@ class AddBookmarkProxyModel(QSortFilterProxyModel):
         """
         return sourceColumn == 0
     
-    def hasChildren(self, parent = QModelIndex()):
+    def hasChildren(self, parent=QModelIndex()):
         """
         Public method to check, if a parent node has some children.
         
@@ -68,27 +65,30 @@ class AddBookmarkProxyModel(QSortFilterProxyModel):
         sindex = self.mapToSource(parent)
         return self.sourceModel().hasChildren(sindex)
 
+
 class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
     """
     Class implementing a dialog to add a bookmark or a bookmark folder.
     """
-    def __init__(self, parent = None, bookmarksManager = None):
+    def __init__(self, parent=None, bookmarksManager=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
-        @param bookmarksManager reference to the bookmarks manager 
+        @param bookmarksManager reference to the bookmarks manager
             object (BookmarksManager)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.__bookmarksManager = None
+        self.__bookmarksManager = bookmarksManager
         self.__addedNode = None
         self.__addFolder = False
         
         if self.__bookmarksManager is None:
-            self.__bookmarksManager = Helpviewer.HelpWindow.HelpWindow.bookmarksManager()
+            import Helpviewer.HelpWindow
+            self.__bookmarksManager = \
+                Helpviewer.HelpWindow.HelpWindow.bookmarksManager()
         
         self.__proxyModel = AddBookmarkProxyModel(self)
         model = self.__bookmarksManager.bookmarksModel()
@@ -116,7 +116,7 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         Public slot to set the URL of the new bookmark.
         
-        @param url URL of the bookmark (QString)
+        @param url URL of the bookmark (string)
         """
         self.addressEdit.setText(url)
         self.resize(self.sizeHint())
@@ -125,7 +125,7 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         Public method to get the URL of the bookmark.
         
-        @return URL of the bookmark (QString)
+        @return URL of the bookmark (string)
         """
         return self.addressEdit.text()
     
@@ -133,7 +133,7 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         Public method to set the title of the new bookmark.
         
-        @param title title of the bookmark (QString)
+        @param title title of the bookmark (string)
         """
         self.nameEdit.setText(title)
     
@@ -141,10 +141,26 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         Public method to get the title of the bookmark.
         
-        @return title of the bookmark (QString)
+        @return title of the bookmark (string)
         """
         return self.nameEdit.text()
     
+    def setDescription(self, description):
+        """
+        Public method to set the description of the new bookmark.
+        
+        @param description description of the bookamrk (string)
+        """
+        self.descriptionEdit.setPlainText(description)
+    
+    def description(self):
+        """
+        Public method to get the description of the bookmark.
+        
+        @return description of the bookamrk (string)
+        """
+        return self.descriptionEdit.toPlainText()
+    
     def setCurrentIndex(self, idx):
         """
         Public method to set the current index.
@@ -202,11 +218,13 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         """
         Public slot handling the acceptance of the dialog.
         """
-        if (not self.__addFolder and self.addressEdit.text().isEmpty()) or \
-           self.nameEdit.text().isEmpty():
-            QDialog.accept(self)
+        if (not self.__addFolder and not self.addressEdit.text()) or \
+           not self.nameEdit.text():
+            super().accept()
             return
         
+        from .BookmarkNode import BookmarkNode
+        
         idx = self.currentIndex()
         if not idx.isValid():
             idx = self.__bookmarksManager.bookmarksModel().index(0, 0)
@@ -220,8 +238,9 @@ class AddBookmarkDialog(QDialog, Ui_AddBookmarkDialog):
         bookmark.title = self.nameEdit.text()
         if not self.__addFolder:
             bookmark.url = self.addressEdit.text()
+        bookmark.desc = self.descriptionEdit.toPlainText()
         
         self.__bookmarksManager.addBookmark(parent, bookmark)
         self.__addedNode = bookmark
         
-        QDialog.accept(self)
+        super().accept()
