@@ -9,111 +9,80 @@ Module implementing the bookmarks manager.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4.QtWebKit import QWebPage
+from PyQt4.QtCore import pyqtSignal, Qt, QT_TRANSLATE_NOOP, QObject, QFile, \
+    QIODevice, QXmlStreamReader, QDate, QDateTime, QFileInfo, QUrl
+from PyQt4.QtGui import QUndoStack, QUndoCommand, QApplication, QDialog
 
-from KdeQt import KQMessageBox, KQFileDialog
+from E5Gui import E5MessageBox, E5FileDialog
 
-from BookmarkNode import BookmarkNode
-from BookmarksModel import BookmarksModel
-from DefaultBookmarks import DefaultBookmarks
-from XbelReader import XbelReader
-from XbelWriter import XbelWriter
+from .BookmarkNode import BookmarkNode
 
 from Utilities.AutoSaver import AutoSaver
 import Utilities
 import Preferences
 
-BOOKMARKBAR  = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Bar")
+BOOKMARKBAR = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Bar")
 BOOKMARKMENU = QT_TRANSLATE_NOOP("BookmarksManager", "Bookmarks Menu")
 
-##########################################################################################
+StartRoot = 0
+StartMenu = 1
+StartToolBar = 2
 
-extract_js = r"""
-function walk() {
-    var parent = arguments[0];
-    var indent = arguments[1];
-
-    var result = "";
-    var children = parent.childNodes;
-    var folderName = "";
-    var folded = "";
-    for (var i = 0; i < children.length; i++) {
-        var object = children.item(i);
-        if (object.nodeName == "HR") {
-            result += indent + "<separator/>\n";
-        }
-        if (object.nodeName == "H3") {
-            folderName = object.innerHTML;
-            folded = object.folded;
-            if (object.folded == undefined)
-                folded = "false";
-            else
-                folded = "true";
-        }
-        if (object.nodeName == "A") {
-            result += indent + "<bookmark href=\"" + encodeURI(object.href).replace(/&/g, '&amp;') + "\">\n";
-            result += indent + indent + "<title>" + object.innerHTML + "</title>\n";
-            result += indent + "</bookmark>\n";
-        }
-
-        var currentIndent = indent;
-        if (object.nodeName == "DL" && folderName != "") {
-            result += indent + "<folder folded=\"" + folded + "\">\n";
-            indent += "    ";
-            result += indent + "<title>" + folderName + "</title>\n";
-        }
-        result += walk(object, indent);
-        if (object.nodeName == "DL" && folderName != "") {
-            result += currentIndent + "</folder>\n";
-        }
-    }
-    return result;
-}
-
-var xbel = walk(document, "    ");
-
-if (xbel != "") {
-    xbel = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE xbel>\n<xbel version=\"1.0\">\n" + xbel + "</xbel>\n";
-}
-
-xbel;
-"""
-
-##########################################################################################
 
 class BookmarksManager(QObject):
     """
     Class implementing the bookmarks manager.
     
-    @signal entryAdded emitted after a bookmark node has been added
-    @signal entryRemoved emitted after a bookmark
-        node has been removed
-    @signal entryChanged emitted after a bookmark node has been changed
+    @signal entryAdded(BookmarkNode) emitted after a bookmark node has been
+        added
+    @signal entryRemoved(BookmarkNode, int, BookmarkNode) emitted after a
+        bookmark node has been removed
+    @signal entryChanged(BookmarkNode) emitted after a bookmark node has been
+        changed
+    @signal bookmarksSaved() emitted after the bookmarks were saved
+    @signal bookmarksReloaded() emitted after the bookmarks were reloaded
     """
-    def __init__(self, parent = None):
+    entryAdded = pyqtSignal(BookmarkNode)
+    entryRemoved = pyqtSignal(BookmarkNode, int, BookmarkNode)
+    entryChanged = pyqtSignal(BookmarkNode)
+    bookmarksSaved = pyqtSignal()
+    bookmarksReloaded = pyqtSignal()
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
-        self.__loaded = False
         self.__saveTimer = AutoSaver(self, self.save)
+        self.entryAdded.connect(self.__saveTimer.changeOccurred)
+        self.entryRemoved.connect(self.__saveTimer.changeOccurred)
+        self.entryChanged.connect(self.__saveTimer.changeOccurred)
+        
+        self.__initialize()
+    
+    def __initialize(self):
+        """
+        Private method to initialize some data.
+        """
+        self.__loaded = False
         self.__bookmarkRootNode = None
         self.__toolbar = None
         self.__menu = None
         self.__bookmarksModel = None
         self.__commands = QUndoStack()
+    
+    @classmethod
+    def getFileName(cls):
+        """
+        Public method to get the file name of the bookmark file.
         
-        self.connect(self, SIGNAL("entryAdded"), 
-                     self.__saveTimer.changeOccurred)
-        self.connect(self, SIGNAL("entryRemoved"), 
-                     self.__saveTimer.changeOccurred)
-        self.connect(self, SIGNAL("entryChanged"), 
-                     self.__saveTimer.changeOccurred)
+        @return name of the bookmark file (string)
+        """
+        return os.path.join(Utilities.getConfigDir(), "browser",
+                            "bookmarks.xbel")
     
     def close(self):
         """
@@ -135,43 +104,58 @@ class BookmarksManager(QObject):
         """
         self.__saveTimer.changeOccurred()
     
+    def reload(self):
+        """
+        Public method used to initiate a reloading of the bookmarks.
+        """
+        self.__initialize()
+        self.load()
+        self.bookmarksReloaded.emit()
+    
     def load(self):
         """
         Public method to load the bookmarks.
+        
+        @exception RuntimeError raised to indicate an error loading the
+            bookmarks
         """
         if self.__loaded:
             return
         
         self.__loaded = True
         
-        bookmarkFile = os.path.join(Utilities.getConfigDir(), "browser", "bookmarks.xbel")
+        bookmarkFile = self.getFileName()
         if not QFile.exists(bookmarkFile):
-            ba = QByteArray(DefaultBookmarks)
-            bookmarkFile = QBuffer(ba)
+            from . import DefaultBookmarks_rc       # __IGNORE_WARNING__
+            bookmarkFile = QFile(":/DefaultBookmarks.xbel")
             bookmarkFile.open(QIODevice.ReadOnly)
         
+        from .XbelReader import XbelReader
         reader = XbelReader()
         self.__bookmarkRootNode = reader.read(bookmarkFile)
         if reader.error() != QXmlStreamReader.NoError:
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                None,
                 self.trUtf8("Loading Bookmarks"),
-                self.trUtf8("""Error when loading bookmarks on line %1, column %2:\n"""
-                            """%3""")\
-                    .arg(reader.lineNumber())\
-                    .arg(reader.columnNumber())\
-                    .arg(reader.errorString()))
+                self.trUtf8(
+                    """Error when loading bookmarks on line {0},"""
+                    """ column {1}:\n {2}""")
+                .format(reader.lineNumber(),
+                        reader.columnNumber(),
+                        reader.errorString()))
         
         others = []
-        for index in range(len(self.__bookmarkRootNode.children()) - 1, -1, -1):
+        for index in range(
+                len(self.__bookmarkRootNode.children()) - 1, -1, -1):
             node = self.__bookmarkRootNode.children()[index]
             if node.type() == BookmarkNode.Folder:
-                if (node.title == self.trUtf8("Toolbar Bookmarks") or \
+                if (node.title == self.trUtf8("Toolbar Bookmarks") or
                     node.title == BOOKMARKBAR) and \
                    self.__toolbar is None:
                     node.title = self.trUtf8(BOOKMARKBAR)
                     self.__toolbar = node
                 
-                if (node.title == self.trUtf8("Menu") or \
+                if (node.title == self.trUtf8("Menu") or
                     node.title == BOOKMARKMENU) and \
                    self.__menu is None:
                     node.title = self.trUtf8(BOOKMARKMENU)
@@ -179,18 +163,20 @@ class BookmarksManager(QObject):
             else:
                 others.append(node)
             self.__bookmarkRootNode.remove(node)
-            
+        
         if len(self.__bookmarkRootNode.children()) > 0:
             raise RuntimeError("Error loading bookmarks.")
         
         if self.__toolbar is None:
-            self.__toolbar = BookmarkNode(BookmarkNode.Folder, self.__bookmarkRootNode)
+            self.__toolbar = BookmarkNode(BookmarkNode.Folder,
+                                          self.__bookmarkRootNode)
             self.__toolbar.title = self.trUtf8(BOOKMARKBAR)
         else:
             self.__bookmarkRootNode.add(self.__toolbar)
         
         if self.__menu is None:
-            self.__menu = BookmarkNode(BookmarkNode.Folder, self.__bookmarkRootNode)
+            self.__menu = BookmarkNode(BookmarkNode.Folder,
+                                       self.__bookmarkRootNode)
             self.__menu.title = self.trUtf8(BOOKMARKMENU)
         else:
             self.__bookmarkRootNode.add(self.__menu)
@@ -207,22 +193,27 @@ class BookmarksManager(QObject):
         if not self.__loaded:
             return
         
+        from .XbelWriter import XbelWriter
         writer = XbelWriter()
-        bookmarkFile = os.path.join(Utilities.getConfigDir(), "browser", "bookmarks.xbel")
+        bookmarkFile = self.getFileName()
         
         # save root folder titles in English (i.e. not localized)
         self.__menu.title = BOOKMARKMENU
         self.__toolbar.title = BOOKMARKBAR
         if not writer.write(bookmarkFile, self.__bookmarkRootNode):
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                None,
                 self.trUtf8("Saving Bookmarks"),
-                self.trUtf8("""Error saving bookmarks to <b>%1</b>.""").arg(bookmarkFile))
+                self.trUtf8("""Error saving bookmarks to <b>{0}</b>.""")
+                .format(bookmarkFile))
         
         # restore localized titles
         self.__menu.title = self.trUtf8(BOOKMARKMENU)
         self.__toolbar.title = self.trUtf8(BOOKMARKBAR)
+        
+        self.bookmarksSaved.emit()
     
-    def addBookmark(self, parent, node, row = -1):
+    def addBookmark(self, parent, node, row=-1):
         """
         Public method to add a bookmark.
         
@@ -233,6 +224,9 @@ class BookmarksManager(QObject):
         if not self.__loaded:
             return
         
+        self.setTimestamp(node,  BookmarkNode.TsAdded,
+                          QDateTime.currentDateTime())
+        
         command = InsertBookmarksCommand(self, parent, node, row)
         self.__commands.push(command)
     
@@ -255,7 +249,7 @@ class BookmarksManager(QObject):
         Public method to set the title of a bookmark.
         
         @param node reference to the node to be changed (BookmarkNode)
-        @param newTitle title to be set (QString)
+        @param newTitle title to be set (string)
         """
         if not self.__loaded:
             return
@@ -268,7 +262,7 @@ class BookmarksManager(QObject):
         Public method to set the URL of a bookmark.
         
         @param node reference to the node to be changed (BookmarkNode)
-        @param newUrl URL to be set (QString)
+        @param newUrl URL to be set (string)
         """
         if not self.__loaded:
             return
@@ -276,6 +270,40 @@ class BookmarksManager(QObject):
         command = ChangeBookmarkCommand(self, node, newUrl, False)
         self.__commands.push(command)
     
+    def setNodeChanged(self, node):
+        """
+        Public method to signal changes of bookmarks other than title, URL
+        or timestamp.
+        
+        @param node reference to the bookmark (BookmarkNode)
+        """
+        self.__saveTimer.changeOccurred()
+    
+    def setTimestamp(self, node, timestampType, timestamp):
+        """
+        Public method to set the URL of a bookmark.
+        
+        @param node reference to the node to be changed (BookmarkNode)
+        @param timestampType type of the timestamp to set
+            (BookmarkNode.TsAdded, BookmarkNode.TsModified,
+            BookmarkNode.TsVisited)
+        @param timestamp timestamp to set (QDateTime)
+        """
+        if not self.__loaded:
+            return
+        
+        assert timestampType in [BookmarkNode.TsAdded,
+                                 BookmarkNode.TsModified,
+                                 BookmarkNode.TsVisited]
+        
+        if timestampType == BookmarkNode.TsAdded:
+            node.added = timestamp
+        elif timestampType == BookmarkNode.TsModified:
+            node.modified = timestamp
+        elif timestampType == BookmarkNode.TsVisited:
+            node.visited = timestamp
+        self.__saveTimer.changeOccurred()
+    
     def bookmarks(self):
         """
         Public method to get a reference to the root bookmark node.
@@ -316,6 +344,7 @@ class BookmarksManager(QObject):
         @return reference to the bookmarks model (BookmarksModel)
         """
         if self.__bookmarksModel is None:
+            from .BookmarksModel import BookmarksModel
             self.__bookmarksModel = BookmarksModel(self, self)
         return self.__bookmarksModel
     
@@ -323,73 +352,46 @@ class BookmarksManager(QObject):
         """
         Public method to import bookmarks.
         """
-        supportedFormats = QStringList() \
-            << self.trUtf8("XBEL bookmarks").append(" (*.xbel *.xml)") \
-            << self.trUtf8("HTML Netscape bookmarks").append(" (*.html *.htm)")
-        
-        fileName = KQFileDialog.getOpenFileName(\
-            None,
-            self.trUtf8("Import Bookmarks"),
-            QString(),
-            supportedFormats.join(";;"),
-            None)
-        if fileName.isEmpty():
-            return
-        
-        reader = XbelReader()
-        importRootNode = None
-        if fileName.endsWith(".html"):
-            inFile = QFile(fileName)
-            inFile.open(QIODevice.ReadOnly)
-            if inFile.openMode == QIODevice.NotOpen:
-                KQMessageBox.warning(None,
-                    self.trUtf8("Import Bookmarks"),
-                    self.trUtf8("""Error opening bookmarks file <b>%1</b>.""")\
-                        .arg(fileName))
-                return
-            
-            webpage = QWebPage()
-            webpage.mainFrame().setHtml(QString(inFile.readAll()))
-            result = webpage.mainFrame().evaluateJavaScript(extract_js).toByteArray()
-            buffer_ = QBuffer(result)
-            buffer_.open(QIODevice.ReadOnly)
-            importRootNode = reader.read(buffer_)
-        else:
-            importRootNode = reader.read(fileName)
-        
-        if reader.error() != QXmlStreamReader.NoError:
-            KQMessageBox.warning(None,
-                self.trUtf8("Import Bookmarks"),
-                self.trUtf8("""Error when importing bookmarks on line %1, column %2:\n"""
-                            """%3""")\
-                    .arg(reader.lineNumber())\
-                    .arg(reader.columnNumber())\
-                    .arg(reader.errorString()))
-            return
-        
-        importRootNode.setType(BookmarkNode.Folder)
-        importRootNode.title = self.trUtf8("Imported %1")\
-            .arg(QDate.currentDate().toString(Qt.SystemLocaleShortDate))
-        self.addBookmark(self.menu(), importRootNode)
+        from .BookmarksImportDialog import BookmarksImportDialog
+        dlg = BookmarksImportDialog()
+        if dlg.exec_() == QDialog.Accepted:
+            importRootNode = dlg.getImportedBookmarks()
+            if importRootNode is not None:
+                self.addBookmark(self.menu(), importRootNode)
     
     def exportBookmarks(self):
         """
         Public method to export the bookmarks.
         """
-        fileName = KQFileDialog.getSaveFileName(\
+        fileName, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             None,
             self.trUtf8("Export Bookmarks"),
-            "eric4_bookmarks.xbel",
-            self.trUtf8("XBEL bookmarks").append(" (*.xbel *.xml)"))
-        if fileName.isEmpty():
+            "eric5_bookmarks.xbel",
+            self.trUtf8("XBEL bookmarks (*.xbel);;"
+                        "XBEL bookmarks (*.xml);;"
+                        "HTML Bookmarks (*.html)"))
+        if not fileName:
             return
         
-        writer = XbelWriter()
+        ext = QFileInfo(fileName).suffix()
+        if not ext:
+            ex = selectedFilter.split("(*")[1].split(")")[0]
+            if ex:
+                fileName += ex
+        
+        ext = QFileInfo(fileName).suffix()
+        if ext == "html":
+            from .NsHtmlWriter import NsHtmlWriter
+            writer = NsHtmlWriter()
+        else:
+            from .XbelWriter import XbelWriter
+            writer = XbelWriter()
         if not writer.write(fileName, self.__bookmarkRootNode):
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                None,
                 self.trUtf8("Exporting Bookmarks"),
-                self.trUtf8("""Error exporting bookmarks to <b>%1</b>.""")\
-                    .arg(fileName))
+                self.trUtf8("""Error exporting bookmarks to <b>{0}</b>.""")
+                .format(fileName))
     
     def __convertFromOldBookmarks(self):
         """
@@ -398,23 +400,120 @@ class BookmarksManager(QObject):
         bmNames = Preferences.Prefs.settings.value('Bookmarks/Names')
         bmFiles = Preferences.Prefs.settings.value('Bookmarks/Files')
         
-        if bmNames.isValid() and bmFiles.isValid():
-            bmNames = bmNames.toStringList()
-            bmFiles = bmFiles.toStringList()
+        if bmNames is not None and bmFiles is not None:
             if len(bmNames) == len(bmFiles):
                 convertedRootNode = BookmarkNode(BookmarkNode.Folder)
-                convertedRootNode.title = self.trUtf8("Converted %1")\
-                    .arg(QDate.currentDate().toString(Qt.SystemLocaleShortDate))
+                convertedRootNode.title = self.trUtf8("Converted {0}")\
+                    .format(QDate.currentDate().toString(
+                        Qt.SystemLocaleShortDate))
                 for i in range(len(bmNames)):
-                    node = BookmarkNode(BookmarkNode.Bookmark, convertedRootNode)
+                    node = BookmarkNode(BookmarkNode.Bookmark,
+                                        convertedRootNode)
                     node.title = bmNames[i]
                     url = QUrl(bmFiles[i])
-                    if url.scheme().isEmpty():
+                    if not url.scheme():
                         url.setScheme("file")
                     node.url = url.toString()
                 self.addBookmark(self.menu(), convertedRootNode)
                 
                 Preferences.Prefs.settings.remove('Bookmarks')
+    
+    def iconChanged(self, url):
+        """
+        Public slot to update the icon image for an URL.
+        
+        @param url URL of the icon to update (QUrl or string)
+        """
+        if isinstance(url, QUrl):
+            url = url.toString()
+        nodes = self.bookmarksForUrl(url)
+        for node in nodes:
+            self.bookmarksModel().entryChanged(node)
+    
+    def bookmarkForUrl(self, url, start=StartRoot):
+        """
+        Public method to get a bookmark node for a given URL.
+        
+        @param url URL of the bookmark to search for (QUrl or string)
+        @keyparam start indicator for the start of the search
+            (StartRoot, StartMenu, StartToolBar)
+        @return bookmark node for the given url (BookmarkNode)
+        """
+        if start == StartMenu:
+            startNode = self.__menu
+        elif start == StartToolBar:
+            startNode = self.__toolbar
+        else:
+            startNode = self.__bookmarkRootNode
+        if startNode is None:
+            return None
+        
+        if isinstance(url, QUrl):
+            url = url.toString()
+        
+        return self.__searchBookmark(url, startNode)
+    
+    def __searchBookmark(self, url, startNode):
+        """
+        Private method get a bookmark node for a given URL.
+        
+        @param url URL of the bookmark to search for (string)
+        @param startNode reference to the node to start searching
+            (BookmarkNode)
+        @return bookmark node for the given url (BookmarkNode)
+        """
+        bm = None
+        for node in startNode.children():
+            if node.type() == BookmarkNode.Folder:
+                bm = self.__searchBookmark(url, node)
+            elif node.type() == BookmarkNode.Bookmark:
+                if node.url == url:
+                    bm = node
+            if bm is not None:
+                return bm
+        return None
+    
+    def bookmarksForUrl(self, url, start=StartRoot):
+        """
+        Public method to get a list of bookmark nodes for a given URL.
+        
+        @param url URL of the bookmarks to search for (QUrl or string)
+        @keyparam start indicator for the start of the search
+            (StartRoot, StartMenu, StartToolBar)
+        @return list of bookmark nodes for the given url (list of BookmarkNode)
+        """
+        if start == StartMenu:
+            startNode = self.__menu
+        elif start == StartToolBar:
+            startNode = self.__toolbar
+        else:
+            startNode = self.__bookmarkRootNode
+        if startNode is None:
+            return None
+        
+        if isinstance(url, QUrl):
+            url = url.toString()
+        
+        return self.__searchBookmarks(url, startNode)
+    
+    def __searchBookmarks(self, url, startNode):
+        """
+        Private method get a list of bookmark nodes for a given URL.
+        
+        @param url URL of the bookmarks to search for (string)
+        @param startNode reference to the node to start searching
+            (BookmarkNode)
+        @return list of bookmark nodes for the given url (list of BookmarkNode)
+        """
+        bm = []
+        for node in startNode.children():
+            if node.type() == BookmarkNode.Folder:
+                bm.extend(self.__searchBookmarks(url, node))
+            elif node.type() == BookmarkNode.Bookmark:
+                if node.url == url:
+                    bm.append(node)
+        return bm
+
 
 class RemoveBookmarksCommand(QUndoCommand):
     """
@@ -424,11 +523,12 @@ class RemoveBookmarksCommand(QUndoCommand):
         """
         Constructor
         
-        @param bookmarksManager reference to the bookmarks manager (BookmarksManager)
+        @param bookmarksManager reference to the bookmarks manager
+            (BookmarksManager)
         @param parent reference to the parent node (BookmarkNode)
         @param row row number of bookmark (integer)
         """
-        QUndoCommand.__init__(self, 
+        super().__init__(
             QApplication.translate("BookmarksManager", "Remove Bookmark"))
         
         self._row = row
@@ -444,17 +544,17 @@ class RemoveBookmarksCommand(QUndoCommand):
         Public slot to perform the undo action.
         """
         self._parent.add(self._node, self._row)
-        self._bookmarksManager.emit(SIGNAL("entryAdded"), self._node)
+        self._bookmarksManager.entryAdded.emit(self._node)
     
     def redo(self):
         """
         Public slot to perform the redo action.
         """
         self._parent.remove(self._node)
-        self._bookmarksManager.emit(
-            SIGNAL("entryRemoved"), 
+        self._bookmarksManager.entryRemoved.emit(
             self._parent, self._row, self._node)
 
+
 class InsertBookmarksCommand(RemoveBookmarksCommand):
     """
     Class implementing the Insert undo command.
@@ -463,13 +563,15 @@ class InsertBookmarksCommand(RemoveBookmarksCommand):
         """
         Constructor
         
-        @param bookmarksManager reference to the bookmarks manager (BookmarksManager)
+        @param bookmarksManager reference to the bookmarks manager
+            (BookmarksManager)
         @param parent reference to the parent node (BookmarkNode)
         @param node reference to the node to be inserted (BookmarkNode)
         @param row row number of bookmark (integer)
         """
         RemoveBookmarksCommand.__init__(self, bookmarksManager, parent, row)
-        self.setText(QApplication.translate("BookmarksManager", "Insert Bookmark"))
+        self.setText(QApplication.translate(
+            "BookmarksManager", "Insert Bookmark"))
         self._node = node
     
     def undo(self):
@@ -484,6 +586,7 @@ class InsertBookmarksCommand(RemoveBookmarksCommand):
         """
         RemoveBookmarksCommand.undo(self)
 
+
 class ChangeBookmarkCommand(QUndoCommand):
     """
     Class implementing the Insert undo command.
@@ -492,13 +595,14 @@ class ChangeBookmarkCommand(QUndoCommand):
         """
         Constructor
         
-        @param bookmarksManager reference to the bookmarks manager (BookmarksManager)
+        @param bookmarksManager reference to the bookmarks manager
+            (BookmarksManager)
         @param node reference to the node to be changed (BookmarkNode)
-        @param newValue new value to be set (QString)
-        @param title flag indicating a change of the title (True) or 
+        @param newValue new value to be set (string)
+        @param title flag indicating a change of the title (True) or
             the URL (False) (boolean)
         """
-        QUndoCommand.__init__(self)
+        super().__init__()
         
         self._bookmarksManager = bookmarksManager
         self._title = title
@@ -507,10 +611,12 @@ class ChangeBookmarkCommand(QUndoCommand):
         
         if self._title:
             self._oldValue = self._node.title
-            self.setText(QApplication.translate("BookmarksManager", "Name Change"))
+            self.setText(QApplication.translate(
+                "BookmarksManager", "Name Change"))
         else:
             self._oldValue = self._node.url
-            self.setText(QApplication.translate("BookmarksManager", "Address Change"))
+            self.setText(QApplication.translate(
+                "BookmarksManager", "Address Change"))
     
     def undo(self):
         """
@@ -520,7 +626,7 @@ class ChangeBookmarkCommand(QUndoCommand):
             self._node.title = self._oldValue
         else:
             self._node.url = self._oldValue
-        self._bookmarksManager.emit(SIGNAL("entryChanged"), self._node)
+        self._bookmarksManager.entryChanged.emit(self._node)
     
     def redo(self):
         """
@@ -530,4 +636,4 @@ class ChangeBookmarkCommand(QUndoCommand):
             self._node.title = self._newValue
         else:
             self._node.url = self._newValue
-        self._bookmarksManager.emit(SIGNAL("entryChanged"), self._node)
+        self._bookmarksManager.entryChanged.emit(self._node)
