@@ -9,8 +9,8 @@ Module implementing a QNetworkCookieJar subclass with various accept policies.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, QByteArray, QDataStream, QIODevice, \
+    QSettings, QDateTime
 from PyQt4.QtNetwork import QNetworkCookieJar, QNetworkCookie
 from PyQt4.QtWebKit import QWebSettings
 
@@ -18,39 +18,43 @@ from Utilities.AutoSaver import AutoSaver
 import Utilities
 import Preferences
 
+
 class CookieJar(QNetworkCookieJar):
     """
-    Class implementing a QNetworkCookieJar subclass with various accept policies.
+    Class implementing a QNetworkCookieJar subclass with various accept
+    policies.
     
     @signal cookiesChanged() emitted after the cookies have been changed
     """
+    cookiesChanged = pyqtSignal()
+    
     JAR_VERSION = 23
     
-    AcceptAlways                    = 0
-    AcceptNever                     = 1
-    AcceptOnlyFromSitesNavigatedTo  = 2
+    AcceptAlways = 0
+    AcceptNever = 1
+    AcceptOnlyFromSitesNavigatedTo = 2
 
-    KeepUntilExpire     = 0
-    KeepUntilExit       = 1
-    KeepUntilTimeLimit  = 2
+    KeepUntilExpire = 0
+    KeepUntilExit = 1
+    KeepUntilTimeLimit = 2
     
-    Allow           = 0
-    Block           = 1
+    Allow = 0
+    Block = 1
     AllowForSession = 2
     
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QNetworkCookieJar.__init__(self, parent)
+        super().__init__(parent)
         
         self.__loaded = False
         self.__acceptCookies = self.AcceptOnlyFromSitesNavigatedTo
         self.__saveTimer = AutoSaver(self, self.save)
         
-        self.__cookiesFile = os.path.join(Utilities.getConfigDir(), 
+        self.__cookiesFile = os.path.join(Utilities.getConfigDir(),
                                           "browser", "cookies.ini")
     
     def saveCookies(self, cookiesList):
@@ -62,6 +66,7 @@ class CookieJar(QNetworkCookieJar):
         """
         data = QByteArray()
         stream = QDataStream(data, QIODevice.WriteOnly)
+        stream.setVersion(QDataStream.Qt_4_6)
         stream.writeUInt16(self.JAR_VERSION)
         stream.writeUInt32(len(cookiesList))
         for cookie in cookiesList:
@@ -82,12 +87,13 @@ class CookieJar(QNetworkCookieJar):
         cookiesList = []
         data = QByteArray(cookies)
         stream = QDataStream(data, QIODevice.ReadOnly)
+        stream.setVersion(QDataStream.Qt_4_6)
         
         version = stream.readUInt16()
         if version != self.JAR_VERSION:
             return []
         
-        noCookies = stream.readUInt32()
+        stream.readUInt32()  # number of cookies
         
         rawCookie = QByteArray()
         while not stream.atEnd():
@@ -115,7 +121,7 @@ class CookieJar(QNetworkCookieJar):
         
         self.setAllCookies([])
         self.__saveTimer.changeOccurred()
-        self.emit(SIGNAL("cookiesChanged()"))
+        self.cookiesChanged.emit()
     
     def load(self):
         """
@@ -128,19 +134,19 @@ class CookieJar(QNetworkCookieJar):
         
         # load cookies
         cookies = cookieSettings.value("Cookies")
-        if cookies.isValid():
-            cookiesList = self.loadCookies(cookies.toByteArray())
+        if cookies:
+            cookiesList = self.loadCookies(cookies)
         else:
             cookiesList = []
         self.setAllCookies(cookiesList)
         
         # load exceptions
-        self.__exceptionsBlock = \
-            cookieSettings.value("Exceptions/block").toStringList()
-        self.__exceptionsAllow = \
-            cookieSettings.value("Exceptions/allow").toStringList()
-        self.__exceptionsAllowForSession = \
-            cookieSettings.value("Exceptions/allowForSession").toStringList()
+        self.__exceptionsBlock = Preferences.toList(
+            cookieSettings.value("Exceptions/block"))
+        self.__exceptionsAllow = Preferences.toList(
+            cookieSettings.value("Exceptions/allow"))
+        self.__exceptionsAllowForSession = Preferences.toList(
+            cookieSettings.value("Exceptions/allowForSession"))
         self.__exceptionsBlock.sort()
         self.__exceptionsAllow.sort()
         self.__exceptionsAllowForSession.sort()
@@ -150,10 +156,11 @@ class CookieJar(QNetworkCookieJar):
         if self.__keepCookies == self.KeepUntilExit:
             self.setAllCookies([])
         
-        self.__filterTrackingCookies = Preferences.getHelp("FilterTrackingCookies")
+        self.__filterTrackingCookies = Preferences.toBool(
+            Preferences.getHelp("FilterTrackingCookies"))
         
         self.__loaded = True
-        self.emit(SIGNAL("cookiesChanged()"))
+        self.cookiesChanged.emit()
     
     def save(self):
         """
@@ -167,27 +174,25 @@ class CookieJar(QNetworkCookieJar):
         cookieSettings = QSettings(self.__cookiesFile, QSettings.IniFormat)
         
         cookiesList = self.allCookies()
-        for index in range(len(cookiesList) -1, -1, -1):
+        for index in range(len(cookiesList) - 1, -1, -1):
             if cookiesList[index].isSessionCookie():
                 del cookiesList[index]
         cookies = self.saveCookies(cookiesList)
         
-        cookieSettings.setValue("Cookies", 
-                                QVariant(cookies))
-        cookieSettings.setValue("Exceptions/block", 
-                                QVariant(self.__exceptionsBlock))
-        cookieSettings.setValue("Exceptions/allow", 
-                                QVariant(self.__exceptionsAllow))
-        cookieSettings.setValue("Exceptions/allowForSession", 
-                                QVariant(self.__exceptionsAllowForSession))
+        cookieSettings.setValue("Cookies", cookies)
+        cookieSettings.setValue("Exceptions/block", self.__exceptionsBlock)
+        cookieSettings.setValue("Exceptions/allow", self.__exceptionsAllow)
+        cookieSettings.setValue("Exceptions/allowForSession",
+                                self.__exceptionsAllowForSession)
         
         Preferences.setHelp("AcceptCookies", self.__acceptCookies)
         Preferences.setHelp("KeepCookiesUntil", self.__keepCookies)
-        Preferences.setHelp("FilterTrackingCookies", int(self.__filterTrackingCookies))
+        Preferences.setHelp("FilterTrackingCookies",
+                            self.__filterTrackingCookies)
     
     def __purgeOldCookies(self):
         """
-        Private method to purge old cookies
+        Private method to purge old cookies.
         """
         cookies = self.allCookies()
         if len(cookies) == 0:
@@ -202,7 +207,7 @@ class CookieJar(QNetworkCookieJar):
         if oldCount == len(cookies):
             return
         self.setAllCookies(cookies)
-        self.emit(SIGNAL("cookiesChanged()"))
+        self.cookiesChanged.emit()
     
     def cookiesForUrl(self, url):
         """
@@ -238,10 +243,11 @@ class CookieJar(QNetworkCookieJar):
         host = url.host()
         eBlock = self.__isOnDomainList(self.__exceptionsBlock, host)
         eAllow = not eBlock and \
-                 self.__isOnDomainList(self.__exceptionsAllow, host)
+            self.__isOnDomainList(self.__exceptionsAllow, host)
         eAllowSession = not eBlock and \
-                        not eAllow and \
-                        self.__isOnDomainList(self.__exceptionsAllowForSession, host)
+            not eAllow and \
+            self.__isOnDomainList(
+                self.__exceptionsAllowForSession, host)
         
         addedCookies = False
         acceptInitially = self.__acceptCookies != self.AcceptNever
@@ -252,7 +258,7 @@ class CookieJar(QNetworkCookieJar):
             soon = soon.addDays(90)
             for cookie in cookieList:
                 lst = []
-                if not (self.__filterTrackingCookies and \
+                if not (self.__filterTrackingCookies and
                         cookie.name().startsWith("__utm")):
                     if eAllowSession:
                         cookie.setExpirationDate(QDateTime())
@@ -280,7 +286,7 @@ class CookieJar(QNetworkCookieJar):
         
         if addedCookies:
             self.__saveTimer.changeOccurred()
-            self.emit(SIGNAL("cookiesChanged()"))
+            self.cookiesChanged.emit()
         
         return addedCookies
     
@@ -312,6 +318,8 @@ class CookieJar(QNetworkCookieJar):
     def keepPolicy(self):
         """
         Private method to get the keep policy.
+        
+        @return keep policy
         """
         if not self.__loaded:
             self.load()
@@ -336,7 +344,7 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to return the blocked cookies.
         
-        @return list of blocked cookies (QStringList)
+        @return list of blocked cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
@@ -346,7 +354,7 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to return the allowed cookies.
         
-        @return list of allowed cookies (QStringList)
+        @return list of allowed cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
@@ -356,7 +364,7 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to return the allowed session cookies.
         
-        @return list of allowed session cookies (QStringList)
+        @return list of allowed session cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
@@ -366,11 +374,11 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to set the list of blocked cookies.
         
-        @param list_ list of blocked cookies (QStringList)
+        @param list_ list of blocked cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
-        self.__exceptionsBlock = QStringList(list_)
+        self.__exceptionsBlock = list_[:]
         self.__exceptionsBlock.sort()
         self.__applyRules()
         self.__saveTimer.changeOccurred()
@@ -379,11 +387,11 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to set the list of allowed cookies.
         
-        @param list_ list of allowed cookies (QStringList)
+        @param list_ list of allowed cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
-        self.__exceptionsAllow = QStringList(list_)
+        self.__exceptionsAllow = list_[:]
         self.__exceptionsAllow.sort()
         self.__applyRules()
         self.__saveTimer.changeOccurred()
@@ -392,11 +400,11 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to set the list of allowed session cookies.
         
-        @param list_ list of allowed session cookies (QStringList)
+        @param list_ list of allowed session cookies (list of strings)
         """
         if not self.__loaded:
             self.load()
-        self.__exceptionsAllowForSession = QStringList(list_)
+        self.__exceptionsAllowForSession = list_[:]
         self.__exceptionsAllowForSession.sort()
         self.__applyRules()
         self.__saveTimer.changeOccurred()
@@ -422,24 +430,23 @@ class CookieJar(QNetworkCookieJar):
         Private method to check, if either the rule matches the domain exactly
         or the domain ends with ".rule".
         
-        @param rules list of rules (QStringList)
-        @param domain domain name to check (QString)
+        @param rules list of rules (list of strings)
+        @param domain domain name to check (string)
         @return flag indicating a match (boolean)
         """
-        domain = QString(domain)
         for rule in rules:
-            if rule.startsWith("."):
-                if domain.endsWith(rule):
+            if rule.startswith("."):
+                if domain.endswith(rule):
                     return True
                 
-                withoutDot = rule.right(rule.size() - 1)
+                withoutDot = rule[1:]
                 if domain == withoutDot:
                     return True
             else:
-                domainEnding = domain.right(rule.size() + 1)
-                if not domainEnding.isEmpty() and \
+                domainEnding = domain[-(len(rule) + 1):]
+                if domainEnding and \
                    domainEnding[0] == "." and \
-                   domain.endsWith(rule):
+                   domain.endswith(rule):
                     return True
                 
                 if rule == domain:
@@ -459,14 +466,15 @@ class CookieJar(QNetworkCookieJar):
             if self.__isOnDomainList(self.__exceptionsBlock, cookie.domain()):
                 del cookiesList[index]
                 changed = True
-            elif self.__isOnDomainList(self.__exceptionsAllowForSession, cookie.domain()):
+            elif self.__isOnDomainList(self.__exceptionsAllowForSession,
+                                       cookie.domain()):
                 cookie.setExpirationDate(QDateTime())
                 changed = True
         
         if changed:
             self.setAllCookies(cookiesList)
             self.__saveTimer.changeOccurred()
-            self.emit(SIGNAL("cookiesChanged()"))
+            self.cookiesChanged.emit()
     
     def cookies(self):
         """
@@ -483,11 +491,11 @@ class CookieJar(QNetworkCookieJar):
         """
         Public method to set all cookies.
         
-        @param cookies list of cookies to be set.
+        @param cookies list of cookies to be set (list of QNetworkCookie)
         """
         if not self.__loaded:
             self.load()
         
         self.setAllCookies(cookies)
         self.__saveTimer.changeOccurred()
-        self.emit(SIGNAL("cookiesChanged()"))
+        self.cookiesChanged.emit()
