@@ -7,74 +7,68 @@
 Module implementing a dialog to show all cookies.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot, Qt, QDateTime, QByteArray
+from PyQt4.QtGui import QDialog, QFont, QFontMetrics, QSortFilterProxyModel
 
-from CookieModel import CookieModel
-from CookieDetailsDialog import CookieDetailsDialog
-from CookiesExceptionsDialog import CookiesExceptionsDialog
+from .CookieModel import CookieModel
 
-from Ui_CookiesDialog import Ui_CookiesDialog
+from .Ui_CookiesDialog import Ui_CookiesDialog
 
-import UI.PixmapCache
 
 class CookiesDialog(QDialog, Ui_CookiesDialog):
     """
     Class implementing a dialog to show all cookies.
     """
-    def __init__(self, cookieJar, parent = None):
+    def __init__(self, cookieJar, parent=None):
         """
         Constructor
         
         @param cookieJar reference to the cookie jar (CookieJar)
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.clearButton.setIcon(UI.PixmapCache.getIcon("clearLeft.png"))
         self.addButton.setEnabled(False)
         
         self.__cookieJar = cookieJar
         
-        self.connect(self.removeButton, SIGNAL("clicked()"), 
-                     self.cookiesTable.removeSelected)
-        self.connect(self.removeAllButton, SIGNAL("clicked()"), 
-                     self.cookiesTable.removeAll)
+        self.removeButton.clicked[()].connect(self.cookiesTable.removeSelected)
+        self.removeAllButton.clicked[()].connect(self.cookiesTable.removeAll)
         
         self.cookiesTable.verticalHeader().hide()
         model = CookieModel(cookieJar, self)
         self.__proxyModel = QSortFilterProxyModel(self)
         self.__proxyModel.setSourceModel(model)
-        self.connect(self.searchEdit, SIGNAL("textChanged(QString)"), 
-                     self.__proxyModel.setFilterFixedString)
+        self.searchEdit.textChanged.connect(
+            self.__proxyModel.setFilterFixedString)
         self.cookiesTable.setModel(self.__proxyModel)
-        self.connect(self.cookiesTable, 
-                     SIGNAL("doubleClicked(const QModelIndex&)"), 
-                     self.__showCookieDetails)
-        self.connect(self.cookiesTable.selectionModel(), 
-                     SIGNAL("selectionChanged(const QItemSelection&, const QItemSelection&)"), 
-                     self.__tableSelectionChanged)
-        self.connect(self.cookiesTable.model(), 
-                     SIGNAL("modelReset()"), 
-                     self.__tableModelReset)
+        self.cookiesTable.doubleClicked.connect(self.__showCookieDetails)
+        self.cookiesTable.selectionModel().selectionChanged.connect(
+            self.__tableSelectionChanged)
+        self.cookiesTable.model().modelReset.connect(self.__tableModelReset)
         
         fm = QFontMetrics(QFont())
-        height = fm.height() + fm.height() / 3
+        height = fm.height() + fm.height() // 3
         self.cookiesTable.verticalHeader().setDefaultSectionSize(height)
         self.cookiesTable.verticalHeader().setMinimumSectionSize(-1)
         for section in range(model.columnCount()):
-            header = self.cookiesTable.horizontalHeader().sectionSizeHint(section)
+            header = self.cookiesTable.horizontalHeader()\
+                .sectionSizeHint(section)
             if section == 0:
                 header = fm.width("averagebiglonghost.averagedomain.info")
             elif section == 1:
                 header = fm.width("_session_id")
             elif section == 4:
-                header = fm.width(QDateTime.currentDateTime().toString(Qt.LocalDate))
+                header = fm.width(
+                    QDateTime.currentDateTime().toString(Qt.LocalDate))
             buffer = fm.width("mm")
             header += buffer
             self.cookiesTable.horizontalHeader().resizeSection(section, header)
         self.cookiesTable.horizontalHeader().setStretchLastSection(True)
+        self.cookiesTable.model().sort(
+            self.cookiesTable.horizontalHeader().sortIndicatorSection(),
+            Qt.AscendingOrder)
         
         self.__detailsDialog = None
     
@@ -94,21 +88,23 @@ class CookiesDialog(QDialog, Ui_CookiesDialog):
         model = cookiesTable.model()
         row = index.row()
         
-        domain = model.data(model.index(row, 0)).toString()
-        name = model.data(model.index(row, 1)).toString()
-        path = model.data(model.index(row, 2)).toString()
-        secure = model.data(model.index(row, 3)).toBool()
-        expires = model.data(model.index(row, 4)).toDateTime()\
-            .toString("yyyy-MM-dd hh:mm")
-        value = QString(
-            QByteArray.fromPercentEncoding(model.data(model.index(row, 5)).toByteArray()))
+        domain = model.data(model.index(row, 0))
+        name = model.data(model.index(row, 1))
+        path = model.data(model.index(row, 2))
+        secure = model.data(model.index(row, 3))
+        expires = model.data(model.index(row, 4)).toString("yyyy-MM-dd hh:mm")
+        value = bytes(
+            QByteArray.fromPercentEncoding(
+                model.data(model.index(row, 5)))).decode()
         
         if self.__detailsDialog is None:
+            from .CookieDetailsDialog import CookieDetailsDialog
             self.__detailsDialog = CookieDetailsDialog(self)
-        self.__detailsDialog.setData(domain, name, path, secure, expires, value)
+        self.__detailsDialog.setData(domain, name, path, secure, expires,
+                                     value)
         self.__detailsDialog.show()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add a new exception.
@@ -117,9 +113,11 @@ class CookiesDialog(QDialog, Ui_CookiesDialog):
         if len(selection) == 0:
             return
         
+        from .CookiesExceptionsDialog import CookiesExceptionsDialog
+        
         firstSelected = selection[0]
         domainSelection = firstSelected.sibling(firstSelected.row(), 0)
-        domain = self.__proxyModel.data(domainSelection, Qt.DisplayRole).toString()
+        domain = self.__proxyModel.data(domainSelection, Qt.DisplayRole)
         dlg = CookiesExceptionsDialog(self.__cookieJar, self)
         dlg.setDomainName(domain)
         dlg.exec_()
