@@ -7,29 +7,32 @@
 Module implementing a window for showing the QtHelp index.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, Qt, QUrl, QEvent
+from PyQt4.QtGui import QWidget, QVBoxLayout, QLabel, QLineEdit, QMenu, QDialog
 
-from HelpTopicDialog import HelpTopicDialog
 
 class HelpIndexWidget(QWidget):
     """
     Class implementing a window for showing the QtHelp index.
     
-    @signal linkActivated(const QUrl&) emitted when an index entry is activated
-    @signal linksActivated(links, keyword) emitted when an index entry referencing
-            multiple targets is activated
+    @signal linkActivated(QUrl) emitted when an index entry is activated
+    @signal linksActivated(links, keyword) emitted when an index entry
+        referencing multiple targets is activated
     @signal escapePressed() emitted when the ESC key was pressed
     """
-    def __init__(self, engine, mainWindow, parent = None):
+    linkActivated = pyqtSignal(QUrl)
+    linksActivated = pyqtSignal(dict, str)
+    escapePressed = pyqtSignal()
+    
+    def __init__(self, engine, mainWindow, parent=None):
         """
         Constructor
         
         @param engine reference to the help engine (QHelpEngine)
-        @param mainWindow reference to the main window object (KQMainWindow)
+        @param mainWindow reference to the main window object (QMainWindow)
         @param parent reference to the parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         
         self.__engine = engine
         self.__mw = mainWindow
@@ -38,26 +41,24 @@ class HelpIndexWidget(QWidget):
         self.__index = None
         
         self.__layout = QVBoxLayout(self)
-        l = QLabel(self.trUtf8("&Look for:"))
-        self.__layout.addWidget(l)
+        label = QLabel(self.trUtf8("&Look for:"))
+        self.__layout.addWidget(label)
         
         self.__searchEdit = QLineEdit()
-        l.setBuddy(self.__searchEdit)
-        self.connect(self.__searchEdit, SIGNAL("textChanged(QString)"), 
-                     self.__filterIndices)
+        label.setBuddy(self.__searchEdit)
+        self.__searchEdit.textChanged.connect(self.__filterIndices)
         self.__searchEdit.installEventFilter(self)
         self.__layout.addWidget(self.__searchEdit)
         
         self.__index = self.__engine.indexWidget()
         self.__index.installEventFilter(self)
-        self.connect(self.__engine.indexModel(), SIGNAL("indexCreationStarted()"), 
-                     self.__disableSearchEdit)
-        self.connect(self.__engine.indexModel(), SIGNAL("indexCreated()"), 
-                     self.__enableSearchEdit)
-        self.connect(self.__index, SIGNAL("activated(const QModelIndex&)"), 
-                     self.__activated)
-        self.connect(self.__searchEdit, SIGNAL("returnPressed()"), 
-                     self.__index, SLOT("activateCurrentItem()"))
+        self.__engine.indexModel().indexCreationStarted.connect(
+            self.__disableSearchEdit)
+        self.__engine.indexModel().indexCreated.connect(
+            self.__enableSearchEdit)
+        self.__index.activated.connect(self.__activated)
+        self.__searchEdit.returnPressed.connect(
+            self.__index.activateCurrentItem)
         self.__layout.addWidget(self.__index)
         
         self.__index.viewport().installEventFilter(self)
@@ -70,19 +71,18 @@ class HelpIndexWidget(QWidget):
         """
         model = self.__index.model()
         if model is not None:
-            keyword = model.data(idx, Qt.DisplayRole).toString()
+            keyword = model.data(idx, Qt.DisplayRole)
             links = model.linksForKeyword(keyword)
             if len(links) == 1:
-                self.emit(SIGNAL("linkActivated(const QUrl&)"), 
-                          QUrl(links[links.keys()[0]]))
+                self.linkActivated.emit(QUrl(links[list(links.keys())[0]]))
             else:
-                self.emit(SIGNAL("linksActivated"), links, keyword)
+                self.linksActivated.emit(links, keyword)
     
     def __filterIndices(self, filter):
         """
         Private slot to filter the indices according to the given filter.
         
-        @param filter filter to be used (QString)
+        @param filter filter to be used (string)
         """
         if '*' in filter:
             self.__index.filterIndices(filter, filter)
@@ -134,9 +134,9 @@ class HelpIndexWidget(QWidget):
                 if idx.isValid():
                     self.__index.setCurrentIndex(idx)
             elif event.key() == Qt.Key_Escape:
-                self.emit(SIGNAL("escapePressed()"))
+                self.escapePressed.emit()
         elif self.__index and watched == self.__index and \
-             event.type() == QEvent.ContextMenu:
+                event.type() == QEvent.ContextMenu:
             idx = self.__index.indexAt(event.pos())
             if idx.isValid():
                 menu = QMenu()
@@ -150,25 +150,27 @@ class HelpIndexWidget(QWidget):
                 elif act == newTab:
                     model = self.__index.model()
                     if model is not None:
-                        keyword = model.data(idx, Qt.DisplayRole).toString()
+                        keyword = model.data(idx, Qt.DisplayRole)
                         links = model.linksForKeyword(keyword)
                         if len(links) == 1:
-                            self.__mw.newTab(links.values()[0])
+                            self.__mw.newTab(list(links.values())[0])
                         elif len(links) > 1:
+                            from .HelpTopicDialog import HelpTopicDialog
                             dlg = HelpTopicDialog(self, keyword, links)
                             if dlg.exec_() == QDialog.Accepted:
                                 self.__mw.newTab(dlg.link())
         elif self.__index and watched == self.__index.viewport() and \
-             event.type() == QEvent.MouseButtonRelease:
+                event.type() == QEvent.MouseButtonRelease:
             idx = self.__index.indexAt(event.pos())
             if idx.isValid() and event.button() == Qt.MidButton:
                 model = self.__index.model()
                 if model is not None:
-                    keyword = model.data(idx, Qt.DisplayRole).toString()
+                    keyword = model.data(idx, Qt.DisplayRole)
                     links = model.linksForKeyword(keyword)
                     if len(links) == 1:
-                        self.__mw.newTab(links.values()[0])
+                        self.__mw.newTab(list(links.values())[0])
                     elif len(links) > 1:
+                        from .HelpTopicDialog import HelpTopicDialog
                         dlg = HelpTopicDialog(self, keyword, links)
                         if dlg.exec_() == QDialog.Accepted:
                             self.__mw.newTab(dlg.link())
