@@ -8,9 +8,10 @@ Module implementing a dialog to select a help topic to display.
 """
 
 from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import pyqtSignature, SIGNAL, QUrl
+from PyQt4.QtCore import QUrl
+
+from .Ui_HelpTopicDialog import Ui_HelpTopicDialog
 
-from Ui_HelpTopicDialog import Ui_HelpTopicDialog
 
 class HelpTopicDialog(QDialog, Ui_HelpTopicDialog):
     """
@@ -21,15 +22,15 @@ class HelpTopicDialog(QDialog, Ui_HelpTopicDialog):
         Constructor
         
         @param parent reference to the parent widget (QWidget)
-        @param keyword keyword for the link set (QString)
-        @param links dictionary with help topic as key (QString) and
+        @param keyword keyword for the link set (string)
+        @param links dictionary with help topic as key (string) and
             URL as value (QUrl)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.label.setText(self.trUtf8("Choose a &topic for <b>%1</b>:")\
-            .arg(keyword))
+        self.label.setText(self.trUtf8("Choose a &topic for <b>{0}</b>:")
+            .format(keyword))
         
         self.__links = links
         for topic in sorted(self.__links):
@@ -38,8 +39,7 @@ class HelpTopicDialog(QDialog, Ui_HelpTopicDialog):
             self.topicsList.setCurrentRow(0)
         self.topicsList.setFocus()
         
-        self.connect(self.topicsList, SIGNAL("itemActivated(QListWidgetItem*)"), 
-                     self.accept)
+        self.topicsList.itemActivated.connect(self.accept)
     
     def link(self):
         """
@@ -52,7 +52,7 @@ class HelpTopicDialog(QDialog, Ui_HelpTopicDialog):
             return QUrl()
         
         topic = itm.text()
-        if topic.isEmpty() or topic not in self.__links:
+        if topic == "" or topic not in self.__links:
             return QUrl()
         
         return self.__links[topic]
