@@ -7,121 +7,78 @@
 Module implementing a web search widget for the web browser.
 """
 
-import os
-import imp
-
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, QUrl, QModelIndex, QTimer, Qt
+from PyQt4.QtGui import QMenu, QStandardItem, QStandardItemModel, \
+    QCompleter, QFont, QIcon, QPixmap
 from PyQt4.QtWebKit import QWebSettings, QWebPage
 
 import UI.PixmapCache
 
 import Preferences
 
-from E4Gui.E4LineEdit import E4LineEdit
-
-from OpenSearch.OpenSearchManager import OpenSearchManager
-from OpenSearch.OpenSearchEngineAction import OpenSearchEngineAction
+from E5Gui.E5LineEdit import E5ClearableLineEdit
 
 
-class HelpWebSearchEdit(E4LineEdit):
-    """
-    Class implementing the web search line edit.
-    """
-    def __init__(self, mainWindow, parent=None):
-        """
-        Constructor
-        
-        @param mainWindow reference to the main window (HelpWindow)
-        @param parent reference to the parent widget (QWidget)
-        """
-        E4LineEdit.__init__(self, parent)
-        
-        self.__mw = mainWindow
-    
-    def mousePressEvent(self, evt):
-        """
-        Protected method called by a mouse press event.
-        
-        @param evt reference to the mouse event (QMouseEvent)
-        """
-        if evt.button() == Qt.XButton1:
-            self.__mw.currentBrowser().pageAction(QWebPage.Back).trigger()
-        elif evt.button() == Qt.XButton2:
-            self.__mw.currentBrowser().pageAction(QWebPage.Forward).trigger()
-        else:
-            E4LineEdit.mousePressEvent(self, evt)
-
-
-class HelpWebSearchWidget(QWidget):
+class HelpWebSearchWidget(E5ClearableLineEdit):
     """
     Class implementing a web search widget for the web browser.
     
-    @signal search(url) emitted when the search should be done
+    @signal search(QUrl) emitted when the search should be done
     """
-    def __init__(self, parent = None):
+    search = pyqtSignal(QUrl)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         
-        self.mw = parent
+        from E5Gui.E5LineEdit import E5LineEdit
+        from E5Gui.E5LineEditButton import E5LineEditButton
+        from .OpenSearch.OpenSearchManager import OpenSearchManager
+
+        self.__mw = parent
         
         self.__openSearchManager = OpenSearchManager(self)
-        self.connect(self.__openSearchManager, 
-                     SIGNAL("currentEngineChanged()"), 
-                     self.__currentEngineChanged)
-        self.__currentEngine = QString()
-        
-        self.__layout = QHBoxLayout(self)
-        self.__layout.setMargin(0)
-        self.__layout.setSpacing(0)
-        self.setLayout(self.__layout)
+        self.__openSearchManager.currentEngineChanged.connect(
+            self.__currentEngineChanged)
+        self.__currentEngine = ""
         
         self.__enginesMenu = QMenu(self)
         
-        self.__engineButton = QToolButton(self)
-        self.__engineButton.setPopupMode(QToolButton.InstantPopup)
+        self.__engineButton = E5LineEditButton(self)
         self.__engineButton.setMenu(self.__enginesMenu)
-        self.__layout.addWidget(self.__engineButton)
+        self.addWidget(self.__engineButton, E5LineEdit.LeftSide)
         
-        self.__searchButton = QToolButton(self)
+        self.__searchButton = E5LineEditButton(self)
         self.__searchButton.setIcon(UI.PixmapCache.getIcon("webSearch.png"))
-        self.__layout.addWidget(self.__searchButton)
-        
-        self.__searchEdit = HelpWebSearchEdit(self.mw, parent = self)
-        self.__layout.addWidget(self.__searchEdit)
-        
-        self.__clearButton = QToolButton(self)
-        self.__clearButton.setIcon(UI.PixmapCache.getIcon("clearLeft.png"))
-        self.__layout.addWidget(self.__clearButton)
+        self.addWidget(self.__searchButton, E5LineEdit.LeftSide)
         
         self.__model = QStandardItemModel(self)
         self.__completer = QCompleter()
         self.__completer.setModel(self.__model)
-        self.__completer.setCompletionMode(QCompleter.UnfilteredPopupCompletion)
-        self.__completer.setWidget(self.__searchEdit)
+        self.__completer.setCompletionMode(
+            QCompleter.UnfilteredPopupCompletion)
+        self.__completer.setWidget(self)
         
-        self.connect(self.__searchButton, SIGNAL("clicked()"), self.__searchButtonClicked)
-        self.connect(self.__searchEdit, SIGNAL("textEdited(const QString&)"), 
-                     self.__textEdited)
-        self.connect(self.__clearButton, SIGNAL("clicked()"), self.__searchEdit.clear)
-        self.connect(self.__searchEdit, SIGNAL("returnPressed()"), self.__searchNow)
-        self.connect(self.__completer, SIGNAL("activated(const QModelIndex &)"), 
-                     self.__completerActivated)
-        self.connect(self.__completer, SIGNAL("highlighted(const QModelIndex &)"), 
-                     self.__completerHighlighted)
-        self.connect(self.__enginesMenu, SIGNAL("aboutToShow()"), self.__showEnginesMenu)
+        self.__searchButton.clicked[()].connect(self.__searchButtonClicked)
+        self.textEdited.connect(self.__textEdited)
+        self.returnPressed[()].connect(self.__searchNow)
+        self.__completer.activated[QModelIndex].connect(
+            self.__completerActivated)
+        self.__completer.highlighted[QModelIndex].connect(
+            self.__completerHighlighted)
+        self.__enginesMenu.aboutToShow.connect(self.__showEnginesMenu)
         
         self.__suggestionsItem = None
-        self.__suggestions = QStringList()
+        self.__suggestions = []
         self.__suggestTimer = None
         self.__suggestionsEnabled = Preferences.getHelp("WebSearchSuggestions")
         
         self.__recentSearchesItem = None
-        self.__recentSearches = QStringList()
+        self.__recentSearches = []
         self.__maxSavedSearches = 10
         
         self.__engine = None
@@ -133,28 +90,31 @@ class HelpWebSearchWidget(QWidget):
         """
         Private slot to perform the web search.
         """
-        searchText = self.__searchEdit.text()
-        if searchText.isEmpty():
+        searchText = self.text()
+        if not searchText:
             return
         
         globalSettings = QWebSettings.globalSettings()
-        if not globalSettings.testAttribute(QWebSettings.PrivateBrowsingEnabled):
-            self.__recentSearches.removeAll(searchText)
-            self.__recentSearches.prepend(searchText)
+        if not globalSettings.testAttribute(
+                QWebSettings.PrivateBrowsingEnabled):
+            if searchText in self.__recentSearches:
+                self.__recentSearches.remove(searchText)
+            self.__recentSearches.insert(0, searchText)
             if len(self.__recentSearches) > self.__maxSavedSearches:
-                self.__recentSearches = self.__recentSearches[:self.__maxSavedSearches]
+                self.__recentSearches = \
+                    self.__recentSearches[:self.__maxSavedSearches]
             self.__setupCompleterMenu()
         
         url = self.__openSearchManager.currentEngine().searchUrl(searchText)
-        self.emit(SIGNAL("search"), url)
+        self.search.emit(url)
     
     def __setupCompleterMenu(self):
         """
         Private method to create the completer menu.
         """
-        if self.__suggestions.isEmpty() or \
-           (self.__model.rowCount() > 0 and \
-            self.__model.item(0) != self.__suggestionsItem):
+        if not self.__suggestions or \
+           (self.__model.rowCount() > 0 and
+                self.__model.item(0) != self.__suggestionsItem):
             self.__model.clear()
             self.__suggestionsItem = None
         else:
@@ -163,33 +123,36 @@ class HelpWebSearchWidget(QWidget):
         boldFont = QFont()
         boldFont.setBold(True)
         
-        if not self.__suggestions.isEmpty():
+        if self.__suggestions:
             if self.__model.rowCount() == 0:
                 if not self.__suggestionsItem:
-                    self.__suggestionsItem = QStandardItem(self.trUtf8("Suggestions"))
+                    self.__suggestionsItem = QStandardItem(
+                        self.trUtf8("Suggestions"))
                     self.__suggestionsItem.setFont(boldFont)
                 self.__model.appendRow(self.__suggestionsItem)
             
             for suggestion in self.__suggestions:
                 self.__model.appendRow(QStandardItem(suggestion))
         
-        if self.__recentSearches.isEmpty():
-            self.__recentSearchesItem = QStandardItem(self.trUtf8("No Recent Searches"))
+        if not self.__recentSearches:
+            self.__recentSearchesItem = QStandardItem(
+                self.trUtf8("No Recent Searches"))
             self.__recentSearchesItem.setFont(boldFont)
             self.__model.appendRow(self.__recentSearchesItem)
         else:
-            self.__recentSearchesItem = QStandardItem(self.trUtf8("Recent Searches"))
+            self.__recentSearchesItem = QStandardItem(
+                self.trUtf8("Recent Searches"))
             self.__recentSearchesItem.setFont(boldFont)
             self.__model.appendRow(self.__recentSearchesItem)
             for recentSearch in self.__recentSearches:
                 self.__model.appendRow(QStandardItem(recentSearch))
         
         view = self.__completer.popup()
-        view.setFixedHeight(
-            view.sizeHintForRow(0) * self.__model.rowCount() + view.frameWidth() * 2)
+        view.setFixedHeight(view.sizeHintForRow(0) * self.__model.rowCount() +
+                            view.frameWidth() * 2)
         
         self.__searchButton.setEnabled(
-            not self.__recentSearches.isEmpty() or not self.__suggestions.isEmpty())
+            bool(self.__recentSearches or self.__suggestions))
     
     def __completerActivated(self, index):
         """
@@ -212,6 +175,7 @@ class HelpWebSearchWidget(QWidget):
         Private slot handling the highlighting of an entry of the completer.
         
         @param index index of the item (QModelIndex)
+        @return flah indicating a successful highlighting (boolean)
         """
         if self.__suggestionsItem and \
            self.__suggestionsItem.index().row() == index.row():
@@ -221,22 +185,21 @@ class HelpWebSearchWidget(QWidget):
            self.__recentSearchesItem.index().row() == index.row():
             return False
         
-        self.__searchEdit.setText(index.data().toString())
+        self.setText(index.data())
         return True
     
     def __textEdited(self, txt):
         """
         Private slot to handle changes of the search text.
         
-        @param txt search text (QString)
+        @param txt search text (string)
         """
         if self.__suggestionsEnabled:
             if self.__suggestTimer is None:
                 self.__suggestTimer = QTimer(self)
                 self.__suggestTimer.setSingleShot(True)
                 self.__suggestTimer.setInterval(200)
-                self.connect(self.__suggestTimer, SIGNAL("timeout()"), 
-                             self.__getSuggestions)
+                self.__suggestTimer.timeout.connect(self.__getSuggestions)
             self.__suggestTimer.start()
         else:
             self.__completer.setCompletionPrefix(txt)
@@ -244,17 +207,19 @@ class HelpWebSearchWidget(QWidget):
     
     def __getSuggestions(self):
         """
-        Private slot to get search suggestions from the configured search engine.
+        Private slot to get search suggestions from the configured search
+        engine.
         """
-        searchText = self.__searchEdit.text()
-        if not searchText.isEmpty():
-            self.__openSearchManager.currentEngine().requestSuggestions(searchText)
+        searchText = self.text()
+        if searchText:
+            self.__openSearchManager.currentEngine()\
+                .requestSuggestions(searchText)
     
     def __newSuggestions(self, suggestions):
         """
         Private slot to receive a new list of suggestions.
         
-        @param suggestions list of suggestions (QStringList)
+        @param suggestions list of suggestions (list of strings)
         """
         self.__suggestions = suggestions
         self.__setupCompleterMenu()
@@ -266,19 +231,20 @@ class HelpWebSearchWidget(QWidget):
         """
         self.__enginesMenu.clear()
         
+        from .OpenSearch.OpenSearchEngineAction import OpenSearchEngineAction
         engineNames = self.__openSearchManager.allEnginesNames()
         for engineName in engineNames:
             engine = self.__openSearchManager.engine(engineName)
             action = OpenSearchEngineAction(engine, self.__enginesMenu)
-            action.setData(QVariant(engineName))
-            self.connect(action, SIGNAL("triggered()"), self.__changeCurrentEngine)
+            action.setData(engineName)
+            action.triggered[()].connect(self.__changeCurrentEngine)
             self.__enginesMenu.addAction(action)
             
             if self.__openSearchManager.currentEngineName() == engineName:
                 action.setCheckable(True)
                 action.setChecked(True)
         
-        ct = self.mw.currentBrowser()
+        ct = self.__mw.currentBrowser()
         linkedResources = ct.linkedResources("search")
         
         if len(linkedResources) > 0:
@@ -297,22 +263,23 @@ class HelpWebSearchWidget(QWidget):
             if url.isRelative():
                 url = ct.url().resolved(url)
             
-            if title.isEmpty():
-                if ct.title().isEmpty():
+            if not title:
+                if not ct.title():
                     title = url.host()
                 else:
                     title = ct.title()
             
-            action = self.__enginesMenu.addAction(self.trUtf8("Add '%1'").arg(title), 
-                                                  self.__addEngineFromUrl)
-            action.setData(QVariant(url))
+            action = self.__enginesMenu.addAction(
+                self.trUtf8("Add '{0}'").format(title),
+                self.__addEngineFromUrl)
+            action.setData(url)
             action.setIcon(ct.icon())
         
         self.__enginesMenu.addSeparator()
-        self.__enginesMenu.addAction(self.mw.searchEnginesAction())
+        self.__enginesMenu.addAction(self.__mw.searchEnginesAction())
         
-        if not self.__recentSearches.isEmpty():
-            self.__enginesMenu.addAction(self.trUtf8("Clear Recent Searches"), 
+        if self.__recentSearches:
+            self.__enginesMenu.addAction(self.trUtf8("Clear Recent Searches"),
                                          self.clear)
     
     def __changeCurrentEngine(self):
@@ -321,7 +288,7 @@ class HelpWebSearchWidget(QWidget):
         """
         action = self.sender()
         if action is not None:
-            name = action.data().toString()
+            name = action.data()
             self.__openSearchManager.setCurrentEngineName(name)
     
     def __addEngineFromUrl(self):
@@ -330,10 +297,9 @@ class HelpWebSearchWidget(QWidget):
         """
         action = self.sender()
         if action is not None:
-            variant = action.data()
-            if not variant.canConvert(QVariant.Url):
+            url = action.data()
+            if not isinstance(url, QUrl):
                 return
-            url = variant.toUrl()
             
             self.__openSearchManager.addEngine(url)
     
@@ -348,9 +314,9 @@ class HelpWebSearchWidget(QWidget):
         """
         Public method to clear all private data.
         """
-        self.__recentSearches.clear()
+        self.__recentSearches = []
         self.__setupCompleterMenu()
-        self.__searchEdit.clear()
+        super().clear()
         self.clearFocus()
     
     def preferencesChanged(self):
@@ -359,23 +325,23 @@ class HelpWebSearchWidget(QWidget):
         """
         self.__suggestionsEnabled = Preferences.getHelp("WebSearchSuggestions")
         if not self.__suggestionsEnabled:
-            self.__suggestions.clear()
+            self.__suggestions = []
             self.__setupCompleterMenu()
     
     def saveSearches(self):
         """
         Public method to save the recently performed web searches.
         """
-        Preferences.Prefs.settings.setValue('Help/WebSearches',
-            QVariant(self.__recentSearches))
+        Preferences.Prefs.settings.setValue(
+            'Help/WebSearches', self.__recentSearches)
     
     def __loadSearches(self):
         """
         Public method to load the recently performed web searches.
         """
         searches = Preferences.Prefs.settings.value('Help/WebSearches')
-        if searches.isValid():
-            self.__recentSearches = searches.toStringList()
+        if searches is not None:
+            self.__recentSearches = searches
     
     def openSearchManager(self):
         """
@@ -391,31 +357,40 @@ class HelpWebSearchWidget(QWidget):
         """
         if self.__openSearchManager.engineExists(self.__currentEngine):
             oldEngine = self.__openSearchManager.engine(self.__currentEngine)
-            self.disconnect(oldEngine, SIGNAL("imageChanged()"), 
-                            self.__engineImageChanged)
+            oldEngine.imageChanged.disconnect(self.__engineImageChanged)
             if self.__suggestionsEnabled:
-                self.disconnect(oldEngine, SIGNAL("suggestions(const QStringList&)"), 
-                                self.__newSuggestions)
+                oldEngine.suggestions.disconnect(self.__newSuggestions)
         
         newEngine = self.__openSearchManager.currentEngine()
         if newEngine.networkAccessManager() is None:
-            newEngine.setNetworkAccessManager(self.mw.networkAccessManager())
-        self.connect(newEngine, SIGNAL("imageChanged()"), 
-                     self.__engineImageChanged)
+            newEngine.setNetworkAccessManager(self.__mw.networkAccessManager())
+        newEngine.imageChanged.connect(self.__engineImageChanged)
         if self.__suggestionsEnabled:
-            self.connect(newEngine, SIGNAL("suggestions(const QStringList&)"), 
-                         self.__newSuggestions)
+            newEngine.suggestions.connect(self.__newSuggestions)
         
-        self.__searchEdit.setInactiveText(self.__openSearchManager.currentEngineName())
+        self.setInactiveText(self.__openSearchManager.currentEngineName())
         self.__currentEngine = self.__openSearchManager.currentEngineName()
-        self.__engineButton.setIcon(
-            QIcon(QPixmap.fromImage(self.__openSearchManager.currentEngine().image())))
-        self.__suggestions.clear()
+        self.__engineButton.setIcon(QIcon(QPixmap.fromImage(
+            self.__openSearchManager.currentEngine().image())))
+        self.__suggestions = []
         self.__setupCompleterMenu()
     
     def __engineImageChanged(self):
         """
         Private slot to handle a change of the current search engine icon.
         """
-        self.__engineButton.setIcon(
-            QIcon(QPixmap.fromImage(self.__openSearchManager.currentEngine().image())))
+        self.__engineButton.setIcon(QIcon(QPixmap.fromImage(
+            self.__openSearchManager.currentEngine().image())))
+    
+    def mousePressEvent(self, evt):
+        """
+        Protected method called by a mouse press event.
+        
+        @param evt reference to the mouse event (QMouseEvent)
+        """
+        if evt.button() == Qt.XButton1:
+            self.__mw.currentBrowser().pageAction(QWebPage.Back).trigger()
+        elif evt.button() == Qt.XButton2:
+            self.__mw.currentBrowser().pageAction(QWebPage.Forward).trigger()
+        else:
+            super().mousePressEvent(evt)
