@@ -7,16 +7,17 @@
 Module implementing the history filter model.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import Qt, QDateTime, QModelIndex
 from PyQt4.QtGui import QAbstractProxyModel
 
-from HistoryModel import HistoryModel
+from .HistoryModel import HistoryModel
+
 
 class HistoryData(object):
     """
     Class storing some history data.
     """
-    def __init__(self, offset, frequency = 0):
+    def __init__(self, offset, frequency=0):
         """
         Constructor
         
@@ -34,15 +35,15 @@ class HistoryData(object):
         @return flag indicating equality (boolean)
         """
         return self.tailOffset == other.tailOffset and \
-            (self.frequency == -1 or other.frequency == -1 or \
+            (self.frequency == -1 or other.frequency == -1 or
              self.frequency == other.frequency)
     
     def __lt__(self, other):
         """
         Special method determining less relation.
         
-        Note: Like the actual history entries the index mapping is sorted in reverse 
-        order by offset
+        Note: Like the actual history entries the index mapping is sorted in
+        reverse order by offset
         
         @param other reference to the history data object to compare against
             (HistoryEntry)
@@ -50,6 +51,7 @@ class HistoryData(object):
         """
         return self.tailOffset > other.tailOffset
 
+
 class HistoryFilterModel(QAbstractProxyModel):
     """
     Class implementing the history filter model.
@@ -57,14 +59,14 @@ class HistoryFilterModel(QAbstractProxyModel):
     FrequencyRole = HistoryModel.MaxRole + 1
     MaxRole = FrequencyRole
     
-    def __init__(self, sourceModel, parent = None):
+    def __init__(self, sourceModel, parent=None):
         """
         Constructor
         
         @param sourceModel reference to the source model (QAbstractItemModel)
         @param parent reference to the parent object (QObject)
         """
-        QAbstractProxyModel.__init__(self, parent)
+        super().__init__(parent)
         
         self.__loaded = False
         self.__filteredRows = []
@@ -77,36 +79,35 @@ class HistoryFilterModel(QAbstractProxyModel):
         """
         Public method to check the history for an entry.
         
-        @param url URL to check for (QString)
+        @param url URL to check for (string)
         @return flag indicating success (boolean)
         """
         self.__load()
-        return unicode(url) in self.__historyDict
+        return url in self.__historyDict
     
     def historyLocation(self, url):
         """
         Public method to get the row number of an entry in the source model.
         
-        @param url URL to check for (QString)
+        @param url URL to check for (tring)
         @return row number in the source model (integer)
         """
         self.__load()
-        url = unicode(url)
         if url not in self.__historyDict:
             return 0
         
         return self.sourceModel().rowCount() - self.__historyDict[url]
     
-    def data(self, index, role = Qt.DisplayRole):
+    def data(self, index, role=Qt.DisplayRole):
         """
         Public method to get data from the model.
         
         @param index index of history entry to get data for (QModelIndex)
         @param role data role (integer)
-        @return history entry data (QVariant)
+        @return history entry data
         """
         if role == self.FrequencyRole and index.isValid():
-            return QVariant(self.__filteredRows[index.row()].frequency)
+            return self.__filteredRows[index.row()].frequency
         
         return QAbstractProxyModel.data(self, index, role)
     
@@ -117,35 +118,20 @@ class HistoryFilterModel(QAbstractProxyModel):
         @param sourceModel reference to the source model (QAbstractItemModel)
         """
         if self.sourceModel() is not None:
-            self.disconnect(self.sourceModel(), 
-                            SIGNAL("modelReset()"), 
-                            self.__sourceReset)
-            self.disconnect(self.sourceModel(), 
-                            SIGNAL("dataChanged(const QModelIndex&, const QModelIndex&)"),
-                            self.__sourceDataChanged)
-            self.disconnect(self.sourceModel(), 
-                            SIGNAL("rowsInserted(const QModelIndex &, int, int)"), 
-                            self.__sourceRowsInserted)
-            self.disconnect(self.sourceModel(), 
-                            SIGNAL("rowsRemoved(const QModelIndex &, int, int)"), 
-                            self.__sourceRowsRemoved)
+            self.sourceModel().modelReset.disconnect(self.__sourceReset)
+            self.sourceModel().dataChanged.disconnect(self.__sourceDataChanged)
+            self.sourceModel().rowsInserted.disconnect(
+                self.__sourceRowsInserted)
+            self.sourceModel().rowsRemoved.disconnect(self.__sourceRowsRemoved)
         
-        QAbstractProxyModel.setSourceModel(self, sourceModel)
+        super().setSourceModel(sourceModel)
         
         if self.sourceModel() is not None:
             self.__loaded = False
-            self.connect(self.sourceModel(), 
-                         SIGNAL("modelReset()"), 
-                         self.__sourceReset)
-            self.connect(self.sourceModel(), 
-                         SIGNAL("dataChanged(const QModelIndex&, const QModelIndex&)"),
-                         self.__sourceDataChanged)
-            self.connect(self.sourceModel(), 
-                         SIGNAL("rowsInserted(const QModelIndex &, int, int)"), 
-                         self.__sourceRowsInserted)
-            self.connect(self.sourceModel(), 
-                         SIGNAL("rowsRemoved(const QModelIndex &, int, int)"), 
-                         self.__sourceRowsRemoved)
+            self.sourceModel().modelReset.connect(self.__sourceReset)
+            self.sourceModel().dataChanged.connect(self.__sourceDataChanged)
+            self.sourceModel().rowsInserted.connect(self.__sourceRowsInserted)
+            self.sourceModel().rowsRemoved.connect(self.__sourceRowsRemoved)
     
     def __sourceDataChanged(self, topLeft, bottomRight):
         """
@@ -154,17 +140,17 @@ class HistoryFilterModel(QAbstractProxyModel):
         @param topLeft index of top left data element (QModelIndex)
         @param bottomRight index of bottom right data element (QModelIndex)
         """
-        self.emit(SIGNAL("dataChanged(const QModelIndex&, const QModelIndex&)"), 
-                  self.mapFromSource(topLeft), self.mapFromSource(bottomRight))
+        self.dataChanged.emit(
+            self.mapFromSource(topLeft), self.mapFromSource(bottomRight))
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get the header data.
         
         @param section section number (integer)
         @param orientation header orientation (Qt.Orientation)
         @param role data role (integer)
-        @return header data (QVariant)
+        @return header data
         """
         return self.sourceModel().headerData(section, orientation, role)
     
@@ -181,7 +167,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         self.__loaded = False
         self.reset()
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to determine the number of rows.
         
@@ -193,7 +179,7 @@ class HistoryFilterModel(QAbstractProxyModel):
             return 0
         return len(self.__historyDict)
     
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the number of columns.
         
@@ -221,7 +207,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         @return proxy model index (QModelIndex)
         """
         self.__load()
-        url = unicode(sourceIndex.data(HistoryModel.UrlStringRole).toString())
+        url = sourceIndex.data(HistoryModel.UrlStringRole)
         if url not in self.__historyDict:
             return QModelIndex()
         
@@ -234,7 +220,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         
         return self.createIndex(row, sourceIndex.column(), sourceOffset)
     
-    def index(self, row, column, parent = QModelIndex()):
+    def index(self, row, column, parent=QModelIndex()):
         """
         Public method to create an index.
         
@@ -248,7 +234,8 @@ class HistoryFilterModel(QAbstractProxyModel):
            column < 0 or column >= self.columnCount(parent):
             return QModelIndex()
         
-        return self.createIndex(row, column, self.__filteredRows[row].tailOffset)
+        return self.createIndex(row, column,
+                                self.__filteredRows[row].tailOffset)
 
     def parent(self, index):
         """
@@ -272,7 +259,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         
         for sourceRow in range(self.sourceModel().rowCount()):
             idx = self.sourceModel().index(sourceRow, 0)
-            url = unicode(idx.data(HistoryModel.UrlStringRole).toString())
+            url = idx.data(HistoryModel.UrlStringRole)
             if url not in self.__historyDict:
                 sourceOffset = self.sourceModel().rowCount() - sourceRow
                 self.__filteredRows.append(
@@ -280,8 +267,10 @@ class HistoryFilterModel(QAbstractProxyModel):
                 self.__historyDict[url] = sourceOffset
             else:
                 # the url is known already, so just update the frequency score
-                row = self.__filteredRows.index(HistoryData(self.__historyDict[url], -1))
-                self.__filteredRows[row].frequency += self.__frequencyScore(idx)
+                row = self.__filteredRows.index(
+                    HistoryData(self.__historyDict[url], -1))
+                self.__filteredRows[row].frequency += \
+                    self.__frequencyScore(idx)
         
         self.__loaded = True
     
@@ -298,10 +287,11 @@ class HistoryFilterModel(QAbstractProxyModel):
                 return
             
             idx = self.sourceModel().index(start, 0, parent)
-            url = unicode(idx.data(HistoryModel.UrlStringRole).toString())
+            url = idx.data(HistoryModel.UrlStringRole)
             currentFrequency = 0
             if url in self.__historyDict:
-                row = self.__filteredRows.index(HistoryData(self.__historyDict[url], -1))
+                row = self.__filteredRows.index(
+                    HistoryData(self.__historyDict[url], -1))
                 currentFrequency = self.__filteredRows[row].frequency
                 self.beginRemoveRows(QModelIndex(), row, row)
                 del self.__filteredRows[row]
@@ -309,8 +299,10 @@ class HistoryFilterModel(QAbstractProxyModel):
                 self.endRemoveRows()
             
             self.beginInsertRows(QModelIndex(), 0, 0)
-            self.__filteredRows.insert(0, HistoryData(self.sourceModel().rowCount(), 
-                self.__frequencyScore(idx) + currentFrequency))
+            self.__filteredRows.insert(
+                0, HistoryData(
+                    self.sourceModel().rowCount(),
+                    self.__frequencyScore(idx) + currentFrequency))
             self.__historyDict[url] = self.sourceModel().rowCount()
             self.endInsertRows()
     
@@ -324,13 +316,13 @@ class HistoryFilterModel(QAbstractProxyModel):
         """
         self.__sourceReset()
     
-    def removeRows(self, row, count, parent = QModelIndex()):
+    def removeRows(self, row, count, parent=QModelIndex()):
         """
         Public method to remove entries from the model.
         
         @param row row of the first entry to remove (integer)
         @param count number of entries to remove (integer)
-        @param index of the parent entry (QModelIndex)
+        @param parent index of the parent entry (QModelIndex)
         @return flag indicating successful removal (boolean)
         """
         if row < 0 or \
@@ -340,18 +332,16 @@ class HistoryFilterModel(QAbstractProxyModel):
             return False
         
         lastRow = row + count - 1
-        self.disconnect(self.sourceModel(), 
-                        SIGNAL("rowsRemoved(const QModelIndex &, int, int)"), 
-                        self.__sourceRowsRemoved)
+        self.sourceModel().rowsRemoved.disconnect(self.__sourceRowsRemoved)
         self.beginRemoveRows(parent, row, lastRow)
         oldCount = self.rowCount()
-        start = self.sourceModel().rowCount() - self.__filteredRows[row].tailOffset
-        end = self.sourceModel().rowCount() - self.__filteredRows[lastRow].tailOffset
+        start = self.sourceModel().rowCount() - \
+            self.__filteredRows[row].tailOffset
+        end = self.sourceModel().rowCount() - \
+            self.__filteredRows[lastRow].tailOffset
         self.sourceModel().removeRows(start, end - start + 1)
         self.endRemoveRows()
-        self.connect(self.sourceModel(), 
-                     SIGNAL("rowsRemoved(const QModelIndex &, int, int)"), 
-                     self.__sourceRowsRemoved)
+        self.sourceModel().rowsRemoved.connect(self.__sourceRowsRemoved)
         self.__loaded = False
         if oldCount - count != self.rowCount():
             self.reset()
@@ -365,7 +355,7 @@ class HistoryFilterModel(QAbstractProxyModel):
         @return frequency score (integer)
         """
         loadTime = \
-            self.sourceModel().data(sourceIndex, HistoryModel.DateTimeRole).toDateTime()
+            self.sourceModel().data(sourceIndex, HistoryModel.DateTimeRole)
         days = loadTime.daysTo(self.__scaleTime)
         
         if days <= 1:
