@@ -7,15 +7,13 @@
 Module implementing the history manager.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+import os
+
+from PyQt4.QtCore import pyqtSignal, QFileInfo, QDateTime, QDate, QTime, \
+    QUrl, QTimer, QFile, QIODevice, QByteArray, QDataStream, QTemporaryFile
 from PyQt4.QtWebKit import QWebHistoryInterface, QWebSettings
 
-from KdeQt import KQMessageBox
-
-from HistoryModel import HistoryModel
-from HistoryFilterModel import HistoryFilterModel
-from HistoryTreeModel import HistoryTreeModel
+from E5Gui import E5MessageBox
 
 from Utilities.AutoSaver import AutoSaver
 import Utilities
@@ -23,27 +21,29 @@ import Preferences
 
 HISTORY_VERSION = 42
 
+
 class HistoryEntry(object):
     """
     Class implementing a history entry.
     """
-    def __init__(self, url = None, dateTime = None, title = None):
+    def __init__(self, url=None, dateTime=None, title=None):
         """
         Constructor
         
-        @param url URL of the history entry (QString)
+        @param url URL of the history entry (string)
         @param dateTime date and time this entry was created (QDateTime)
-        @param title title string for the history entry (QString)
+        @param title title string for the history entry (string)
         """
-        self.url = url and url or QString()
+        self.url = url and url or ""
         self.dateTime = dateTime and dateTime or QDateTime()
-        self.title = title and title or QString()
+        self.title = title and title or ""
     
     def __eq__(self, other):
         """
         Special method determining equality.
         
-        @param other reference to the history entry to compare against (HistoryEntry)
+        @param other reference to the history entry to compare against
+            (HistoryEntry)
         @return flag indicating equality (boolean)
         """
         return other.title == self.title and \
@@ -56,7 +56,8 @@ class HistoryEntry(object):
         
         Note: History is sorted in reverse order by date and time
         
-        @param other reference to the history entry to compare against (HistoryEntry)
+        @param other reference to the history entry to compare against
+            (HistoryEntry)
         @return flag indicating less (boolean)
         """
         return self.dateTime > other.dateTime
@@ -65,60 +66,73 @@ class HistoryEntry(object):
         """
         Public method to get the title of the history entry.
         
-        @return title of the entry (QString)
+        @return title of the entry (string)
         """
-        if self.title.isEmpty():
+        if not self.title:
             page = QFileInfo(QUrl(self.url).path()).fileName()
-            if not page.isEmpty():
+            if page:
                 return page
             return self.url
         return self.title
 
+
 class HistoryManager(QWebHistoryInterface):
     """
     Class implementing the history manager.
     
     @signal historyCleared() emitted after the history has been cleared
     @signal historyReset() emitted after the history has been reset
-    @signal entryAdded emitted after a history entry has been added
-    @signal entryRemoved emitted after a history entry has been removed
+    @signal entryAdded(HistoryEntry) emitted after a history entry has been
+        added
+    @signal entryRemoved(HistoryEntry) emitted after a history entry has been
+        removed
     @signal entryUpdated(int) emitted after a history entry has been updated
+    @signal historySaved() emitted after the history was saved
     """
-    def __init__(self, parent = None):
+    historyCleared = pyqtSignal()
+    historyReset = pyqtSignal()
+    entryAdded = pyqtSignal(HistoryEntry)
+    entryRemoved = pyqtSignal(HistoryEntry)
+    entryUpdated = pyqtSignal(int)
+    historySaved = pyqtSignal()
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QWebHistoryInterface.__init__(self, parent)
+        super().__init__(parent)
         
         self.__saveTimer = AutoSaver(self, self.save)
         self.__daysToExpire = Preferences.getHelp("HistoryLimit")
         self.__history = []
-        self.__lastSavedUrl = QString()
+        self.__lastSavedUrl = ""
         
-        self.__expiredTimer = QTimer()
+        self.__expiredTimer = QTimer(self)
         self.__expiredTimer.setSingleShot(True)
-        self.connect(self.__expiredTimer, SIGNAL("timeout()"), 
-                     self.__checkForExpired)
+        self.__expiredTimer.timeout.connect(self.__checkForExpired)
         
-        self.__frequencyTimer = QTimer()
+        self.__frequencyTimer = QTimer(self)
         self.__frequencyTimer.setSingleShot(True)
-        self.connect(self.__frequencyTimer, SIGNAL("timeout()"), 
-                     self.__refreshFrequencies)
+        self.__frequencyTimer.timeout.connect(self.__refreshFrequencies)
         
-        self.connect(self, SIGNAL("entryAdded"), 
-                     self.__saveTimer.changeOccurred)
-        self.connect(self, SIGNAL("entryRemoved"), 
-                     self.__saveTimer.changeOccurred)
+        self.entryAdded.connect(self.__saveTimer.changeOccurred)
+        self.entryRemoved.connect(self.__saveTimer.changeOccurred)
         
         self.__load()
         
-        self.__historyModel = HistoryModel(self, self)
-        self.__historyFilterModel = HistoryFilterModel(self.__historyModel, self)
-        self.__historyTreeModel = HistoryTreeModel(self.__historyFilterModel, self)
+        from .HistoryModel import HistoryModel
+        from .HistoryFilterModel import HistoryFilterModel
+        from .HistoryTreeModel import HistoryTreeModel
         
-        QWebHistoryInterface.setDefaultInterface(self)
+        self.__historyModel = HistoryModel(self, self)
+        self.__historyFilterModel = \
+            HistoryFilterModel(self.__historyModel, self)
+        self.__historyTreeModel = \
+            HistoryTreeModel(self.__historyFilterModel, self)
+        
+        super().setDefaultInterface(self)
         self.__startFrequencyTimer()
     
     def close(self):
@@ -138,13 +152,14 @@ class HistoryManager(QWebHistoryInterface):
         """
         return self.__history[:]
     
-    def setHistory(self, history, loadedAndSorted = False):
+    def setHistory(self, history, loadedAndSorted=False):
         """
         Public method to set a new history.
         
         @param history reference to the list of history entries to be set
             (list of HistoryEntry)
-        @param loadedAndSorted flag indicating that the list is sorted (boolean)
+        @param loadedAndSorted flag indicating that the list is sorted
+            (boolean)
         """
         self.__history = history[:]
         if not loadedAndSorted:
@@ -154,19 +169,19 @@ class HistoryManager(QWebHistoryInterface):
         
         if loadedAndSorted:
             try:
-                self.__lastSavedUrl = QString(self.__history[0].url)
+                self.__lastSavedUrl = self.__history[0].url
             except IndexError:
-                self.__lastSavedUrl = QString()
+                self.__lastSavedUrl = ""
         else:
-            self.__lastSavedUrl.clear()
+            self.__lastSavedUrl = ""
             self.__saveTimer.changeOccurred()
-        self.emit(SIGNAL("historyReset()"))
+        self.historyReset.emit()
     
     def historyContains(self, url):
         """
         Public method to check the history for an entry.
         
-        @param url URL to check for (QString)
+        @param url URL to check for (string)
         @return flag indicating success (boolean)
         """
         return self.__historyFilterModel.historyContains(url)
@@ -182,7 +197,7 @@ class HistoryManager(QWebHistoryInterface):
             return
         
         self.__history.insert(0, itm)
-        self.emit(SIGNAL("entryAdded"), itm)
+        self.entryAdded.emit(itm)
         if len(self.__history) == 1:
             self.__checkForExpired()
     
@@ -192,48 +207,55 @@ class HistoryManager(QWebHistoryInterface):
         
         @param itm reference to the history item to remove (HistoryEntry)
         """
-        self.__lastSavedUrl.clear()
+        self.__lastSavedUrl = ""
         self.__history.remove(itm)
-        self.emit(SIGNAL("entryRemoved"), itm)
+        self.entryRemoved.emit(itm)
     
     def addHistoryEntry(self, url):
         """
         Public method to add a history entry.
         
-        @param url URL to be added (QString)
+        @param url URL to be added (string)
         """
         cleanurl = QUrl(url)
-        cleanurl.setPassword("")
-        cleanurl.setHost(cleanurl.host().toLower())
-        itm = HistoryEntry(cleanurl.toString(), QDateTime.currentDateTime())
-        self._addHistoryEntry(itm)
+        if cleanurl.scheme() not in ["eric", "about"]:
+            if cleanurl.password():
+                # don't save the password in the history
+                cleanurl.setPassword("")
+            if cleanurl.host():
+                cleanurl.setHost(cleanurl.host().lower())
+            itm = HistoryEntry(cleanurl.toString(),
+                               QDateTime.currentDateTime())
+            self._addHistoryEntry(itm)
     
     def updateHistoryEntry(self, url, title):
         """
         Public method to update a history entry.
         
-        @param url URL of the entry to update (QString)
-        @param title title of the entry to update (QString)
+        @param url URL of the entry to update (string)
+        @param title title of the entry to update (string)
         """
-        for index in range(len(self.__history)):
-            if url == self.__history[index].url:
-                self.__history[index].title = title
-                self.__saveTimer.changeOccurred()
-                if self.__lastSavedUrl.isEmpty():
-                    self.__lastSavedUrl = QString(self.__history[index].url)
-                self.emit(SIGNAL("entryUpdated(int)"), index)
-                break
+        cleanurl = QUrl(url)
+        if cleanurl.scheme() not in ["eric", "about"]:
+            for index in range(len(self.__history)):
+                if url == self.__history[index].url:
+                    self.__history[index].title = title
+                    self.__saveTimer.changeOccurred()
+                    if not self.__lastSavedUrl:
+                        self.__lastSavedUrl = self.__history[index].url
+                    self.entryUpdated.emit(index)
+                    break
     
-    def removeHistoryEntry(self, url, title = QString()):
+    def removeHistoryEntry(self, url, title=""):
         """
         Public method to remove a history entry.
         
         @param url URL of the entry to remove (QUrl)
-        @param title title of the entry to remove (QString)
+        @param title title of the entry to remove (string)
         """
         for index in range(len(self.__history)):
             if url == QUrl(self.__history[index].url) and \
-               (title.isEmpty() or title == self.__history[index].title):
+               (not title or title == self.__history[index].title):
                 self._removeHistoryEntry(self.__history[index])
                 break
     
@@ -273,7 +295,8 @@ class HistoryManager(QWebHistoryInterface):
         
         while self.__history:
             checkForExpired = QDateTime(self.__history[-1].dateTime)
-            checkForExpired.setDate(checkForExpired.date().addDays(self.__daysToExpire))
+            checkForExpired.setDate(
+                checkForExpired.date().addDays(self.__daysToExpire))
             if now.daysTo(checkForExpired) > 7:
                 nextTimeout = 7 * 86400
             else:
@@ -282,8 +305,8 @@ class HistoryManager(QWebHistoryInterface):
                 break
             
             itm = self.__history.pop(-1)
-            self.__lastSavedUrl.clear()
-            self.emit(SIGNAL("entryRemoved"), itm)
+            self.__lastSavedUrl = ""
+            self.entryRemoved.emit(itm)
         self.__saveTimer.saveIfNeccessary()
         
         if nextTimeout > 0:
@@ -316,60 +339,80 @@ class HistoryManager(QWebHistoryInterface):
         """
         self.setDaysToExpire(Preferences.getHelp("HistoryLimit"))
     
-    def clear(self):
+    def clear(self, period=0):
         """
         Public slot to clear the complete history.
+        
+        @param period history period in milliseconds to be cleared (integer)
         """
-        self.__history = []
-        self.__lastSavedUrl.clear()
+        if period == 0:
+            self.__history = []
+            self.historyReset.emit()
+        else:
+            breakMS = QDateTime.currentMSecsSinceEpoch() - period
+            while self.__history and \
+                (QDateTime(self.__history[0].dateTime).toMSecsSinceEpoch() >
+                 breakMS):
+                itm = self.__history.pop(0)
+                self.entryRemoved.emit(itm)
+        self.__lastSavedUrl = ""
         self.__saveTimer.changeOccurred()
         self.__saveTimer.saveIfNeccessary()
-        self.emit(SIGNAL("historyReset()"))
-        self.emit(SIGNAL("historyCleared()"))
+        self.historyCleared.emit()
+    
+    def getFileName(self):
+        """
+        Public method to get the file name of the history file.
+        
+        @return name of the history file (string)
+        """
+        return os.path.join(Utilities.getConfigDir(), "browser", "history")
+    
+    def reload(self):
+        """
+        Public method to reload the history.
+        """
+        self.__load()
     
     def __load(self):
         """
         Private method to load the saved history entries from disk.
         """
-        historyFile = QFile(Utilities.getConfigDir() + "/browser/history")
+        historyFile = QFile(self.getFileName())
         if not historyFile.exists():
             return
         if not historyFile.open(QIODevice.ReadOnly):
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                None,
                 self.trUtf8("Loading History"),
-                self.trUtf8("""<p>Unable to open history file <b>%1</b>."""
-                            """<br/>Reason: %2</p>""")\
-                    .arg(historyFile.fileName).arg(historyFile.errorString()))
+                self.trUtf8(
+                    """<p>Unable to open history file <b>{0}</b>.<br/>"""
+                    """Reason: {1}</p>""")
+                .format(historyFile.fileName, historyFile.errorString()))
             return
         
         history = []
-        historyStream = QDataStream(historyFile)
         
         # double check, that the history file is sorted as it is read
         needToSort = False
         lastInsertedItem = HistoryEntry()
-        data = QByteArray()
-        stream = QDataStream()
-        buffer = QBuffer()
-        stream.setDevice(buffer)
-        while not historyFile.atEnd():
-            historyStream >> data
-            buffer.close()
-            buffer.setBuffer(data)
-            buffer.open(QIODevice.ReadOnly)
+        data = QByteArray(historyFile.readAll())
+        stream = QDataStream(data, QIODevice.ReadOnly)
+        stream.setVersion(QDataStream.Qt_4_6)
+        while not stream.atEnd():
             ver = stream.readUInt32()
             if ver != HISTORY_VERSION:
                 continue
             itm = HistoryEntry()
-            stream >> itm.url
+            itm.url = Utilities.readStringFromStream(stream)
             stream >> itm.dateTime
-            stream >> itm.title
+            itm.title = Utilities.readStringFromStream(stream)
             
             if not itm.dateTime.isValid():
                 continue
             
             if itm == lastInsertedItem:
-                if lastInsertedItem.title.isEmpty() and len(history) > 0:
+                if not lastInsertedItem.title and len(history) > 0:
                     history[0].title = itm.title
                 continue
             
@@ -387,18 +430,18 @@ class HistoryManager(QWebHistoryInterface):
         
         # if the history had to be sorted, rewrite the history sorted
         if needToSort:
-            self.__lastSavedUrl.clear()
+            self.__lastSavedUrl = ""
             self.__saveTimer.changeOccurred()
     
     def save(self):
         """
         Public slot to save the history entries to disk.
         """
-        historyFile = QFile(Utilities.getConfigDir() + "/browser/history")
+        historyFile = QFile(self.getFileName())
         if not historyFile.exists():
-            self.__lastSavedUrl.clear()
+            self.__lastSavedUrl = ""
         
-        saveAll = self.__lastSavedUrl.isEmpty()
+        saveAll = self.__lastSavedUrl == ""
         first = len(self.__history) - 1
         if not saveAll:
             # find the first one to save
@@ -409,61 +452,60 @@ class HistoryManager(QWebHistoryInterface):
         if first == len(self.__history) - 1:
             saveAll = True
         
-        # use a temporary file when saving everything
-        tempFile = QTemporaryFile()
-        tempFile.setAutoRemove(False)
         if saveAll:
-            opened = tempFile.open()
+            # use a temporary file when saving everything
+            f = QTemporaryFile()
+            f.setAutoRemove(False)
+            opened = f.open()
         else:
-            opened = historyFile.open(QIODevice.Append)
+            f = historyFile
+            opened = f.open(QIODevice.Append)
         
         if not opened:
-            if saveAll:
-                f = tempFile
-            else:
-                f = historyFile
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                None,
                 self.trUtf8("Saving History"),
-                self.trUtf8("""<p>Unable to open history file <b>%1</b>."""
-                            """<br/>Reason: %2</p>""")\
-                    .arg(f.fileName()).arg(f.errorString()))
+                self.trUtf8(
+                    """<p>Unable to open history file <b>{0}</b>.<br/>"""
+                    """Reason: {1}</p>""")
+                .format(f.fileName(), f.errorString()))
             return
         
-        if saveAll:
-            historyStream = QDataStream(tempFile)
-        else:
-            historyStream = QDataStream(historyFile)
         for index in range(first, -1, -1):
             data = QByteArray()
             stream = QDataStream(data, QIODevice.WriteOnly)
+            stream.setVersion(QDataStream.Qt_4_6)
             itm = self.__history[index]
             stream.writeUInt32(HISTORY_VERSION)
-            stream << itm.url
+            stream.writeString(itm.url.encode())
             stream << itm.dateTime
-            stream << itm.title
-            historyStream << data
+            stream.writeString(itm.title.encode())
+            f.write(data)
         
+        f.close()
         if saveAll:
-            tempFile.close()
             if historyFile.exists() and not historyFile.remove():
-                KQMessageBox.warning(None,
+                E5MessageBox.warning(
+                    None,
                     self.trUtf8("Saving History"),
-                    self.trUtf8("""<p>Error removing old history file <b>%1</b>."""
-                                """<br/>Reason: %2</p>""")\
-                        .arg(historyFile.fileName()).arg(historyFile.errorString()))
-            if not tempFile.copy(historyFile.fileName()):
-                KQMessageBox.warning(None,
+                    self.trUtf8(
+                        """<p>Error removing old history file <b>{0}</b>."""
+                        """<br/>Reason: {1}</p>""")
+                    .format(historyFile.fileName(),
+                            historyFile.errorString()))
+            if not f.copy(historyFile.fileName()):
+                E5MessageBox.warning(
+                    None,
                     self.trUtf8("Saving History"),
-                    self.trUtf8("""<p>Error moving new history file over old one """
-                                """(<b>%1</b>).<br/>Reason: %2</p>""")\
-                        .arg(historyFile.fileName()).arg(tempFile.errorString()))
-        else:
-            historyFile.close()
-        
+                    self.trUtf8(
+                        """<p>Error moving new history file over old one """
+                        """(<b>{0}</b>).<br/>Reason: {1}</p>""")
+                    .format(historyFile.fileName(), f.errorString()))
+        self.historySaved.emit()
         try:
-            self.__lastSavedUrl = QString(self.__history[0].url)
+            self.__lastSavedUrl = self.__history[0].url
         except IndexError:
-            self.__lastSavedUrl = QString()
+            self.__lastSavedUrl = ""
     
     def __refreshFrequencies(self):
         """
@@ -477,4 +519,5 @@ class HistoryManager(QWebHistoryInterface):
         Private method to start the timer to recalculate the frequencies.
         """
         tomorrow = QDateTime(QDate.currentDate().addDays(1), QTime(3, 0))
-        self.__frequencyTimer.start(QDateTime.currentDateTime().secsTo(tomorrow) * 1000)
+        self.__frequencyTimer.start(
+            QDateTime.currentDateTime().secsTo(tomorrow) * 1000)
