@@ -9,20 +9,17 @@ Module implementing the history menu.
 
 import sys
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, Qt, QMimeData, QUrl, QModelIndex
+from PyQt4.QtGui import QAbstractProxyModel, QSortFilterProxyModel, QMenu
 
-from KdeQt import KQMessageBox
+from E5Gui.E5ModelMenu import E5ModelMenu
+from E5Gui import E5MessageBox
 
-from E4Gui.E4ModelMenu import E4ModelMenu
-
-import Helpviewer.HelpWindow
-
-from HistoryModel import HistoryModel
-from HistoryDialog import HistoryDialog
+from .HistoryModel import HistoryModel
 
 import UI.PixmapCache
 
+
 class HistoryMenuModel(QAbstractProxyModel):
     """
     Class implementing a model for the history menu.
@@ -31,14 +28,14 @@ class HistoryMenuModel(QAbstractProxyModel):
     """
     MOVEDROWS = 15
     
-    def __init__(self, sourceModel, parent = None):
+    def __init__(self, sourceModel, parent=None):
         """
         Constructor
         
         @param sourceModel reference to the source model (QAbstractItemModel)
         @param parent reference to the parent object (QObject)
         """
-        QAbstractProxyModel.__init__(self, parent)
+        super().__init__(parent)
         
         self.__treeModel = sourceModel
         
@@ -55,7 +52,7 @@ class HistoryMenuModel(QAbstractProxyModel):
             return 0
         return min(self.__treeModel.rowCount(first), self.MOVEDROWS)
     
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the number of columns.
         
@@ -64,7 +61,7 @@ class HistoryMenuModel(QAbstractProxyModel):
         """
         return self.__treeModel.columnCount(self.mapToSource(parent))
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to determine the number of rows.
         
@@ -78,11 +75,12 @@ class HistoryMenuModel(QAbstractProxyModel):
             folders = self.sourceModel().rowCount()
             bumpedItems = self.bumpedRows()
             if bumpedItems <= self.MOVEDROWS and \
-               bumpedItems == self.sourceModel().rowCount(self.sourceModel().index(0, 0)):
+                    bumpedItems == self.sourceModel().rowCount(
+                        self.sourceModel().index(0, 0)):
                 folders -= 1
             return bumpedItems + folders
         
-        if parent.internalId() == sys.maxint:
+        if parent.internalId() == sys.maxsize:
             if parent.row() < self.bumpedRows():
                 return 0
         
@@ -100,9 +98,9 @@ class HistoryMenuModel(QAbstractProxyModel):
         @param sourceIndex reference to a source model index (QModelIndex)
         @return proxy model index (QModelIndex)
         """
-        assert False
         sourceRow = self.__treeModel.mapToSource(sourceIndex).row()
-        return self.createIndex(sourceIndex.row(), sourceIndex.column(), sourceRow)
+        return self.createIndex(
+            sourceIndex.row(), sourceIndex.column(), sourceRow)
     
     def mapToSource(self, proxyIndex):
         """
@@ -114,15 +112,17 @@ class HistoryMenuModel(QAbstractProxyModel):
         if not proxyIndex.isValid():
             return QModelIndex()
         
-        if proxyIndex.internalId() == sys.maxint:
+        if proxyIndex.internalId() == sys.maxsize:
             bumpedItems = self.bumpedRows()
             if proxyIndex.row() < bumpedItems:
-                return self.__treeModel.index(proxyIndex.row(), proxyIndex.column(), 
+                return self.__treeModel.index(
+                    proxyIndex.row(), proxyIndex.column(),
                     self.__treeModel.index(0, 0))
             if bumpedItems <= self.MOVEDROWS and \
-               bumpedItems == self.sourceModel().rowCount(self.__treeModel.index(0, 0)):
+                    bumpedItems == self.sourceModel().rowCount(
+                        self.__treeModel.index(0, 0)):
                 bumpedItems -= 1
-            return self.__treeModel.index(proxyIndex.row() - bumpedItems, 
+            return self.__treeModel.index(proxyIndex.row() - bumpedItems,
                                           proxyIndex.column())
         
         historyIndex = self.__treeModel.sourceModel()\
@@ -130,7 +130,7 @@ class HistoryMenuModel(QAbstractProxyModel):
         treeIndex = self.__treeModel.mapFromSource(historyIndex)
         return treeIndex
     
-    def index(self, row, column, parent = QModelIndex()):
+    def index(self, row, column, parent=QModelIndex()):
         """
         Public method to create an index.
         
@@ -146,14 +146,15 @@ class HistoryMenuModel(QAbstractProxyModel):
             return QModelIndex()
         
         if not parent.isValid():
-            return self.createIndex(row, column, sys.maxint)
+            return self.createIndex(row, column, sys.maxsize)
         
         treeIndexParent = self.mapToSource(parent)
         
         bumpedItems = 0
         if treeIndexParent == self.sourceModel().index(0, 0):
             bumpedItems = self.bumpedRows()
-        treeIndex = self.__treeModel.index(row + bumpedItems, column, treeIndexParent)
+        treeIndex = self.__treeModel.index(
+            row + bumpedItems, column, treeIndexParent)
         historyIndex = self.__treeModel.mapToSource(treeIndex)
         historyRow = historyIndex.row()
         if historyRow == -1:
@@ -168,21 +169,23 @@ class HistoryMenuModel(QAbstractProxyModel):
         @return index of parent (QModelIndex)
         """
         offset = index.internalId()
-        if offset == sys.maxint or not index.isValid():
+        if offset == sys.maxsize or not index.isValid():
             return QModelIndex()
         
-        historyIndex = self.__treeModel.sourceModel().index(index.internalId(), 0)
+        historyIndex = self.__treeModel.sourceModel().index(
+            index.internalId(), 0)
         treeIndex = self.__treeModel.mapFromSource(historyIndex)
         treeIndexParent = treeIndex.parent()
         
         sourceRow = self.sourceModel().mapToSource(treeIndexParent).row()
         bumpedItems = self.bumpedRows()
         if bumpedItems <= self.MOVEDROWS and \
-           bumpedItems == self.sourceModel().rowCount(self.sourceModel().index(0, 0)):
+                bumpedItems == self.sourceModel().rowCount(
+                    self.sourceModel().index(0, 0)):
             bumpedItems -= 1
         
-        return self.createIndex(bumpedItems + treeIndexParent.row(), 
-                                treeIndexParent.column(), 
+        return self.createIndex(bumpedItems + treeIndexParent.row(),
+                                treeIndexParent.column(),
                                 sourceRow)
     
     def mimeData(self, indexes):
@@ -194,36 +197,92 @@ class HistoryMenuModel(QAbstractProxyModel):
         """
         urls = []
         for index in indexes:
-            url = index.data(HistoryModel.UrlRole).toUrl()
+            url = index.data(HistoryModel.UrlRole)
             urls.append(url)
         
         mdata = QMimeData()
         mdata.setUrls(urls)
         return mdata
 
-class HistoryMenu(E4ModelMenu):
+
+class HistoryMostVisitedMenuModel(QSortFilterProxyModel):
+    """
+    Class implementing a model to show the most visited history entries.
+    """
+    def __init__(self, sourceModel, parent=None):
+        """
+        Constructor
+        
+        @param sourceModel reference to the source model (QAbstractItemModel)
+        @param parent reference to the parent object (QObject)
+        """
+        super().__init__(parent)
+        
+        self.setDynamicSortFilter(True)
+        self.setSourceModel(sourceModel)
+    
+    def lessThan(self, left, right):
+        """
+        Protected method used to sort the displayed items.
+        
+        @param left index of left item (QModelIndex)
+        @param right index of right item (QModelIndex)
+        @return true, if left is less than right (boolean)
+        """
+        from .HistoryFilterModel import HistoryFilterModel
+        frequency_L = \
+            self.sourceModel().data(left, HistoryFilterModel.FrequencyRole)
+        dateTime_L = \
+            self.sourceModel().data(left, HistoryModel.DateTimeRole)
+        frequency_R = \
+            self.sourceModel().data(right, HistoryFilterModel.FrequencyRole)
+        dateTime_R = \
+            self.sourceModel().data(right, HistoryModel.DateTimeRole)
+        
+        # Sort results in descending frequency-derived score. If frequencies
+        # are equal, sort on most recently viewed
+        if frequency_R == frequency_L:
+            return dateTime_R < dateTime_L
+        
+        return frequency_R < frequency_L
+
+
+class HistoryMenu(E5ModelMenu):
     """
     Class implementing the history menu.
     
-    @signal openUrl(const QUrl&, const QString&) emitted to open a URL in the current
-            tab
-    @signal newUrl(const QUrl&, const QString&) emitted to open a URL in a new tab
+    @signal openUrl(QUrl, str) emitted to open a URL in the current tab
+    @signal newUrl(QUrl, str) emitted to open a URL in a new tab
     """
-    def __init__(self, parent = None):
+    openUrl = pyqtSignal(QUrl, str)
+    newUrl = pyqtSignal(QUrl, str)
+    
+    def __init__(self, parent=None, tabWidget=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
+        @param tabWidget reference to the tab widget managing the browser
+            tabs (HelpTabWidget
         """
-        E4ModelMenu.__init__(self, parent)
+        E5ModelMenu.__init__(self, parent)
+        
+        self.__tabWidget = tabWidget
         
         self.__historyManager = None
         self.__historyMenuModel = None
         self.__initialActions = []
+        self.__mostVisitedMenu = None
+        
+        self.__closedTabsMenu = QMenu(self.trUtf8("Closed Tabs"))
+        self.__closedTabsMenu.aboutToShow.connect(
+            self.__aboutToShowClosedTabsMenu)
+        self.__tabWidget.closedTabsManager().closedTabAvailable.connect(
+            self.__closedTabAvailable)
         
         self.setMaxRows(7)
         
-        self.connect(self, SIGNAL("activated(const QModelIndex&)"), self.__activated)
+        self.activated.connect(self.__activated)
         self.setStatusBarTextRole(HistoryModel.UrlStringRole)
     
     def __activated(self, idx):
@@ -233,24 +292,26 @@ class HistoryMenu(E4ModelMenu):
         @param idx index of the activated item (QModelIndex)
         """
         if self._keyboardModifiers & Qt.ControlModifier:
-            self.emit(SIGNAL("newUrl(const QUrl&, const QString&)"), 
-                      idx.data(HistoryModel.UrlRole).toUrl(), 
-                      idx.data(HistoryModel.TitleRole).toString())
+            self.newUrl.emit(
+                idx.data(HistoryModel.UrlRole),
+                idx.data(HistoryModel.TitleRole))
         else:
-            self.emit(SIGNAL("openUrl(const QUrl&, const QString&)"), 
-                      idx.data(HistoryModel.UrlRole).toUrl(), 
-                      idx.data(HistoryModel.TitleRole).toString())
+            self.openUrl.emit(
+                idx.data(HistoryModel.UrlRole),
+                idx.data(HistoryModel.TitleRole))
     
     def prePopulated(self):
         """
         Public method to add any actions before the tree.
        
-        @return flag indicating if any actions were added
+        @return flag indicating if any actions were added (boolean)
         """
         if self.__historyManager is None:
-            self.__historyManager = Helpviewer.HelpWindow.HelpWindow.historyManager()
-            self.__historyMenuModel = \
-                HistoryMenuModel(self.__historyManager.historyTreeModel(), self)
+            import Helpviewer.HelpWindow
+            self.__historyManager = \
+                Helpviewer.HelpWindow.HelpWindow.historyManager()
+            self.__historyMenuModel = HistoryMenuModel(
+                self.__historyManager.historyTreeModel(), self)
             self.setModel(self.__historyMenuModel)
         
         # initial actions
@@ -269,16 +330,28 @@ class HistoryMenu(E4ModelMenu):
         if len(self.__historyManager.history()) > 0:
             self.addSeparator()
         
-        act = self.addAction(UI.PixmapCache.getIcon("history.png"), 
+        if self.__mostVisitedMenu is None:
+            self.__mostVisitedMenu = HistoryMostVisitedMenu(10, self)
+            self.__mostVisitedMenu.setTitle(self.trUtf8("Most Visited"))
+            self.__mostVisitedMenu.openUrl.connect(self.openUrl)
+            self.__mostVisitedMenu.newUrl.connect(self.newUrl)
+        self.addMenu(self.__mostVisitedMenu)
+        act = self.addMenu(self.__closedTabsMenu)
+        act.setIcon(UI.PixmapCache.getIcon("trash.png"))
+        act.setEnabled(self.__tabWidget.canRestoreClosedTab())
+        self.addSeparator()
+        
+        act = self.addAction(UI.PixmapCache.getIcon("history.png"),
                              self.trUtf8("Show All History..."))
-        self.connect(act, SIGNAL("triggered()"), self.__showHistoryDialog)
-        act = self.addAction(UI.PixmapCache.getIcon("historyClear.png"), 
+        act.triggered[()].connect(self.__showHistoryDialog)
+        act = self.addAction(UI.PixmapCache.getIcon("historyClear.png"),
                              self.trUtf8("Clear History..."))
-        self.connect(act, SIGNAL("triggered()"), self.__clearHistoryDialog)
+        act.triggered[()].connect(self.__clearHistoryDialog)
     
     def setInitialActions(self, actions):
         """
-        Public method to set the list of actions that should appear first in the menu.
+        Public method to set the list of actions that should appear first in
+        the menu.
         
         @param actions list of initial actions (list of QAction)
         """
@@ -290,24 +363,109 @@ class HistoryMenu(E4ModelMenu):
         """
         Private slot to show the history dialog.
         """
+        from .HistoryDialog import HistoryDialog
         dlg = HistoryDialog(self)
         dlg.setAttribute(Qt.WA_DeleteOnClose)
-        self.connect(dlg,  SIGNAL("newUrl(const QUrl&, const QString&)"), 
-                     self, SIGNAL("newUrl(const QUrl&, const QString&)"))
-        self.connect(dlg,  SIGNAL("openUrl(const QUrl&, const QString&)"), 
-                     self, SIGNAL("openUrl(const QUrl&, const QString&)"))
+        dlg.newUrl.connect(self.newUrl)
+        dlg.openUrl.connect(self.openUrl)
         dlg.show()
     
     def __clearHistoryDialog(self):
         """
         Private slot to clear the history.
         """
-        if self.__historyManager is not None and \
-           KQMessageBox.question(None,
+        if self.__historyManager is not None and E5MessageBox.yesNo(
+                self,
                 self.trUtf8("Clear History"),
-                self.trUtf8("""Do you want to clear the history?"""),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.No | \
-                    QMessageBox.Yes),
-                QMessageBox.No) == QMessageBox.Yes:
+                self.trUtf8("""Do you want to clear the history?""")):
             self.__historyManager.clear()
+    
+    def __aboutToShowClosedTabsMenu(self):
+        """
+        Private slot to populate the closed tabs menu.
+        """
+        fm = self.__closedTabsMenu.fontMetrics()
+        maxWidth = fm.width('m') * 40
+        
+        import Helpviewer.HelpWindow
+        self.__closedTabsMenu.clear()
+        index = 0
+        for tab in self.__tabWidget.closedTabsManager().allClosedTabs():
+            title = fm.elidedText(tab.title, Qt.ElideRight, maxWidth)
+            self.__closedTabsMenu.addAction(
+                Helpviewer.HelpWindow.HelpWindow.icon(tab.url), title,
+                self.__tabWidget.restoreClosedTab).setData(index)
+            index += 1
+        self.__closedTabsMenu.addSeparator()
+        self.__closedTabsMenu.addAction(
+            self.trUtf8("Restore All Closed Tabs"),
+            self.__tabWidget.restoreAllClosedTabs)
+        self.__closedTabsMenu.addAction(
+            self.trUtf8("Clear List"),
+            self.__tabWidget.clearClosedTabsList)
+    
+    def __closedTabAvailable(self, avail):
+        """
+        Private slot to handle changes of the availability of closed tabs.
+        
+        @param avail flag indicating the availability of closed tabs (boolean)
+        """
+        self.__closedTabsMenu.setEnabled(avail)
+
+
+class HistoryMostVisitedMenu(E5ModelMenu):
+    """
+    Class implementing the most visited history menu.
+    
+    @signal openUrl(QUrl, str) emitted to open a URL in the current tab
+    @signal newUrl(QUrl, str) emitted to open a URL in a new tab
+    """
+    openUrl = pyqtSignal(QUrl, str)
+    newUrl = pyqtSignal(QUrl, str)
+    
+    def __init__(self, count, parent=None):
+        """
+        Constructor
+        
+        @param count maximum number of entries to be shown (integer)
+        @param parent reference to the parent widget (QWidget)
+        """
+        E5ModelMenu.__init__(self, parent)
+        
+        self.__historyMenuModel = None
+        
+        self.setMaxRows(count + 1)
+        
+        self.activated.connect(self.__activated)
+        self.setStatusBarTextRole(HistoryModel.UrlStringRole)
+    
+    def __activated(self, idx):
+        """
+        Private slot handling the activated signal.
+        
+        @param idx index of the activated item (QModelIndex)
+        """
+        if self._keyboardModifiers & Qt.ControlModifier:
+            self.newUrl.emit(
+                idx.data(HistoryModel.UrlRole),
+                idx.data(HistoryModel.TitleRole))
+        else:
+            self.openUrl.emit(
+                idx.data(HistoryModel.UrlRole),
+                idx.data(HistoryModel.TitleRole))
+    
+    def prePopulated(self):
+        """
+        Public method to add any actions before the tree.
+       
+        @return flag indicating if any actions were added (boolean)
+        """
+        if self.__historyMenuModel is None:
+            import Helpviewer.HelpWindow
+            historyManager = Helpviewer.HelpWindow.HelpWindow.historyManager()
+            self.__historyMenuModel = HistoryMostVisitedMenuModel(
+                historyManager.historyFilterModel(), self)
+            self.setModel(self.__historyMenuModel)
+        self.__historyMenuModel.sort(0)
+        
+        return False
