@@ -7,10 +7,11 @@
 Module implementing the history model.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import Qt, QAbstractTableModel, QModelIndex, QUrl
 
 import Helpviewer.HelpWindow
 
+
 class HistoryModel(QAbstractTableModel):
     """
     Class implementing the history model.
@@ -22,30 +23,27 @@ class HistoryModel(QAbstractTableModel):
     TitleRole = Qt.UserRole + 5
     MaxRole = TitleRole
     
-    def __init__(self, historyManager, parent = None):
+    def __init__(self, historyManager, parent=None):
         """
         Constructor
         
-        @param historyManager reference to the history manager object (HistoryManager)
+        @param historyManager reference to the history manager object
+            (HistoryManager)
         @param parent reference to the parent object (QObject)
         """
-        QAbstractTableModel.__init__(self, parent)
+        super().__init__(parent)
         
         self.__historyManager = historyManager
         
         self.__headers = [
-            self.trUtf8("Title"), 
-            self.trUtf8("Address"), 
+            self.trUtf8("Title"),
+            self.trUtf8("Address"),
         ]
         
-        self.connect(self.__historyManager, SIGNAL("historyReset()"), 
-                     self.historyReset)
-        self.connect(self.__historyManager, SIGNAL("entryRemoved"), 
-                     self.historyReset)
-        self.connect(self.__historyManager, SIGNAL("entryAdded"), 
-                     self.entryAdded)
-        self.connect(self.__historyManager, SIGNAL("entryUpdated(int)"), 
-                     self.entryUpdated)
+        self.__historyManager.historyReset.connect(self.historyReset)
+        self.__historyManager.entryRemoved.connect(self.historyReset)
+        self.__historyManager.entryAdded.connect(self.entryAdded)
+        self.__historyManager.entryUpdated.connect(self.entryUpdated)
     
     def historyReset(self):
         """
@@ -67,60 +65,59 @@ class HistoryModel(QAbstractTableModel):
         @param row row number of the updated entry (integer)
         """
         idx = self.index(row, 0)
-        self.emit(SIGNAL("dataChanged(const QModelIndex&, const QModelIndex&)"), 
-            idx, idx)
+        self.dataChanged.emit(idx, idx)
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get the header data.
         
         @param section section number (integer)
         @param orientation header orientation (Qt.Orientation)
         @param role data role (integer)
-        @return header data (QVariant)
+        @return header data
         """
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             try:
-                return QVariant(self.__headers[section])
+                return self.__headers[section]
             except IndexError:
                 pass
         return QAbstractTableModel.headerData(self, section, orientation, role)
     
-    def data(self, index, role = Qt.DisplayRole):
+    def data(self, index, role=Qt.DisplayRole):
         """
         Public method to get data from the model.
         
         @param index index of history entry to get data for (QModelIndex)
         @param role data role (integer)
-        @return history entry data (QVariant)
+        @return history entry data
         """
         lst = self.__historyManager.history()
         if index.row() < 0 or index.row() > len(lst):
-            return QVariant()
+            return None
         
         itm = lst[index.row()]
         if role == self.DateTimeRole:
-            return QVariant(itm.dateTime)
+            return itm.dateTime
         elif role == self.DateRole:
-            return QVariant(itm.dateTime.date())
+            return itm.dateTime.date()
         elif role == self.UrlRole:
-            return QVariant(QUrl(itm.url))
+            return QUrl(itm.url)
         elif role == self.UrlStringRole:
-            return QVariant(itm.url)
+            return itm.url
         elif role == self.TitleRole:
-            return QVariant(itm.userTitle())
+            return itm.userTitle()
         elif role in [Qt.DisplayRole, Qt.EditRole]:
             if index.column() == 0:
-                return QVariant(itm.userTitle())
+                return itm.userTitle()
             elif index.column() == 1:
-                return QVariant(itm.url)
+                return itm.url
         elif role == Qt.DecorationRole:
             if index.column() == 0:
-                return QVariant(Helpviewer.HelpWindow.HelpWindow.icon(QUrl(itm.url)))
+                return Helpviewer.HelpWindow.HelpWindow.icon(QUrl(itm.url))
         
-        return QVariant()
+        return None
     
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the number of columns.
         
@@ -132,7 +129,7 @@ class HistoryModel(QAbstractTableModel):
         else:
             return len(self.__headers)
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to determine the number of rows.
         
@@ -144,13 +141,13 @@ class HistoryModel(QAbstractTableModel):
         else:
             return len(self.__historyManager.history())
     
-    def removeRows(self, row, count, parent = QModelIndex()):
+    def removeRows(self, row, count, parent=QModelIndex()):
         """
         Public method to remove history entries from the model.
         
         @param row row of the first history entry to remove (integer)
         @param count number of history entries to remove (integer)
-        @param index of the parent entry (QModelIndex)
+        @param parent index of the parent entry (QModelIndex)
         @return flag indicating successful removal (boolean)
         """
         if parent.isValid():
@@ -161,10 +158,8 @@ class HistoryModel(QAbstractTableModel):
         lst = self.__historyManager.history()[:]
         for index in range(lastRow, row - 1, -1):
             del lst[index]
-        self.disconnect(self.__historyManager, SIGNAL("historyReset()"), 
-                        self.historyReset)
+        self.__historyManager.historyReset.disconnect(self.historyReset)
         self.__historyManager.setHistory(lst)
-        self.connect(self.__historyManager, SIGNAL("historyReset()"), 
-                     self.historyReset)
+        self.__historyManager.historyReset.connect(self.historyReset)
         self.endRemoveRows()
         return True
