@@ -8,7 +8,7 @@ Module implementing a network reply class for an empty reply
 (i.e. request was handle other way).
 """
 
-from PyQt4.QtCore import QTimer, SIGNAL
+from PyQt4.QtCore import QTimer
 from PyQt4.QtNetwork import QNetworkReply, QNetworkAccessManager
 
 
@@ -22,12 +22,12 @@ class EmptyNetworkReply(QNetworkReply):
         
         @param parent reference to the parent object (QObject)
         """
-        QNetworkReply.__init__(self, parent)
+        super().__init__(parent)
         
         self.setOperation(QNetworkAccessManager.GetOperation)
-        self.setError(QNetworkReply.OperationCanceledError, "eric4:No Error")
+        self.setError(QNetworkReply.OperationCanceledError, "eric5:No Error")
         
-        QTimer.singleShot(0, self, SIGNAL("finished()"))
+        QTimer.singleShot(0, lambda: self.finished.emit())
     
     def abort(self):
         """
@@ -41,6 +41,6 @@ class EmptyNetworkReply(QNetworkReply):
         Protected method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
-        @return string containing the data (string)
+        @return string containing the data (bytes)
         """
-        return str()
+        return bytes()
