@@ -7,27 +7,27 @@
 Module implementing a network access manager proxy for web pages.
 """
 
-from PyQt4.QtCore import SIGNAL
 from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest
 try:
-    from PyQt4.QtNetwork import QSslError
+    from PyQt4.QtNetwork import QSslError   # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
     SSL_AVAILABLE = True
 except ImportError:
     SSL_AVAILABLE = False
 
+
 class NetworkAccessManagerProxy(QNetworkAccessManager):
     """
     Class implementing a network access manager proxy for web pages.
     """
     primaryManager = None
     
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QNetworkAccessManager.__init__(self, parent)
+        super().__init__(parent)
         self.__webPage = None
     
     def setWebPage(self, page):
@@ -54,35 +54,30 @@ class NetworkAccessManagerProxy(QNetworkAccessManager):
         self.cookieJar().setParent(self.__class__.primaryManager)
         
         if SSL_AVAILABLE:
-            self.connect(self, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'), 
-                self.__class__.primaryManager, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'))
-        self.connect(self, 
-            SIGNAL('proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)'),
-            self.__class__.primaryManager, 
-            SIGNAL('proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)'))
-        self.connect(self, 
-            SIGNAL('authenticationRequired(QNetworkReply *, QAuthenticator *)'), 
-            self.__class__.primaryManager, 
-            SIGNAL('authenticationRequired(QNetworkReply *, QAuthenticator *)'))
-        self.connect(self, SIGNAL("finished(QNetworkReply *)"), 
-            self.__class__.primaryManager, SIGNAL("finished(QNetworkReply *)"))
+            self.sslErrors.connect(self.__class__.primaryManager.sslErrors)
+        self.proxyAuthenticationRequired.connect(
+            self.__class__.primaryManager.proxyAuthenticationRequired)
+        self.authenticationRequired.connect(
+            self.__class__.primaryManager.authenticationRequired)
+        self.finished.connect(self.__class__.primaryManager.finished)
     
-    def createRequest(self, op, request, outgoingData = None):
+    def createRequest(self, op, request, outgoingData=None):
         """
         Protected method to create a request.
         
-        @param op the operation to be performed (QNetworkAccessManager.Operation)
+        @param op the operation to be performed
+            (QNetworkAccessManager.Operation)
         @param request reference to the request object (QNetworkRequest)
         @param outgoingData reference to an IODevice containing data to be sent
             (QIODevice)
         @return reference to the created reply object (QNetworkReply)
         """
-        if self.primaryManager is not None and \
-           self.__webPage is not None:
+        if self.primaryManager is not None:
             pageRequest = QNetworkRequest(request)
-            self.__webPage.populateNetworkRequest(pageRequest)
-            return self.primaryManager.createRequest(op, pageRequest, outgoingData)
+            if self.__webPage is not None:
+                self.__webPage.populateNetworkRequest(pageRequest)
+            return self.primaryManager.createRequest(
+                op, pageRequest, outgoingData)
         else:
-            return QNetworkAccessManager.createRequest(self, op, request, outgoingData)
+            return QNetworkAccessManager.createRequest(
+                self, op, request, outgoingData)
