@@ -4,35 +4,38 @@
 #
 
 """
-Module implementing a QNetworkReply subclass reporting an unknown protocol error.
+Module implementing a QNetworkReply subclass reporting an unknown protocol
+error.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtNetwork import QNetworkReply, QNetworkRequest
+from PyQt4.QtCore import QTimer
+from PyQt4.QtNetwork import QNetworkReply
+
 
 class NetworkProtocolUnknownErrorReply(QNetworkReply):
     """
-    Class implementing a QNetworkReply subclass reporting an unknown protocol error.
+    Class implementing a QNetworkReply subclass reporting an unknown protocol
+    error.
     """
-    def __init__(self, protocol, parent = None):
+    def __init__(self, protocol, parent=None):
         """
         Constructor
         
-        @param protocol protocol name (string or QString)
+        @param protocol protocol name (string)
         @param parent reference to the parent object (QObject)
         """
-        QNetworkReply.__init__(self, parent)
-        self.setError(QNetworkReply.ProtocolUnknownError, 
-                      self.trUtf8("Protocol '%1' not supported.").arg(protocol))
+        super().__init__(parent)
+        self.setError(
+            QNetworkReply.ProtocolUnknownError,
+            self.trUtf8("Protocol '{0}' not supported.").format(protocol))
         QTimer.singleShot(0, self.__fireSignals)
     
     def __fireSignals(self):
         """
         Private method to send some signals to end the connection.
         """
-        self.emit(SIGNAL("error(QNetworkReply::NetworkError)"), 
-                         QNetworkReply.ProtocolUnknownError)
-        self.emit(SIGNAL("finished()"))
+        self.error.emit(QNetworkReply.ProtocolUnknownError)
+        self.finished[()].emit()
     
     def abort(self):
         """
