@@ -7,14 +7,15 @@
 Module implementing a network reply object for special data.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import QTimer, QIODevice, QByteArray
 from PyQt4.QtNetwork import QNetworkReply, QNetworkRequest
 
+
 class NetworkReply(QNetworkReply):
     """
     Class implementing a QNetworkReply subclass for special data.
     """
-    def __init__(self, request, fileData, mimeType, parent = None):
+    def __init__(self, request, fileData, mimeType, parent=None):
         """
         Constructor
         
@@ -23,18 +24,21 @@ class NetworkReply(QNetworkReply):
         @param mimeType for the reply (string)
         @param parent reference to the parent object (QObject)
         """
-        QNetworkReply.__init__(self, parent)
+        super().__init__(parent)
         
         self.__data = fileData
         
         self.setRequest(request)
         self.setOpenMode(QIODevice.ReadOnly)
         
-        self.setHeader(QNetworkRequest.ContentTypeHeader, QVariant(mimeType))
-        self.setHeader(QNetworkRequest.ContentLengthHeader, 
-                       QVariant(QByteArray.number(fileData.length())))
-        QTimer.singleShot(0, self, SIGNAL("metaDataChanged()"))
-        QTimer.singleShot(0, self, SIGNAL("readyRead()"))
+        self.setHeader(QNetworkRequest.ContentTypeHeader, mimeType)
+        self.setHeader(QNetworkRequest.ContentLengthHeader,
+                       QByteArray.number(fileData.length()))
+        self.setAttribute(QNetworkRequest.HttpStatusCodeAttribute, 200)
+        self.setAttribute(QNetworkRequest.HttpReasonPhraseAttribute, "OK")
+        QTimer.singleShot(0, lambda: self.metaDataChanged.emit())
+        QTimer.singleShot(0, lambda: self.readyRead.emit())
+        QTimer.singleShot(0, lambda: self.finished.emit())
     
     def abort(self):
         """
@@ -49,8 +53,6 @@ class NetworkReply(QNetworkReply):
         
         @return bytes available (integer)
         """
-        if self.__data.length() == 0:
-            QTimer.singleShot(0, self, SIGNAL("finished()"))
         return self.__data.length() + QNetworkReply.bytesAvailable(self)
     
     def readData(self, maxlen):
@@ -58,11 +60,17 @@ class NetworkReply(QNetworkReply):
         Protected method to retrieve data from the reply object.
         
         @param maxlen maximum number of bytes to read (integer)
-        @return string containing the data (string)
+        @return string containing the data (bytes)
         """
         len_ = min(maxlen, self.__data.length())
-        buffer = str(self.__data[:len_])
+        buffer = bytes(self.__data[:len_])
         self.__data.remove(0, len_)
-        if self.__data.length() == 0:
-            QTimer.singleShot(0, self, SIGNAL("finished()"))
         return buffer
+    
+    def isFinished(self):
+        """
+        Public method to check, if the reply has finished.
+        
+        @return flag indicating the finished state (boolean)
+        """
+        return True
