@@ -8,26 +8,26 @@ Module implementing a dialog for the configuration of search engines.
 """
 
 from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import pyqtSignature, QString, SIGNAL
+from PyQt4.QtCore import pyqtSlot
 
-from KdeQt import KQFileDialog, KQMessageBox
+from E5Gui import E5MessageBox, E5FileDialog
 
-from E4Gui.E4ListView import E4ListView
+from .OpenSearchEngineModel import OpenSearchEngineModel
 
-from OpenSearchEngineModel import OpenSearchEngineModel
-from OpenSearchEditDialog import OpenSearchEditDialog
+from .Ui_OpenSearchDialog import Ui_OpenSearchDialog
 
-from Ui_OpenSearchDialog import Ui_OpenSearchDialog
 
 class OpenSearchDialog(QDialog, Ui_OpenSearchDialog):
     """
     Class implementing a dialog for the configuration of search engines.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
+        
+        @param parent reference to the parent object (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.setModal(True)
@@ -43,55 +43,58 @@ class OpenSearchDialog(QDialog, Ui_OpenSearchDialog):
         self.enginesTable.verticalHeader().setDefaultSectionSize(
             1.2 * self.fontMetrics().height())
         
-        self.connect(self.enginesTable.selectionModel(), 
-                     SIGNAL("selectionChanged(const QItemSelection&, const QItemSelection&)"), 
-                     self.__selectionChanged)
+        self.enginesTable.selectionModel().selectionChanged.connect(
+            self.__selectionChanged)
         self.editButton.setEnabled(False)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add a new search engine.
         """
-        fileNames = KQFileDialog.getOpenFileNames(\
+        fileNames = E5FileDialog.getOpenFileNames(
             self,
             self.trUtf8("Add search engine"),
-            QString(),
-            self.trUtf8("OpenSearch (*.xml);;All Files (*)"),
-            None)
+            "",
+            self.trUtf8("OpenSearch (*.xml);;All Files (*)"))
         
         osm = self.__mw.openSearchManager()
         for fileName in fileNames:
             if not osm.addEngine(fileName):
-                KQMessageBox.critical(self,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Add search engine"),
-                    self.trUtf8("""%1 is not a valid OpenSearch 1.1 description or"""
-                                """ is already on your list.""").arg(fileName))
+                    self.trUtf8(
+                        """{0} is not a valid OpenSearch 1.1 description or"""
+                        """ is already on your list.""").format(fileName))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteButton_clicked(self):
         """
         Private slot to delete the selected search engines.
         """
         if self.enginesTable.model().rowCount() == 1:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Delete selected engines"),
                 self.trUtf8("""You must have at least one search engine."""))
         
         self.enginesTable.removeSelected()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_restoreButton_clicked(self):
         """
         Private slot to restore the default search engines.
         """
         self.__mw.openSearchManager().restoreDefaults()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_editButton_clicked(self):
         """
         Private slot to edit the data of the current search engine.
         """
+        from .OpenSearchEditDialog import OpenSearchEditDialog
+        
         rows = self.enginesTable.selectionModel().selectedRows()
         if len(rows) == 0:
             row = self.enginesTable.selectionModel().currentIndex().row()
