@@ -9,17 +9,21 @@ Module implementing a dialog to edit the data of a search engine.
 
 from PyQt4.QtGui import QDialog
 
-from Ui_OpenSearchEditDialog import Ui_OpenSearchEditDialog
+from .Ui_OpenSearchEditDialog import Ui_OpenSearchEditDialog
+
 
 class OpenSearchEditDialog(QDialog, Ui_OpenSearchEditDialog):
     """
     Class implementing a dialog to edit the data of a search engine.
     """
-    def __init__(self, engine, parent = None):
+    def __init__(self, engine, parent=None):
         """
         Constructor
+        
+        @param engine reference to the search engine (OpenSearchEngine)
+        @param parent reference to the parent object (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.__engine = engine
@@ -40,4 +44,4 @@ class OpenSearchEditDialog(QDialog, Ui_OpenSearchEditDialog):
         self.__engine.setSearchUrlTemplate(self.searchEdit.text())
         self.__engine.setSuggestionsUrlTemplate(self.suggestionsEdit.text())
         
-        QDialog.accept(self)
+        super().accept()
