@@ -7,16 +7,12 @@
 Module implementing the open search engine.
 """
 
-try:
-    import json
-except ImportError:
-    try:
-        import simplejson as json
-    except ImportError:
-        import ThirdParty.SimpleJSON.simplejson as json
+import re
+import json
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, pyqtSlot, QLocale, QUrl, QByteArray, \
+    QBuffer, QIODevice, QObject
+from PyQt4.QtGui import QImage
 from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager
 
 from UI.Info import Program
@@ -24,38 +20,42 @@ from UI.Info import Program
 import Preferences
 import Utilities
 
+
 class OpenSearchEngine(QObject):
     """
     Class implementing the open search engine.
     
     @signal imageChanged() emitted after the icon has been changed
-    @signal suggestions(const QStringList&) emitted after the suggestions have 
+    @signal suggestions(list of strings) emitted after the suggestions have
             been received
     """
-    def __init__(self, parent = None):
+    imageChanged = pyqtSignal()
+    suggestions = pyqtSignal(list)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.__suggestionsReply = None
         self.__networkAccessManager = None
-        self._name = QString()
-        self._description = QString()
-        self._searchUrlTemplate = QString()
-        self._suggestionsUrlTemplate = QString()
+        self._name = ""
+        self._description = ""
+        self._searchUrlTemplate = ""
+        self._suggestionsUrlTemplate = ""
         self._searchParameters = []            # list of two tuples
         self._suggestionsParameters = []       # list of two tuples
-        self._imageUrl = QString()
+        self._imageUrl = ""
         self.__image = QImage()
         self.__iconMoved = False
-        self.__searchMethod = QString("get")
-        self.__suggestionsMethod = QString("get")
+        self.__searchMethod = "get"
+        self.__suggestionsMethod = "get"
         self.__requestMethods = {
-            QString("get")  : QNetworkAccessManager.GetOperation, 
-            QString("post") : QNetworkAccessManager.PostOperation, 
+            "get": QNetworkAccessManager.GetOperation,
+            "post": QNetworkAccessManager.PostOperation,
         }
         
         self.__replies = []
@@ -65,92 +65,94 @@ class OpenSearchEngine(QObject):
         """
         Class method to parse a search template.
         
-        @param searchTerm term to search for (string or QString)
-        @param searchTemplate template to be parsed (string or QString)
-        @return parsed template (QString)
+        @param searchTerm term to search for (string)
+        @param searchTemplate template to be parsed (string)
+        @return parsed template (string)
         """
         locale = QLocale(Preferences.getHelp("SearchLanguage"))
         language = locale.name().split("_")[0]
-        country = language.toLower()
+        country = language.lower()
         
-        result = QString(searchTemplate)
-        result.replace("{count}", "20")
-        result.replace("{startIndex}", "0")
-        result.replace("{startPage}", "0")
-        result.replace("{language}", language)
-        result.replace("{country}", country)
-        result.replace("{inputEncoding}", "UTF-8")
-        result.replace("{outputEncoding}", "UTF-8")
-        result.replace("{searchTerms}", QString(QUrl.toPercentEncoding(searchTerm)))
-        result.replace(QRegExp(r"""\{([^\}]*:|)source\??\}"""), Program)
+        result = searchTemplate
+        result = result.replace("{count}", "20")
+        result = result.replace("{startIndex}", "0")
+        result = result.replace("{startPage}", "0")
+        result = result.replace("{language}", language)
+        result = result.replace("{country}", country)
+        result = result.replace("{inputEncoding}", "UTF-8")
+        result = result.replace("{outputEncoding}", "UTF-8")
+        result = result.replace(
+            "{searchTerms}",
+            bytes(QUrl.toPercentEncoding(searchTerm)).decode())
+        result = re.sub(r"""\{([^\}]*:|)source\??\}""", Program, result)
 
         return result
     
-    @pyqtSignature("", "QString")
+    @pyqtSlot(result=str)
     def name(self):
         """
         Public method to get the name of the engine.
         
-        @return name of the engine (QString)
+        @return name of the engine (string)
         """
-        return QString(self._name)
+        return self._name
     
     def setName(self, name):
         """
         Public method to set the engine name.
         
-        @param name name of the engine (string or QString)
+        @param name name of the engine (string)
         """
-        self._name = QString(name)
+        self._name = name
     
     def description(self):
         """
         Public method to get the description of the engine.
         
-        @return description of the engine (QString)
+        @return description of the engine (string)
         """
-        return QString(self._description)
+        return self._description
     
     def setDescription(self, description):
         """
         Public method to set the engine description.
         
-        @param description description of the engine (string or QString)
+        @param description description of the engine (string)
         """
-        self._description = QString(description)
+        self._description = description
     
     def searchUrlTemplate(self):
         """
         Public method to get the search URL template of the engine.
         
-        @return search URL template of the engine (QString)
+        @return search URL template of the engine (string)
         """
-        return QString(self._searchUrlTemplate)
+        return self._searchUrlTemplate
     
     def setSearchUrlTemplate(self, searchUrlTemplate):
         """
         Public method to set the engine search URL template.
         
-        @param searchUrlTemplate search URL template of the engine (string or QString)
+        @param searchUrlTemplate search URL template of the engine (string)
         """
-        self._searchUrlTemplate = QString(searchUrlTemplate)
+        self._searchUrlTemplate = searchUrlTemplate
     
     def searchUrl(self, searchTerm):
         """
         Public method to get a URL ready for searching.
         
-        @param searchTerm term to search for (string or QString)
+        @param searchTerm term to search for (string)
         @return URL (QUrl)
         """
-        if self._searchUrlTemplate.isEmpty():
+        if not self._searchUrlTemplate:
             return QUrl()
         
         ret = QUrl.fromEncoded(
-              self.parseTemplate(searchTerm, self._searchUrlTemplate).toUtf8())
+            self.parseTemplate(searchTerm, self._searchUrlTemplate))
         
         if self.__searchMethod != "post":
             for parameter in self._searchParameters:
-                ret.addQueryItem(parameter[0], 
+                ret.addQueryItem(parameter[0],
                                  self.parseTemplate(searchTerm, parameter[1]))
         
         return ret
@@ -161,41 +163,42 @@ class OpenSearchEngine(QObject):
         
         @return flag indicating suggestions are provided (boolean)
         """
-        return not self._suggestionsUrlTemplate.isEmpty()
+        return self._suggestionsUrlTemplate != ""
     
     def suggestionsUrlTemplate(self):
         """
         Public method to get the search URL template of the engine.
         
-        @return search URL template of the engine (QString)
+        @return search URL template of the engine (string)
         """
-        return QString(self._suggestionsUrlTemplate)
+        return self._suggestionsUrlTemplate
     
     def setSuggestionsUrlTemplate(self, suggestionsUrlTemplate):
         """
         Public method to set the engine suggestions URL template.
         
         @param suggestionsUrlTemplate suggestions URL template of the
-            engine (string or QString)
+            engine (string)
         """
-        self._suggestionsUrlTemplate = QString(suggestionsUrlTemplate)
+        self._suggestionsUrlTemplate = suggestionsUrlTemplate
     
     def suggestionsUrl(self, searchTerm):
         """
         Public method to get a URL ready for suggestions.
         
-        @param searchTerm term to search for (string or QString)
+        @param searchTerm term to search for (string)
         @return URL (QUrl)
         """
-        if self._suggestionsUrlTemplate.isEmpty():
+        if not self._suggestionsUrlTemplate:
             return QUrl()
         
-        ret = QUrl.fromEncoded(
-              self.parseTemplate(searchTerm, self._suggestionsUrlTemplate).toUtf8())
+        ret = QUrl.fromEncoded(QByteArray(self.parseTemplate(
+            searchTerm, self._suggestionsUrlTemplate)))
         
         if self.__searchMethod != "post":
             for parameter in self._suggestionsParameters:
-                ret.addQueryItem(parameter[0], self.parseTemplate(searchTerm, parameter[1]))
+                ret.addQueryItem(parameter[0],
+                                 self.parseTemplate(searchTerm, parameter[1]))
         
         return ret
     
@@ -211,7 +214,8 @@ class OpenSearchEngine(QObject):
         """
         Public method to set the engine search parameters.
         
-        @param searchParameters search parameters of the engine (list of two tuples)
+        @param searchParameters search parameters of the engine
+            (list of two tuples)
         """
         self._searchParameters = searchParameters[:]
     
@@ -227,26 +231,28 @@ class OpenSearchEngine(QObject):
         """
         Public method to set the engine suggestions parameters.
         
-        @param suggestionsParameters suggestions parameters of the 
+        @param suggestionsParameters suggestions parameters of the
             engine (list of two tuples)
         """
         self._suggestionsParameters = suggestionsParameters[:]
     
     def searchMethod(self):
         """
-        Public method to get the HTTP request method used to perform search requests.
+        Public method to get the HTTP request method used to perform search
+        requests.
         
-        @return HTTP request method (QString)
+        @return HTTP request method (string)
         """
         return self.__searchMethod
     
     def setSearchMethod(self, method):
         """
-        Public method to set the HTTP request method used to perform search requests.
+        Public method to set the HTTP request method used to perform search
+        requests.
         
-        @param method HTTP request method (QString)
+        @param method HTTP request method (string)
         """
-        requestMethod = QString(method).toLower()
+        requestMethod = method.lower()
         if requestMethod not in self.__requestMethods:
             return
         
@@ -254,19 +260,21 @@ class OpenSearchEngine(QObject):
     
     def suggestionsMethod(self):
         """
-        Public method to get the HTTP request method used to perform suggestions requests.
+        Public method to get the HTTP request method used to perform
+        suggestions requests.
         
-        @return HTTP request method (QString)
+        @return HTTP request method (string)
         """
         return self.__suggestionsMethod
     
     def setSuggestionsMethod(self, method):
         """
-        Public method to set the HTTP request method used to perform suggestions requests.
+        Public method to set the HTTP request method used to perform
+        suggestions requests.
         
-        @param method HTTP request method (QString)
+        @param method HTTP request method (string)
         """
-        requestMethod = QString(method).toLower()
+        requestMethod = method.lower()
         if requestMethod not in self.__requestMethods:
             return
         
@@ -276,23 +284,23 @@ class OpenSearchEngine(QObject):
         """
         Public method to get the image URL of the engine.
         
-        @return image URL of the engine (QString)
+        @return image URL of the engine (string)
         """
-        return QString(self._imageUrl)
+        return self._imageUrl
     
     def setImageUrl(self, imageUrl):
         """
         Public method to set the engine image URL.
         
-        @param description image URL of the engine (string or QString)
+        @param imageUrl image URL of the engine (string)
         """
-        self._imageUrl = QString(imageUrl)
+        self._imageUrl = imageUrl
     
     def setImageUrlAndLoad(self, imageUrl):
         """
         Public method to set the engine image URL.
         
-        @param description image URL of the engine (string or QString)
+        @param imageUrl image URL of the engine (string)
         """
         self.setImageUrl(imageUrl)
         self.__iconMoved = False
@@ -302,12 +310,12 @@ class OpenSearchEngine(QObject):
         """
         Public method to load the image of the engine.
         """
-        if self.__networkAccessManager is None or self._imageUrl.isEmpty():
+        if self.__networkAccessManager is None or not self._imageUrl:
             return
         
         reply = self.__networkAccessManager.get(
-            QNetworkRequest(QUrl.fromEncoded(self._imageUrl.toUtf8())))
-        self.connect(reply, SIGNAL("finished()"), self.__imageObtained)
+            QNetworkRequest(QUrl.fromEncoded(self._imageUrl)))
+        reply.finished[()].connect(self.__imageObtained)
         self.__replies.append(reply)
     
     def __imageObtained(self):
@@ -333,7 +341,7 @@ class OpenSearchEngine(QObject):
             self.__image = QImage()
         else:
             self.__image.loadFromData(response)
-        self.emit(SIGNAL("imageChanged()"))
+        self.imageChanged.emit()
     
     def image(self):
         """
@@ -352,15 +360,15 @@ class OpenSearchEngine(QObject):
         
         @param image image to be set (QImage)
         """
-        if self._imageUrl.isEmpty():
+        if not self._imageUrl:
             imageBuffer = QBuffer()
             imageBuffer.open(QIODevice.ReadWrite)
             if image.save(imageBuffer, "PNG"):
-                self._imageUrl = QString("data:image/png;base64,%1")\
-                                .arg(QString(imageBuffer.buffer().toBase64()))
+                self._imageUrl = "data:image/png;base64,{0}".format(
+                    bytes(imageBuffer.buffer().toBase64()).decode())
         
         self.__image = QImage(image)
-        self.emit(SIGNAL("imageChanged()"))
+        self.imageChanged.emit()
     
     def isValid(self):
         """
@@ -368,7 +376,7 @@ class OpenSearchEngine(QObject):
         
         @return flag indicating validity (boolean)
         """
-        return not self._name.isEmpty() and not self._searchUrlTemplate.isEmpty()
+        return self._name and self._searchUrlTemplate
     
     def __eq__(self, other):
         """
@@ -384,7 +392,7 @@ class OpenSearchEngine(QObject):
             self._description == other._description and \
             self._imageUrl == other._imageUrl and \
             self._searchUrlTemplate == other._searchUrlTemplate and \
-            self._suggestionsUrlTemplate ==other._suggestionsUrlTemplate and \
+            self._suggestionsUrlTemplate == other._suggestionsUrlTemplate and \
             self._searchParameters == other._searchParameters and \
             self._suggestionsParameters == other._suggestionsParameters
     
@@ -404,19 +412,17 @@ class OpenSearchEngine(QObject):
         """
         Public method to request suggestions.
         
-        @param searchTerm term to get suggestions for (string or QString)
+        @param searchTerm term to get suggestions for (string)
         """
-        searchTerm = QString(searchTerm)
-        if searchTerm.isEmpty() or not self.providesSuggestions():
+        if not searchTerm or not self.providesSuggestions():
             return
         
         if self.__networkAccessManager is None:
             return
         
         if self.__suggestionsReply is not None:
-            self.disconnect(self.__suggestionsReply, SIGNAL("finished()"), 
-                            self.__suggestionsObtained)
             self.__suggestionsReply.abort()
+            self.__suggestionsReply.deleteLater()
             self.__suggestionsReply = None
         
         if self.__suggestionsMethod not in self.__requestMethods:
@@ -427,20 +433,20 @@ class OpenSearchEngine(QObject):
             self.__suggestionsReply = self.networkAccessManager().get(
                 QNetworkRequest(self.suggestionsUrl(searchTerm)))
         else:
-            parameters = QStringList()
+            parameters = []
             for parameter in self._suggestionsParameters:
                 parameters.append(parameter[0] + "=" + parameter[1])
-            data = parameters.join("&").toUtf8()
+            data = "&".join(parameters)
             self.__suggestionsReply = self.networkAccessManager().post(
                 QNetworkRequest(self.suggestionsUrl(searchTerm)), data)
-        self.connect(self.__suggestionsReply, SIGNAL("finished()"), 
-                     self.__suggestionsObtained)
+        self.__suggestionsReply.finished[()].connect(
+            self.__suggestionsObtained)
     
     def __suggestionsObtained(self):
         """
         Private slot to receive the suggestions.
         """
-        buffer = str(self.__suggestionsReply.readAll())
+        buffer = bytes(self.__suggestionsReply.readAll())
         response = Utilities.decodeBytes(buffer)
         response = response.strip()
         
@@ -456,17 +462,18 @@ class OpenSearchEngine(QObject):
             return
         
         try:
-            suggestions = QStringList(result[1])
+            suggestions = result[1]
         except IndexError:
             return
         
-        self.emit(SIGNAL("suggestions(const QStringList&)"), suggestions)
+        self.suggestions.emit(suggestions)
     
     def networkAccessManager(self):
         """
         Public method to get a reference to the network access manager object.
         
-        @return reference to the network access manager object (QNetworkAccessManager)
+        @return reference to the network access manager object
+            (QNetworkAccessManager)
         """
         return self.__networkAccessManager
     
@@ -474,7 +481,7 @@ class OpenSearchEngine(QObject):
         """
         Public method to set the reference to the network access manager.
         
-        @param networkAccessManager reference to the network access manager 
+        @param networkAccessManager reference to the network access manager
             object (QNetworkAccessManager)
         """
         self.__networkAccessManager = networkAccessManager
