@@ -7,33 +7,34 @@
 Module implementing a QAction subclass for open search.
 """
 
-from PyQt4.QtCore import SIGNAL, QUrl
+from PyQt4.QtCore import QUrl
 from PyQt4.QtGui import QPixmap, QIcon, QAction
 
-import Helpviewer.HelpWindow
 
 class OpenSearchEngineAction(QAction):
     """
     Class implementing a QAction subclass for open search.
     """
-    def __init__(self, engine, parent = None):
+    def __init__(self, engine, parent=None):
         """
         Constructor
         
-        @param engine reference to the open search engine object (OpenSearchEngine)
+        @param engine reference to the open search engine object
+            (OpenSearchEngine)
         @param parent reference to the parent object (QObject)
         """
-        QAction.__init__(self, parent)
+        super().__init__(parent)
         
         self.__engine = engine
         if self.__engine.networkAccessManager() is None:
+            import Helpviewer.HelpWindow
             self.__engine.setNetworkAccessManager(
                 Helpviewer.HelpWindow.HelpWindow.networkAccessManager())
         
         self.setText(engine.name())
         self.__imageChanged()
         
-        self.connect(engine, SIGNAL("imageChanged()"), self.__imageChanged)
+        engine.imageChanged.connect(self.__imageChanged)
     
     def __imageChanged(self):
         """
@@ -41,7 +42,9 @@ class OpenSearchEngineAction(QAction):
         """
         image = self.__engine.image()
         if image.isNull():
+            import Helpviewer.HelpWindow
             self.setIcon(
-                Helpviewer.HelpWindow.HelpWindow.icon(QUrl(self.__engine.imageUrl())))
+                Helpviewer.HelpWindow.HelpWindow.icon(
+                    QUrl(self.__engine.imageUrl())))
         else:
             self.setIcon(QIcon(QPixmap.fromImage(image)))
