@@ -7,31 +7,35 @@
 Module implementing a model for search engines.
 """
 
-from PyQt4.QtCore import *
+import re
+
+from PyQt4.QtCore import Qt, QUrl, QAbstractTableModel, QModelIndex
 from PyQt4.QtGui import QPixmap, QIcon
 
+
 class OpenSearchEngineModel(QAbstractTableModel):
     """
     Class implementing a model for search engines.
     """
-    def __init__(self, manager, parent = None):
+    def __init__(self, manager, parent=None):
         """
         Constructor
         
-        @param manager reference to the search engine manager (OpenSearchManager)
+        @param manager reference to the search engine manager
+            (OpenSearchManager)
         @param parent reference to the parent object (QObject)
         """
-        QAbstractTableModel.__init__(self, parent)
+        super().__init__(parent)
         
         self.__manager = manager
-        self.connect(manager, SIGNAL("changed()"), self.__enginesChanged)
+        manager.changed.connect(self.__enginesChanged)
         
         self.__headers = [
-            self.trUtf8("Name"), 
-            self.trUtf8("Keywords"), 
+            self.trUtf8("Name"),
+            self.trUtf8("Keywords"),
         ]
     
-    def removeRows(self, row, count, parent = QModelIndex()):
+    def removeRows(self, row, count, parent=QModelIndex()):
         """
         Public method to remove entries from the model.
         
@@ -62,7 +66,7 @@ class OpenSearchEngineModel(QAbstractTableModel):
         
         return True
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to get the number of rows of the model.
         
@@ -74,7 +78,7 @@ class OpenSearchEngineModel(QAbstractTableModel):
         else:
             return self.__manager.enginesCount()
     
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the number of columns of the model.
         
@@ -101,19 +105,20 @@ class OpenSearchEngineModel(QAbstractTableModel):
         
         @param index index to get data for (QModelIndex)
         @param role role of the data to retrieve (integer)
-        @return requested data (QVariant)
+        @return requested data
         """
         if index.row() >= self.__manager.enginesCount() or index.row() < 0:
-            return QVariant()
+            return None
         
-        engine = self.__manager.engine(self.__manager.allEnginesNames()[index.row()])
+        engine = self.__manager.engine(
+            self.__manager.allEnginesNames()[index.row()])
         
         if engine is None:
-            return QVariant()
+            return None
         
         if index.column() == 0:
             if role == Qt.DisplayRole:
-                return QVariant(engine.name())
+                return engine.name()
                 
             elif role == Qt.DecorationRole:
                 image = engine.image()
@@ -122,34 +127,34 @@ class OpenSearchEngineModel(QAbstractTableModel):
                     icon = HelpWindow.icon(QUrl(engine.imageUrl()))
                 else:
                     icon = QIcon(QPixmap.fromImage(image))
-                return QVariant(icon)
+                return icon
                 
             elif role == Qt.ToolTipRole:
-                description = self.trUtf8("<strong>Description:</strong> %1")\
-                              .arg(engine.description())
+                description = self.trUtf8("<strong>Description:</strong> {0}")\
+                    .format(engine.description())
                 if engine.providesSuggestions():
-                    description.append("<br/>")
-                    description.append(
-                        self.trUtf8("<strong>Provides contextual suggestions</strong>"))
+                    description += "<br/>"
+                    description += self.trUtf8(
+                        "<strong>Provides contextual suggestions</strong>")
                 
-                return QVariant(description)
+                return description
         elif index.column() == 1:
             if role in [Qt.EditRole, Qt.DisplayRole]:
-                return QVariant(
-                    QStringList(self.__manager.keywordsForEngine(engine)).join(","))
+                return ",".join(self.__manager.keywordsForEngine(engine))
             elif role == Qt.ToolTipRole:
-                return QVariant(self.trUtf8("Comma-separated list of keywords that may"
-                    " be entered in the location bar followed by search terms to search"
-                    " with this engine"))
+                return self.trUtf8(
+                    "Comma-separated list of keywords that may"
+                    " be entered in the location bar followed by search terms"
+                    " to search with this engine")
         
-        return QVariant()
+        return None
     
-    def setData(self, index, value, role = Qt.EditRole):
+    def setData(self, index, value, role=Qt.EditRole):
         """
         Public method to set the data of a model cell.
         
         @param index index of the model cell (QModelIndex)
-        @param value value to be set (QVariant)
+        @param value value to be set
         @param role role of the data (integer)
         @return flag indicating success (boolean)
         """
@@ -163,30 +168,31 @@ class OpenSearchEngineModel(QAbstractTableModel):
             return False
         
         engineName = self.__manager.allEnginesNames()[index.row()]
-        keywords = value.toString().split(QRegExp("[ ,]+"), QString.SkipEmptyParts)
-        self.__manager.setKeywordsForEngine(self.__manager.engine(engineName), keywords)
+        keywords = re.split("[ ,]+", value)
+        self.__manager.setKeywordsForEngine(
+            self.__manager.engine(engineName), keywords)
         
         return True
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get the header data.
         
         @param section section number (integer)
         @param orientation header orientation (Qt.Orientation)
         @param role data role (integer)
-        @return header data (QVariant)
+        @return header data
         """
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             try:
-                return QVariant(self.__headers[section])
+                return self.__headers[section]
             except IndexError:
                 pass
         
-        return QVariant()
+        return None
     
     def __enginesChanged(self):
         """
         Private slot handling a change of the registered engines.
         """
-        QAbstractTableModel.reset(self)
+        super().reset()
