@@ -7,9 +7,8 @@
 Module implementing a reader for open search engine descriptions.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import QXmlStreamReader, QIODevice, QCoreApplication
 
-from OpenSearchEngine import OpenSearchEngine
 
 class OpenSearchReader(QXmlStreamReader):
     """
@@ -36,6 +35,7 @@ class OpenSearchReader(QXmlStreamReader):
         
         @return search engine object (OpenSearchEngine)
         """
+        from .OpenSearchEngine import OpenSearchEngine
         engine = OpenSearchEngine()
         
         while not self.isStartElement() and not self.atEnd():
@@ -43,7 +43,9 @@ class OpenSearchReader(QXmlStreamReader):
         
         if self.name() != "OpenSearchDescription" or \
            self.namespaceUri() != "http://a9.com/-/spec/opensearch/1.1/":
-            self.raiseError(self.trUtf8("The file is not an OpenSearch 1.1 file."))
+            self.raiseError(QCoreApplication.translate(
+                "OpenSearchReader",
+                "The file is not an OpenSearch 1.1 file."))
             return engine
         
         while not self.atEnd():
@@ -59,21 +61,21 @@ class OpenSearchReader(QXmlStreamReader):
                 engine.setDescription(self.readElementText())
                 
             elif self.name() == "Url":
-                type_ = self.attributes().value("type").toString()
-                url = self.attributes().value("template").toString()
-                method = self.attributes().value("method").toString()
+                type_ = self.attributes().value("type")
+                url = self.attributes().value("template")
+                method = self.attributes().value("method")
                 
                 if type_ == "application/x-suggestions+json" and \
-                   not engine.suggestionsUrlTemplate().isEmpty():
+                   engine.suggestionsUrlTemplate():
                     continue
                 
-                if (type_.isEmpty() or \
-                    type_ == "text/html" or \
+                if (not type_ or
+                    type_ == "text/html" or
                     type_ == "application/xhtml+xml") and \
-                   not engine.suggestionsUrlTemplate().isEmpty():
+                   engine.suggestionsUrlTemplate():
                     continue
                 
-                if url.isEmpty():
+                if not url:
                     continue
                 
                 parameters = []
@@ -86,10 +88,10 @@ class OpenSearchReader(QXmlStreamReader):
                         self.readNext()
                         continue
                     
-                    key = self.attributes().value("name").toString()
-                    value = self.attributes().value("value").toString()
+                    key = self.attributes().value("name")
+                    value = self.attributes().value("value")
                     
-                    if not key.isEmpty() and not value.isEmpty():
+                    if key and value:
                         parameters.append((key, value))
                     
                     while not self.isEndElement():
@@ -99,22 +101,21 @@ class OpenSearchReader(QXmlStreamReader):
                     engine.setSuggestionsUrlTemplate(url)
                     engine.setSuggestionsParameters(parameters)
                     engine.setSuggestionsMethod(method)
-                elif type_.isEmpty() or \
-                     type_ == "text/html" or \
-                     type_ == "application/xhtml+xml":
+                elif not type_ or \
+                    type_ == "text/html" or \
+                        type_ == "application/xhtml+xml":
                     engine.setSearchUrlTemplate(url)
                     engine.setSearchParameters(parameters)
                     engine.setSearchMethod(method)
                 
             elif self.name() == "Image":
                 engine.setImageUrl(self.readElementText())
-                
             
-            if not engine.name().isEmpty() and \
-               not engine.description().isEmpty() and \
-               not engine.suggestionsUrlTemplate().isEmpty() and \
-               not engine.searchUrlTemplate().isEmpty() and \
-               not engine.imageUrl().isEmpty():
+            if engine.name() and \
+               engine.description() and \
+               engine.suggestionsUrlTemplate() and \
+               engine.searchUrlTemplate() and \
+               engine.imageUrl():
                 break
         
         return engine
