@@ -9,84 +9,42 @@ Module implementing the password manager.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import QMessageBox
+from PyQt4.QtCore import pyqtSignal, QObject, QByteArray, QUrl, \
+    QCoreApplication, QXmlStreamReader
+from PyQt4.QtGui import QApplication
 from PyQt4.QtNetwork import QNetworkRequest
-from PyQt4.QtWebKit import *
+from PyQt4.QtWebKit import QWebSettings, QWebPage
 
-from Helpviewer.JavaScriptResources import parseForms_js
+from E5Gui import E5MessageBox
+from E5Gui.E5ProgressDialog import E5ProgressDialog
 
 from Utilities.AutoSaver import AutoSaver
 import Utilities
+import Utilities.crypto
 import Preferences
 
-class LoginForm(object):
-    """
-    Class implementing a data structure for login forms.
-    """
-    def __init__(self):
-        """
-        Constructor
-        """
-        self.url = QUrl()
-        self.name = ""
-        self.hasAPassword = False
-        self.elements = []      # list of tuples of element name and value 
-                                # (QString, QString)
-        self.elementTypes = {}  # dict of element name as key and type as value
-    
-    def isValid(self):
-        """
-        Public method to test for validity.
-        
-        @return flag indicating a valid form (boolean)
-        """
-        return len(self.elements) > 0
-    
-    def load(self, data):
-        """
-        Public method to load the form data from a file.
-        
-        @param data list of strings to load data from (list of strings)
-        @return flag indicating success (boolean)
-        """
-        self.url = QUrl(data[0])
-        self.name = data[1]
-        self.hasAPassword = data[2] == "True"
-        for element in data[3:]:
-            name, value = element.split(" = ", 1)
-            self.elements.append((name, value))
-    
-    def save(self, f):
-        """
-        Public method to save the form data to a file.
-        
-        @param f file or file like object open for writing
-        @return flag indicating success (booelan)
-        """
-        f.write("%s\n" % self.url.toString())
-        f.write("%s\n" % self.name)
-        f.write("%s\n" % self.hasAPassword)
-        for element in self.elements:
-            f.write("%s = %s\n" % (element[0], element[1]))
 
 class PasswordManager(QObject):
     """
     Class implementing the password manager.
     
     @signal changed() emitted to indicate a change
+    @signal passwordsSaved() emitted after the passwords were saved
     """
+    changed = pyqtSignal()
+    passwordsSaved = pyqtSignal()
+    
     SEPARATOR = "===================="
     FORMS = "=====FORMS====="
     NEVER = "=====NEVER====="
     
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.__logins = {}
         self.__loginForms = {}
@@ -94,7 +52,7 @@ class PasswordManager(QObject):
         self.__loaded = False
         self.__saveTimer = AutoSaver(self, self.save)
         
-        self.connect(self, SIGNAL("changed()"), self.__saveTimer.changeOccurred)
+        self.changed.connect(self.__saveTimer.changeOccurred)
     
     def clear(self):
         """
@@ -109,14 +67,14 @@ class PasswordManager(QObject):
         self.__saveTimer.changeOccurred()
         self.__saveTimer.saveIfNeccessary()
         
-        self.emit(SIGNAL("changed()"))
+        self.changed.emit()
     
     def getLogin(self, url, realm):
         """
         Public method to get the login credentials.
         
         @param url URL to get the credentials for (QUrl)
-        @param realm realm to get the credentials for (string or QString)
+        @param realm realm to get the credentials for (string)
         @return tuple containing the user name (string) and password (string)
         """
         if not self.__loaded:
@@ -124,7 +82,8 @@ class PasswordManager(QObject):
         
         key = self.__createKey(url, realm)
         try:
-            return self.__logins[key][0], Utilities.pwDecode(self.__logins[key][1])
+            return self.__logins[key][0], Utilities.crypto.pwConvert(
+                self.__logins[key][1], encode=False)
         except KeyError:
             return "", ""
     
@@ -133,32 +92,43 @@ class PasswordManager(QObject):
         Public method to set the login credentials.
         
         @param url URL to set the credentials for (QUrl)
-        @param realm realm to set the credentials for (string or QString)
-        @param username username for the login (string or QString)
-        @param password password for the login (string or QString)
+        @param realm realm to set the credentials for (string)
+        @param username username for the login (string)
+        @param password password for the login (string)
         """
         if not self.__loaded:
             self.__load()
         
         key = self.__createKey(url, realm)
-        self.__logins[key] = (unicode(username), Utilities.pwEncode(password))
-        self.emit(SIGNAL("changed()"))
+        self.__logins[key] = (
+            username,
+            Utilities.crypto.pwConvert(password, encode=True)
+        )
+        self.changed.emit()
     
     def __createKey(self, url, realm):
         """
         Private method to create the key string for the login credentials.
         
         @param url URL to get the credentials for (QUrl)
-        @param realm realm to get the credentials for (string or QString)
+        @param realm realm to get the credentials for (string)
         @return key string (string)
         """
-        realm = unicode(realm)
         if realm:
-            key = "%s://%s (%s)" % (url.scheme(), url.authority(), realm)
+            key = "{0}://{1} ({2})".format(
+                url.scheme(), url.authority(), realm)
         else:
-            key = "%s://%s" % (url.scheme(), url.authority())
+            key = "{0}://{1}".format(url.scheme(), url.authority())
         return key
     
+    def getFileName(self):
+        """
+        Public method to get the file name of the passwords file.
+        
+        @return name of the passwords file (string)
+        """
+        return os.path.join(Utilities.getConfigDir(), "browser", "logins.xml")
+    
     def save(self):
         """
         Public slot to save the login entries to disk.
@@ -166,51 +136,71 @@ class PasswordManager(QObject):
         if not self.__loaded:
             return
         
-        loginFile = os.path.join(Utilities.getConfigDir(), "browser", "logins")
-        try:
-            f = open(loginFile, "w")
-            for key, login in self.__logins.items():
-                f.write("%s\n" % key)
-                f.write("%s\n" % login[0])
-                f.write("%s\n" % login[1])
-                f.write("%s\n" % self.SEPARATOR)
-            if self.__loginForms:
-                f.write("%s\n" % self.FORMS)
-                for key, form in self.__loginForms.items():
-                    f.write("%s\n" % key)
-                    form.save(f)
-                    f.write("%s\n" % self.SEPARATOR)
-            if self.__never:
-                f.write("%s\n" % self.NEVER)
-                for key in self.__never:
-                    f.write("%s\n") % key
-            f.close()
-        except IOError, err:
-            KQMessageBox.critical(None,
+        from .PasswordWriter import PasswordWriter
+        loginFile = self.getFileName()
+        writer = PasswordWriter()
+        if not writer.write(
+                loginFile, self.__logins, self.__loginForms, self.__never):
+            E5MessageBox.critical(
+                None,
                 self.trUtf8("Saving login data"),
-                self.trUtf8("""<p>Login data could not be saved to <b>%1</b></p>"""
-                            """<p>Reason: %2</p>""").arg(loginFile).arg(str(err)))
-            return
+                self.trUtf8(
+                    """<p>Login data could not be saved to <b>{0}</b></p>"""
+                ).format(loginFile))
+        else:
+            self.passwordsSaved.emit()
     
     def __load(self):
         """
         Private method to load the saved login credentials.
         """
-        loginFile = os.path.join(Utilities.getConfigDir(), "browser", "logins")
+        loginFile = self.getFileName()
+        if not os.path.exists(loginFile):
+            self.__loadNonXml(os.path.splitext(loginFile)[0])
+        else:
+            from .PasswordReader import PasswordReader
+            reader = PasswordReader()
+            self.__logins, self.__loginForms, self.__never = \
+                reader.read(loginFile)
+            if reader.error() != QXmlStreamReader.NoError:
+                E5MessageBox.warning(
+                    None,
+                    self.trUtf8("Loading login data"),
+                    self.trUtf8("""Error when loading login data on"""
+                                """ line {0}, column {1}:\n{2}""")
+                    .format(reader.lineNumber(),
+                            reader.columnNumber(),
+                            reader.errorString()))
+        
+        self.__loaded = True
+    
+    def __loadNonXml(self, loginFile):
+        """
+        Private method to load non-XML password files.
+        
+        This method is to convert from the old, non-XML format to the new
+        XML based format.
+        
+        @param loginFile name of the non-XML password file (string)
+        """
         if os.path.exists(loginFile):
             try:
-                f = open(loginFile, "r")
+                f = open(loginFile, "r", encoding="utf-8")
                 lines = f.read()
                 f.close()
-            except IOError, err:
-                KQMessageBox.critical(None,
+            except IOError as err:
+                E5MessageBox.critical(
+                    None,
                     self.trUtf8("Loading login data"),
-                    self.trUtf8("""<p>Login data could not be loaded from <b>%1</b></p>"""
-                                """<p>Reason: %2</p>""").arg(loginFile).arg(str(err)))
+                    self.trUtf8("""<p>Login data could not be loaded """
+                                """from <b>{0}</b></p>"""
+                                """<p>Reason: {1}</p>""")
+                    .format(loginFile, str(err)))
                 return
             
             data = []
-            section = 0     # 0 = login data, 1 = forms data, 2 = never store info
+            section = 0     # 0 = login data, 1 = forms data,
+                            # 2 = never store info
             for line in lines.splitlines():
                 if line == self.FORMS:
                     section = 1
@@ -224,12 +214,14 @@ class PasswordManager(QObject):
                         data.append(line)
                     else:
                         if len(data) != 3:
-                            KQMessageBox.critical(None,
+                            E5MessageBox.critical(
+                                None,
                                 self.trUtf8("Loading login data"),
-                                self.trUtf8("""<p>Login data could not be loaded """
-                                            """from <b>%1</b></p>"""
-                                            """<p>Reason: Wrong input format</p>""")\
-                                    .arg(loginFile))
+                                self.trUtf8(
+                                    """<p>Login data could not be loaded """
+                                    """from <b>{0}</b></p>"""
+                                    """<p>Reason: Wrong input format</p>""")
+                                .format(loginFile))
                             return
                         self.__logins[data[0]] = (data[1], data[2])
                         data = []
@@ -238,20 +230,40 @@ class PasswordManager(QObject):
                     if line != self.SEPARATOR:
                         data.append(line)
                     else:
+                        from .LoginForm import LoginForm
                         key = data[0]
                         form = LoginForm()
-                        form.load(data[1:])
+                        form.url = QUrl(data[1])
+                        form.name = data[2]
+                        form.hasAPassword = data[3] == "True"
+                        for element in data[4:]:
+                            name, value = element.split(" = ", 1)
+                            form.elements.append((name, value))
                         self.__loginForms[key] = form
                         data = []
                 
                 elif section == 2:
                     self.__never.append(line)
+            
+            os.remove(loginFile)
         
         self.__loaded = True
+        
+        # this does the conversion
+        self.save()
+    
+    def reload(self):
+        """
+        Public method to reload the login data.
+        """
+        if not self.__loaded:
+            return
+        
+        self.__load()
     
     def close(self):
         """
-        Public method to close the open search engines manager.
+        Public method to close the passwords manager.
         """
         self.__saveTimer.saveIfNeccessary()
     
@@ -259,25 +271,24 @@ class PasswordManager(QObject):
         """
         Public method to remove a password entry.
         
-        @param site web site name (string or QString)
+        @param site web site name (string)
         """
-        site = unicode(site)
         if site in self.__logins:
             del self.__logins[site]
             if site in self.__loginForms:
                 del self.__loginForms[site]
-            self.emit(SIGNAL("changed()"))
+            self.changed.emit()
     
     def allSiteNames(self):
         """
         Public method to get a list of all site names.
         
-        @return sorted list of all site names (QStringList)
+        @return sorted list of all site names (list of strings)
         """
         if not self.__loaded:
             self.__load()
         
-        return QStringList(sorted(self.__logins.keys()))
+        return sorted(self.__logins.keys())
     
     def sitesCount(self):
         """
@@ -294,17 +305,17 @@ class PasswordManager(QObject):
         """
         Public method to get a reference to the named site.
         
-        @param site web site name (string or QString)
+        @param site web site name (string)
         @return tuple containing the user name (string) and password (string)
         """
         if not self.__loaded:
             self.__load()
         
-        site = unicode(site)
         if site not in self.__logins:
             return None
         
-        return self.__logins[site][0], Utilities.pwDecode(self.__logins[site][1])
+        return self.__logins[site][0], Utilities.crypto.pwConvert(
+            self.__logins[site][1], encode=False)
     
     def post(self, request, data):
         """
@@ -314,7 +325,7 @@ class PasswordManager(QObject):
         @param data data to be sent (QByteArray)
         """
         # shall passwords be saved?
-        if not Preferences.getHelp("SavePasswords"):
+        if not Preferences.getUser("SavePasswords"):
             return
         
         # observe privacy
@@ -333,21 +344,19 @@ class PasswordManager(QObject):
         url = self.__stripUrl(url)
         
         # check that url isn't in __never
-        if unicode(url.toString()) in self.__never:
+        if url.toString() in self.__never:
             return
         
         # check the request type
-        v = request.attribute(QNetworkRequest.User + 101)
-        if not v.isValid():
+        navType = request.attribute(QNetworkRequest.User + 101)
+        if navType is None:
             return
-        navType = v.toInt()[0]
         if navType != QWebPage.NavigationTypeFormSubmitted:
             return
         
         # determine the QWebPage
-        v = request.attribute(QNetworkRequest.User + 100)
-        webPage = v.toPyObject()
-        if webPage == NotImplemented or webPage is None:
+        webPage = request.attribute(QNetworkRequest.User + 100)
+        if webPage is None:
             return
         
         # determine the requests content type
@@ -361,7 +370,7 @@ class PasswordManager(QObject):
             boundary = None
         
         # find the matching form on the web page
-        form = self.__findForm(webPage, data, boundary = boundary)
+        form = self.__findForm(webPage, data, boundary=boundary)
         if not form.isValid():
             return
         form.url = QUrl(url)
@@ -373,19 +382,24 @@ class PasswordManager(QObject):
         # prompt, if the form has never be seen
         key = self.__createKey(url, "")
         if key not in self.__loginForms:
-            mb = QMessageBox()
-            mb.setText(self.trUtf8(
-                """<b>Would you like to save this password?</b><br/>"""
-                """To review passwords you have saved and remove them, """
-                """use the password management dialog of the Settings menu."""
-            ))
+            mb = E5MessageBox.E5MessageBox(
+                E5MessageBox.Question,
+                self.trUtf8("Save password"),
+                self.trUtf8(
+                    """<b>Would you like to save this password?</b><br/>"""
+                    """To review passwords you have saved and remove them, """
+                    """use the password management dialog of the Settings"""
+                    """ menu."""),
+                modal=True)
             neverButton = mb.addButton(
-                self.trUtf8("Never for this site"), QMessageBox.DestructiveRole)
-            noButton = mb.addButton(self.trUtf8("Not now"), QMessageBox.RejectRole)
-            yesButton = mb.addButton(QMessageBox.Yes)
+                self.trUtf8("Never for this site"),
+                E5MessageBox.DestructiveRole)
+            noButton = mb.addButton(
+                self.trUtf8("Not now"), E5MessageBox.RejectRole)
+            mb.addButton(E5MessageBox.Yes)
             mb.exec_()
             if mb.clickedButton() == neverButton:
-                self.__never.append(unicode(url.toString()))
+                self.__never.append(url.toString())
                 return
             elif mb.clickedButton() == noButton:
                 return
@@ -395,19 +409,19 @@ class PasswordManager(QObject):
         password = ""
         for index in range(len(form.elements)):
             element = form.elements[index]
-            name = element[0].toLower()
-            type_ = form.elementTypes[unicode(element[0])]
+            type_ = form.elementTypes[element[0]]
             if user == "" and \
                type_ == "text":
                 user = element[1]
             elif password == "" and \
-                 type_ == "password":
+                    type_ == "password":
                 password = element[1]
-                form.elements[index] = (element[0], QString("--PASSWORD--"))
+                form.elements[index] = (element[0], "--PASSWORD--")
         if user and password:
-            self.__logins[key] = (unicode(user), Utilities.pwEncode(password))
+            self.__logins[key] = \
+                (user, Utilities.crypto.pwConvert(password, encode=True))
             self.__loginForms[key] = form
-            self.emit(SIGNAL("changed()"))
+            self.changed.emit()
     
     def __stripUrl(self, url):
         """
@@ -422,22 +436,23 @@ class PasswordManager(QObject):
         cleanUrl.setUserInfo("")
         return cleanUrl
     
-    def __findForm(self, webPage, data, boundary = None):
+    def __findForm(self, webPage, data, boundary=None):
         """
         Private method to find the form used for logging in.
         
         @param webPage reference to the web page (QWebPage)
         @param data data to be sent (QByteArray)
-        @keyparam boundary boundary string (QByteArray) for multipart encoded data,
-            None for urlencoded data
+        @keyparam boundary boundary string (QByteArray) for multipart
+            encoded data, None for urlencoded data
         @return parsed form (LoginForm)
         """
+        from .LoginForm import LoginForm
         form = LoginForm()
         if boundary is not None:
             args = self.__extractMultipartQueryItems(data, boundary)
         else:
             argsUrl = QUrl.fromEncoded(
-                QByteArray("foo://bar.com/?" + data.replace("+", "%20")))
+                QByteArray("foo://bar.com/?" + data.replace(b"+", b"%20")))
             encodedArgs = argsUrl.queryItems()
             args = set()
             for arg in encodedArgs:
@@ -446,45 +461,46 @@ class PasswordManager(QObject):
                 args.add((key, value))
         
         # extract the forms
-        lst = webPage.mainFrame().evaluateJavaScript(parseForms_js).toList()
-        for formVariant in lst:
-            map = formVariant.toMap()
+        from Helpviewer.JavaScriptResources import parseForms_js
+        lst = webPage.mainFrame().evaluateJavaScript(parseForms_js)
+        for map in lst:
             formHasPasswords = False
-            formName = map[QString("name")].toString()
-            formIndex = map[QString("index")].toInt()[0]
-            elements = map[QString("elements")].toList()
+            formName = map["name"]
+            formIndex = map["index"]
+            if isinstance(formIndex, float) and formIndex.is_integer():
+                formIndex = int(formIndex)
+            elements = map["elements"]
             formElements = set()
             formElementTypes = {}
             deadElements = set()
-            for element in elements:
-                elementMap = element.toMap()
+            for elementMap in elements:
                 try:
-                    name = elementMap[QString("name")].toString()
-                    value = elementMap[QString("value")].toString()
-                    type_ = elementMap[QString("type")].toString()
+                    name = elementMap["name"]
+                    value = elementMap["value"]
+                    type_ = elementMap["type"]
                 except KeyError:
                     continue
                 if type_ == "password":
                     formHasPasswords = True
                 t = (name, value)
                 try:
-                    if elementMap[QString("autocomplete")].toString() == "off":
+                    if elementMap["autocomplete"] == "off":
                         deadElements.add(t)
                 except KeyError:
                     pass
-                if not name.isEmpty():
+                if name:
                     formElements.add(t)
-                    formElementTypes[unicode(name)] = type_
+                    formElementTypes[name] = type_
             if formElements.intersection(args) == args:
                 form.hasAPassword = formHasPasswords
-                if formName.isEmpty():
+                if not formName:
                     form.name = formIndex
                 else:
                     form.name = formName
                 args.difference_update(deadElements)
                 for elt in deadElements:
-                    if unicode(elt[0]) in formElementTypes:
-                        del formElementTypes[unicode(elt[0])]
+                    if elt[0] in formElementTypes:
+                        del formElementTypes[elt[0]]
                 form.elements = list(args)
                 form.elementTypes = formElementTypes
                 break
@@ -497,16 +513,16 @@ class PasswordManager(QObject):
         
         @param data data to be sent (QByteArray)
         @param boundary boundary string (QByteArray)
-        @return set of name, value pairs (set of tuple of QString, QString)
+        @return set of name, value pairs (set of tuple of string, string)
         """
         args = set()
         
-        dataStr = QString(data)
-        boundaryStr = QString(boundary)
+        dataStr = bytes(data).decode()
+        boundaryStr = bytes(boundary).decode()
         
         parts = dataStr.split(boundaryStr + "\r\n")
         for part in parts:
-            if part.startsWith("Content-Disposition"):
+            if part.startswith("Content-Disposition"):
                 lines = part.split("\r\n")
                 name = lines[0].split("=")[1][1:-1]
                 value = lines[2]
@@ -538,36 +554,70 @@ class PasswordManager(QObject):
             return
         
         if form.name == "":
-            formName = QString("0")
+            formName = "0"
         else:
             try:
-                formName = QString("%d" % int(form.name))
+                formName = "{0:d}".format(int(form.name))
             except ValueError:
-                formName = QString('"%1"').arg(form.name)
+                formName = '"{0}"'.format(form.name)
         for element in form.elements:
             name = element[0]
             value = element[1]
             
             disabled = page.mainFrame().evaluateJavaScript(
-                'document.forms[%s].elements["%s"].disabled' % (formName, name)).toBool()
+                'document.forms[{0}].elements["{1}"].disabled'.format(
+                    formName, name))
             if disabled:
                 continue
             
             readOnly = page.mainFrame().evaluateJavaScript(
-                'document.forms[%s].elements["%s"].readOnly' % (formName, name)).toBool()
+                'document.forms[{0}].elements["{1}"].readOnly'.format(
+                    formName, name))
             if readOnly:
                 continue
             
             type_ = page.mainFrame().evaluateJavaScript(
-                'document.forms[%s].elements["%s"].type' % (formName, name)).toString()
+                'document.forms[{0}].elements["{1}"].type'.format(
+                    formName, name))
             if type_ == "" or \
                type_ in ["hidden", "reset", "submit"]:
                 continue
             if type_ == "password":
-                value = Utilities.pwDecode(self.__logins[key][1])
+                value = Utilities.crypto.pwConvert(
+                    self.__logins[key][1], encode=False)
             setType = type_ == "checkbox" and "checked" or "value"
             value = value.replace("\\", "\\\\")
             value = value.replace('"', '\\"')
-            javascript = 'document.forms[%s].elements["%s"].%s="%s";' % \
-                         (formName, name, setType, value)
+            javascript = \
+                'document.forms[{0}].elements["{1}"].{2}="{3}";'.format(
+                    formName, name, setType, value)
             page.mainFrame().evaluateJavaScript(javascript)
+    
+    def masterPasswordChanged(self, oldPassword, newPassword):
+        """
+        Public slot to handle the change of the master password.
+        
+        @param oldPassword current master password (string)
+        @param newPassword new master password (string)
+        """
+        if not self.__loaded:
+            self.__load()
+        
+        progress = E5ProgressDialog(
+            self.trUtf8("Re-encoding saved passwords..."),
+            None, 0, len(self.__logins), self.trUtf8("%v/%m Passwords"),
+            QApplication.activeModalWidget())
+        progress.setMinimumDuration(0)
+        count = 0
+        
+        for key in self.__logins:
+            progress.setValue(count)
+            QCoreApplication.processEvents()
+            username, hash = self.__logins[key]
+            hash = Utilities.crypto.pwRecode(hash, oldPassword, newPassword)
+            self.__logins[key] = (username, hash)
+            count += 1
+        
+        progress.setValue(len(self.__logins))
+        QCoreApplication.processEvents()
+        self.changed.emit()
