@@ -7,27 +7,28 @@
 Module implementing a model for password management.
 """
 
-from PyQt4.QtCore import *
+from PyQt4.QtCore import Qt, QModelIndex, QAbstractTableModel
+
 
 class PasswordModel(QAbstractTableModel):
     """
     Class implementing a model for password management.
     """
-    def __init__(self, manager, parent = None):
+    def __init__(self, manager, parent=None):
         """
         Constructor
         
         @param manager reference to the password manager (PasswordManager)
         @param parent reference to the parent object (QObject)
         """
-        QAbstractTableModel.__init__(self, parent)
+        super().__init__(parent)
         
         self.__manager = manager
-        self.connect(manager, SIGNAL("changed()"), self.__passwordsChanged)
+        manager.changed.connect(self.__passwordsChanged)
         
         self.__headers = [
-            self.trUtf8("Website"), 
-            self.trUtf8("Username"), 
+            self.trUtf8("Website"),
+            self.trUtf8("Username"),
             self.trUtf8("Password")
         ]
         
@@ -56,7 +57,7 @@ class PasswordModel(QAbstractTableModel):
         """
         self.reset()
     
-    def removeRows(self, row, count, parent = QModelIndex()):
+    def removeRows(self, row, count, parent=QModelIndex()):
         """
         Public method to remove entries from the model.
         
@@ -84,7 +85,7 @@ class PasswordModel(QAbstractTableModel):
         
         return True
     
-    def rowCount(self, parent = QModelIndex()):
+    def rowCount(self, parent=QModelIndex()):
         """
         Public method to get the number of rows of the model.
         
@@ -96,7 +97,7 @@ class PasswordModel(QAbstractTableModel):
         else:
             return self.__manager.sitesCount()
     
-    def columnCount(self, parent = QModelIndex()):
+    def columnCount(self, parent=QModelIndex()):
         """
         Public method to get the number of columns of the model.
         
@@ -114,38 +115,38 @@ class PasswordModel(QAbstractTableModel):
         
         @param index index to get data for (QModelIndex)
         @param role role of the data to retrieve (integer)
-        @return requested data (QVariant)
+        @return requested data
         """
         if index.row() >= self.__manager.sitesCount() or index.row() < 0:
-            return QVariant()
+            return None
         
         site = self.__manager.allSiteNames()[index.row()]
         siteInfo = self.__manager.siteInfo(site)
         
         if siteInfo is None:
-            return QVariant()
+            return None
         
         if role == Qt.DisplayRole:
             if index.column() == 0:
-                return QVariant(site)
+                return site
             elif index.column() in [1, 2]:
-                return QVariant(siteInfo[index.column() - 1])
+                return siteInfo[index.column() - 1]
         
-        return QVariant()
+        return None
     
-    def headerData(self, section, orientation, role = Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.DisplayRole):
         """
         Public method to get the header data.
         
         @param section section number (integer)
         @param orientation header orientation (Qt.Orientation)
         @param role data role (integer)
-        @return header data (QVariant)
+        @return header data
         """
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             try:
-                return QVariant(self.__headers[section])
+                return self.__headers[section]
             except IndexError:
                 pass
         
-        return QVariant()
+        return None
