@@ -9,26 +9,26 @@ Module implementing a dialog to manage the QtHelp filters.
 
 import sqlite3
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt4.QtCore import pyqtSlot, Qt
+from PyQt4.QtGui import QDialog, QTreeWidgetItem, QListWidgetItem, \
+    QInputDialog, QLineEdit
 from PyQt4.QtHelp import QHelpEngineCore
 
-from KdeQt import KQInputDialog
+from .Ui_QtHelpFiltersDialog import Ui_QtHelpFiltersDialog
 
-from Ui_QtHelpFiltersDialog import Ui_QtHelpFiltersDialog
 
 class QtHelpFiltersDialog(QDialog, Ui_QtHelpFiltersDialog):
     """
-    Class implementing a dialog to manage the QtHelp filters
+    Class implementing a dialog to manage the QtHelp filters.
     """
-    def __init__(self, engine, parent = None):
+    def __init__(self, engine, parent=None):
         """
         Constructor
         
         @param engine reference to the help engine (QHelpEngine)
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.__engine = engine
@@ -48,37 +48,37 @@ class QtHelpFiltersDialog(QDialog, Ui_QtHelpFiltersDialog):
         
         for filter in help.customFilters():
             atts = help.filterAttributes(filter)
-            ufilter = unicode(filter)
-            self.__filterMapBackup[ufilter] = atts
-            if ufilter not in self.__filterMap:
-                self.__filterMap[ufilter] = atts
+            self.__filterMapBackup[filter] = atts
+            if filter not in self.__filterMap:
+                self.__filterMap[filter] = atts
         
         self.filtersList.addItems(sorted(self.__filterMap.keys()))
         for attr in help.filterAttributes():
-            QTreeWidgetItem(self.attributesList, QStringList(attr))
+            QTreeWidgetItem(self.attributesList, [attr])
         
         if self.__filterMap:
             self.filtersList.setCurrentRow(0)
     
-    @pyqtSignature("QListWidgetItem*, QListWidgetItem*")
+    @pyqtSlot(QListWidgetItem, QListWidgetItem)
     def on_filtersList_currentItemChanged(self, current, previous):
         """
         Private slot to update the attributes depending on the current filter.
         
         @param current reference to the current item (QListWidgetitem)
-        @param previous reference to the previous current item (QListWidgetItem)
+        @param previous reference to the previous current item
+            (QListWidgetItem)
         """
-        checkedList = QStringList()
+        checkedList = []
         if current is not None:
-            checkedList = self.__filterMap[unicode(current.text())]
+            checkedList = self.__filterMap[current.text()]
         for index in range(0, self.attributesList.topLevelItemCount()):
             itm = self.attributesList.topLevelItem(index)
-            if checkedList.contains(itm.text(0)):
+            if itm.text(0) in checkedList:
                 itm.setCheckState(0, Qt.Checked)
             else:
                 itm.setCheckState(0, Qt.Unchecked)
     
-    @pyqtSignature("QTreeWidgetItem*, int")
+    @pyqtSlot(QTreeWidgetItem, int)
     def on_attributesList_itemChanged(self, item, column):
         """
         Private slot to handle a change of an attribute.
@@ -89,54 +89,54 @@ class QtHelpFiltersDialog(QDialog, Ui_QtHelpFiltersDialog):
         if self.filtersList.currentItem() is None:
             return
         
-        filter = unicode(self.filtersList.currentItem().text())
+        filter = self.filtersList.currentItem().text()
         if filter not in self.__filterMap:
             return
         
-        newAtts = QStringList()
+        newAtts = []
         for index in range(0, self.attributesList.topLevelItemCount()):
             itm = self.attributesList.topLevelItem(index)
             if itm.checkState(0) == Qt.Checked:
                 newAtts.append(itm.text(0))
         self.__filterMap[filter] = newAtts
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add a new filter.
         """
-        filter, ok = KQInputDialog.getText(\
+        filter, ok = QInputDialog.getText(
             None,
             self.trUtf8("Add Filter"),
             self.trUtf8("Filter name:"),
             QLineEdit.Normal)
-        if filter.isEmpty():
+        if not filter:
             return
         
-        ufilter = unicode(filter)
-        if ufilter not in self.__filterMap:
-            self.__filterMap[ufilter] = QStringList()
+        if filter not in self.__filterMap:
+            self.__filterMap[filter] = []
             self.filtersList.addItem(filter)
         
         itm = self.filtersList.findItems(filter, Qt.MatchCaseSensitive)[0]
         self.filtersList.setCurrentItem(itm)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_removeButton_clicked(self):
         """
         Private slot to remove a filter.
         """
-        itm = self.filtersList.takeItem(self.filtersList.currentRow())
+        row = self.filtersList.currentRow()
+        itm = self.filtersList.takeItem(row)
         if itm is None:
             return
         
-        del self.__filterMap[unicode(itm.text())]
+        del self.__filterMap[itm.text()]
         self.__removedFilters.append(itm.text())
         del itm
         if self.filtersList.count():
-            self.filtersList.setCurrentRow(0)
+            self.filtersList.setCurrentRow(row)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_removeAttributeButton_clicked(self):
         """
         Private slot to remove a filter attribute.
@@ -151,7 +151,7 @@ class QtHelpFiltersDialog(QDialog, Ui_QtHelpFiltersDialog):
         self.__removedAttributes.append(attr)
         for filter in self.__filterMap:
             if attr in self.__filterMap[filter]:
-                self.__filterMap[filter].removeAll(attr)
+                self.__filterMap[filter].remove(attr)
         
         del itm
     
@@ -160,17 +160,18 @@ class QtHelpFiltersDialog(QDialog, Ui_QtHelpFiltersDialog):
         Private method to remove attributes from the Qt Help database.
         """
         try:
-            self.__db = sqlite3.connect(unicode(self.__engine.collectionFile()))
+            self.__db = sqlite3.connect(self.__engine.collectionFile())
         except sqlite3.DatabaseError:
             pass        # ignore database errors
         
         for attr in self.__removedAttributes:
             self.__db.execute(
-                "DELETE FROM FilterAttributeTable WHERE Name = '%s'" % attr)
+                "DELETE FROM FilterAttributeTable WHERE Name = '{0}'"
+                .format(attr))
         self.__db.commit()
         self.__db.close()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_buttonBox_accepted(self):
         """
         Private slot to update the database, if the dialog is accepted.
