@@ -7,25 +7,27 @@
 Module implementing the search bar for the web browser.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot, Qt
+from PyQt4.QtGui import QWidget, QPalette, QBrush, QColor
+from PyQt4.QtWebKit import QWebPage
 
-from Ui_SearchWidget import Ui_SearchWidget
+from .Ui_SearchWidget import Ui_SearchWidget
 
 import UI.PixmapCache
 
+
 class SearchWidget(QWidget, Ui_SearchWidget):
     """
     Class implementing the search bar for the web browser.
     """
-    def __init__(self, mainWindow, parent = None):
+    def __init__(self, mainWindow, parent=None):
         """
         Constructor
         
         @param mainWindow reference to the main window (QMainWindow)
         @param parent parent widget of this dialog (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.__mainWindow = mainWindow
@@ -40,20 +42,39 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         self.__defaultTextColor = \
             self.findtextCombo.lineEdit().palette().color(QPalette.Text)
         
-        self.findHistory = QStringList()
+        self.findHistory = []
         self.havefound = False
         self.__findBackwards = False
         
-        self.connect(self.findtextCombo.lineEdit(), SIGNAL("returnPressed()"), 
-                     self.__findByReturnPressed)
+        self.findtextCombo.lineEdit().returnPressed.connect(
+            self.__findByReturnPressed)
+        self.findtextCombo.lineEdit().textEdited.connect(
+            self.__searchTextEdited)
+        
+        if hasattr(QWebPage, "HighlightAllOccurrences"):
+            self.highlightAllCheckBox.setChecked(True)
+        else:
+            self.highlightAllCheckBox.setVisible(False)
 
     def on_findtextCombo_editTextChanged(self, txt):
         """
         Private slot to enable/disable the find buttons.
+        
+        @param txt text of the combobox (string)
         """
-        self.findPrevButton.setEnabled(not txt.isEmpty())
-        self.findNextButton.setEnabled(not txt.isEmpty())
-
+        self.findPrevButton.setEnabled(txt != "")
+        self.findNextButton.setEnabled(txt != "")
+    
+    def __searchTextEdited(self, txt):
+        """
+        Private slot to perform an incremental search.
+        
+        @param txt current text of the search combos line edit (string)
+            (unused)
+        """
+        self.on_highlightAllCheckBox_toggled(True)
+        self.__findNextPrev()
+    
     def __findNextPrev(self):
         """
         Private slot to find the next occurrence of text.
@@ -61,18 +82,37 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         self.infoLabel.clear()
         self.__setFindtextComboBackground(False)
         
-        if not self.havefound or self.findtextCombo.currentText().isEmpty():
-            self.showFind()
+        if not self.findtextCombo.currentText():
             return
         
         if not self.__mainWindow.currentBrowser().findNextPrev(
-                self.findtextCombo.currentText(), 
-                self.caseCheckBox.isChecked(), 
-                self.__findBackwards, 
-                self.wrapCheckBox.isChecked()):
+                self.findtextCombo.currentText(),
+                self.caseCheckBox.isChecked(),
+                self.__findBackwards,
+                self.wrapCheckBox.isChecked(),
+                False):
             self.infoLabel.setText(self.trUtf8("Expression was not found."))
             self.__setFindtextComboBackground(True)
-    @pyqtSignature("")
+    
+    @pyqtSlot(bool)
+    def on_highlightAllCheckBox_toggled(self, checked):
+        """
+        Private slot to toggle the highlight of all occurrences.
+        
+        @param checked flag indicating the check box toggle state (boolean)
+        """
+        cbr = self.__mainWindow.currentBrowser()
+        if cbr is None:
+            return
+        cbr.findNextPrev(
+            "", False, False, False, True)
+        if self.highlightAllCheckBox.isChecked():
+            cbr.findNextPrev(
+                self.findtextCombo.currentText(),
+                self.caseCheckBox.isChecked(),
+                False, False, True)
+    
+    @pyqtSlot()
     def on_findNextButton_clicked(self):
         """
         Private slot to find the next occurrence.
@@ -81,8 +121,9 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         
         # This moves any previous occurrence of this statement to the head
         # of the list and updates the combobox
-        self.findHistory.removeAll(txt)
-        self.findHistory.prepend(txt)
+        if txt in self.findHistory:
+            self.findHistory.remove(txt)
+        self.findHistory.insert(0, txt)
         self.findtextCombo.clear()
         self.findtextCombo.addItems(self.findHistory)
         
@@ -93,9 +134,13 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         """
         Public slot to find the next occurrence.
         """
+        if not self.havefound or not self.findtextCombo.currentText():
+            self.showFind()
+            return
+        
         self.on_findNextButton_clicked()
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_findPrevButton_clicked(self):
         """
         Private slot to find the previous occurrence.
@@ -104,8 +149,9 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         
         # This moves any previous occurrence of this statement to the head
         # of the list and updates the combobox
-        self.findHistory.removeAll(txt)
-        self.findHistory.prepend(txt)
+        if txt in self.findHistory:
+            self.findHistory.remove(txt)
+        self.findHistory.insert(0, txt)
         self.findtextCombo.clear()
         self.findtextCombo.addItems(self.findHistory)
         
@@ -116,11 +162,16 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         """
         Public slot to find the previous occurrence.
         """
+        if not self.havefound or not self.findtextCombo.currentText():
+            self.showFind()
+            return
+        
         self.on_findPrevButton_clicked()
     
     def __findByReturnPressed(self):
         """
-        Private slot to handle the returnPressed signal of the findtext combobox.
+        Private slot to handle the returnPressed signal of the findtext
+        combobox.
         """
         if self.__findBackwards:
             self.on_findPrevButton_clicked()
@@ -148,7 +199,7 @@ class SearchWidget(QWidget, Ui_SearchWidget):
         self.__setFindtextComboBackground(False)
         self.show()
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_closeButton_clicked(self):
         """
         Private slot to close the widget.
@@ -170,7 +221,8 @@ class SearchWidget(QWidget, Ui_SearchWidget):
     
     def __setFindtextComboBackground(self, error):
         """
-        Private slot to change the findtext combo background to indicate errors.
+        Private slot to change the findtext combo background to indicate
+        errors.
         
         @param error flag indicating an error condition (boolean)
         """
