@@ -7,29 +7,31 @@
 Module implementing the icon editor grid.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, Qt, QPoint, QRect, QSize
+from PyQt4.QtGui import QUndoCommand, QImage, QWidget, QColor, QPixmap, \
+    QSizePolicy, QUndoStack, qRgba, QPainter, QApplication, QCursor, \
+    QBrush, QDialog, qGray, qAlpha
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-import cursors.cursors_rc
+from .cursors import cursors_rc     # __IGNORE_WARNING__
 
-from IconSizeDialog import IconSizeDialog
 
 class IconEditCommand(QUndoCommand):
     """
     Class implementing an undo command for the icon editor.
     """
-    def __init__(self, grid, text, oldImage, parent = None):
+    def __init__(self, grid, text, oldImage, parent=None):
         """
         Constructor
         
         @param grid reference to the icon editor grid (IconEditorGrid)
-        @param text text for the undo command (QString)
-        @param oldImage copy of the icon before the changes were applied (QImage)
+        @param text text for the undo command (string)
+        @param oldImage copy of the icon before the changes were applied
+            (QImage)
         @param parent reference to the parent command (QUndoCommand)
         """
-        QUndoCommand.__init__(self, text, parent)
+        super().__init__(text, parent)
         
         self.__grid = grid
         self.__imageBefore = QImage(oldImage)
@@ -47,30 +49,45 @@ class IconEditCommand(QUndoCommand):
         """
         Public method to perform the undo.
         """
-        self.__grid.setIconImage(self.__imageBefore, undoRedo = True)
+        self.__grid.setIconImage(self.__imageBefore, undoRedo=True)
     
     def redo(self):
         """
         Public method to perform the redo.
         """
         if self.__imageAfter:
-            self.__grid.setIconImage(self.__imageAfter, undoRedo = True)
+            self.__grid.setIconImage(self.__imageAfter, undoRedo=True)
     
+
 class IconEditorGrid(QWidget):
     """
     Class implementing the icon editor grid.
     
     @signal canRedoChanged(bool) emitted after the redo status has changed
     @signal canUndoChanged(bool) emitted after the undo status has changed
-    @signal clipboardImageAvailable(bool) emitted to signal the availability of an 
-        image to be pasted
-    @signal colorChanged(const QColor&) emitted after the drawing color was changed
+    @signal clipboardImageAvailable(bool) emitted to signal the availability
+        of an image to be pasted
+    @signal colorChanged(QColor) emitted after the drawing color was changed
     @signal imageChanged(bool) emitted after the image was modified
-    @signal positionChanged(int, int) emitted after the cursor poition was changed
-    @signal previewChanged(const QPixmap&) emitted to signal a new preview pixmap
-    @signal selectionAvailable(bool) emitted to signal a change of the selection
+    @signal positionChanged(int, int) emitted after the cursor poition was
+        changed
+    @signal previewChanged(QPixmap) emitted to signal a new preview pixmap
+    @signal selectionAvailable(bool) emitted to signal a change of the
+        selection
     @signal sizeChanged(int, int) emitted after the size has been changed
+    @signal zoomChanged(int) emitted to signal a change of the zoom value
     """
+    canRedoChanged = pyqtSignal(bool)
+    canUndoChanged = pyqtSignal(bool)
+    clipboardImageAvailable = pyqtSignal(bool)
+    colorChanged = pyqtSignal(QColor)
+    imageChanged = pyqtSignal(bool)
+    positionChanged = pyqtSignal(int, int)
+    previewChanged = pyqtSignal(QPixmap)
+    selectionAvailable = pyqtSignal(bool)
+    sizeChanged = pyqtSignal(int, int)
+    zoomChanged = pyqtSignal(int)
+    
     Pencil = 1
     Rubber = 2
     Line = 3
@@ -89,13 +106,19 @@ class IconEditorGrid(QWidget):
     MarkColor = QColor(255, 255, 255, 255)
     NoMarkColor = QColor(0, 0, 0, 0)
     
-    def __init__(self, parent = None):
+    ZoomMinimum = 100
+    ZoomMaximum = 10000
+    ZoomStep = 100
+    ZoomDefault = 1200
+    ZoomPercent = True
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         
         self.setAttribute(Qt.WA_StaticContents)
         self.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
@@ -120,6 +143,9 @@ class IconEditorGrid(QWidget):
         self.__markImage = QImage(self.__image)
         self.__markImage.fill(self.NoMarkColor.rgba())
         
+        self.__compositingMode = QPainter.CompositionMode_SourceOver
+        self.__lastPos = (-1, -1)
+        
         self.__gridEnabled = True
         self.__selectionAvailable = False
         
@@ -128,16 +154,12 @@ class IconEditorGrid(QWidget):
         
         self.setMouseTracking(True)
         
-        self.connect(self.__undoStack, SIGNAL("canRedoChanged(bool)"), 
-                     self, SIGNAL("canRedoChanged(bool)"))
-        self.connect(self.__undoStack, SIGNAL("canUndoChanged(bool)"), 
-                     self, SIGNAL("canUndoChanged(bool)"))
-        self.connect(self.__undoStack, SIGNAL("cleanChanged(bool)"), 
-                     self.__cleanChanged)
+        self.__undoStack.canRedoChanged.connect(self.canRedoChanged)
+        self.__undoStack.canUndoChanged.connect(self.canUndoChanged)
+        self.__undoStack.cleanChanged.connect(self.__cleanChanged)
         
-        self.connect(self, SIGNAL("imageChanged(bool)"), self.__updatePreviewPixmap)
-        self.connect(QApplication.clipboard(), SIGNAL("dataChanged()"), 
-                     self.__checkClipboard)
+        self.imageChanged.connect(self.__updatePreviewPixmap)
+        QApplication.clipboard().dataChanged.connect(self.__checkClipboard)
         
         self.__checkClipboard()
     
@@ -174,20 +196,20 @@ class IconEditorGrid(QWidget):
     
     def __initUndoTexts(self):
         """
-        Private method to initialize texts to be associated with undo commands for
-        the various drawing tools.
+        Private method to initialize texts to be associated with undo commands
+        for the various drawing tools.
         """
         self.__undoTexts = {
-            self.Pencil          : self.trUtf8("Set Pixel"), 
-            self.Rubber          : self.trUtf8("Erase Pixel"), 
-            self.Line            : self.trUtf8("Draw Line"), 
-            self.Rectangle       : self.trUtf8("Draw Rectangle"), 
-            self.FilledRectangle : self.trUtf8("Draw Filled Rectangle"), 
-            self.Circle          : self.trUtf8("Draw Circle"), 
-            self.FilledCircle    : self.trUtf8("Draw Filled Circle"), 
-            self.Ellipse         : self.trUtf8("Draw Ellipse"), 
-            self.FilledEllipse   : self.trUtf8("Draw Filled Ellipse"), 
-            self.Fill            : self.trUtf8("Fill Region"), 
+            self.Pencil: self.trUtf8("Set Pixel"),
+            self.Rubber: self.trUtf8("Erase Pixel"),
+            self.Line: self.trUtf8("Draw Line"),
+            self.Rectangle: self.trUtf8("Draw Rectangle"),
+            self.FilledRectangle: self.trUtf8("Draw Filled Rectangle"),
+            self.Circle: self.trUtf8("Draw Circle"),
+            self.FilledCircle: self.trUtf8("Draw Filled Circle"),
+            self.Ellipse: self.trUtf8("Draw Ellipse"),
+            self.FilledEllipse: self.trUtf8("Draw Filled Ellipse"),
+            self.Fill: self.trUtf8("Fill Region"),
         }
     
     def isDirty(self):
@@ -198,15 +220,16 @@ class IconEditorGrid(QWidget):
         """
         return self.__dirty
     
-    def setDirty(self, dirty, setCleanState = False):
+    def setDirty(self, dirty, setCleanState=False):
         """
         Public slot to set the dirty flag.
         
         @param dirty flag indicating the new modification status (boolean)
-        @param setCleanState flag indicating to set the undo stack to clean (boolean)
+        @param setCleanState flag indicating to set the undo stack to clean
+            (boolean)
         """
         self.__dirty = dirty
-        self.emit(SIGNAL("imageChanged(bool)"), dirty)
+        self.imageChanged.emit(dirty)
         
         if not dirty and setCleanState:
             self.__undoStack.setClean()
@@ -229,7 +252,7 @@ class IconEditorGrid(QWidget):
         @param newColor reference to the new color (QColor)
         """
         self.__curColor = QColor(newColor)
-        self.emit(SIGNAL("colorChanged(const QColor&)"), QColor(newColor))
+        self.colorChanged.emit(QColor(newColor))
     
     def penColor(self):
         """
@@ -239,6 +262,22 @@ class IconEditorGrid(QWidget):
         """
         return QColor(self.__curColor)
     
+    def setCompositingMode(self, mode):
+        """
+        Public method to set the compositing mode.
+        
+        @param mode compositing mode to set (QPainter.CompositionMode)
+        """
+        self.__compositingMode = mode
+    
+    def compositingMode(self):
+        """
+        Public method to get the compositing mode.
+        
+        @return compositing mode (QPainter.CompositionMode)
+        """
+        return self.__compositingMode
+    
     def setTool(self, tool):
         """
         Public method to set the current drawing tool.
@@ -247,15 +286,16 @@ class IconEditorGrid(QWidget):
             (IconEditorGrid.Pencil ... IconEditorGrid.CircleSelection)
         """
         self.__curTool = tool
+        self.__lastPos = (-1, -1)
         
         if self.__curTool in [self.RectangleSelection, self.CircleSelection]:
             self.__selecting = True
         else:
             self.__selecting = False
         
-        if self.__curTool in [self.RectangleSelection, self.CircleSelection, self.Line, 
-                              self.Rectangle, self.FilledRectangle, 
-                              self.Circle, self.FilledCircle, 
+        if self.__curTool in [self.RectangleSelection, self.CircleSelection,
+                              self.Line, self.Rectangle, self.FilledRectangle,
+                              self.Circle, self.FilledCircle,
                               self.Ellipse, self.FilledEllipse]:
             self.setCursor(self.__aimCursor)
         elif self.__curTool == self.Fill:
@@ -266,7 +306,7 @@ class IconEditorGrid(QWidget):
             self.setCursor(self.__paintCursor)
         elif self.__curTool == self.Rubber:
             self.setCursor(self.__rubberCursor)
-        else:    
+        else:
             self.setCursor(self.__normalCursor)
     
     def tool(self):
@@ -278,7 +318,7 @@ class IconEditorGrid(QWidget):
         """
         return self.__curTool
     
-    def setIconImage(self, newImage, undoRedo = False, clearUndo = False):
+    def setIconImage(self, newImage, undoRedo=False, clearUndo=False):
         """
         Public method to set a new icon image.
         
@@ -303,7 +343,7 @@ class IconEditorGrid(QWidget):
             if clearUndo:
                 self.__undoStack.clear()
             
-            self.emit(SIGNAL("sizeChanged(int, int)"), *self.iconSize())
+            self.sizeChanged.emit(*self.iconSize())
     
     def iconImage(self):
         """
@@ -323,24 +363,25 @@ class IconEditorGrid(QWidget):
     
     def setZoomFactor(self, newZoom):
         """
-        Public method to set the zoom factor.
+        Public method to set the zoom factor in percent.
         
-        @param newZoom zoom factor (integer >= 1)
+        @param newZoom zoom factor (integer >= 100)
         """
-        newZoom = max(1, newZoom)   # must not be less than 1
+        newZoom = max(100, newZoom)   # must not be less than 100
         if newZoom != self.__zoom:
-            self.__zoom = newZoom
+            self.__zoom = newZoom // 100
             self.update()
             self.updateGeometry()
             self.resize(self.sizeHint())
+            self.zoomChanged.emit(int(self.__zoom * 100))
     
     def zoomFactor(self):
         """
-        Public method to get the current zoom factor.
+        Public method to get the current zoom factor in percent.
         
         @return zoom factor (integer)
         """
-        return self.__zoom
+        return self.__zoom * 100
     
     def setGridEnabled(self, enable):
         """
@@ -369,18 +410,21 @@ class IconEditorGrid(QWidget):
         painter = QPainter(self)
         
         if self.__zoom >= 3 and self.__gridEnabled:
-            painter.setPen(self.palette().foreground().color())
+            painter.setPen(self.palette().windowText().color())
             i = 0
             while i <= self.__image.width():
-                painter.drawLine(self.__zoom * i, 0, 
-                                 self.__zoom * i, self.__zoom * self.__image.height())
+                painter.drawLine(
+                    self.__zoom * i, 0,
+                    self.__zoom * i, self.__zoom * self.__image.height())
                 i += 1
             j = 0
             while j <= self.__image.height():
-                painter.drawLine(0,  self.__zoom * j, 
-                                 self.__zoom * self.__image.width(), self.__zoom * j)
+                painter.drawLine(
+                    0,  self.__zoom * j,
+                    self.__zoom * self.__image.width(), self.__zoom * j)
                 j += 1
         
+        col = QColor("#aaa")
         painter.setPen(Qt.DashLine)
         for i in range(0, self.__image.width()):
             for j in range(0, self.__image.height()):
@@ -388,7 +432,9 @@ class IconEditorGrid(QWidget):
                 if evt.region().intersects(rect):
                     color = QColor.fromRgba(self.__image.pixel(i, j))
                     painter.fillRect(rect, QBrush(Qt.white))
-                    painter.fillRect(rect, QBrush(Qt.Dense5Pattern))
+                    painter.fillRect(QRect(rect.topLeft(), rect.center()), col)
+                    painter.fillRect(QRect(rect.center(), rect.bottomRight()),
+                                     col)
                     painter.fillRect(rect, QBrush(color))
                 
                     if self.__isMarked(i, j):
@@ -402,13 +448,14 @@ class IconEditorGrid(QWidget):
         
         @param i x-coordinate of the pixel in the image (integer)
         @param j y-coordinate of the pixel in the image (integer)
-        return rectangle for the given pixel coordinates (QRect)
+        @return rectangle for the given pixel coordinates (QRect)
         """
         if self.__zoom >= 3 and self.__gridEnabled:
-            return QRect(self.__zoom * i + 1, self.__zoom * j + 1, 
+            return QRect(self.__zoom * i + 1, self.__zoom * j + 1,
                          self.__zoom - 1, self.__zoom - 1)
         else:
-            return QRect(self.__zoom * i, self.__zoom * j, self.__zoom, self.__zoom)
+            return QRect(self.__zoom * i, self.__zoom * j,
+                         self.__zoom, self.__zoom)
     
     def mousePressEvent(self, evt):
         """
@@ -426,14 +473,14 @@ class IconEditorGrid(QWidget):
                 return
             
             if self.__curTool == self.Pencil:
-                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool], 
+                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool],
                                       self.__image)
                 self.__setImagePixel(evt.pos(), True)
                 self.setDirty(True)
                 self.__undoStack.push(cmd)
                 self.__currentUndoCmd = cmd
             elif self.__curTool == self.Rubber:
-                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool], 
+                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool],
                                       self.__image)
                 self.__setImagePixel(evt.pos(), False)
                 self.setDirty(True)
@@ -443,7 +490,7 @@ class IconEditorGrid(QWidget):
                 i, j = self.__imageCoordinates(evt.pos())
                 col = QColor()
                 col.setRgba(self.__image.pixel(i, j))
-                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool], 
+                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool],
                                       self.__image)
                 self.__drawFlood(i, j, col)
                 self.setDirty(True)
@@ -465,8 +512,7 @@ class IconEditorGrid(QWidget):
         
         @param evt reference to the mouse event object (QMouseEvent)
         """
-        self.emit(SIGNAL("positionChanged(int, int)"), 
-                  *self.__imageCoordinates(evt.pos()))
+        self.positionChanged.emit(*self.__imageCoordinates(evt.pos()))
         
         if self.__isPasting and not (evt.buttons() & Qt.LeftButton):
             self.__drawPasteRect(evt.pos())
@@ -496,10 +542,11 @@ class IconEditorGrid(QWidget):
                     self.__currentUndoCmd.setAfterImage(self.__image)
                     self.__currentUndoCmd = None
             
-            if self.__curTool not in [self.Pencil, self.Rubber, 
-                                      self.Fill, self.ColorPicker, 
-                                      self.RectangleSelection, self.CircleSelection]:
-                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool], 
+            if self.__curTool not in [self.Pencil, self.Rubber,
+                                      self.Fill, self.ColorPicker,
+                                      self.RectangleSelection,
+                                      self.CircleSelection]:
+                cmd = IconEditCommand(self, self.__undoTexts[self.__curTool],
                                       self.__image)
                 if self.__drawTool(evt.pos(), False):
                     self.__undoStack.push(cmd)
@@ -515,13 +562,17 @@ class IconEditorGrid(QWidget):
         """
         i, j = self.__imageCoordinates(pos)
         
-        if self.__image.rect().contains(i, j):
+        if self.__image.rect().contains(i, j) and (i, j) != self.__lastPos:
             if opaque:
-                self.__image.setPixel(i, j, self.penColor().rgba())
+                painter = QPainter(self.__image)
+                painter.setPen(self.penColor())
+                painter.setCompositionMode(self.__compositingMode)
+                painter.drawPoint(i, j)
             else:
                 self.__image.setPixel(i, j, qRgba(0, 0, 0, 0))
+            self.__lastPos = (i, j)
         
-        self.update(self.__pixelRect(i, j))
+            self.update(self.__pixelRect(i, j))
     
     def __imageCoordinates(self, pos):
         """
@@ -542,8 +593,9 @@ class IconEditorGrid(QWidget):
         """
         self.__markImage.fill(self.NoMarkColor.rgba())
         if self.__pasteRect.isValid():
-            self.__updateImageRect(self.__pasteRect.topLeft(), 
-                                   self.__pasteRect.bottomRight() + QPoint(1, 1))
+            self.__updateImageRect(
+                self.__pasteRect.topLeft(),
+                self.__pasteRect.bottomRight() + QPoint(1, 1))
         
         x, y = self.__imageCoordinates(pos)
         isize = self.__image.size()
@@ -563,16 +615,17 @@ class IconEditorGrid(QWidget):
         painter.drawRect(self.__pasteRect)
         painter.end()
         
-        self.__updateImageRect(self.__pasteRect.topLeft(), 
+        self.__updateImageRect(self.__pasteRect.topLeft(),
                                self.__pasteRect.bottomRight() + QPoint(1, 1))
     
     def __drawTool(self, pos, mark):
         """
-        Public method to perform a draw operation depending of the current tool.
+        Public method to perform a draw operation depending of the current
+        tool.
         
         @param pos widget coordinate to perform the draw operation at (QPoint)
         @param mark flag indicating a mark operation (boolean)
-        @param flag indicating a successful draw (boolean)
+        @return flag indicating a successful draw (boolean)
         """
         self.__unMark()
         
@@ -589,39 +642,41 @@ class IconEditorGrid(QWidget):
         
         painter = QPainter(img)
         painter.setPen(drawColor)
-        painter.setCompositionMode(QPainter.CompositionMode_Source)
+        painter.setCompositionMode(self.__compositingMode)
         
         if self.__curTool == self.Line:
             painter.drawLine(start, end)
         
-        elif self.__curTool in [self.Rectangle, self.FilledRectangle, 
+        elif self.__curTool in [self.Rectangle, self.FilledRectangle,
                                 self.RectangleSelection]:
-            l = min(start.x(), end.x())
-            t = min(start.y(), end.y())
-            r = max(start.x(), end.x())
-            b = max(start.y(), end.y())
+            left = min(start.x(), end.x())
+            top = min(start.y(), end.y())
+            right = max(start.x(), end.x())
+            bottom = max(start.y(), end.y())
             if self.__curTool == self.RectangleSelection:
                 painter.setBrush(QBrush(drawColor))
             if self.__curTool == self.FilledRectangle:
-                for y in range(t, b + 1):
-                    painter.drawLine(l, y, r, y)
+                for y in range(top, bottom + 1):
+                    painter.drawLine(left, y, right, y)
             else:
-                painter.drawRect(l, t, r - l, b - t)
+                painter.drawRect(left, top, right - left, bottom - top)
             if self.__selecting:
-                self.__selRect = QRect(l, t, r - l + 1, b - t + 1)
+                self.__selRect = QRect(
+                    left, top, right - left + 1, bottom - top + 1)
                 self.__selectionAvailable = True
-                self.emit(SIGNAL("selectionAvailable(bool)"), True)
+                self.selectionAvailable.emit(True)
         
-        elif self.__curTool in [self.Circle, self.FilledCircle, 
+        elif self.__curTool in [self.Circle, self.FilledCircle,
                                 self.CircleSelection]:
             r = max(abs(start.x() - end.x()), abs(start.y() - end.y()))
             if self.__curTool in [self.FilledCircle, self.CircleSelection]:
                 painter.setBrush(QBrush(drawColor))
             painter.drawEllipse(start, r, r)
             if self.__selecting:
-                self.__selRect = QRect(start.x() - r, start.y() - r, 2 * r + 1, 2 * r + 1)
+                self.__selRect = QRect(start.x() - r, start.y() - r,
+                                       2 * r + 1, 2 * r + 1)
                 self.__selectionAvailable = True
-                self.emit(SIGNAL("selectionAvailable(bool)"), True)
+                self.selectionAvailable.emit(True)
         
         elif self.__curTool in [self.Ellipse, self.FilledEllipse]:
             r1 = abs(start.x() - end.x())
@@ -634,7 +689,7 @@ class IconEditorGrid(QWidget):
         
         painter.end()
         
-        if self.__curTool in [self.Circle, self.FilledCircle, 
+        if self.__curTool in [self.Circle, self.FilledCircle,
                               self.Ellipse, self.FilledEllipse]:
             self.update()
         else:
@@ -642,7 +697,7 @@ class IconEditorGrid(QWidget):
         
         return True
     
-    def __drawFlood(self, i, j, oldColor, doUpdate = True):
+    def __drawFlood(self, i, j, oldColor, doUpdate=True):
         """
         Private method to perform a flood fill operation.
         
@@ -671,18 +726,22 @@ class IconEditorGrid(QWidget):
         """
         Private slot to update parts of the widget.
         
-        @param pos1 top, left position for the update in widget coordinates (QPoint)
-        @param pos2 bottom, right position for the update in widget coordinates (QPoint)
+        @param pos1 top, left position for the update in widget coordinates
+            (QPoint)
+        @param pos2 bottom, right position for the update in widget
+            coordinates (QPoint)
         """
-        self.__updateImageRect(QPoint(*self.__imageCoordinates(pos1)), 
+        self.__updateImageRect(QPoint(*self.__imageCoordinates(pos1)),
                                QPoint(*self.__imageCoordinates(pos2)))
     
     def __updateImageRect(self, ipos1, ipos2):
         """
         Private slot to update parts of the widget.
         
-        @param ipos1 top, left position for the update in image coordinates (QPoint)
-        @param ipos2 bottom, right position for the update in image coordinates (QPoint)
+        @param ipos1 top, left position for the update in image coordinates
+            (QPoint)
+        @param ipos2 bottom, right position for the update in image
+            coordinates (QPoint)
         """
         r1 = self.__pixelRect(ipos1.x(), ipos1.y())
         r2 = self.__pixelRect(ipos2.x(), ipos2.y())
@@ -698,8 +757,8 @@ class IconEditorGrid(QWidget):
         Private slot to remove the mark indicator.
         """
         self.__markImage.fill(self.NoMarkColor.rgba())
-        if self.__curTool in [self.Circle, self.FilledCircle, 
-                              self.Ellipse, self.FilledEllipse, 
+        if self.__curTool in [self.Circle, self.FilledCircle,
+                              self.Ellipse, self.FilledEllipse,
                               self.CircleSelection]:
             self.update()
         else:
@@ -708,7 +767,7 @@ class IconEditorGrid(QWidget):
         if self.__selecting:
             self.__selRect = QRect()
             self.__selectionAvailable = False
-            self.emit(SIGNAL("selectionAvailable(bool)"), False)
+            self.selectionAvailable.emit(False)
     
     def __isMarked(self, i, j):
         """
@@ -725,7 +784,7 @@ class IconEditorGrid(QWidget):
         Private slot to generate and signal an updated preview pixmap.
         """
         p = QPixmap.fromImage(self.__image)
-        self.emit(SIGNAL("previewChanged(const QPixmap&)"), p)
+        self.previewChanged.emit(p)
     
     def previewPixmap(self):
         """
@@ -738,12 +797,12 @@ class IconEditorGrid(QWidget):
     
     def __checkClipboard(self):
         """
-        Private slot to check, if the clipboard contains a valid image, and signal
-        the result.
+        Private slot to check, if the clipboard contains a valid image, and
+        signal the result.
         """
         ok = self.__clipboardImage()[1]
         self.__clipboardImageAvailable = ok
-        self.emit(SIGNAL("clipboardImageAvailable(bool)"), ok)
+        self.clipboardImageAvailable.emit(ok)
     
     def canPaste(self):
         """
@@ -757,7 +816,7 @@ class IconEditorGrid(QWidget):
         """
         Private method to get an image from the clipboard.
         
-        @return tuple with the image (QImage) and a flag indicating a 
+        @return tuple with the image (QImage) and a flag indicating a
             valid image (boolean)
         """
         img = QApplication.clipboard().image()
@@ -775,20 +834,22 @@ class IconEditorGrid(QWidget):
         @return image of the selection (QImage)
         """
         if cut:
-            cmd = IconEditCommand(self, self.trUtf8("Cut Selection"), self.__image)
+            cmd = IconEditCommand(self, self.trUtf8("Cut Selection"),
+                                  self.__image)
         
         img = QImage(self.__selRect.size(), QImage.Format_ARGB32)
         img.fill(qRgba(0, 0, 0, 0))
         for i in range(0, self.__selRect.width()):
             for j in range(0, self.__selRect.height()):
-                if self.__image.rect().contains(self.__selRect.x() + i, 
+                if self.__image.rect().contains(self.__selRect.x() + i,
                                                 self.__selRect.y() + j):
-                    if self.__isMarked(self.__selRect.x() + i, self.__selRect.y() + j):
-                        img.setPixel(i, j, self.__image.pixel(self.__selRect.x() + i, 
-                                                              self.__selRect.y() + j))
+                    if self.__isMarked(
+                            self.__selRect.x() + i, self.__selRect.y() + j):
+                        img.setPixel(i, j, self.__image.pixel(
+                            self.__selRect.x() + i, self.__selRect.y() + j))
                         if cut:
-                            self.__image.setPixel(self.__selRect.x() + i, 
-                                                  self.__selRect.y() + j, 
+                            self.__image.setPixel(self.__selRect.x() + i,
+                                                  self.__selRect.y() + j,
                                                   qRgba(0, 0, 0, 0))
         
         if cut:
@@ -818,98 +879,50 @@ class IconEditorGrid(QWidget):
             img = self.__getSelectionImage(True)
             QApplication.clipboard().setImage(img)
     
-    def editPaste(self, pasting = False):
+    def editPaste(self, pasting=False):
         """
         Public slot to paste an image from the clipboard.
         
-        @param pasting flag indicating part two of the paste operation (boolean)
+        @param pasting flag indicating part two of the paste operation
+            (boolean)
         """
-        img, ok  = self.__clipboardImage()
+        img, ok = self.__clipboardImage()
         if ok:
-            if img.width() > self.__image.width() or img.height() > self.__image.height():
-                res = KQMessageBox.question(self,
+            if img.width() > self.__image.width() or \
+                    img.height() > self.__image.height():
+                res = E5MessageBox.yesNo(
+                    self,
                     self.trUtf8("Paste"),
-                    self.trUtf8("""<p>The clipboard image is larger than the current """
-                                """image.<br/>Paste as new image?</p>"""),
-                    QMessageBox.StandardButtons(\
-                        QMessageBox.No | \
-                        QMessageBox.Yes),
-                    QMessageBox.No)
-                if res == QMessageBox.Yes:
+                    self.trUtf8(
+                        """<p>The clipboard image is larger than the"""
+                        """ current image.<br/>Paste as new image?</p>"""))
+                if res:
                     self.editPasteAsNew()
                 return
             elif not pasting:
                 self.__isPasting = True
                 self.__clipboardSize = img.size()
             else:
-                cmd = IconEditCommand(self, self.trUtf8("Paste Clipboard"), self.__image)
+                cmd = IconEditCommand(self, self.trUtf8("Paste Clipboard"),
+                                      self.__image)
                 self.__markImage.fill(self.NoMarkColor.rgba())
-                for sx in range(self.__pasteRect.width() + 1):
-                    for sy in range(self.__pasteRect.height() + 1):
-                        dx = self.__pasteRect.x() + sx
-                        dy = self.__pasteRect.y() + sy
-                        if True:    # TODO: insert code to test for compositing
-                            # Porter-Duff Over composition
-                            colorS = img.pixel(sx, sy)
-                            colorD = self.__image.pixel(dx, dy)
-                            
-                            alphaS = qAlpha(colorS) / 255.0
-                            alphaD = qAlpha(colorD) / 255.0
-                            
-                            r = qRed(colorS) * alphaS + \
-                                (1 - alphaS) * qRed(colorD) * alphaD
-                            g = qGreen(colorS) * alphaS + \
-                                (1 - alphaS) * qGreen(colorD) * alphaD
-                            b = qBlue(colorS) * alphaS + \
-                                (1 - alphaS) * qBlue(colorD) * alphaD
-                            a = alphaS + \
-                                (1 - alphaS) * alphaD
-                            
-                            # Remove multiplication by alpha
-                            if a > 0:
-                                r /= a
-                                g /= a
-                                b /= a
-                            else:
-                                r = 0
-                                g = 0
-                                b = 0
-                            
-                            ir = int(r + 0.5)
-                            if ir < 0:
-                                ir = 0
-                            elif ir > 255:
-                                ir = 255
-                            
-                            ig = int(g + 0.5)
-                            if ig < 0:
-                                ig = 0
-                            elif ig > 255:
-                                ig = 255
-                            
-                            ib = int(b + 0.5)
-                            if ib < 0:
-                                ib = 0
-                            elif ib > 255:
-                                ib = 255
-                            
-                            ia = int(a * 255 + 0.5)
-                            if ia < 0:
-                                ia = 0
-                            elif ia > 255:
-                                ia = 255
-                            
-                            self.__image.setPixel(dx, dy, qRgba(ir, ig, ib, ia))
-                        else:
-                            self.__image.setPixel(dx, dy, img.pixel(sx, sy))
+                painter = QPainter(self.__image)
+                painter.setPen(self.penColor())
+                painter.setCompositionMode(self.__compositingMode)
+                painter.drawImage(
+                    self.__pasteRect.x(), self.__pasteRect.y(), img, 0, 0,
+                    self.__pasteRect.width() + 1,
+                    self.__pasteRect.height() + 1)
                 
                 self.__undoStack.push(cmd)
                 cmd.setAfterImage(self.__image)
                 
-                self.__updateImageRect(self.__pasteRect.topLeft(), 
-                                       self.__pasteRect.bottomRight() + QPoint(1, 1))
+                self.__updateImageRect(
+                    self.__pasteRect.topLeft(),
+                    self.__pasteRect.bottomRight() + QPoint(1, 1))
         else:
-            KQMessageBox.warning(self,
+            E5MessageBox.warning(
+                self,
                 self.trUtf8("Pasting Image"),
                 self.trUtf8("""Invalid image data in clipboard."""))
     
@@ -917,10 +930,11 @@ class IconEditorGrid(QWidget):
         """
         Public slot to paste the clipboard as a new image.
         """
-        img, ok  = self.__clipboardImage()
+        img, ok = self.__clipboardImage()
         if ok:
-            cmd = IconEditCommand(self, self.trUtf8("Paste Clipboard as New Image"), 
-                                  self.__image)
+            cmd = IconEditCommand(
+                self, self.trUtf8("Paste Clipboard as New Image"),
+                self.__image)
             self.setIconImage(img)
             self.setDirty(True)
             self.__undoStack.push(cmd)
@@ -937,7 +951,7 @@ class IconEditorGrid(QWidget):
         self.__markImage.fill(self.MarkColor.rgba())
         self.__selRect = self.__image.rect()
         self.__selectionAvailable = True
-        self.emit(SIGNAL("selectionAvailable(bool)"), True)
+        self.selectionAvailable.emit(True)
         
         self.update()
     
@@ -958,14 +972,18 @@ class IconEditorGrid(QWidget):
         """
         Public slot to resize the image.
         """
+        from .IconSizeDialog import IconSizeDialog
         dlg = IconSizeDialog(self.__image.width(), self.__image.height())
         res = dlg.exec_()
         if res == QDialog.Accepted:
             newWidth, newHeight = dlg.getData()
-            if newWidth != self.__image.width() or newHeight != self.__image.height():
-                cmd = IconEditCommand(self, self.trUtf8("Resize Image"), self.__image)
-                img = self.__image.scaled(newWidth, newHeight, Qt.IgnoreAspectRatio, 
-                                          Qt.SmoothTransformation)
+            if newWidth != self.__image.width() or \
+                    newHeight != self.__image.height():
+                cmd = IconEditCommand(self, self.trUtf8("Resize Image"),
+                                      self.__image)
+                img = self.__image.scaled(
+                    newWidth, newHeight, Qt.IgnoreAspectRatio,
+                    Qt.SmoothTransformation)
                 self.setIconImage(img)
                 self.setDirty(True)
                 self.__undoStack.push(cmd)
@@ -975,6 +993,7 @@ class IconEditorGrid(QWidget):
         """
         Public slot to generate a new, empty image.
         """
+        from .IconSizeDialog import IconSizeDialog
         dlg = IconSizeDialog(self.__image.width(), self.__image.height())
         res = dlg.exec_()
         if res == QDialog.Accepted:
@@ -987,13 +1006,15 @@ class IconEditorGrid(QWidget):
         """
         Public slot to convert the image to gray preserving transparency.
         """
-        cmd = IconEditCommand(self, self.trUtf8("Convert to Grayscale"), self.__image)
+        cmd = IconEditCommand(self, self.trUtf8("Convert to Grayscale"),
+                              self.__image)
         for x in range(self.__image.width()):
             for y in range(self.__image.height()):
                 col = self.__image.pixel(x, y)
                 if col != qRgba(0, 0, 0, 0):
                     gray = qGray(col)
-                    self.__image.setPixel(x, y, qRgba(gray, gray, gray, qAlpha(col)))
+                    self.__image.setPixel(
+                        x, y, qRgba(gray, gray, gray, qAlpha(col)))
         self.update()
         self.setDirty(True)
         self.__undoStack.push(cmd)
@@ -1041,12 +1062,9 @@ class IconEditorGrid(QWidget):
         """
         Public slot to perform some shutdown actions.
         """
-        self.disconnect(self.__undoStack, SIGNAL("canRedoChanged(bool)"), 
-                        self, SIGNAL("canRedoChanged(bool)"))
-        self.disconnect(self.__undoStack, SIGNAL("canUndoChanged(bool)"), 
-                        self, SIGNAL("canUndoChanged(bool)"))
-        self.disconnect(self.__undoStack, SIGNAL("cleanChanged(bool)"), 
-                        self.__cleanChanged)
+        self.__undoStack.canRedoChanged.disconnect(self.canRedoChanged)
+        self.__undoStack.canUndoChanged.disconnect(self.canUndoChanged)
+        self.__undoStack.cleanChanged.disconnect(self.__cleanChanged)
     
     def isSelectionAvailable(self):
         """
