@@ -5,15 +5,15 @@ Module implementing a dialog to enter the icon size.
 """
 
 from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import pyqtSignature
 
-from Ui_IconSizeDialog import Ui_IconSizeDialog
+from .Ui_IconSizeDialog import Ui_IconSizeDialog
+
 
 class IconSizeDialog(QDialog, Ui_IconSizeDialog):
     """
     Class implementing a dialog to enter the icon size.
     """
-    def __init__(self, width, height, parent = None):
+    def __init__(self, width, height, parent=None):
         """
         Constructor
         
@@ -21,7 +21,7 @@ class IconSizeDialog(QDialog, Ui_IconSizeDialog):
         @param height height to be set (integer)
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.widthSpin.setValue(width)
