@@ -7,33 +7,35 @@
 Module implementing the add project dialog.
 """
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+import os
 
-from KdeQt import KQFileDialog
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from E4Gui.E4Completers import E4FileCompleter
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from Ui_AddProjectDialog import Ui_AddProjectDialog
+from .Ui_AddProjectDialog import Ui_AddProjectDialog
 
 import Utilities
 
+
 class AddProjectDialog(QDialog, Ui_AddProjectDialog):
     """
     Class implementing the add project dialog.
     """
-    def __init__(self, parent = None, startdir = None, project = None):
+    def __init__(self, parent=None, startdir=None, project=None):
         """
         Constructor
         
         @param parent parent widget of this dialog (QWidget)
-        @param startdir start directory for the selection dialog (string or QString)
+        @param startdir start directory for the selection dialog (string)
         @param project dictionary containing project data
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.fileCompleter = E4FileCompleter(self.filenameEdit)
+        self.fileCompleter = E5FileCompleter(self.filenameEdit)
         
         self.startdir = startdir
         
@@ -51,48 +53,57 @@ class AddProjectDialog(QDialog, Ui_AddProjectDialog):
             self.descriptionEdit.setPlainText(project['description'])
             self.masterCheckBox.setChecked(project['master'])
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fileButton_clicked(self):
         """
         Private slot to display a file selection dialog.
         """
         startdir = self.filenameEdit.text()
-        if startdir.isEmpty() and self.startdir is not None:
+        if not startdir and self.startdir is not None:
             startdir = self.startdir
-            projectFile = KQFileDialog.getOpenFileName(\
+            projectFile = E5FileDialog.getOpenFileName(
                 self,
                 self.trUtf8("Add Project"),
                 startdir,
-                self.trUtf8("Project Files (*.e4p *.e4pz)"),
-                None)
-        
-        if not projectFile.isEmpty():
-            self.filenameEdit.setText(Utilities.toNativeSeparators(projectFile))
+                self.trUtf8("Project Files (*.e4p)"))
+            
+            if projectFile:
+                self.filenameEdit.setText(
+                    Utilities.toNativeSeparators(projectFile))
     
     def getData(self):
         """
         Public slot to retrieve the dialogs data.
         
-        @return tuple of four values (string, string, boolean, string) giving the 
-            project name, the name of the project file, a flag telling, whether
-            the project shall be the master project and a short description
-            for the project
+        @return tuple of four values (string, string, boolean, string) giving
+            the project name, the name of the project file, a flag telling,
+            whether the project shall be the main project and a short
+            description for the project
         """
-        return (unicode(self.nameEdit.text()), unicode(self.filenameEdit.text()), 
-                self.masterCheckBox.isChecked(), 
-                unicode(self.descriptionEdit.toPlainText()))
+        filename = Utilities.toNativeSeparators(self.filenameEdit.text())
+        if not os.path.isabs(filename):
+            filename = Utilities.toNativeSeparators(
+                os.path.join(self.startdir, filename))
+        
+        return (self.nameEdit.text(), filename,
+                self.masterCheckBox.isChecked(),
+                self.descriptionEdit.toPlainText())
     
-    @pyqtSignature("QString")
-    def on_nameEdit_textChanged(self, p0):
+    @pyqtSlot(str)
+    def on_nameEdit_textChanged(self, txt):
         """
         Private slot called when the project name has changed.
+        
+        @param txt text of the edit (string)
         """
         self.__updateUi()
     
-    @pyqtSignature("QString")
-    def on_filenameEdit_textChanged(self, p0):
+    @pyqtSlot(str)
+    def on_filenameEdit_textChanged(self, txt):
         """
         Private slot called when the project filename has changed.
+        
+        @param txt text of the edit (string)
         """
         self.__updateUi()
     
@@ -100,5 +111,5 @@ class AddProjectDialog(QDialog, Ui_AddProjectDialog):
         """
         Private method to update the dialog.
         """
-        self.__okButton.setEnabled(not self.nameEdit.text().isEmpty() and \
-                                   not self.filenameEdit.text().isEmpty())
+        self.__okButton.setEnabled(self.nameEdit.text() != "" and
+                                   self.filenameEdit.text() != "")
