@@ -7,56 +7,56 @@
 Module implementing the multi project browser.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt
+from PyQt4.QtGui import QListWidget, QListWidgetItem, QDialog, QMenu
 
-from KdeQt.KQApplication import e4App
-
-from AddProjectDialog import AddProjectDialog
+from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
 
+
 class MultiProjectBrowser(QListWidget):
     """
     Class implementing the multi project browser.
     """
-    def __init__(self, multiProject, parent = None):
+    def __init__(self, multiProject, parent=None):
         """
         Constructor
         
-        @param project reference to the multi project object
+        @param multiProject reference to the multi project object
         @param parent parent widget (QWidget)
         """
-        QListWidget.__init__(self, parent)
+        super().__init__(parent)
         self.multiProject = multiProject
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         self.setAlternatingRowColors(True)
         
-        self.connect(self.multiProject, SIGNAL("newMultiProject"), 
-                     self.__newMultiProject)
-        self.connect(self.multiProject, SIGNAL("multiProjectOpened"), 
-                     self.__multiProjectOpened)
-        self.connect(self.multiProject, SIGNAL("multiProjectClosed"), 
-                     self.__multiProjectClosed)
-        self.connect(self.multiProject, SIGNAL("projectDataChanged"), 
-                     self.__projectDataChanged)
-        self.connect(self.multiProject, SIGNAL("projectAdded"), 
-                     self.__projectAdded)
-        self.connect(self.multiProject, SIGNAL("projectRemoved"), 
-                     self.__projectRemoved)
-        self.connect(self.multiProject, SIGNAL("projectOpened"), 
-                     self.__projectOpened)
+        self.__openingProject = False
+        
+        self.multiProject.newMultiProject.connect(
+            self.__newMultiProject)
+        self.multiProject.multiProjectOpened.connect(
+            self.__multiProjectOpened)
+        self.multiProject.multiProjectClosed.connect(
+            self.__multiProjectClosed)
+        self.multiProject.projectDataChanged.connect(
+            self.__projectDataChanged)
+        self.multiProject.projectAdded.connect(
+            self.__projectAdded)
+        self.multiProject.projectRemoved.connect(
+            self.__projectRemoved)
+        self.multiProject.projectOpened.connect(
+            self.__projectOpened)
         
         self.__createPopupMenu()
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"),
-                     self.__contextMenuRequested)
-        self.connect(self, SIGNAL("itemActivated(QListWidgetItem*)"), self.__openItem)
+        self.customContextMenuRequested.connect(self.__contextMenuRequested)
+        self.itemActivated.connect(self.__openItem)
     
-    ############################################################################
+    ###########################################################################
     ## Slot handling methods below
-    ############################################################################
+    ###########################################################################
     
     def __newMultiProject(self):
         """
@@ -114,12 +114,14 @@ class MultiProjectBrowser(QListWidget):
     def __projectOpened(self, projectfile):
         """
         Private slot to handle the opening of a project.
+        
+        @param projectfile file name of the opened project file (string)
         """
         project = {
-            'name' : "", 
-            'file' : projectfile, 
-            'master' : False, 
-            'description' : "", 
+            'name': "",
+            'file': projectfile,
+            'master': False,
+            'description': "",
         }
         row = self.__findProjectItem(project)
         if row > -1:
@@ -137,7 +139,7 @@ class MultiProjectBrowser(QListWidget):
         else:
             self.__menu.popup(self.mapToGlobal(coord))
     
-    def __openItem(self, itm = None):
+    def __openItem(self, itm=None):
         """
         Private slot to open a project.
         
@@ -148,13 +150,16 @@ class MultiProjectBrowser(QListWidget):
             if itm is None:
                 return
         
-        filename = unicode(itm.data(Qt.UserRole).toString())
-        if filename:
-            self.multiProject.openProject(filename)
+        if not self.__openingProject:
+            filename = itm.data(Qt.UserRole)
+            if filename:
+                self.__openingProject = True
+                self.multiProject.openProject(filename)
+                self.__openingProject = False
     
-    ############################################################################
+    ###########################################################################
     ## Private methods below
-    ############################################################################
+    ###########################################################################
     
     def __addProject(self, project):
         """
@@ -178,18 +183,19 @@ class MultiProjectBrowser(QListWidget):
         else:
             itm.setIcon(UI.PixmapCache.getIcon("empty.png"))
         itm.setToolTip(project['file'])
-        itm.setData(Qt.UserRole, QVariant(project['file']))
+        itm.setData(Qt.UserRole, project['file'])
     
     def __findProjectItem(self, project):
         """
         Private method to search a specific project item.
         
         @param project reference to the project data dictionary
+        @return row number of the project, -1 if not found (integer)
         """
         row = 0
         while row < self.count():
             itm = self.item(row)
-            data = itm.data(Qt.UserRole).toString()
+            data = itm.data(Qt.UserRole)
             if data == project['file']:
                 return row
             row += 1
@@ -202,7 +208,7 @@ class MultiProjectBrowser(QListWidget):
         """
         itm = self.currentItem()
         if itm is not None:
-            filename = unicode(itm.data(Qt.UserRole).toString())
+            filename = itm.data(Qt.UserRole)
             if filename:
                 self.multiProject.removeProject(filename)
     
@@ -212,21 +218,28 @@ class MultiProjectBrowser(QListWidget):
         """
         itm = self.currentItem()
         if itm is not None:
-            filename = unicode(itm.data(Qt.UserRole).toString())
+            filename = itm.data(Qt.UserRole)
             if filename:
                 project = self.multiProject.getProject(filename)
                 if project is not None:
-                    dlg = AddProjectDialog(self, project = project)
+                    from .AddProjectDialog import AddProjectDialog
+                    dlg = AddProjectDialog(self, project=project)
                     if dlg.exec_() == QDialog.Accepted:
                         name, filename, isMaster, description = dlg.getData()
                         project = {
-                            'name' : name, 
-                            'file' : filename, 
-                            'master' : isMaster, 
-                            'description' : description, 
+                            'name': name,
+                            'file': filename,
+                            'master': isMaster,
+                            'description': description,
                         }
                         self.multiProject.changeProjectProperties(project)
     
+    def __addNewProject(self):
+        """
+        Private method to add a new project entry.
+        """
+        self.multiProject.addProject()
+    
     def __createPopupMenu(self):
         """
         Private method to create the popup menu.
@@ -234,15 +247,23 @@ class MultiProjectBrowser(QListWidget):
         self.__menu = QMenu(self)
         self.__menu.addAction(self.trUtf8("Open"), self.__openItem)
         self.__menu.addAction(self.trUtf8("Remove"), self.__removeProject)
-        self.__menu.addAction(self.trUtf8("Properties"), self.__showProjectProperties)
+        self.__menu.addAction(self.trUtf8("Properties"),
+                              self.__showProjectProperties)
+        self.__menu.addSeparator()
+        self.__menu.addAction(self.trUtf8("Add Project..."),
+                              self.__addNewProject)
         self.__menu.addSeparator()
         self.__menu.addAction(self.trUtf8("Configure..."), self.__configure)
         
         self.__backMenu = QMenu(self)
-        self.__backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
+        self.__backMenu.addAction(self.trUtf8("Add Project..."),
+                                  self.__addNewProject)
+        self.__backMenu.addSeparator()
+        self.__backMenu.addAction(self.trUtf8("Configure..."),
+                                  self.__configure)
     
     def __configure(self):
         """
         Private method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("multiProjectPage")
+        e5App().getObject("UserInterface").showPreferences("multiProjectPage")
