@@ -8,15 +8,15 @@ Module implementing the multi project properties dialog.
 """
 
 from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import pyqtSignature
 
-from Ui_PropertiesDialog import Ui_PropertiesDialog
+from .Ui_PropertiesDialog import Ui_PropertiesDialog
+
 
 class PropertiesDialog(QDialog, Ui_PropertiesDialog):
     """
     Class implementing the multi project properties dialog.
     """
-    def __init__(self, multiProject, new = True, parent = None):
+    def __init__(self, multiProject, new=True, parent=None):
         """
         Constructor
         
@@ -24,7 +24,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         @param new flag indicating the generation of a new multi project
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.multiProject = multiProject
@@ -37,4 +37,4 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         """
         Public method to store the entered/modified data.
         """
-        self.multiProject.description = unicode(self.descriptionEdit.toPlainText())
+        self.multiProject.description = self.descriptionEdit.toPlainText()
