@@ -8,26 +8,24 @@
 Module implementing the Plugin Info Dialog.
 """
 
-from PyQt4.QtCore import QStringList, Qt,  SIGNAL
+from PyQt4.QtCore import pyqtSlot, Qt
 from PyQt4.QtGui import QDialog, QTreeWidgetItem, QHeaderView, QMenu, QBrush
-from PyQt4.QtCore import pyqtSignature
 
-from PluginDetailsDialog import PluginDetailsDialog
+from .Ui_PluginInfoDialog import Ui_PluginInfoDialog
 
-from Ui_PluginInfoDialog import Ui_PluginInfoDialog
 
 class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
     """
     Class implementing the Plugin Info Dialog.
     """
-    def __init__(self, pluginManager, parent = None):
+    def __init__(self, pluginManager, parent=None):
         """
         Constructor
         
         @param pluginManager reference to the plugin manager object
         @param parent parent of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.pm = pluginManager
@@ -43,14 +41,13 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         
         self.__menu = QMenu(self)
         self.__menu.addAction(self.trUtf8('Show details'), self.__showDetails)
-        self.__activateAct = \
-            self.__menu.addAction(self.trUtf8('Activate'), self.__activatePlugin)
-        self.__deactivateAct = \
-            self.__menu.addAction(self.trUtf8('Deactivate'), self.__deactivatePlugin)
+        self.__activateAct = self.__menu.addAction(
+            self.trUtf8('Activate'), self.__activatePlugin)
+        self.__deactivateAct = self.__menu.addAction(
+            self.trUtf8('Deactivate'), self.__deactivatePlugin)
         self.pluginList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.pluginList, 
-                     SIGNAL('customContextMenuRequested(const QPoint &)'),
-                     self.__showContextMenu)
+        self.pluginList.customContextMenuRequested.connect(
+            self.__showContextMenu)
     
     def __populateList(self):
         """
@@ -59,8 +56,9 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         self.pluginList.clear()
         for info in self.pm.getPluginInfos():
             self.__createEntry(info)
-        self.pluginList.sortItems(self.pluginList.sortColumn(), 
-                                  self.pluginList.header().sortIndicatorOrder())
+        self.pluginList.sortItems(
+            self.pluginList.sortColumn(),
+            self.pluginList.header().sortIndicatorOrder())
         
     def __createEntry(self, info):
         """
@@ -68,13 +66,14 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         
         @param info tuple giving the info for the entry
         """
-        infoList = QStringList() \
-            << info[0] \
-            << info[1] \
-            << info[2] \
-            << (info[3] and self.trUtf8("Yes") or self.trUtf8("No")) \
-            << (info[4] and self.trUtf8("Yes") or self.trUtf8("No")) \
-            << info[5]
+        infoList = [
+            info[0],
+            info[1],
+            info[2],
+            (info[3] and self.trUtf8("Yes") or self.trUtf8("No")),
+            (info[4] and self.trUtf8("Yes") or self.trUtf8("No")),
+            info[5]
+        ]
         itm = QTreeWidgetItem(self.pluginList, infoList)
         if info[6]:
             # plugin error
@@ -94,7 +93,8 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         """
         itm = self.pluginList.itemAt(coord)
         if itm is not None:
-            autoactivate = itm.text(self.__autoActivateColumn) == self.trUtf8("Yes")
+            autoactivate = (itm.text(self.__autoActivateColumn) ==
+                            self.trUtf8("Yes"))
             if itm.text(self.__activeColumn) == self.trUtf8("Yes"):
                 self.__activateAct.setEnabled(False)
                 self.__deactivateAct.setEnabled(autoactivate)
@@ -103,7 +103,7 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
                 self.__deactivateAct.setEnabled(False)
             self.__menu.popup(self.mapToGlobal(coord))
     
-    @pyqtSignature("QTreeWidgetItem*, int")
+    @pyqtSlot(QTreeWidgetItem, int)
     def on_pluginList_itemActivated(self, item, column):
         """
         Private slot to show details about a plugin.
@@ -111,11 +111,12 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         @param item reference to the selected item (QTreeWidgetItem)
         @param column column number (integer)
         """
-        moduleName = unicode(item.text(0))
+        moduleName = item.text(0)
         details = self.pm.getPluginDetails(moduleName)
         if details is None:
             pass
         else:
+            from .PluginDetailsDialog import PluginDetailsDialog
             dlg = PluginDetailsDialog(details, self)
             dlg.show()
     
@@ -131,7 +132,7 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         Private slot to handle the "Deactivate" context menu action.
         """
         itm = self.pluginList.currentItem()
-        moduleName = unicode(itm.text(0))
+        moduleName = itm.text(0)
         self.pm.activatePlugin(moduleName)
         # repopulate the list
         self.__populateList()
@@ -141,7 +142,7 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         Private slot to handle the "Activate" context menu action.
         """
         itm = self.pluginList.currentItem()
-        moduleName = unicode(itm.text(0))
+        moduleName = itm.text(0)
         self.pm.deactivatePlugin(moduleName)
         # repopulate the list
         self.__populateList()
