@@ -12,67 +12,70 @@ import sys
 import shutil
 import zipfile
 import compileall
-import urlparse
+import urllib.parse
+import glob
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt4.QtCore import pyqtSlot, Qt, QDir, QFileInfo
+from PyQt4.QtGui import QWidget, QDialogButtonBox, QAbstractButton, \
+    QApplication, QDialog, QVBoxLayout
 
-from KdeQt import KQFileDialog
-from KdeQt.KQMainWindow import KQMainWindow
+from E5Gui import E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from PluginManager import PluginManager
-from Ui_PluginInstallDialog import Ui_PluginInstallDialog
+from .Ui_PluginInstallDialog import Ui_PluginInstallDialog
 
 import Utilities
 import Preferences
 
 from Utilities.uic import compileUiFiles
 
+
 class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
     """
     Class implementing the Plugin installation dialog.
     """
-    def __init__(self, pluginManager, pluginFileNames, parent = None):
+    def __init__(self, pluginManager, pluginFileNames, parent=None):
         """
         Constructor
         
         @param pluginManager reference to the plugin manager object
-        @param pluginFileNames list of plugin files suggested for 
-            installation (QStringList)
+        @param pluginFileNames list of plugin files suggested for
+            installation (list of strings)
         @param parent parent of this dialog (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         if pluginManager is None:
             # started as external plugin installer
-            self.__pluginManager = PluginManager(doLoadPlugins = False)
+            from .PluginManager import PluginManager
+            self.__pluginManager = PluginManager(doLoadPlugins=False)
             self.__external = True
         else:
             self.__pluginManager = pluginManager
             self.__external = False
         
-        self.__backButton = \
-            self.buttonBox.addButton(self.trUtf8("< Back"), QDialogButtonBox.ActionRole)
-        self.__nextButton = \
-            self.buttonBox.addButton(self.trUtf8("Next >"), QDialogButtonBox.ActionRole)
-        self.__finishButton = \
-            self.buttonBox.addButton(self.trUtf8("Install"), QDialogButtonBox.ActionRole)
+        self.__backButton = self.buttonBox.addButton(
+            self.trUtf8("< Back"), QDialogButtonBox.ActionRole)
+        self.__nextButton = self.buttonBox.addButton(
+            self.trUtf8("Next >"), QDialogButtonBox.ActionRole)
+        self.__finishButton = self.buttonBox.addButton(
+            self.trUtf8("Install"), QDialogButtonBox.ActionRole)
         
         self.__closeButton = self.buttonBox.button(QDialogButtonBox.Close)
         self.__cancelButton = self.buttonBox.button(QDialogButtonBox.Cancel)
         
         userDir = self.__pluginManager.getPluginDir("user")
         if userDir is not None:
-            self.destinationCombo.addItem(self.trUtf8("User plugins directory"), 
-                QVariant(userDir))
+            self.destinationCombo.addItem(
+                self.trUtf8("User plugins directory"),
+                userDir)
         
         globalDir = self.__pluginManager.getPluginDir("global")
         if globalDir is not None and os.access(globalDir, os.W_OK):
-            self.destinationCombo.addItem(self.trUtf8("Global plugins directory"), 
-                QVariant(globalDir))
+            self.destinationCombo.addItem(
+                self.trUtf8("Global plugins directory"),
+                globalDir)
         
         self.__installedDirs = []
         self.__installedFiles = []
@@ -83,7 +86,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         for pluginFileName in pluginFileNames:
             fi = QFileInfo(pluginFileName)
             if fi.isRelative():
-                pluginFileName = QFileInfo(downloadDir, fi.fileName()).absoluteFilePath()
+                pluginFileName = QFileInfo(
+                    downloadDir, fi.fileName()).absoluteFilePath()
             self.archivesList.addItem(pluginFileName)
             self.archivesList.sortItems()
         
@@ -102,9 +106,9 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Private method to create a list of plugin archive names.
         
-        @return list of plugin archive names (QStringList)
+        @return list of plugin archive names (list of strings)
         """
-        archivesList = QStringList()
+        archivesList = []
         for row in range(self.archivesList.count()):
             archivesList.append(self.archivesList.item(row).text())
         return archivesList
@@ -133,27 +137,28 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.__closeButton.hide()
             self.__cancelButton.show()
             
-            msg = self.trUtf8("Plugin ZIP-Archives:\n%1\n\nDestination:\n%2 (%3)")\
-                .arg(self.__createArchivesList().join("\n"))\
-                .arg(self.destinationCombo.currentText())\
-                .arg(self.destinationCombo.itemData(self.destinationCombo.currentIndex())\
-                     .toString()
-                )
+            msg = self.trUtf8(
+                "Plugin ZIP-Archives:\n{0}\n\nDestination:\n{1} ({2})")\
+                .format("\n".join(self.__createArchivesList()),
+                        self.destinationCombo.currentText(),
+                        self.destinationCombo.itemData(
+                            self.destinationCombo.currentIndex())
+                        )
             self.summaryEdit.setPlainText(msg)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addArchivesButton_clicked(self):
         """
         Private slot to select plugin ZIP-archives via a file selection dialog.
         """
         dn = Preferences.getPluginManager("DownloadPath")
-        archives = KQFileDialog.getOpenFileNames(\
+        archives = E5FileDialog.getOpenFileNames(
             self,
             self.trUtf8("Select plugin ZIP-archives"),
             dn,
             self.trUtf8("Plugin archive (*.zip)"))
         
-        if not archives.isEmpty():
+        if archives:
             matchflags = Qt.MatchFixedString
             if not Utilities.isWindowsPlatform():
                 matchflags |= Qt.MatchCaseSensitive
@@ -165,28 +170,32 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         
         self.__nextButton.setEnabled(self.archivesList.count() > 0)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_archivesList_itemSelectionChanged(self):
         """
         Private slot called, when the selection of the archives list changes.
         """
-        self.removeArchivesButton.setEnabled(len(self.archivesList.selectedItems()) > 0)
+        self.removeArchivesButton.setEnabled(
+            len(self.archivesList.selectedItems()) > 0)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_removeArchivesButton_clicked(self):
         """
         Private slot to remove archives from the list.
         """
         for archiveItem in self.archivesList.selectedItems():
-            itm = self.archivesList.takeItem(self.archivesList.row(archiveItem))
+            itm = self.archivesList.takeItem(
+                self.archivesList.row(archiveItem))
             del itm
         
         self.__nextButton.setEnabled(self.archivesList.count() > 0)
     
-    @pyqtSignature("QAbstractButton*")
+    @pyqtSlot(QAbstractButton)
     def on_buttonBox_clicked(self, button):
         """
         Private slot to handle the click of a button of the button box.
+        
+        @param button reference to the button pressed (QAbstractButton)
         """
         if button == self.__backButton:
             self.__currentIndex -= 1
@@ -195,8 +204,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             self.__currentIndex += 1
             self.__selectPage()
         elif button == self.__finishButton:
-            self.__installPlugins()
             self.__finishButton.setEnabled(False)
+            self.__installPlugins()
             self.__closeButton.show()
             self.__cancelButton.hide()
     
@@ -209,7 +218,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         res = True
         self.summaryEdit.clear()
         for archive in self.__createArchivesList():
-            self.summaryEdit.append(self.trUtf8("Installing %1 ...").arg(archive))
+            self.summaryEdit.append(
+                self.trUtf8("Installing {0} ...").format(archive))
             ok, msg, restart = self.__installPlugin(archive)
             res = res and ok
             if ok:
@@ -220,10 +230,10 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                 self.__restartNeeded = True
         self.summaryEdit.append("\n")
         if res:
-            self.summaryEdit.append(self.trUtf8(\
+            self.summaryEdit.append(self.trUtf8(
                 """The plugins were installed successfully."""))
         else:
-            self.summaryEdit.append(self.trUtf8(\
+            self.summaryEdit.append(self.trUtf8(
                 """Some plugins could not be installed."""))
         
         return res
@@ -232,43 +242,45 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         """
         Private slot to install the selected plugin.
         
-        @param archiveFilename name of the plugin archive 
-            file (string or QString)
+        @param archiveFilename name of the plugin archive
+            file (string)
         @return flag indicating success (boolean), error message
-            upon failure (QString) and flag indicating a restart
+            upon failure (string) and flag indicating a restart
             of the IDE is required (boolean)
         """
         installedPluginName = ""
         
-        archive = unicode(archiveFilename)
-        destination = \
-            unicode(self.destinationCombo.itemData(self.destinationCombo.currentIndex())\
-                .toString())
+        archive = archiveFilename
+        destination = self.destinationCombo.itemData(
+            self.destinationCombo.currentIndex())
         
         # check if archive is a local url
-        url = urlparse.urlparse(archive)
+        url = urllib.parse.urlparse(archive)
         if url[0].lower() == 'file':
             archive = url[2]
 
         # check, if the archive exists
         if not os.path.exists(archive):
             return False, \
-                self.trUtf8("""<p>The archive file <b>%1</b> does not exist. """
-                            """Aborting...</p>""").arg(archive), \
+                self.trUtf8(
+                    """<p>The archive file <b>{0}</b> does not exist. """
+                    """Aborting...</p>""").format(archive), \
                 False
         
         # check, if the archive is a valid zip file
         if not zipfile.is_zipfile(archive):
             return False, \
-                self.trUtf8("""<p>The file <b>%1</b> is not a valid plugin """
-                            """ZIP-archive. Aborting...</p>""").arg(archive), \
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> is not a valid plugin """
+                    """ZIP-archive. Aborting...</p>""").format(archive), \
                 False
         
         # check, if the destination is writeable
         if not os.access(destination, os.W_OK):
             return False, \
-                self.trUtf8("""<p>The destination directory <b>%1</b> is not """
-                            """writeable. Aborting...</p>""").arg(destination), \
+                self.trUtf8(
+                    """<p>The destination directory <b>{0}</b> is not """
+                    """writeable. Aborting...</p>""").format(destination), \
                 False
         
         zip = zipfile.ZipFile(archive, "r")
@@ -285,15 +297,18 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         
         if not pluginFound:
             return False, \
-                self.trUtf8("""<p>The file <b>%1</b> is not a valid plugin """
-                            """ZIP-archive. Aborting...</p>""").arg(archive), \
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> is not a valid plugin """
+                    """ZIP-archive. Aborting...</p>""").format(archive), \
                 False
         
         # parse the plugin module's plugin header
-        pluginSource = zip.read(pluginFileName)
+        pluginSource = Utilities.decode(zip.read(pluginFileName))[0]
         packageName = ""
         internalPackages = []
         needsRestart = False
+        pyqtApi = 0
+        doCompile = True
         for line in pluginSource.splitlines():
             if line.startswith("packageName"):
                 tokens = line.split("=")
@@ -306,19 +321,39 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                             packageName = "None"
             elif line.startswith("internalPackages"):
                 tokens = line.split("=")
-                token = tokens[1].strip()[1:-1]    # it is a comma separated string
+                token = tokens[1].strip()[1:-1]
+                # it is a comma separated string
                 internalPackages = [p.strip() for p in token.split(",")]
             elif line.startswith("needsRestart"):
                 tokens = line.split("=")
                 needsRestart = tokens[1].strip() == "True"
+            elif line.startswith("pyqtApi"):
+                tokens = line.split("=")
+                try:
+                    pyqtApi = int(tokens[1].strip())
+                except ValueError:
+                    pass
+            elif line.startswith("doNotCompile"):
+                tokens = line.split("=")
+                if tokens[1].strip() == "True":
+                    doCompile = False
             elif line.startswith("# End-Of-Header"):
                 break
         
         if not packageName:
             return False, \
-                self.trUtf8("""<p>The plugin module <b>%1</b> does not contain """
-                            """a 'packageName' attribute. Aborting...</p>""")\
-                    .arg(pluginFileName), \
+                self.trUtf8(
+                    """<p>The plugin module <b>{0}</b> does not contain """
+                    """a 'packageName' attribute. Aborting...</p>""")\
+                .format(pluginFileName), \
+                False
+        
+        if pyqtApi < 2:
+            return False, \
+                self.trUtf8(
+                    """<p>The plugin module <b>{0}</b> does not conform"""
+                    """ with the PyQt v2 API. Aborting...</p>""")\
+                .format(pluginFileName), \
                 False
         
         # check, if it is a plugin, that collides with others
@@ -326,28 +361,29 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
            packageName != "None" and \
            os.path.exists(os.path.join(destination, packageName)):
             return False, \
-                self.trUtf8("""<p>The plugin package <b>%1</b> exists. """
+                self.trUtf8("""<p>The plugin package <b>{0}</b> exists. """
                             """Aborting...</p>""")\
-                    .arg(os.path.join(destination, packageName)), \
+                    .format(os.path.join(destination, packageName)), \
                 False
         
         if os.path.exists(os.path.join(destination, pluginFileName)) and \
            packageName != "None" and \
            not os.path.exists(os.path.join(destination, packageName)):
             return False, \
-                self.trUtf8("""<p>The plugin module <b>%1</b> exists. """
+                self.trUtf8("""<p>The plugin module <b>{0}</b> exists. """
                             """Aborting...</p>""")\
-                    .arg(os.path.join(destination, pluginFileName)), \
+                    .format(os.path.join(destination, pluginFileName)), \
                 False
         
         activatePlugin = False
         if not self.__external:
             activatePlugin = \
-                not self.__pluginManager.isPluginLoaded(installedPluginName) or \
-                (self.__pluginManager.isPluginLoaded(installedPluginName) and \
+                not self.__pluginManager.isPluginLoaded(
+                    installedPluginName) or \
+                (self.__pluginManager.isPluginLoaded(installedPluginName) and
                  self.__pluginManager.isPluginActive(installedPluginName))
             # try to unload a plugin with the same name
-            self.__pluginManager.unloadPlugin(installedPluginName, destination)
+            self.__pluginManager.unloadPlugin(installedPluginName)
         
         # uninstall existing plugin first to get clean conditions
         self.__uninstallPackage(destination, pluginFileName, packageName)
@@ -361,9 +397,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         self.__installedFiles = []
         try:
             if packageName != "None":
-                packageDirs = ["%s/" % packageName, "%s\\" % packageName]
-                namelist = zip.namelist()
-                namelist.sort()
+                namelist = sorted(zip.namelist())
                 tot = len(namelist)
                 prog = 0
                 self.progress.setMaximum(tot)
@@ -373,8 +407,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     QApplication.processEvents()
                     prog += 1
                     if name == pluginFileName or \
-                       name.startswith("%s/" % packageName) or \
-                       name.startswith("%s\\" % packageName):
+                       name.startswith("{0}/".format(packageName)) or \
+                       name.startswith("{0}\\".format(packageName)):
                         outname = name.replace("/", os.sep)
                         outname = os.path.join(destination, outname)
                         if outname.endswith("/") or outname.endswith("\\"):
@@ -396,42 +430,50 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                 compileUiFiles(os.path.join(destination, packageName), True)
             else:
                 outname = os.path.join(destination, pluginFileName)
-                f = open(outname, "wb")
+                f = open(outname, "w", encoding="utf-8")
                 f.write(pluginSource)
                 f.close()
                 self.__installedFiles.append(outname)
-        except os.error, why:
+        except os.error as why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
+                self.trUtf8(
+                    "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
-        except IOError, why:
+        except IOError as why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
+                self.trUtf8(
+                    "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
-        except OSError, why:
+        except OSError as why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
+                self.trUtf8(
+                    "Error installing plugin. Reason: {0}").format(str(why)), \
                 False
         except:
-            print >>sys.stderr, "Unspecific exception installing plugin."
+            print("Unspecific exception installing plugin.", file=sys.stderr)
             self.__rollback()
             return False, \
                 self.trUtf8("Unspecific exception installing plugin."), \
                 False
         
         # now compile the plugins
-        compileall.compile_dir(destination, quiet = True)
+        if doCompile:
+            compileall.compile_dir(
+                os.path.join(destination, packageName), quiet=True)
+            compileall.compile_file(
+                os.path.join(destination, pluginFileName), quiet=True)
         
         if not self.__external:
             # now load and activate the plugin
-            self.__pluginManager.loadPlugin(installedPluginName, destination, reload_)
+            self.__pluginManager.loadPlugin(installedPluginName, destination,
+                                            reload_)
             if activatePlugin:
                 self.__pluginManager.activatePlugin(installedPluginName)
         
-        return True, QString(""), needsRestart
+        return True, "", needsRestart
     
     def __rollback(self):
         """
@@ -444,7 +486,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             if os.path.exists(dname):
                 shutil.rmtree(dname)
     
-    def __makedirs(self, name, mode = 0777):
+    def __makedirs(self, name, mode=0o777):
         """
         Private method to create a directory and all intermediate ones.
         
@@ -459,7 +501,8 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             head, tail = os.path.split(head)
         if head and tail and not os.path.exists(head):
             self.__makedirs(head, mode)
-            if tail == os.curdir:           # xxx/newdir/. exists if xxx/newdir exists
+            if tail == os.curdir:
+                # xxx/newdir/. exists if xxx/newdir exists
                 return
         os.mkdir(name, mode)
         self.__installedDirs.append(name)
@@ -483,46 +526,62 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
             if packageDir and os.path.exists(packageDir):
                 shutil.rmtree(packageDir)
             
-            fnameo = "%so" % pluginFile
+            fnameo = "{0}o".format(pluginFile)
             if os.path.exists(fnameo):
                 os.remove(fnameo)
             
-            fnamec = "%sc" % pluginFile
+            fnamec = "{0}c".format(pluginFile)
             if os.path.exists(fnamec):
                 os.remove(fnamec)
             
+            pluginDirCache = os.path.join(
+                os.path.dirname(pluginFile), "__pycache__")
+            if os.path.exists(pluginDirCache):
+                pluginFileName = os.path.splitext(
+                    os.path.basename(pluginFile))[0]
+                for fnameo in glob.glob(
+                    os.path.join(pluginDirCache,
+                                 "{0}*.pyo".format(pluginFileName))):
+                    os.remove(fnameo)
+                for fnamec in glob.glob(
+                    os.path.join(pluginDirCache,
+                                 "{0}*.pyc".format(pluginFileName))):
+                    os.remove(fnamec)
+            
             os.remove(pluginFile)
         except (IOError, OSError, os.error):
             # ignore some exceptions
             pass
 
+
 class PluginInstallDialog(QDialog):
     """
     Class for the dialog variant.
     """
-    def __init__(self, pluginManager, pluginFileNames, parent = None):
+    def __init__(self, pluginManager, pluginFileNames, parent=None):
         """
         Constructor
         
         @param pluginManager reference to the plugin manager object
-        @param pluginFileNames list of plugin files suggested for 
-            installation (QStringList)
+        @param pluginFileNames list of plugin files suggested for
+            installation (list of strings)
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setSizeGripEnabled(True)
         
         self.__layout = QVBoxLayout(self)
-        self.__layout.setMargin(0)
+        self.__layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(self.__layout)
         
         self.cw = PluginInstallWidget(pluginManager, pluginFileNames, self)
         size = self.cw.size()
         self.__layout.addWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
+        self.cw.buttonBox.accepted[()].connect(self.accept)
+        self.cw.buttonBox.rejected[()].connect(self.reject)
     
     def restartNeeded(self):
         """
@@ -532,23 +591,28 @@ class PluginInstallDialog(QDialog):
         """
         return self.cw.restartNeeded()
 
-class PluginInstallWindow(KQMainWindow):
+
+class PluginInstallWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, pluginFileNames, parent = None):
+    def __init__(self, pluginFileNames, parent=None):
         """
         Constructor
         
-        @param pluginFileNames list of plugin files suggested for 
-            installation (QStringList)
+        @param pluginFileNames list of plugin files suggested for
+            installation (list of strings)
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
         self.cw = PluginInstallWidget(None, pluginFileNames, self)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.close)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
+        self.cw.buttonBox.accepted[()].connect(self.close)
+        self.cw.buttonBox.rejected[()].connect(self.close)
