@@ -11,115 +11,134 @@ Module implementing a dialog showing the available plugins.
 import sys
 import os
 import zipfile
-import cStringIO
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
+from PyQt4.QtCore import pyqtSignal, pyqtSlot, Qt, QFile, QIODevice, QUrl, \
+    QProcess
+from PyQt4.QtGui import QWidget, QDialogButtonBox, QAbstractButton, \
+    QTreeWidgetItem, QDialog, QVBoxLayout
+from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, \
+    QNetworkReply
+
+from .Ui_PluginRepositoryDialog import Ui_PluginRepositoryDialog
+
+from E5Gui import E5MessageBox
+from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5Application import e5App
+
+from E5Network.E5NetworkProxyFactory import proxyAuthenticationRequired
 try:
-    from PyQt4.QtNetwork import QSslError
+    from E5Network.E5SslErrorHandler import E5SslErrorHandler
     SSL_AVAILABLE = True
 except ImportError:
     SSL_AVAILABLE = False
 
-from KdeQt import KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
-
-from Ui_PluginRepositoryDialog import Ui_PluginRepositoryDialog
-
-from UI.AuthenticationDialog import AuthenticationDialog
-
-from E4XML.XMLUtilities import make_parser
-from E4XML.XMLErrorHandler import XMLErrorHandler, XMLFatalParseError
-from E4XML.XMLEntityResolver import XMLEntityResolver
-from E4XML.PluginRepositoryHandler import PluginRepositoryHandler
-
 import Utilities
 import Preferences
 
 import UI.PixmapCache
 
-from eric4config import getConfig
+from eric5config import getConfig
 
-descrRole    = Qt.UserRole
-urlRole      = Qt.UserRole + 1
+descrRole = Qt.UserRole
+urlRole = Qt.UserRole + 1
 filenameRole = Qt.UserRole + 2
-authorRole   = Qt.UserRole + 3
+authorRole = Qt.UserRole + 3
+
 
 class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
     """
     Class implementing a dialog showing the available plugins.
     
-    @signal closeAndInstall emitted when the Close & Install button is pressed
+    @signal closeAndInstall() emitted when the Close & Install button is
+        pressed
     """
-    def __init__(self, parent = None):
+    closeAndInstall = pyqtSignal()
+    
+    def __init__(self, parent=None, external=False):
         """
         Constructor
         
         @param parent parent of this dialog (QWidget)
+        @param external flag indicating an instatiation as a main
+            window (boolean)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.__updateButton = \
-            self.buttonBox.addButton(self.trUtf8("Update"), QDialogButtonBox.ActionRole)
-        self.__downloadButton = \
-            self.buttonBox.addButton(self.trUtf8("Download"), QDialogButtonBox.ActionRole)
+        self.__updateButton = self.buttonBox.addButton(
+            self.trUtf8("Update"), QDialogButtonBox.ActionRole)
+        self.__downloadButton = self.buttonBox.addButton(
+            self.trUtf8("Download"), QDialogButtonBox.ActionRole)
         self.__downloadButton.setEnabled(False)
-        self.__downloadCancelButton = \
-            self.buttonBox.addButton(self.trUtf8("Cancel"), QDialogButtonBox.ActionRole)
+        self.__downloadInstallButton = self.buttonBox.addButton(
+            self.trUtf8("Download && Install"),
+            QDialogButtonBox.ActionRole)
+        self.__downloadInstallButton.setEnabled(False)
+        self.__downloadCancelButton = self.buttonBox.addButton(
+            self.trUtf8("Cancel"), QDialogButtonBox.ActionRole)
         self.__installButton = \
-            self.buttonBox.addButton(self.trUtf8("Close && Install"), 
+            self.buttonBox.addButton(self.trUtf8("Close && Install"),
                                      QDialogButtonBox.ActionRole)
         self.__downloadCancelButton.setEnabled(False)
         self.__installButton.setEnabled(False)
         
-        self.repositoryUrlEdit.setText(Preferences.getUI("PluginRepositoryUrl"))
+        self.repositoryUrlEdit.setText(
+            Preferences.getUI("PluginRepositoryUrl5"))
         
-        self.repositoryList.headerItem().setText(self.repositoryList.columnCount(), "")
+        self.repositoryList.headerItem().setText(
+            self.repositoryList.columnCount(), "")
         self.repositoryList.header().setSortIndicator(0, Qt.AscendingOrder)
         
         self.pluginRepositoryFile = \
             os.path.join(Utilities.getConfigDir(), "PluginRepository")
         
+        self.__external = external
+        
         # attributes for the network objects
         self.__networkManager = QNetworkAccessManager(self)
-        self.connect(self.__networkManager, 
-            SIGNAL('proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)'),
-            self.__proxyAuthenticationRequired)
+        self.__networkManager.proxyAuthenticationRequired.connect(
+            proxyAuthenticationRequired)
         if SSL_AVAILABLE:
-            self.connect(self.__networkManager, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'), 
-                self.__sslErrors)
+            self.__sslErrorHandler = E5SslErrorHandler(self)
+            self.__networkManager.sslErrors.connect(self.__sslErrors)
         self.__replies = []
         
         self.__doneMethod = None
         self.__inDownload = False
         self.__pluginsToDownload = []
-        self.__pluginsDownloaded = QStringList()
+        self.__pluginsDownloaded = []
+        self.__isDownloadInstall = False
+        self.__allDownloadedOk = False
         
         self.__populateList()
     
-    @pyqtSignature("QAbstractButton*")
+    @pyqtSlot(QAbstractButton)
     def on_buttonBox_clicked(self, button):
         """
         Private slot to handle the click of a button of the button box.
+        
+        @param button reference to the button pressed (QAbstractButton)
         """
         if button == self.__updateButton:
             self.__updateList()
         elif button == self.__downloadButton:
+            self.__isDownloadInstall = False
+            self.__downloadPlugins()
+        elif button == self.__downloadInstallButton:
+            self.__isDownloadInstall = True
+            self.__allDownloadedOk = True
             self.__downloadPlugins()
         elif button == self.__downloadCancelButton:
             self.__downloadCancel()
         elif button == self.__installButton:
-            self.emit(SIGNAL("closeAndInstall"))
+            self.closeAndInstall.emit()
     
     def __formatDescription(self, lines):
         """
         Private method to format the description.
         
-        @param lines lines of the description (QStringList)
-        @return formatted description (QString)
+        @param lines lines of the description (list of strings)
+        @return formatted description (string)
         """
         # remove empty line at start and end
         newlines = lines[:]
@@ -136,9 +155,9 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             index += 1
         
         # join lines by a blank
-        return newlines.join(' ')
+        return ' '.join(newlines)
     
-    @pyqtSignature("QTreeWidgetItem*, QTreeWidgetItem*")
+    @pyqtSlot(QTreeWidgetItem, QTreeWidgetItem)
     def on_repositoryList_currentItemChanged(self, current, previous):
         """
         Private slot to handle the change of the current item.
@@ -149,16 +168,17 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         if self.__repositoryMissing or current is None:
             return
         
-        self.urlEdit.setText(current.data(0, urlRole).toString())
-        self.descriptionEdit.setPlainText(\
-            self.__formatDescription(current.data(0, descrRole).toStringList()))
-        self.authorEdit.setText(current.data(0, authorRole).toString())
+        self.urlEdit.setText(current.data(0, urlRole) or "")
+        self.descriptionEdit.setPlainText(
+            current.data(0, descrRole) and
+            self.__formatDescription(current.data(0, descrRole)) or "")
+        self.authorEdit.setText(current.data(0, authorRole) or "")
     
     def __selectedItems(self):
         """
         Private method to get all selected items without the toplevel ones.
         
-        @return list of selected items (QList)
+        @return list of selected items (list)
         """
         ql = self.repositoryList.selectedItems()
         for index in range(self.repositoryList.topLevelItemCount()):
@@ -167,20 +187,21 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 ql.remove(ti)
         return ql
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_repositoryList_itemSelectionChanged(self):
         """
         Private slot to handle a change of the selection.
         """
         self.__downloadButton.setEnabled(len(self.__selectedItems()))
+        self.__downloadInstallButton.setEnabled(len(self.__selectedItems()))
     
     def __updateList(self):
         """
         Private slot to download a new list and display the contents.
         """
         url = self.repositoryUrlEdit.text()
-        self.__downloadFile(url, 
-                            self.pluginRepositoryFile, 
+        self.__downloadFile(url,
+                            self.pluginRepositoryFile,
                             self.__downloadRepositoryFileDone)
     
     def __downloadRepositoryFileDone(self, status, filename):
@@ -188,7 +209,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         Private method called after the repository file was downloaded.
         
         @param status flaging indicating a successful download (boolean)
-        @param filename full path of the downloaded file (QString)
+        @param filename full path of the downloaded file (string)
         """
         self.__populateList()
     
@@ -196,11 +217,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private method called, when the download of a plugin is finished.
         
-        @param status flaging indicating a successful download (boolean)
-        @param filename full path of the downloaded file (QString)
+        @param status flag indicating a successful download (boolean)
+        @param filename full path of the downloaded file (string)
         """
         if status:
             self.__pluginsDownloaded.append(filename)
+        if self.__isDownloadInstall:
+            self.__allDownloadedOk &= status
         
         del self.__pluginsToDownload[0]
         if len(self.__pluginsToDownload):
@@ -212,24 +235,26 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private method to download the next plugin.
         """
-        self.__downloadFile(self.__pluginsToDownload[0][0], 
-                            self.__pluginsToDownload[0][1], 
+        self.__downloadFile(self.__pluginsToDownload[0][0],
+                            self.__pluginsToDownload[0][1],
                             self.__downloadPluginDone)
     
     def __downloadPlugins(self):
         """
         Private slot to download the selected plugins.
         """
-        self.__pluginsDownloaded.clear()
+        self.__pluginsDownloaded = []
         self.__pluginsToDownload = []
         self.__downloadButton.setEnabled(False)
+        self.__downloadInstallButton.setEnabled(False)
         self.__installButton.setEnabled(False)
         for itm in self.repositoryList.selectedItems():
-            if itm not in [self.__stableItem, self.__unstableItem, self.__unknownItem]:
-                url = itm.data(0, urlRole).toString()
-                filename = os.path.join(\
-                    unicode(Preferences.getPluginManager("DownloadPath")),
-                    unicode(itm.data(0, filenameRole).toString()))
+            if itm not in [self.__stableItem, self.__unstableItem,
+                           self.__unknownItem]:
+                url = itm.data(0, urlRole)
+                filename = os.path.join(
+                    Preferences.getPluginManager("DownloadPath"),
+                    itm.data(0, filenameRole))
                 self.__pluginsToDownload.append((url, filename))
         self.__downloadPlugin()
     
@@ -238,22 +263,39 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         Private method called, when the download of the plugins is finished.
         """
         self.__downloadButton.setEnabled(len(self.__selectedItems()))
+        self.__downloadInstallButton.setEnabled(len(self.__selectedItems()))
         self.__installButton.setEnabled(True)
         self.__doneMethod = None
-        KQMessageBox.information(None,
-            self.trUtf8("Download Plugin Files"),
-            self.trUtf8("""The requested plugins were downloaded."""))
-        self.downloadProgress.setValue(0)
+        if not self.__external:
+            ui = e5App().getObject("UserInterface")
+        else:
+            ui = None
+        if ui and ui.notificationsEnabled():
+            ui.showNotification(
+                UI.PixmapCache.getPixmap("plugin48.png"),
+                self.trUtf8("Download Plugin Files"),
+                self.trUtf8("""The requested plugins were downloaded."""))
         
-        # repopulate the list to update the refresh icons
-        self.__populateList()
+        if self.__isDownloadInstall:
+            self.closeAndInstall.emit()
+        else:
+            if ui is None or not ui.notificationsEnabled():
+                E5MessageBox.information(
+                    self,
+                    self.trUtf8("Download Plugin Files"),
+                    self.trUtf8("""The requested plugins were downloaded."""))
+            self.downloadProgress.setValue(0)
+            
+            # repopulate the list to update the refresh icons
+            self.__populateList()
     
     def __resortRepositoryList(self):
         """
         Private method to resort the tree.
         """
-        self.repositoryList.sortItems(self.repositoryList.sortColumn(), 
-                                      self.repositoryList.header().sortIndicatorOrder())
+        self.repositoryList.sortItems(
+            self.repositoryList.sortColumn(),
+            self.repositoryList.header().sortIndicatorOrder())
     
     def __populateList(self):
         """
@@ -269,98 +311,59 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         
         if os.path.exists(self.pluginRepositoryFile):
             self.__repositoryMissing = False
-            try:
-                f = open(self.pluginRepositoryFile, "rb")
-                line = f.readline()
-                dtdLine = f.readline()
-                f.close()
-            except IOError:
-                KQMessageBox.critical(None,
-                    self.trUtf8("Read plugins repository file"),
-                    self.trUtf8("<p>The plugins repository file <b>%1</b> "
-                                "could not be read. Select Update</p>")\
-                        .arg(self.pluginRepositoryFile))
-                return
-            
-            # now read the file
-            if line.startswith('<?xml'):
-                parser = make_parser(dtdLine.startswith("<!DOCTYPE"))
-                handler = PluginRepositoryHandler(self)
-                er = XMLEntityResolver()
-                eh = XMLErrorHandler()
-                
-                parser.setContentHandler(handler)
-                parser.setEntityResolver(er)
-                parser.setErrorHandler(eh)
-                
-                try:
-                    f = open(self.pluginRepositoryFile, "rb")
-                    try:
-                        try:
-                            parser.parse(f)
-                        except UnicodeEncodeError:
-                            f.seek(0)
-                            buf = cStringIO.StringIO(f.read())
-                            parser.parse(buf)
-                    finally:
-                        f.close()
-                except IOError:
-                    KQMessageBox.critical(None,
-                        self.trUtf8("Read plugins repository file"),
-                        self.trUtf8("<p>The plugins repository file <b>%1</b> "
-                                    "could not be read. Select Update</p>")\
-                            .arg(self.pluginRepositoryFile))
-                    return
-                except XMLFatalParseError:
-                    pass
-                
-                eh.showParseMessages()
-                
+            f = QFile(self.pluginRepositoryFile)
+            if f.open(QIODevice.ReadOnly):
+                from E5XML.PluginRepositoryReader import PluginRepositoryReader
+                reader = PluginRepositoryReader(f, self.addEntry)
+                reader.readXML()
                 self.repositoryList.resizeColumnToContents(0)
                 self.repositoryList.resizeColumnToContents(1)
                 self.repositoryList.resizeColumnToContents(2)
                 self.__resortRepositoryList()
-                
-                url = Preferences.getUI("PluginRepositoryUrl")
+                url = Preferences.getUI("PluginRepositoryUrl5")
                 if url != self.repositoryUrlEdit.text():
                     self.repositoryUrlEdit.setText(url)
-                    KQMessageBox.warning(self,
+                    E5MessageBox.warning(
+                        self,
                         self.trUtf8("Plugins Repository URL Changed"),
-                        self.trUtf8("""The URL of the Plugins Repository has"""
-                                    """ changed. Select the "Update" button to get"""
-                                    """ the new repository file."""))
+                        self.trUtf8(
+                            """The URL of the Plugins Repository has"""
+                            """ changed. Select the "Update" button to get"""
+                            """ the new repository file."""))
             else:
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Read plugins repository file"),
-                    self.trUtf8("<p>The plugins repository file <b>%1</b> "
-                                "has an unsupported format.</p>")\
-                        .arg(self.pluginRepositoryFile))
+                    self.trUtf8("<p>The plugins repository file <b>{0}</b> "
+                                "could not be read. Select Update</p>")
+                    .format(self.pluginRepositoryFile))
         else:
             self.__repositoryMissing = True
-            QTreeWidgetItem(self.repositoryList, \
-                QStringList() \
-                    << "" \
-                    << self.trUtf8("No plugin repository file available."
-                                   "\nSelect Update."))
+            QTreeWidgetItem(
+                self.repositoryList,
+                ["", self.trUtf8(
+                    "No plugin repository file available.\nSelect Update.")
+                 ])
             self.repositoryList.resizeColumnToContents(1)
     
-    def __downloadFile(self, url, filename, doneMethod = None):
+    def __downloadFile(self, url, filename, doneMethod=None):
         """
         Private slot to download the given file.
         
-        @param url URL for the download (string or QString)
-        @param filename local name of the file (string or QString)
+        @param url URL for the download (string)
+        @param filename local name of the file (string)
         @param doneMethod method to be called when done
         """
         self.__updateButton.setEnabled(False)
         self.__downloadButton.setEnabled(False)
+        self.__downloadInstallButton.setEnabled(False)
         self.__downloadCancelButton.setEnabled(True)
         
         self.statusLabel.setText(url)
         
         self.__doneMethod = doneMethod
         self.__downloadURL = url
-        self.__downloadFileName = QString(filename)
+        self.__downloadFileName = filename
         self.__downloadIODevice = QFile(self.__downloadFileName + ".tmp")
         self.__downloadCancelled = False
         
@@ -368,9 +371,8 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
                              QNetworkRequest.AlwaysNetwork)
         reply = self.__networkManager.get(request)
-        self.connect(reply, SIGNAL("finished()"), self.__downloadFileDone)
-        self.connect(reply, SIGNAL("downloadProgress(qint64, qint64)"), 
-            self.__downloadProgress)
+        reply.finished[()].connect(self.__downloadFileDone)
+        reply.downloadProgress.connect(self.__downloadProgress)
         self.__replies.append(reply)
     
     def __downloadFileDone(self):
@@ -389,12 +391,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         if reply.error() != QNetworkReply.NoError:
             ok = False
             if not self.__downloadCancelled:
-                KQMessageBox.warning(None,
+                E5MessageBox.warning(
+                    self,
                     self.trUtf8("Error downloading file"),
                     self.trUtf8(
-                        """<p>Could not download the requested file from %1.</p>"""
-                        """<p>Error: %2</p>"""
-                    ).arg(self.__downloadURL).arg(reply.errorString())
+                        """<p>Could not download the requested file"""
+                        """ from {0}.</p><p>Error: {1}</p>"""
+                    ).format(self.__downloadURL, reply.errorString())
                 )
             self.downloadProgress.setValue(0)
             self.__downloadURL = None
@@ -402,10 +405,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.__downloadIODevice = None
             if self.repositoryList.topLevelItemCount():
                 if self.repositoryList.currentItem() is None:
-                    self.repositoryList.setCurrentItem(\
+                    self.repositoryList.setCurrentItem(
                         self.repositoryList.topLevelItem(0))
                 else:
-                    self.__downloadButton.setEnabled(len(self.__selectedItems()))
+                    self.__downloadButton.setEnabled(
+                        len(self.__selectedItems()))
+                    self.__downloadInstallButton.setEnabled(
+                        len(self.__selectedItems()))
             return
         
         self.__downloadIODevice.open(QIODevice.WriteOnly)
@@ -441,53 +447,47 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             self.downloadProgress.setMaximum(total)
             self.downloadProgress.setValue(done)
     
-    def addEntry(self, name, short, description, url, author, version, filename, status):
+    def addEntry(self, name, short, description, url, author, version,
+                 filename, status):
         """
         Public method to add an entry to the list.
         
-        @param name data for the name field (string or QString)
-        @param short data for the short field (string or QString)
-        @param description data for the description field (list of string or QStringList)
-        @param url data for the url field (string or QString)
-        @param author data for the author field (string or QString)
-        @param version data for the version field (string or QString)
-        @param filename data for the filename field (string or QString)
+        @param name data for the name field (string)
+        @param short data for the short field (string)
+        @param description data for the description field (list of strings)
+        @param url data for the url field (string)
+        @param author data for the author field (string)
+        @param version data for the version field (string)
+        @param filename data for the filename field (string)
         @param status status of the plugin (string [stable, unstable, unknown])
         """
         if status == "stable":
             if self.__stableItem is None:
                 self.__stableItem = \
-                    QTreeWidgetItem(self.repositoryList, 
-                                    QStringList(self.trUtf8("Stable")))
+                    QTreeWidgetItem(self.repositoryList,
+                                    [self.trUtf8("Stable")])
                 self.__stableItem.setExpanded(True)
             parent = self.__stableItem
         elif status == "unstable":
             if self.__unstableItem is None:
                 self.__unstableItem = \
-                    QTreeWidgetItem(self.repositoryList, 
-                                    QStringList(self.trUtf8("Unstable")))
+                    QTreeWidgetItem(self.repositoryList,
+                                    [self.trUtf8("Unstable")])
                 self.__unstableItem.setExpanded(True)
             parent = self.__unstableItem
         else:
             if self.__unknownItem is None:
                 self.__unknownItem = \
-                    QTreeWidgetItem(self.repositoryList, 
-                                    QStringList(self.trUtf8("Unknown")))
+                    QTreeWidgetItem(self.repositoryList,
+                                    [self.trUtf8("Unknown")])
                 self.__unknownItem.setExpanded(True)
             parent = self.__unknownItem
-        itm = QTreeWidgetItem(parent, 
-                              QStringList() << name << version << short)
+        itm = QTreeWidgetItem(parent, [name, version, short])
         
-        itm.setData(0, urlRole, QVariant(url))
-        itm.setData(0, filenameRole, QVariant(filename))
-        itm.setData(0, authorRole, QVariant(author))
-        if type(description) == type([]):
-            descr = QStringList()
-            for line in description:
-                descr.append(line)
-        else:
-            descr = description
-        itm.setData(0, descrRole, QVariant(descr))
+        itm.setData(0, urlRole, url)
+        itm.setData(0, filenameRole, filename)
+        itm.setData(0, authorRole, author)
+        itm.setData(0, descrRole, description)
         
         if self.__isUpToDate(filename, version):
             itm.setIcon(1, UI.PixmapCache.getIcon("empty.png"))
@@ -498,11 +498,11 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private method to check, if the given archive is up-to-date.
         
-        @param filename data for the filename field (string or QString)
-        @param version data for the version field (string or QString)
+        @param filename data for the filename field (string)
+        @param version data for the version field (string)
         @return flag indicating up-to-date (boolean)
         """
-        archive = os.path.join(unicode(Preferences.getPluginManager("DownloadPath")),
+        archive = os.path.join(Preferences.getPluginManager("DownloadPath"),
                                filename)
 
         # check, if the archive exists
@@ -515,33 +515,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         
         zip = zipfile.ZipFile(archive, "r")
         try:
-            aversion = zip.read("VERSION")
+            aversion = zip.read("VERSION").decode("utf-8")
         except KeyError:
             aversion = ""
         zip.close()
         
         return aversion == version
     
-    def __proxyAuthenticationRequired(self, proxy, auth):
-        """
-        Private slot to handle a proxy authentication request.
-        
-        @param proxy reference to the proxy object (QNetworkProxy)
-        @param auth reference to the authenticator object (QAuthenticator)
-        """
-        info = self.trUtf8("<b>Connect to proxy '%1' using:</b>")\
-            .arg(Qt.escape(proxy.hostName()))
-        
-        dlg = AuthenticationDialog(info, proxy.user(), True)
-        dlg.setData(proxy.user(), proxy.password())
-        if dlg.exec_() == QDialog.Accepted:
-            username, password = dlg.getData()
-            auth.setUser(username)
-            auth.setPassword(password)
-            if dlg.shallSave():
-                Preferences.setUI("ProxyUser", username)
-                Preferences.setUI("ProxyPassword", password)
-    
     def __sslErrors(self, reply, errors):
         """
         Private slot to handle SSL errors.
@@ -549,68 +529,55 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @param reply reference to the reply object (QNetworkReply)
         @param errors list of SSL errors (list of QSslError)
         """
-        errorStrings = QStringList()
-        for err in errors:
-            errorStrings.append(err.errorString())
-        errorString = errorStrings.join('.<br />')
-        ret = KQMessageBox.warning(self,
-            self.trUtf8("SSL Errors"),
-            self.trUtf8("""<p>SSL Errors:</p>"""
-                        """<p>%1</p>"""
-                        """<p>Do you want to ignore these errors?</p>""")\
-                .arg(errorString),
-            QMessageBox.StandardButtons(\
-                QMessageBox.No | \
-                QMessageBox.Yes),
-            QMessageBox.No)
-        if ret == QMessageBox.Yes:
-            reply.ignoreSslErrors()
-        else:
+        ignored = self.__sslErrorHandler.sslErrorsReply(reply, errors)[0]
+        if ignored == E5SslErrorHandler.NotIgnored:
             self.__downloadCancelled = True
-            reply.abort()
     
     def getDownloadedPlugins(self):
         """
         Public method to get the list of recently downloaded plugin files.
         
-        @return list of plugin filenames (QStringList)
+        @return list of plugin filenames (list of strings)
         """
         return self.__pluginsDownloaded
     
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_repositoryUrlEditButton_toggled(self, checked):
         """
-        Private slot to set the read only status of the repository URL line edit.
+        Private slot to set the read only status of the repository URL line
+        edit.
         
         @param checked state of the push button (boolean)
         """
         self.repositoryUrlEdit.setReadOnly(not checked)
 
+
 class PluginRepositoryDialog(QDialog):
     """
     Class for the dialog variant.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setSizeGripEnabled(True)
         
         self.__layout = QVBoxLayout(self)
-        self.__layout.setMargin(0)
+        self.__layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(self.__layout)
         
         self.cw = PluginRepositoryWidget(self)
         size = self.cw.size()
         self.__layout.addWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
-        self.connect(self.cw, SIGNAL("closeAndInstall"), self.__closeAndInstall)
+        self.cw.buttonBox.accepted[()].connect(self.accept)
+        self.cw.buttonBox.rejected[()].connect(self.reject)
+        self.cw.closeAndInstall.connect(self.__closeAndInstall)
         
     def __closeAndInstall(self):
         """
@@ -622,48 +589,55 @@ class PluginRepositoryDialog(QDialog):
         """
         Public method to get the list of recently downloaded plugin files.
         
-        @return list of plugin filenames (QStringList)
+        @return list of plugin filenames (list of strings)
         """
         return self.cw.getDownloadedPlugins()
 
-class PluginRepositoryWindow(KQMainWindow):
+
+class PluginRepositoryWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
-        self.cw = PluginRepositoryWidget(self)
+        super().__init__(parent)
+        self.cw = PluginRepositoryWidget(self, external=True)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.close)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
-        self.connect(self.cw, SIGNAL("closeAndInstall"), self.__startPluginInstall)
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
+        self.cw.buttonBox.accepted[()].connect(self.close)
+        self.cw.buttonBox.rejected[()].connect(self.close)
+        self.cw.closeAndInstall.connect(self.__startPluginInstall)
     
     def __startPluginInstall(self):
         """
-        Private slot to start the eric4 plugin installation dialog.
+        Private slot to start the eric5 plugin installation dialog.
         """
         proc = QProcess()
-        applPath = os.path.join(getConfig("ericDir"), "eric4_plugininstall.py")
+        applPath = os.path.join(getConfig("ericDir"), "eric5_plugininstall.py")
         
-        args = QStringList()
+        args = []
         args.append(applPath)
         args += self.cw.getDownloadedPlugins()
         
-        if not os.path.isfile(applPath) or not proc.startDetached(sys.executable, args):
-            KQMessageBox.critical(self,
+        if not os.path.isfile(applPath) or \
+                not proc.startDetached(sys.executable, args):
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
                     '<p>Could not start the process.<br>'
-                    'Ensure that it is available as <b>%1</b>.</p>'
-                ).arg(applPath),
+                    'Ensure that it is available as <b>{0}</b>.</p>'
+                ).format(applPath),
                 self.trUtf8('OK'))
         
         self.close()
