@@ -7,34 +7,36 @@
 Module implementing an 'About Eric' dialog.
 """
 
-import sys
+from PyQt4.QtGui import QApplication, QDialog
 
-from PyQt4.QtCore import QString, Qt, SIGNAL
-from PyQt4.QtGui import QApplication
+from .Ui_AboutDialog import Ui_AboutDialog
 
-from UI.Info import *
+import Preferences
 
-import Utilities
+import UI.PixmapCache
+import UI.Info
 
 
-titleText = QString("<b>%1 - %2</b>").arg(Program).arg(Version)
+titleText = "<b>{0} - {1}</b>".format(UI.Info.Program, UI.Info.Version)
 
-aboutText = QApplication.translate("AboutDialog",
-    """<p>%1 is an Integrated Development Environment for the Python"""
-    """ programming language. It is written using the PyQt Python bindings for"""
-    """ the Qt GUI toolkit and the QScintilla editor widget.</p>"""
+aboutText = QApplication.translate(
+    "AboutDialog",
+    """<p>{0} is an Integrated Development Environment for the Python"""
+    """ programming language. It is written using the PyQt Python bindings"""
+    """ for the Qt GUI toolkit and the QScintilla editor widget.</p>"""
     """<p>For more information see"""
-    """ <a href="%2">%2</a>.</p>"""
-    """<p>Please send bug reports to <a href="mailto:%3">%3</a>.</p>"""
+    """ <a href="{1}">{1}</a>.</p>"""
+    """<p>Please send bug reports to <a href="mailto:{2}">{2}</a>.</p>"""
     """<p>To request a new feature please send an email to"""
-    """ <a href="mailto:%4">%4</a>.</p>"""
-    """<p>%1 uses third party software which is copyrighted"""
+    """ <a href="mailto:{3}">{3}</a>.</p>"""
+    """<p>{0} uses third party software which is copyrighted"""
     """ by its respective copyright holder. For details see"""
     """ the copyright notice of the individual package.</p>"""
-).arg(Program).arg(Homepage).arg(BugAddress).arg(FeatureAddress)
+).format(UI.Info.Program, UI.Info.Homepage, UI.Info.BugAddress,
+         UI.Info.FeatureAddress)
 
-authorsText = QString(
-u"""\
+authorsText = \
+"""\
 Detlev Offenbach
     Project Manager, Maintainer and German translation
     
@@ -61,13 +63,12 @@ Xia WeiPeng
     Chinese translations
 
 Gianluca
-Leonardo Giordani
     Italian translations
 """
-)
 
-thanksText = QString(
-u"""Phil Thompson for providing PyQt and QScintilla and pushing me into this business.
+thanksText = """\
+Phil Thompson for providing PyQt and QScintilla and pushing me into this
+business.
 
 Andrew Bushnell of Fluent Inc. for contributing the multithreading debugger
 and a bunch of fixes to enhance the platform independence.
@@ -90,16 +91,15 @@ Ralf Ahlbrink
 Stefan Jaensch
 Martin v. Löwis
 Thorsten Kohnhorst
-for providing patches to improve eric3 and eric4.
+for providing patches to improve eric3, eric4 and eric5.
 
 And all the people who reported bugs and made suggestions."""
-)
 
-licenseText = QString(
-"""Eric is %1
+licenseText = \
+"""Eric is {0}
 
 You may use, distribute and copy Eric under the terms of the GNU
-General Public License as published by the Free Software Foundation, 
+General Public License as published by the Free Software Foundation,
 either version 3 of the License, which is shown below, or (at your
 option) any later version.
 
@@ -725,60 +725,52 @@ an absolute waiver of all civil liability in connection with the
 Program, unless a warranty or assumption of liability accompanies a
 copy of the Program in return for a fee.
 
-                     END OF TERMS AND CONDITIONS""").arg(Copyright)
+                     END OF TERMS AND CONDITIONS""" \
+.format(UI.Info.Copyright)                  # __IGNORE_WARNING__
 
 
-import os
-
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
-
-import UI.PixmapCache
-
-from Ui_AboutDialog import Ui_AboutDialog
-
 class AboutDialog(QDialog, Ui_AboutDialog):
     """
     Class implementing an 'About Eric' dialog.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.ericLabel.setText(titleText)
-        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric.png").scaled(48, 48))
+        self.ericPixmap.setPixmap(
+            UI.PixmapCache.getPixmap("eric.png").scaled(48, 48))
         
         ####################################################################
-        ## ABOUT        
+        ## ABOUT
         ####################################################################
         
         self.aboutEdit.setHtml(aboutText)
         
         ####################################################################
-        ## Copyright, Authors        
+        ## Copyright, Authors
         ####################################################################
         
         self.authorsEdit.setPlainText(authorsText)
         
         ####################################################################
-        ## THANKS        
+        ## THANKS
         ####################################################################
         
         self.thanksEdit.setPlainText(thanksText)
         
         ####################################################################
-        ## LICENSE        
+        ## LICENSE
         ####################################################################
         
-        if Utilities.isWindowsPlatform():
-            self.licenseEdit.setFontFamily("Lucida Console")
-        else:
-            self.licenseEdit.setFontFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.licenseEdit.setFontFamily(font.family())
+        self.licenseEdit.setFontPointSize(font.pointSize())
         
         self.licenseEdit.setPlainText(licenseText)
         
