@@ -13,7 +13,7 @@ Warning: The API provided by this module is likely to change in future
 releases; such changes may not be backward compatible.
 
 This is a modified version to make the original tabnanny better suitable
-for being called from within the eric4 IDE.
+for being called from within the eric5 IDE.
 
 @exception ValueError The tokenize module is too old.
 """
@@ -26,7 +26,7 @@ for being called from within the eric4 IDE.
 
 #
 # This is a modified version to make the original tabnanny better suitable
-# for being called from within the eric4 IDE. The modifications are as
+# for being called from within the eric5 IDE. The modifications are as
 # follows:
 #
 # - there is no main function anymore
@@ -35,15 +35,14 @@ for being called from within the eric4 IDE.
 #   linenumber and the error message (boolean, string, string, string). The
 #   values are only valid, if the status equals 1.
 #
-# Modifications copyright (c) 2003 Detlev Offenbach <detlev@die-offenbachs.de>
+# Mofifications Copyright (c) 2003-2014 Detlev Offenbach
+# <detlev@die-offenbachs.de>
 #
 
 __version__ = "6_eric"
 
-import os
-import sys
 import tokenize
-import cStringIO
+import io
 
 import Utilities
 
@@ -52,8 +51,11 @@ if not hasattr(tokenize, 'NL'):
 
 __all__ = ["check", "NannyNag", "process_tokens"]
 
+
 class NannyNag(Exception):
     """
+    Class implementing an exception for indentation issues.
+    
     Raised by tokeneater() if detecting an ambiguous indent.
     Captured and handled in check().
     """
@@ -91,11 +93,14 @@ class NannyNag(Exception):
         """
         return self.line
 
-def check(file):
+
+def check(file, text=""):
     """
-    Private function to check one Python source file for whitespace related problems.
+    Private function to check one Python source file for whitespace related
+    problems.
     
     @param file source filename (string)
+    @param text source text (string)
     @return A tuple indicating status (True = an error was found), the
         filename, the linenumber and the error message
         (boolean, string, string, string). The values are only
@@ -104,45 +109,38 @@ def check(file):
     global indents, check_equal
     indents = [Whitespace("")]
     check_equal = 0
-
-    try:
-        f = open(file)
-    except IOError, msg:
-        return (True, file, "1", "I/O Error: %s" % str(msg))
-
-    try:
-        text = Utilities.decode(f.read())[0].encode('utf-8')
-    finally:
-        f.close()
-        
-    # convert eols
-    text = Utilities.convertLineEnds(text, os.linesep)
     
-    source = cStringIO.StringIO(text)
+    if not text:
+        try:
+            text = Utilities.readEncodedFile(file)[0]
+        except (UnicodeError, IOError) as msg:
+            return (True, file, "1", "Error: {0}".format(str(msg)))
+            
+        # convert eols
+        text = Utilities.convertLineEnds(text, "\n")
+    
+    source = io.StringIO(text)
     try:
         process_tokens(tokenize.generate_tokens(source.readline))
     
-    except tokenize.TokenError, msg:
-        f.close()
-        return (True, file, "1", "Token Error: %s" % str(msg))
+    except tokenize.TokenError as msg:
+        return (True, file, "1", "Token Error: {0}".format(str(msg)))
     
-    except IndentationError, err:
-        f.close()
-        return (True, file, err.lineno, "Indentation Error: %s" % str(err.msg))
+    except IndentationError as err:
+        return (True, file, err.lineno,
+                "Indentation Error: {0}".format(str(err.msg)))
     
-    except NannyNag, nag:
+    except NannyNag as nag:
         badline = nag.get_lineno()
         line = nag.get_line()
-        f.close()
         return (True, file, str(badline), line)
     
-    except Exception, err:
-        f.close()
-        return (True, file, "1", "Unspecific Error: %s" % str(err))
+    except Exception as err:
+        return (True, file, "1", "Unspecific Error: {0}".format(str(err)))
     
-    f.close()
     return (False, None, None, None)
 
+
 class Whitespace(object):
     """
     Class implementing the whitespace checker.
@@ -175,7 +173,7 @@ class Whitespace(object):
         
         @param ws The string to be checked.
         """
-        self.raw  = ws
+        self.raw = ws
         S, T = Whitespace.S, Whitespace.T
         count = []
         b = n = nt = 0
@@ -192,8 +190,8 @@ class Whitespace(object):
                 b = 0
             else:
                 break
-        self.n    = n
-        self.nt   = nt
+        self.n = n
+        self.nt = nt
         self.norm = tuple(count), b
         self.is_simple = len(count) <= 1
 
@@ -207,7 +205,7 @@ class Whitespace(object):
             preceding a tab)
         """
         count, trailing = self.norm
-        return max(len(count)-1, trailing)
+        return max(len(count) - 1, trailing)
 
     def indent_level(self, tabsize):
         """
@@ -233,14 +231,15 @@ class Whitespace(object):
         count, trailing = self.norm
         il = 0
         for i in range(tabsize, len(count)):
-            il = il + i/tabsize * count[i]
+            il = il + i / tabsize * count[i]
         return trailing + tabsize * (il + self.nt)
 
     # return true iff self.indent_level(t) == other.indent_level(t)
     # for all t >= 1
     def equal(self, other):
         """
-        Method to compare the indentation levels of two Whitespace objects for equality.
+        Method to compare the indentation levels of two Whitespace objects for
+        equality.
         
         @param other Whitespace object to compare against.
         @return True, if we compare equal against the other Whitespace object.
@@ -265,11 +264,11 @@ class Whitespace(object):
         n = max(self.longest_run_of_spaces(),
                 other.longest_run_of_spaces()) + 1
         a = []
-        for ts in range(1, n+1):
+        for ts in range(1, n + 1):
             if self.indent_level(ts) != other.indent_level(ts):
-                a.append( (ts,
-                           self.indent_level(ts),
-                           other.indent_level(ts)) )
+                a.append((ts,
+                         self.indent_level(ts),
+                         other.indent_level(ts)))
         return a
 
     # Return True iff self.indent_level(t) < other.indent_level(t)
@@ -287,8 +286,8 @@ class Whitespace(object):
     # Note that M is of the form (T*)(S*) iff len(M.norm[0]) <= 1.
     def less(self, other):
         """
-        Method to compare the indentation level against another Whitespace objects to 
-        be smaller.
+        Method to compare the indentation level against another Whitespace
+        objects to be smaller.
         
         @param other Whitespace object to compare against.
         @return True, if we compare less against the other Whitespace object.
@@ -300,7 +299,7 @@ class Whitespace(object):
         n = max(self.longest_run_of_spaces(),
                 other.longest_run_of_spaces()) + 1
         # the self.n >= other.n test already did it for ts=1
-        for ts in range(2, n+1):
+        for ts in range(2, n + 1):
             if self.indent_level(ts) >= other.indent_level(ts):
                 return False
         return True
@@ -323,13 +322,14 @@ class Whitespace(object):
         n = max(self.longest_run_of_spaces(),
                 other.longest_run_of_spaces()) + 1
         a = []
-        for ts in range(1, n+1):
+        for ts in range(1, n + 1):
             if self.indent_level(ts) >= other.indent_level(ts):
-                a.append( (ts,
-                           self.indent_level(ts),
-                           other.indent_level(ts)) )
+                a.append((ts,
+                         self.indent_level(ts),
+                         other.indent_level(ts)))
         return a
 
+
 def format_witnesses(w):
     """
     Function to format the witnesses as a readable string.
@@ -337,17 +337,19 @@ def format_witnesses(w):
     @param w A list of witnesses
     @return A formated string of the witnesses.
     """
-    firsts = map(lambda tup: str(tup[0]), w)
+    firsts = [str(tup[0]) for tup in w]
     prefix = "at tab size"
     if len(w) > 1:
         prefix = prefix + "s"
     return prefix + " " + ', '.join(firsts)
 
+
 def process_tokens(tokens):
     """
     Function processing all tokens generated by a tokenizer run.
     
     @param tokens list of tokens
+    @exception NannyNag raised to indicate an indentation error
     """
     INDENT = tokenize.INDENT
     DEDENT = tokenize.DEDENT
@@ -383,7 +385,8 @@ def process_tokens(tokens):
             # Ouch!  This assert triggers if the last line of the source
             # is indented *and* lacks a newline -- then DEDENTs pop out
             # of thin air.
-            # assert check_equal  # else no earlier NEWLINE, or an earlier INDENT
+            # assert check_equal  # else no earlier NEWLINE, or an
+            # earlier INDENT
             check_equal = 1
 
             del indents[-1]
