@@ -9,12 +9,15 @@ Module implementing a dialog to show the output of the ericapi process.
 
 import os.path
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QProcess, QTimer
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
+
+from .Ui_EricapiExecDialog import Ui_EricapiExecDialog
+
+import Preferences
 
-from Ui_EricapiExecDialog import Ui_EricapiExecDialog
 
 class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
     """
@@ -23,14 +26,14 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
     This class starts a QProcess and displays a dialog that
     shows the output of the documentation command process.
     """
-    def __init__(self, cmdname, parent = None):
+    def __init__(self, cmdname, parent=None):
         """
         Constructor
         
         @param cmdname name of the ericapi generator (string)
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setModal(True)
         self.setupUi(self)
         
@@ -44,13 +47,14 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         """
         Public slot to start the ericapi command.
         
-        @param args commandline arguments for ericapi program (QStringList)
+        @param args commandline arguments for ericapi program (list of strings)
         @param fn filename or dirname to be processed by ericapi program
-        @return flag indicating the successful start of the process
+            (string)
+        @return flag indicating the successful start of the process (boolean)
         """
         self.errorGroup.hide()
         
-        self.filename = unicode(fn)
+        self.filename = fn
         if os.path.isdir(self.filename):
             dname = os.path.abspath(self.filename)
             fname = "."
@@ -71,23 +75,22 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         self.process = QProcess()
         self.process.setWorkingDirectory(dname)
         
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__finish)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
+        self.process.finished.connect(self.__finish)
             
-        self.setWindowTitle(self.trUtf8('%1 - %2').arg(self.cmdname).arg(self.filename))
+        self.setWindowTitle(
+            self.trUtf8('{0} - {1}').format(self.cmdname, self.filename))
         self.process.start(program, args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg(program))
+                ).format(program))
         return procStarted
         
     def on_buttonBox_clicked(self, button):
@@ -111,7 +114,7 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
@@ -120,12 +123,13 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         
         self.process = None
         
-        self.contents.insertPlainText(self.trUtf8('\n%1 finished.\n').arg(self.cmdname))
+        self.contents.insertPlainText(
+            self.trUtf8('\n{0} finished.\n').format(self.cmdname))
         self.contents.ensureCursorVisible()
         
     def __readStdout(self):
         """
-        Private slot to handle the readyReadStandardOutput signal. 
+        Private slot to handle the readyReadStandardOutput signal.
         
         It reads the output of the process, formats it and inserts it into
         the contents pane.
@@ -133,13 +137,15 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            s = QString(self.process.readLine())
+            s = str(self.process.readLine(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.contents.insertPlainText(s)
             self.contents.ensureCursorVisible()
         
     def __readStderr(self):
         """
-        Private slot to handle the readyReadStandardError signal. 
+        Private slot to handle the readyReadStandardError signal.
         
         It reads the error output of the process and inserts it into the
         error pane.
@@ -148,6 +154,8 @@ class EricapiExecDialog(QDialog, Ui_EricapiExecDialog):
         
         while self.process.canReadLine():
             self.errorGroup.show()
-            s = QString(self.process.readLine())
+            s = str(self.process.readLine(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
