@@ -4,31 +4,32 @@
 #
 
 """
-Module implementing a dialog to enter the parameters for eric4_doc.
+Module implementing a dialog to enter the parameters for eric5_doc.
 """
 
 import sys
 import os
 import copy
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QColorDialog, QColor
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4DirCompleter
-
-from Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
-from DocumentationTools.Config import eric4docDefaultColors, eric4docColorParameterNames
+from .Ui_EricdocConfigDialog import Ui_EricdocConfigDialog
+from DocumentationTools.Config import eric5docDefaultColors, \
+    eric5docColorParameterNames
 import Utilities
 
-from eric4config import getConfig
+from eric5config import getConfig
+
 
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     """
-    Class implementing a dialog to enter the parameters for eric4_doc.
+    Class implementing a dialog to enter the parameters for eric5_doc.
     """
-    def __init__(self, project, parms = None, parent = None):
+    def __init__(self, project, parms=None, parent=None):
         """
         Constructor
         
@@ -36,50 +37,63 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         @param parms parameters to set in the dialog
         @param parent parent widget of this dialog
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.__okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         
         self.__initializeDefaults()
         
-        self.sampleText = unicode(self.trUtf8(\
+        self.sampleText = self.trUtf8(
             '''<?xml version="1.0" encoding="utf-8"?>'''
             '''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"'''
             '''"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'''
             '''<html><head>'''
-            '''<title>%%(Title)s</title>'''
+            '''<title></title>'''
             '''</head>'''
-            '''<body style="background-color:%(BodyBgColor)s;color:%(BodyColor)s">'''
-            '''<h1 style="background-color:%(Level1HeaderBgColor)s;color:%(Level1HeaderColor)s">'''
+            '''<body style="background-color:{BodyBgColor};'''
+            '''color:{BodyColor}">'''
+            '''<h1 style="background-color:{Level1HeaderBgColor};'''
+            '''color:{Level1HeaderColor}">'''
             '''Level 1 Header</h1>'''
-            '''<h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">'''
+            '''<h3 style="background-color:{Level2HeaderBgColor};'''
+            '''color:{Level2HeaderColor}">'''
             '''Level 2 Header</h3>'''
-            '''<h2 style="background-color:%(CFBgColor)s;color:%(CFColor)s">'''
+            '''<h2 style="background-color:{CFBgColor};color:{CFColor}">'''
             '''Class and Function Header</h2>'''
             '''Standard body text with '''
-            '''<a style="color:%(LinkColor)s">some links</a> embedded.'''
+            '''<a style="color:{LinkColor}">some links</a> embedded.'''
             '''</body></html>'''
-        ))
+        )
         
         # get a copy of the defaults to store the user settings
         self.parameters = copy.deepcopy(self.defaults)
-        self.colors = eric4docDefaultColors.copy()
+        self.colors = eric5docDefaultColors.copy()
         
         # combine it with the values of parms
         if parms is not None:
-            for key, value in parms.items():
+            for key, value in list(parms.items()):
                 if key.endswith("Color"):
                     self.colors[key] = parms[key]
                 else:
                     self.parameters[key] = parms[key]
+        self.parameters['outputDirectory'] = \
+            Utilities.toNativeSeparators(self.parameters['outputDirectory'])
+        self.parameters['qtHelpOutputDirectory'] = \
+            Utilities.toNativeSeparators(
+                self.parameters['qtHelpOutputDirectory'])
+        self.parameters['cssFile'] = \
+            Utilities.toNativeSeparators(self.parameters['cssFile'])
+        if self.parameters['cssFile'].startswith("%PYTHON%"):
+            self.parameters['cssFile'] = self.parameters['cssFile'].replace(
+                "%PYTHON%", Utilities.getPythonModulesDirectory())
         
         self.ppath = project.getProjectPath()
         self.project = project
         
-        self.outputDirCompleter = E4DirCompleter(self.outputDirEdit)
-        self.ignoreDirCompleter = E4DirCompleter(self.ignoreDirEdit)
-        self.qtHelpDirCompleter = E4DirCompleter(self.qtHelpDirEdit)
+        self.outputDirCompleter = E5DirCompleter(self.outputDirEdit)
+        self.ignoreDirCompleter = E5DirCompleter(self.ignoreDirEdit)
+        self.qtHelpDirCompleter = E5DirCompleter(self.qtHelpDirEdit)
         
         self.recursionCheckBox.setChecked(self.parameters['useRecursion'])
         self.noindexCheckBox.setChecked(self.parameters['noindex'])
@@ -89,85 +103,97 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         for d in self.parameters['ignoreDirectories']:
             self.ignoreDirsList.addItem(d)
         self.cssEdit.setText(self.parameters['cssFile'])
-        self.sourceExtEdit.setText(", ".join(self.parameters['sourceExtensions']))
-        self.excludeFilesEdit.setText(", ".join(self.parameters['ignoreFilePatterns']))
-        self.sample.setHtml(self.sampleText % self.colors)
+        self.sourceExtEdit.setText(
+            ", ".join(self.parameters['sourceExtensions']))
+        self.excludeFilesEdit.setText(
+            ", ".join(self.parameters['ignoreFilePatterns']))
+        self.sample.setHtml(self.sampleText.format(**self.colors))
         
         self.qtHelpGroup.setChecked(self.parameters['qtHelpEnabled'])
         self.qtHelpDirEdit.setText(self.parameters['qtHelpOutputDirectory'])
         self.qtHelpNamespaceEdit.setText(self.parameters['qtHelpNamespace'])
         self.qtHelpFolderEdit.setText(self.parameters['qtHelpVirtualFolder'])
         self.qtHelpFilterNameEdit.setText(self.parameters['qtHelpFilterName'])
-        self.qtHelpFilterAttributesEdit.setText(self.parameters['qtHelpFilterAttributes'])
+        self.qtHelpFilterAttributesEdit.setText(
+            self.parameters['qtHelpFilterAttributes'])
         self.qtHelpTitleEdit.setText(self.parameters['qtHelpTitle'])
         self.qtHelpGenerateCollectionCheckBox.setChecked(
             self.parameters['qtHelpCreateCollection'])
     
     def __initializeDefaults(self):
         """
-        Private method to set the default values. 
+        Private method to set the default values.
         
         These are needed later on to generate the commandline
         parameters.
         """
         self.defaults = {
-            'useRecursion' : 0,
-            'noindex' : 0,
-            'noempty' : 0,
-            'outputDirectory' : '',
-            'ignoreDirectories' : [],
-            'ignoreFilePatterns' : [],
-            'cssFile' : '',
-            'sourceExtensions' : [],
+            'useRecursion': 0,
+            'noindex': 0,
+            'noempty': 0,
+            'outputDirectory': '',
+            'ignoreDirectories': [],
+            'ignoreFilePatterns': [],
+            'cssFile': '',
+            'sourceExtensions': [],
             
-            'qtHelpEnabled' : False, 
-            'qtHelpOutputDirectory' : '', 
-            'qtHelpNamespace' : '', 
-            'qtHelpVirtualFolder' : 'source', 
-            'qtHelpFilterName' : 'unknown', 
-            'qtHelpFilterAttributes' : '', 
-            'qtHelpTitle' : '', 
-            'qtHelpCreateCollection' : False, 
+            'qtHelpEnabled': False,
+            'qtHelpOutputDirectory': '',
+            'qtHelpNamespace': '',
+            'qtHelpVirtualFolder': 'source',
+            'qtHelpFilterName': 'unknown',
+            'qtHelpFilterAttributes': '',
+            'qtHelpTitle': '',
+            'qtHelpCreateCollection': False,
         }
     
     def generateParameters(self):
         """
         Public method that generates the commandline parameters.
         
-        It generates a QStringList to be used
+        It generates a list of strings to be used
         to set the QProcess arguments for the ericdoc call and
-        a list containing the non default parameters. The second
-        list can be passed back upon object generation to overwrite
+        a dictionary containing the non default parameters. This
+        dictionary can be passed back upon object generation to overwrite
         the default settings.
         
-        @return a tuple of the commandline parameters and non default parameters
-            (QStringList, dictionary)
+        @return a tuple of the commandline parameters and non default
+            parameters (list of strings, dictionary)
         """
         parms = {}
-        args = QStringList()
+        args = []
         
         # 1. the program name
         args.append(sys.executable)
-        args.append(Utilities.normabsjoinpath(getConfig('ericDir'), "eric4_doc.py"))
+        args.append(
+            Utilities.normabsjoinpath(getConfig('ericDir'), "eric5_doc.py"))
         
         # 2. the commandline options
         # 2a. general commandline options
-        if self.parameters['outputDirectory'] != self.defaults['outputDirectory']:
-            parms['outputDirectory'] = self.parameters['outputDirectory']
+        if self.parameters['outputDirectory'] != \
+                self.defaults['outputDirectory']:
+            parms['outputDirectory'] = Utilities.fromNativeSeparators(
+                self.project.getRelativePath(
+                    self.parameters['outputDirectory']))
             args.append('-o')
             if os.path.isabs(self.parameters['outputDirectory']):
                 args.append(self.parameters['outputDirectory'])
             else:
-                args.append(os.path.join(self.ppath, self.parameters['outputDirectory']))
-        if self.parameters['ignoreDirectories'] != self.defaults['ignoreDirectories']:
-            parms['ignoreDirectories'] = self.parameters['ignoreDirectories'][:]
+                args.append(os.path.join(
+                    self.ppath, self.parameters['outputDirectory']))
+        if self.parameters['ignoreDirectories'] != \
+                self.defaults['ignoreDirectories']:
+            parms['ignoreDirectories'] = \
+                self.parameters['ignoreDirectories'][:]
             for d in self.parameters['ignoreDirectories']:
                 args.append('-x')
                 args.append(d)
-        if self.parameters['ignoreFilePatterns'] != self.defaults['ignoreFilePatterns']:
-            parms['ignoreFilePatterns'] = self.parameters['ignoreFilePatterns'][:]
+        if self.parameters['ignoreFilePatterns'] != \
+                self.defaults['ignoreFilePatterns']:
+            parms['ignoreFilePatterns'] = \
+                self.parameters['ignoreFilePatterns'][:]
             for pattern in self.parameters['ignoreFilePatterns']:
-                args.append("--exclude-file=%s" % pattern)
+                args.append("--exclude-file={0}".format(pattern))
         if self.parameters['useRecursion'] != self.defaults['useRecursion']:
             parms['useRecursion'] = self.parameters['useRecursion']
             args.append('-r')
@@ -177,7 +203,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if self.parameters['noempty'] != self.defaults['noempty']:
             parms['noempty'] = self.parameters['noempty']
             args.append('-e')
-        if self.parameters['sourceExtensions'] != self.defaults['sourceExtensions']:
+        if self.parameters['sourceExtensions'] != \
+                self.defaults['sourceExtensions']:
             parms['sourceExtensions'] = self.parameters['sourceExtensions'][:]
             for ext in self.parameters['sourceExtensions']:
                 args.append('-t')
@@ -185,17 +212,22 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         
         # 2b. style commandline options
         if self.parameters['cssFile'] != self.defaults['cssFile']:
-            parms['cssFile'] = self.parameters['cssFile']
+            cssFile = self.project.getRelativePath(self.parameters['cssFile'])
+            if cssFile.startswith(Utilities.getPythonModulesDirectory()):
+                cssFile = cssFile.replace(
+                    Utilities.getPythonModulesDirectory(), "%PYTHON%")
+            parms['cssFile'] = Utilities.fromNativeSeparators(cssFile)
             args.append('-c')
             if os.path.isabs(self.parameters['cssFile']):
                 args.append(self.parameters['cssFile'])
             else:
-                args.append(os.path.join(self.ppath, self.parameters['cssFile']))
-        for key, value in self.colors.items():
-            if self.colors[key] != eric4docDefaultColors[key]:
+                args.append(
+                    os.path.join(self.ppath, self.parameters['cssFile']))
+        for key, value in list(self.colors.items()):
+            if self.colors[key] != eric5docDefaultColors[key]:
                 parms[key] = self.colors[key]
-                args.append("--%s=%s" % \
-                            (eric4docColorParameterNames[key], self.colors[key]))
+                args.append("--{0}={1}".format(
+                    eric5docColorParameterNames[key], self.colors[key]))
         
         # 2c. QtHelp commandline options
         parms['qtHelpEnabled'] = self.parameters['qtHelpEnabled']
@@ -203,37 +235,51 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
             args.append('--create-qhp')
         if self.parameters['qtHelpOutputDirectory'] != \
            self.defaults['qtHelpOutputDirectory']:
-            parms['qtHelpOutputDirectory'] = self.parameters['qtHelpOutputDirectory']
+            parms['qtHelpOutputDirectory'] = Utilities.fromNativeSeparators(
+                self.project.getRelativePath(
+                    self.parameters['qtHelpOutputDirectory']))
             if os.path.isabs(self.parameters['outputDirectory']):
-                args.append("--qhp-outdir=%s" % self.parameters['qtHelpOutputDirectory'])
+                args.append("--qhp-outdir={0}".format(
+                    self.parameters['qtHelpOutputDirectory']))
             else:
-                args.append("--qhp-outdir=%s" % \
-                    os.path.join(self.ppath, self.parameters['qtHelpOutputDirectory']))
-        if self.parameters['qtHelpNamespace'] != self.defaults['qtHelpNamespace']:
+                args.append("--qhp-outdir={0}".format(
+                    os.path.join(self.ppath,
+                                 self.parameters['qtHelpOutputDirectory'])))
+        if self.parameters['qtHelpNamespace'] != \
+                self.defaults['qtHelpNamespace']:
             parms['qtHelpNamespace'] = self.parameters['qtHelpNamespace']
-            args.append("--qhp-namespace=%s" % self.parameters['qtHelpNamespace'])
-        if self.parameters['qtHelpVirtualFolder'] != self.defaults['qtHelpVirtualFolder']:
-            parms['qtHelpVirtualFolder'] = self.parameters['qtHelpVirtualFolder']
-            args.append("--qhp-virtualfolder=%s" % self.parameters['qtHelpVirtualFolder'])
-        if self.parameters['qtHelpFilterName'] != self.defaults['qtHelpFilterName']:
+            args.append("--qhp-namespace={0}".format(
+                self.parameters['qtHelpNamespace']))
+        if self.parameters['qtHelpVirtualFolder'] != \
+                self.defaults['qtHelpVirtualFolder']:
+            parms['qtHelpVirtualFolder'] = \
+                self.parameters['qtHelpVirtualFolder']
+            args.append("--qhp-virtualfolder={0}".format(
+                self.parameters['qtHelpVirtualFolder']))
+        if self.parameters['qtHelpFilterName'] != \
+                self.defaults['qtHelpFilterName']:
             parms['qtHelpFilterName'] = self.parameters['qtHelpFilterName']
-            args.append("--qhp-filtername=%s" % self.parameters['qtHelpFilterName'])
+            args.append("--qhp-filtername={0}".format(
+                self.parameters['qtHelpFilterName']))
         if self.parameters['qtHelpFilterAttributes'] != \
            self.defaults['qtHelpFilterAttributes']:
-            parms['qtHelpFilterAttributes'] = self.parameters['qtHelpFilterAttributes']
-            args.append("--qhp-filterattribs=%s" % \
-                self.parameters['qtHelpFilterAttributes'])
+            parms['qtHelpFilterAttributes'] = \
+                self.parameters['qtHelpFilterAttributes']
+            args.append("--qhp-filterattribs={0}".format(
+                self.parameters['qtHelpFilterAttributes']))
         if self.parameters['qtHelpTitle'] != self.defaults['qtHelpTitle']:
             parms['qtHelpTitle'] = self.parameters['qtHelpTitle']
-            args.append("--qhp-title=%s" % self.parameters['qtHelpTitle'])
+            args.append("--qhp-title={0}".format(
+                self.parameters['qtHelpTitle']))
         if self.parameters['qtHelpCreateCollection'] != \
            self.defaults['qtHelpCreateCollection']:
-            parms['qtHelpCreateCollection'] = self.parameters['qtHelpCreateCollection']
+            parms['qtHelpCreateCollection'] = \
+                self.parameters['qtHelpCreateCollection']
             args.append('--create-qhc')
         
         return (args, parms)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_outputDirButton_clicked(self):
         """
         Private slot to select the output directory.
@@ -241,21 +287,21 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         It displays a directory selection dialog to
         select the directory the documentations is written to.
         """
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select output directory"),
             self.outputDirEdit.text(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-        if not directory.isNull():
-            # make it relative, if it is a subdirectory of the project path 
-            dn = unicode(Utilities.toNativeSeparators(directory))
+        if directory:
+            # make it relative, if it is a subdirectory of the project path
+            dn = Utilities.toNativeSeparators(directory)
             dn = self.project.getRelativePath(dn)
             while dn.endswith(os.sep):
                 dn = dn[:-1]
             self.outputDirEdit.setText(dn)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_ignoreDirButton_clicked(self):
         """
         Private slot to select a directory to be ignored.
@@ -264,23 +310,23 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         select a directory to be ignored.
         """
         startDir = self.ignoreDirEdit.text()
-        if startDir.isEmpty():
+        if not startDir:
             startDir = self.ppath
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select directory to exclude"),
             startDir,
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-        if not directory.isNull():
-            # make it relative, if it is a subdirectory of the project path 
-            dn = unicode(Utilities.toNativeSeparators(directory))
+        if directory:
+            # make it relative, if it is a subdirectory of the project path
+            dn = Utilities.toNativeSeparators(directory)
             dn = self.project.getRelativePath(dn)
             while dn.endswith(os.sep):
                 dn = dn[:-1]
             self.ignoreDirEdit.setText(dn)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add the directory displayed to the listview.
@@ -288,12 +334,12 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         The directory in the ignore directories
         line edit is moved to the listbox above and the edit is cleared.
         """
-        basename = os.path.basename(unicode(self.ignoreDirEdit.text()))
+        basename = os.path.basename(self.ignoreDirEdit.text())
         if basename:
             self.ignoreDirsList.addItem(basename)
             self.ignoreDirEdit.clear()
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteButton_clicked(self):
         """
         Private slot to delete the currently selected directory of the listbox.
@@ -301,20 +347,20 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         itm = self.ignoreDirsList.takeItem(self.ignoreDirsList.currentRow())
         del itm
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_cssButton_clicked(self):
         """
         Private slot to select a css style sheet.
         """
-        cssFile = KQFileDialog.getOpenFileName(\
+        cssFile = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select CSS style sheet"),
             getConfig('ericCSSDir'),
             self.trUtf8("Style sheet (*.css);;All files (*)"))
             
-        if not cssFile.isEmpty():
-            # make it relative, if it is in a subdirectory of the project path 
-            cf = unicode(Utilities.toNativeSeparators(cssFile))
+        if cssFile:
+            # make it relative, if it is in a subdirectory of the project path
+            cf = Utilities.toNativeSeparators(cssFile)
             cf = self.project.getRelativePath(cf)
             self.cssEdit.setText(cf)
 
@@ -326,66 +372,66 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         color = QColorDialog.getColor(QColor(self.colors[colorKey]))
         if color.isValid():
-            self.colors[colorKey] = unicode(color.name())
-            self.sample.setHtml(self.sampleText % self.colors)
+            self.colors[colorKey] = color.name()
+            self.sample.setHtml(self.sampleText.format(self.colors))
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_bodyFgButton_clicked(self):
         """
         Private slot to select the body foreground color.
         """
         self.__selectColor('BodyColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_bodyBgButton_clicked(self):
         """
         Private slot to select the body background color.
         """
         self.__selectColor('BodyBgColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_l1FgButton_clicked(self):
         """
         Private slot to select the level 1 header foreground color.
         """
         self.__selectColor('Level1HeaderColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_l1BgButton_clicked(self):
         """
         Private slot to select the level 1 header background color.
         """
         self.__selectColor('Level1HeaderBgColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_l2FgButton_clicked(self):
         """
         Private slot to select the level 2 header foreground color.
         """
         self.__selectColor('Level2HeaderColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_l2BgButton_clicked(self):
         """
         Private slot to select the level 2 header background color.
         """
         self.__selectColor('Level2HeaderBgColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_cfFgButton_clicked(self):
         """
         Private slot to select the class/function header foreground color.
         """
         self.__selectColor('CFColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_cfBgButton_clicked(self):
         """
         Private slot to select the class/function header background color.
         """
         self.__selectColor('CFBgColor')
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_linkFgButton_clicked(self):
         """
         Private slot to select the foreground color of links.
@@ -394,23 +440,24 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     
     def __checkQtHelpOptions(self):
         """
-        Private slot to check the QtHelp options and set the ok button accordingly.
+        Private slot to check the QtHelp options and set the ok button
+        accordingly.
         """
         setOn = True
         if self.qtHelpGroup.isChecked():
-            if self.qtHelpNamespaceEdit.text().isEmpty():
+            if not self.qtHelpNamespaceEdit.text():
                 setOn = False
-            if self.qtHelpFolderEdit.text().isEmpty():
+            if not self.qtHelpFolderEdit.text():
                 setOn = False
             else:
                 if '/' in self.qtHelpFolderEdit.text():
                     setOn = False
-            if self.qtHelpTitleEdit.text().isEmpty():
+            if not self.qtHelpTitleEdit.text():
                 setOn = False
         
         self.__okButton.setEnabled(setOn)
     
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_qtHelpGroup_toggled(self, enabled):
         """
         Private slot to toggle the generation of QtHelp files.
@@ -419,34 +466,34 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         """
         self.__checkQtHelpOptions()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_qtHelpNamespaceEdit_textChanged(self, txt):
         """
         Private slot to check the namespace.
         
-        @param txt text of the line edit (QString)
+        @param txt text of the line edit (string)
         """
         self.__checkQtHelpOptions()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_qtHelpFolderEdit_textChanged(self, txt):
         """
         Private slot to check the virtual folder.
         
-        @param txt text of the line edit (QString)
+        @param txt text of the line edit (string)
         """
         self.__checkQtHelpOptions()
     
-    @pyqtSignature("QString")
-    def on_qtHelpTitleEdit_textChanged(self, p0):
+    @pyqtSlot(str)
+    def on_qtHelpTitleEdit_textChanged(self, txt):
         """
         Private slot to check the title.
         
-        @param txt text of the line edit (QString)
+        @param txt text of the line edit (string)
         """
         self.__checkQtHelpOptions()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_qtHelpDirButton_clicked(self):
         """
         Private slot to select the output directory for the QtHelp files.
@@ -454,15 +501,15 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         It displays a directory selection dialog to
         select the directory the QtHelp files are written to.
         """
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select output directory for QtHelp files"),
             self.qtHelpDirEdit.text(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-        if not directory.isNull():
-            # make it relative, if it is a subdirectory of the project path 
-            dn = unicode(Utilities.toNativeSeparators(directory))
+        if directory:
+            # make it relative, if it is a subdirectory of the project path
+            dn = Utilities.toNativeSeparators(directory)
             dn = self.project.getRelativePath(dn)
             while dn.endswith(os.sep):
                 dn = dn[:-1]
@@ -470,14 +517,14 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     
     def accept(self):
         """
-        Protected slot called by the Ok button. 
+        Protected slot called by the Ok button.
         
         It saves the values in the parameters dictionary.
         """
         self.parameters['useRecursion'] = self.recursionCheckBox.isChecked()
         self.parameters['noindex'] = self.noindexCheckBox.isChecked()
         self.parameters['noempty'] = self.noemptyCheckBox.isChecked()
-        outdir = unicode(self.outputDirEdit.text())
+        outdir = self.outputDirEdit.text()
         if outdir != '':
             outdir = os.path.normpath(outdir)
             if outdir.endswith(os.sep):
@@ -486,29 +533,29 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         self.parameters['ignoreDirectories'] = []
         for row in range(0, self.ignoreDirsList.count()):
             itm = self.ignoreDirsList.item(row)
-            self.parameters['ignoreDirectories'].append(\
-                os.path.normpath(unicode(itm.text())))
-        cssFile = unicode(self.cssEdit.text())
+            self.parameters['ignoreDirectories'].append(
+                os.path.normpath(itm.text()))
+        cssFile = self.cssEdit.text()
         if cssFile != '':
             cssFile = os.path.normpath(cssFile)
         self.parameters['cssFile'] = cssFile
-        extensions = unicode(self.sourceExtEdit.text()).split(',')
+        extensions = self.sourceExtEdit.text().split(',')
         self.parameters['sourceExtensions'] = \
             [ext.strip() for ext in extensions]
-        patterns = unicode(self.excludeFilesEdit.text()).split(',')
+        patterns = self.excludeFilesEdit.text().split(',')
         self.parameters['ignoreFilePatterns'] = \
             [pattern.strip() for pattern in patterns]
         
         self.parameters['qtHelpEnabled'] = self.qtHelpGroup.isChecked()
-        self.parameters['qtHelpOutputDirectory'] = unicode(self.qtHelpDirEdit.text())
-        self.parameters['qtHelpNamespace'] = unicode(self.qtHelpNamespaceEdit.text())
-        self.parameters['qtHelpVirtualFolder'] = unicode(self.qtHelpFolderEdit.text())
-        self.parameters['qtHelpFilterName'] = unicode(self.qtHelpFilterNameEdit.text())
+        self.parameters['qtHelpOutputDirectory'] = self.qtHelpDirEdit.text()
+        self.parameters['qtHelpNamespace'] = self.qtHelpNamespaceEdit.text()
+        self.parameters['qtHelpVirtualFolder'] = self.qtHelpFolderEdit.text()
+        self.parameters['qtHelpFilterName'] = self.qtHelpFilterNameEdit.text()
         self.parameters['qtHelpFilterAttributes'] = \
-            unicode(self.qtHelpFilterAttributesEdit.text())
-        self.parameters['qtHelpTitle'] = unicode(self.qtHelpTitleEdit.text())
+            self.qtHelpFilterAttributesEdit.text()
+        self.parameters['qtHelpTitle'] = self.qtHelpTitleEdit.text()
         self.parameters['qtHelpCreateCollection'] = \
             self.qtHelpGenerateCollectionCheckBox.isChecked()
         
         # call the accept slot of the base class
-        QDialog.accept(self)
+        super().accept()
