@@ -7,31 +7,30 @@
 Module implementing the About plugin.
 """
 
-from PyQt4.QtCore import QObject, SIGNAL, QString
-from PyQt4.QtGui import QMessageBox, QAction
+from PyQt4.QtCore import QObject
+from PyQt4.QtGui import QAction
 
-import KdeQt
-
-from UI.Info import *
+import UI.Info
 import UI.PixmapCache
 
-from E4Gui.E4Action import E4Action
-
-from AboutPlugin.AboutDialog import AboutDialog
+from E5Gui.E5Action import E5Action
+from E5Gui import E5MessageBox
 
 # Start-Of-Header
 name = "About Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.4.0"
+version = "5.4.0"
 className = "AboutPlugin"
 packageName = "__core__"
 shortDescription = "Show the About dialogs."
 longDescription = """This plugin shows the About dialogs."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 class AboutPlugin(QObject):
     """
@@ -43,7 +42,7 @@ class AboutPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        QObject.__init__(self, ui)
+        super().__init__(ui)
         self.__ui = ui
 
     def activate(self):
@@ -65,12 +64,8 @@ class AboutPlugin(QObject):
         if menu:
             menu.removeAction(self.aboutAct)
             menu.removeAction(self.aboutQtAct)
-            if self.aboutKdeAct is not None:
-                menu.removeAction(self.aboutKdeAct)
         acts = [self.aboutAct, self.aboutQtAct]
-        if self.aboutKdeAct is not None:
-            acts.append(self.aboutKdeAct)
-        self.__ui.removeE4Actions(acts, 'ui')
+        self.__ui.removeE5Actions(acts, 'ui')
     
     def __initActions(self):
         """
@@ -78,47 +73,36 @@ class AboutPlugin(QObject):
         """
         acts = []
         
-        self.aboutAct = E4Action(self.trUtf8('About %1').arg(Program),
-                UI.PixmapCache.getIcon("helpAbout.png"),
-                self.trUtf8('&About %1').arg(Program),
-                0, 0, self, 'about_eric')
-        self.aboutAct.setStatusTip(self.trUtf8('Display information about this software'))
+        self.aboutAct = E5Action(
+            self.trUtf8('About {0}').format(UI.Info.Program),
+            UI.PixmapCache.getIcon("helpAbout.png"),
+            self.trUtf8('&About {0}').format(UI.Info.Program),
+            0, 0, self, 'about_eric')
+        self.aboutAct.setStatusTip(self.trUtf8(
+            'Display information about this software'))
         self.aboutAct.setWhatsThis(self.trUtf8(
-            """<b>About %1</b>"""
+            """<b>About {0}</b>"""
             """<p>Display some information about this software.</p>"""
-                             ).arg(Program))
-        self.connect(self.aboutAct, SIGNAL('triggered()'), self.__about)
+        ).format(UI.Info.Program))
+        self.aboutAct.triggered[()].connect(self.__about)
         self.aboutAct.setMenuRole(QAction.AboutRole)
         acts.append(self.aboutAct)
         
-        self.aboutQtAct = E4Action(self.trUtf8('About Qt'),
-                UI.PixmapCache.getIcon("helpAboutQt.png"),
-                self.trUtf8('About &Qt'), 0, 0, self, 'about_qt')
-        self.aboutQtAct.setStatusTip(\
+        self.aboutQtAct = E5Action(
+            self.trUtf8('About Qt'),
+            UI.PixmapCache.getIcon("helpAboutQt.png"),
+            self.trUtf8('About &Qt'), 0, 0, self, 'about_qt')
+        self.aboutQtAct.setStatusTip(
             self.trUtf8('Display information about the Qt toolkit'))
         self.aboutQtAct.setWhatsThis(self.trUtf8(
             """<b>About Qt</b>"""
             """<p>Display some information about the Qt toolkit.</p>"""
         ))
-        self.connect(self.aboutQtAct, SIGNAL('triggered()'), self.__aboutQt)
+        self.aboutQtAct.triggered[()].connect(self.__aboutQt)
         self.aboutQtAct.setMenuRole(QAction.AboutQtRole)
         acts.append(self.aboutQtAct)
         
-        if KdeQt.isKDE():
-            self.aboutKdeAct = E4Action(self.trUtf8('About KDE'),
-                    UI.PixmapCache.getIcon("helpAboutKde.png"),
-                    self.trUtf8('About &KDE'), 0, 0, self, 'about_kde')
-            self.aboutKdeAct.setStatusTip(self.trUtf8('Display information about KDE'))
-            self.aboutKdeAct.setWhatsThis(self.trUtf8(
-                """<b>About KDE</b>"""
-                """<p>Display some information about KDE.</p>"""
-            ))
-            self.connect(self.aboutKdeAct, SIGNAL('triggered()'), self.__aboutKde)
-            acts.append(self.aboutKdeAct)
-        else:
-            self.aboutKdeAct = None
-        
-        self.__ui.addE4Actions(acts, 'ui')
+        self.__ui.addE5Actions(acts, 'ui')
 
     def __initMenu(self):
         """
@@ -130,18 +114,15 @@ class AboutPlugin(QObject):
             if act:
                 menu.insertAction(act, self.aboutAct)
                 menu.insertAction(act, self.aboutQtAct)
-                if self.aboutKdeAct is not None:
-                    menu.insertAction(act, self.aboutKdeAct)
             else:
                 menu.addAction(self.aboutAct)
                 menu.addAction(self.aboutQtAct)
-                if self.aboutKdeAct is not None:
-                    menu.addAction(self.aboutKdeAct)
     
     def __about(self):
         """
         Private slot to handle the About dialog.
         """
+        from AboutPlugin.AboutDialog import AboutDialog
         dlg = AboutDialog(self.__ui)
         dlg.exec_()
         
@@ -149,12 +130,4 @@ class AboutPlugin(QObject):
         """
         Private slot to handle the About Qt dialog.
         """
-        QMessageBox.aboutQt(self.__ui, Program)
-        
-    def __aboutKde(self):
-        """
-        Private slot to handle the About KDE dialog.
-        """
-        from PyKDE4.kdeui import KHelpMenu
-        menu = KHelpMenu(self.__ui)
-        menu.aboutKDE()
+        E5MessageBox.aboutQt(self.__ui, UI.Info.Program)
