@@ -8,37 +8,35 @@ Module implementing the Ericapi plugin.
 """
 
 import os
-import sys
-import copy
 
-from PyQt4.QtCore import QObject, SIGNAL, QString
+from PyQt4.QtCore import QObject
 from PyQt4.QtGui import QDialog, QApplication
 
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
-from E4Gui.E4Action import E4Action
-
-from DocumentationPlugins.Ericapi.EricapiConfigDialog import EricapiConfigDialog
-from DocumentationPlugins.Ericapi.EricapiExecDialog import EricapiExecDialog
+from E5Gui.E5Action import E5Action
 
 import Utilities
 
-from eric4config import getConfig
+from eric5config import getConfig
 
 # Start-Of-Header
 name = "Ericapi Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.4.0"
+version = "5.4.0"
 className = "EricapiPlugin"
 packageName = "__core__"
 shortDescription = "Show the Ericapi dialogs."
 longDescription = """This plugin implements the Ericapi dialogs.""" \
- """ Ericapi is used to generate a QScintilla API file for Python and Ruby projects."""
+    """ Ericapi is used to generate a QScintilla API file for Python and""" \
+    """ Ruby projects."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 def exeDisplayData():
     """
@@ -47,24 +45,25 @@ def exeDisplayData():
     @return dictionary containing the data to query the presence of
         the executable
     """
-    exe = 'eric4_api'
+    exe = 'eric5_api'
     if Utilities.isWindowsPlatform():
-        exe = os.path.join(getConfig("bindir"), exe +'.bat')
+        exe = os.path.join(getConfig("bindir"), exe + '.bat')
     
     data = {
-        "programEntry"      : True, 
-        "header"            : QApplication.translate("EricapiPlugin",
-                                "Eric4 API File Generator"), 
-        "exe"               : exe, 
-        "versionCommand"    : '--version', 
-        "versionStartsWith" : 'eric4_', 
-        "versionPosition"   : -2, 
-        "version"           : "", 
-        "versionCleanup"    : None, 
+        "programEntry": True,
+        "header": QApplication.translate(
+            "EricapiPlugin", "Eric5 API File Generator"),
+        "exe": exe,
+        "versionCommand": '--version',
+        "versionStartsWith": 'eric5_',
+        "versionPosition": -3,
+        "version": "",
+        "versionCleanup": None,
     }
     
     return data
 
+
 class EricapiPlugin(QObject):
     """
     Class implementing the Ericapi plugin.
@@ -75,7 +74,7 @@ class EricapiPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        QObject.__init__(self, ui)
+        super().__init__(ui)
         self.__ui = ui
         self.__initialize()
         
@@ -91,23 +90,23 @@ class EricapiPlugin(QObject):
         
         @return tuple of None and activation status (boolean)
         """
-        menu = e4App().getObject("Project").getMenu("Apidoc")
+        menu = e5App().getObject("Project").getMenu("Apidoc")
         if menu:
-            self.__projectAct = E4Action(self.trUtf8('Generate API file (eric4_api)'),
-                    self.trUtf8('Generate &API file (eric4_api)'), 0, 0,
-                    self, 'doc_eric4_api')
-            self.__projectAct.setStatusTip(\
-                self.trUtf8('Generate an API file using eric4_api'))
+            self.__projectAct = E5Action(
+                self.trUtf8('Generate API file (eric5_api)'),
+                self.trUtf8('Generate &API file (eric5_api)'), 0, 0,
+                self, 'doc_eric5_api')
+            self.__projectAct.setStatusTip(self.trUtf8(
+                'Generate an API file using eric5_api'))
             self.__projectAct.setWhatsThis(self.trUtf8(
                 """<b>Generate API file</b>"""
-                """<p>Generate an API file using eric4_api.</p>"""
+                """<p>Generate an API file using eric5_api.</p>"""
             ))
-            self.connect(self.__projectAct, SIGNAL('triggered()'), self.__doEricapi)
-            e4App().getObject("Project").addE4Actions([self.__projectAct])
+            self.__projectAct.triggered[()].connect(self.__doEricapi)
+            e5App().getObject("Project").addE5Actions([self.__projectAct])
             menu.addAction(self.__projectAct)
         
-        self.connect(e4App().getObject("Project"), SIGNAL("showMenu"), 
-                     self.__projectShowMenu)
+        e5App().getObject("Project").showMenu.connect(self.__projectShowMenu)
         
         return None, True
 
@@ -115,18 +114,18 @@ class EricapiPlugin(QObject):
         """
         Public method to deactivate this plugin.
         """
-        self.disconnect(e4App().getObject("Project"), SIGNAL("showMenu"), 
-                        self.__projectShowMenu)
+        e5App().getObject("Project").showMenu.disconnect(
+            self.__projectShowMenu)
         
-        menu = e4App().getObject("Project").getMenu("Apidoc")
+        menu = e5App().getObject("Project").getMenu("Apidoc")
         if menu:
             menu.removeAction(self.__projectAct)
-            e4App().getObject("Project").removeE4Actions([self.__projectAct])
+            e5App().getObject("Project").removeE5Actions([self.__projectAct])
         self.__initialize()
     
     def __projectShowMenu(self, menuName, menu):
         """
-        Private slot called, when the the project menu or a submenu is 
+        Private slot called, when the the project menu or a submenu is
         about to be shown.
         
         @param menuName name of the menu to be shown (string)
@@ -134,29 +133,43 @@ class EricapiPlugin(QObject):
         """
         if menuName == "Apidoc":
             if self.__projectAct is not None:
-                self.__projectAct.setEnabled(\
-                    e4App().getObject("Project").getProjectLanguage() in \
-                        ["Python", "Python3", "Ruby"])
+                self.__projectAct.setEnabled(
+                    e5App().getObject("Project").getProjectLanguage() in
+                    ["Python", "Python2", "Python3", "Ruby"])
     
     def __doEricapi(self):
         """
-        Private slot to perform the eric4_api api generation.
+        Private slot to perform the eric5_api api generation.
         """
-        project = e4App().getObject("Project")
+        from DocumentationPlugins.Ericapi.EricapiConfigDialog import \
+            EricapiConfigDialog
+        eolTranslation = {
+            '\r': 'cr',
+            '\n': 'lf',
+            '\r\n': 'crlf',
+        }
+        project = e5App().getObject("Project")
         parms = project.getData('DOCUMENTATIONPARMS', "ERIC4API")
         dlg = EricapiConfigDialog(project, parms)
         if dlg.exec_() == QDialog.Accepted:
             args, parms = dlg.generateParameters()
             project.setData('DOCUMENTATIONPARMS', "ERIC4API", parms)
             
+            # add parameter for the eol setting
+            if not project.useSystemEol():
+                args.append(
+                    "--eol={0}".format(eolTranslation[project.getEolString()]))
+            
             # now do the call
+            from DocumentationPlugins.Ericapi.EricapiExecDialog import \
+                EricapiExecDialog
             dia = EricapiExecDialog("Ericapi")
             res = dia.start(args, project.ppath)
             if res:
                 dia.exec_()
-                
-            outputFileName = parms['outputFile']
-                
+            
+            outputFileName = Utilities.toNativeSeparators(parms['outputFile'])
+            
             # add output files to the project data, if they aren't in already
             for progLanguage in parms['languages']:
                 if "%L" in outputFileName:
@@ -166,7 +179,8 @@ class EricapiPlugin(QObject):
                         outfile = outputFileName
                     else:
                         root, ext = os.path.splitext(outputFileName)
-                        outfile = "%s-%s%s" % (root, progLanguage.lower(), ext)
+                        outfile = "{0}-{1}{2}".format(
+                            root, progLanguage.lower(), ext)
                 
                 outfile = project.getRelativePath(outfile)
                 if outfile not in project.pdata['OTHERS']:
