@@ -4,33 +4,36 @@
 #
 
 """
-Module implementing the Tabnanny plugin.
+Module implementing the Syntax Checker plugin.
 """
 
 import os
 
-from PyQt4.QtCore import QObject, SIGNAL, QString
+from PyQt4.QtCore import QObject
 
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
-from E4Gui.E4Action import E4Action
+from E5Gui.E5Action import E5Action
 
-from CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog import SyntaxCheckerDialog
+import Preferences
 
 # Start-Of-Header
 name = "Syntax Checker Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.4.0"
+version = "5.4.0"
 className = "SyntaxCheckerPlugin"
 packageName = "__core__"
 shortDescription = "Show the Syntax Checker dialog."
 longDescription = """This plugin implements the Syntax Checker dialog.""" \
- """ Syntax Checker is used to check Python source files for correct syntax."""
+    """ Syntax Checker is used to check Python source files for correct""" \
+    """ syntax."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 class SyntaxCheckerPlugin(QObject):
     """
@@ -42,7 +45,7 @@ class SyntaxCheckerPlugin(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        QObject.__init__(self, ui)
+        super().__init__(ui)
         self.__ui = ui
         self.__initialize()
         
@@ -67,41 +70,41 @@ class SyntaxCheckerPlugin(QObject):
         
         @return tuple of None and activation status (boolean)
         """
-        menu = e4App().getObject("Project").getMenu("Checks")
+        menu = e5App().getObject("Project").getMenu("Checks")
         if menu:
-            self.__projectAct = E4Action(self.trUtf8('Check Syntax'),
-                    self.trUtf8('&Syntax...'), 0, 0,
-                    self, 'project_check_syntax')
-            self.__projectAct.setStatusTip(\
+            self.__projectAct = E5Action(
+                self.trUtf8('Check Syntax'),
+                self.trUtf8('&Syntax...'), 0, 0,
+                self, 'project_check_syntax')
+            self.__projectAct.setStatusTip(
                 self.trUtf8('Check syntax.'))
             self.__projectAct.setWhatsThis(self.trUtf8(
                 """<b>Check Syntax...</b>"""
                 """<p>This checks Python files for syntax errors.</p>"""
             ))
-            self.connect(self.__projectAct, SIGNAL('triggered()'), 
-                         self.__projectSyntaxCheck)
-            e4App().getObject("Project").addE4Actions([self.__projectAct])
+            self.__projectAct.triggered[()].connect(self.__projectSyntaxCheck)
+            e5App().getObject("Project").addE5Actions([self.__projectAct])
             menu.addAction(self.__projectAct)
         
-        self.__editorAct = E4Action(self.trUtf8('Check Syntax'),
-                self.trUtf8('&Syntax...'), 0, 0,
-                self, "")
+        self.__editorAct = E5Action(
+            self.trUtf8('Check Syntax'),
+            self.trUtf8('&Syntax...'), 0, 0,
+            self, "")
         self.__editorAct.setWhatsThis(self.trUtf8(
-                """<b>Check Syntax...</b>"""
-                """<p>This checks Python files for syntax errors.</p>"""
+            """<b>Check Syntax...</b>"""
+            """<p>This checks Python files for syntax errors.</p>"""
         ))
-        self.connect(self.__editorAct, SIGNAL('triggered()'), self.__editorSyntaxCheck)
+        self.__editorAct.triggered[()].connect(self.__editorSyntaxCheck)
         
-        self.connect(e4App().getObject("Project"), SIGNAL("showMenu"), 
-                     self.__projectShowMenu)
-        self.connect(e4App().getObject("ProjectBrowser").getProjectBrowser("sources"), 
-                     SIGNAL("showMenu"), self.__projectBrowserShowMenu)
-        self.connect(e4App().getObject("ViewManager"), SIGNAL("editorOpenedEd"), 
-                     self.__editorOpened)
-        self.connect(e4App().getObject("ViewManager"), SIGNAL("editorClosedEd"), 
-                     self.__editorClosed)
+        e5App().getObject("Project").showMenu.connect(self.__projectShowMenu)
+        e5App().getObject("ProjectBrowser").getProjectBrowser("sources")\
+            .showMenu.connect(self.__projectBrowserShowMenu)
+        e5App().getObject("ViewManager").editorOpenedEd.connect(
+            self.__editorOpened)
+        e5App().getObject("ViewManager").editorClosedEd.connect(
+            self.__editorClosed)
         
-        for editor in e4App().getObject("ViewManager").getOpenEditors():
+        for editor in e5App().getObject("ViewManager").getOpenEditors():
             self.__editorOpened(editor)
         
         return None, True
@@ -110,25 +113,26 @@ class SyntaxCheckerPlugin(QObject):
         """
         Public method to deactivate this plugin.
         """
-        self.disconnect(e4App().getObject("Project"), SIGNAL("showMenu"), 
-                        self.__projectShowMenu)
-        self.disconnect(e4App().getObject("ProjectBrowser").getProjectBrowser("sources"), 
-                        SIGNAL("showMenu"), self.__projectBrowserShowMenu)
-        self.disconnect(e4App().getObject("ViewManager"), SIGNAL("editorOpenedEd"), 
-                        self.__editorOpened)
-        self.disconnect(e4App().getObject("ViewManager"), SIGNAL("editorClosedEd"), 
-                        self.__editorClosed)
+        e5App().getObject("Project").showMenu.disconnect(
+            self.__projectShowMenu)
+        e5App().getObject("ProjectBrowser").getProjectBrowser("sources")\
+            .showMenu.disconnect(self.__projectBrowserShowMenu)
+        e5App().getObject("ViewManager").editorOpenedEd.disconnect(
+            self.__editorOpened)
+        e5App().getObject("ViewManager").editorClosedEd.disconnect(
+            self.__editorClosed)
         
-        menu = e4App().getObject("Project").getMenu("Checks")
+        menu = e5App().getObject("Project").getMenu("Checks")
         if menu:
             menu.removeAction(self.__projectAct)
         
         if self.__projectBrowserMenu:
             if self.__projectBrowserAct:
-                self.__projectBrowserMenu.removeAction(self.__projectBrowserAct)
+                self.__projectBrowserMenu.removeAction(
+                    self.__projectBrowserAct)
         
         for editor in self.__editors:
-            self.disconnect(editor, SIGNAL("showMenu"), self.__editorShowMenu)
+            editor.showMenu.disconnect(self.__editorShowMenu)
             menu = editor.getMenu("Checks")
             if menu is not None:
                 menu.removeAction(self.__editorAct)
@@ -137,68 +141,77 @@ class SyntaxCheckerPlugin(QObject):
     
     def __projectShowMenu(self, menuName, menu):
         """
-        Private slot called, when the the project menu or a submenu is 
+        Private slot called, when the the project menu or a submenu is
         about to be shown.
         
         @param menuName name of the menu to be shown (string)
         @param menu reference to the menu (QMenu)
         """
         if menuName == "Checks" and self.__projectAct is not None:
-            self.__projectAct.setEnabled(\
-                e4App().getObject("Project").getProjectLanguage() == "Python")
+            self.__projectAct.setEnabled(
+                e5App().getObject("Project").getProjectLanguage() in
+                ["Python3", "Python2", "Python"])
     
     def __projectBrowserShowMenu(self, menuName, menu):
         """
-        Private slot called, when the the project browser menu or a submenu is 
+        Private slot called, when the the project browser menu or a submenu is
         about to be shown.
         
         @param menuName name of the menu to be shown (string)
         @param menu reference to the menu (QMenu)
         """
         if menuName == "Checks" and \
-           e4App().getObject("Project").getProjectLanguage() == "Python":
+           e5App().getObject("Project").getProjectLanguage() in \
+                ["Python3", "Python2", "Python"]:
             self.__projectBrowserMenu = menu
             if self.__projectBrowserAct is None:
-                self.__projectBrowserAct = E4Action(self.trUtf8('Check Syntax'),
-                        self.trUtf8('&Syntax...'), 0, 0,
-                        self, "")
+                self.__projectBrowserAct = E5Action(
+                    self.trUtf8('Check Syntax'),
+                    self.trUtf8('&Syntax...'), 0, 0,
+                    self, "")
                 self.__projectBrowserAct.setWhatsThis(self.trUtf8(
                     """<b>Check Syntax...</b>"""
                     """<p>This checks Python files for syntax errors.</p>"""
                 ))
-                self.connect(self.__projectBrowserAct, SIGNAL('triggered()'), 
-                             self.__projectBrowserSyntaxCheck)
+                self.__projectBrowserAct.triggered[()].connect(
+                    self.__projectBrowserSyntaxCheck)
             if not self.__projectBrowserAct in menu.actions():
                 menu.addAction(self.__projectBrowserAct)
     
     def __projectSyntaxCheck(self):
         """
-        Public slot used to check the project files for bad indentations.
+        Public slot used to check the project files for syntax errors.
         """
-        project = e4App().getObject("Project")
+        project = e5App().getObject("Project")
         project.saveAllScripts()
-        files = [os.path.join(project.ppath, file) \
-            for file in project.pdata["SOURCES"] \
-                if file.endswith(".py") or \
-                   file.endswith(".pyw") or \
-                   file.endswith(".ptl")]
+        ppath = project.getProjectPath()
+        files = [os.path.join(ppath, file)
+                 for file in project.pdata["SOURCES"]
+                 if file.endswith(
+                     tuple(Preferences.getPython("Python3Extensions")) +
+                     tuple(Preferences.getPython("PythonExtensions")))]
         
+        from CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog import \
+            SyntaxCheckerDialog
         self.__projectSyntaxCheckerDialog = SyntaxCheckerDialog()
         self.__projectSyntaxCheckerDialog.show()
-        self.__projectSyntaxCheckerDialog.start(files)
+        self.__projectSyntaxCheckerDialog.prepare(files, project)
     
     def __projectBrowserSyntaxCheck(self):
         """
-        Private method to handle the syntax check context menu action of the project
-        sources browser.
+        Private method to handle the syntax check context menu action of the
+        project sources browser.
         """
-        browser = e4App().getObject("ProjectBrowser").getProjectBrowser("sources")
+        browser = e5App().getObject("ProjectBrowser").getProjectBrowser(
+            "sources")
         itm = browser.model().item(browser.currentIndex())
         try:
             fn = itm.fileName()
         except AttributeError:
             fn = itm.dirName()
         
+        from CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog import \
+            SyntaxCheckerDialog
         self.__projectBrowserSyntaxCheckerDialog = SyntaxCheckerDialog()
         self.__projectBrowserSyntaxCheckerDialog.show()
         self.__projectBrowserSyntaxCheckerDialog.start(fn)
@@ -212,7 +225,7 @@ class SyntaxCheckerPlugin(QObject):
         menu = editor.getMenu("Checks")
         if menu is not None:
             menu.addAction(self.__editorAct)
-            self.connect(editor, SIGNAL("showMenu"), self.__editorShowMenu)
+            editor.showMenu.connect(self.__editorShowMenu)
             self.__editors.append(editor)
     
     def __editorClosed(self, editor):
@@ -228,7 +241,7 @@ class SyntaxCheckerPlugin(QObject):
     
     def __editorShowMenu(self, menuName, menu, editor):
         """
-        Private slot called, when the the editor context menu or a submenu is 
+        Private slot called, when the the editor context menu or a submenu is
         about to be shown.
         
         @param menuName name of the menu to be shown (string)
@@ -238,15 +251,19 @@ class SyntaxCheckerPlugin(QObject):
         if menuName == "Checks":
             if not self.__editorAct in menu.actions():
                 menu.addAction(self.__editorAct)
-            self.__editorAct.setEnabled(editor.isPyFile())
+            self.__editorAct.setEnabled(
+                editor.isPy3File() or editor.isPy2File())
     
     def __editorSyntaxCheck(self):
         """
-        Private slot to handle the syntax check context menu action of the editors.
+        Private slot to handle the syntax check context menu action of the
+        editors.
         """
-        editor = e4App().getObject("ViewManager").activeWindow()
+        editor = e5App().getObject("ViewManager").activeWindow()
         if editor is not None:
-            self.__editorSyntaxCheckerDialog = SyntaxCheckerDialog()
-            self.__editorSyntaxCheckerDialog.show()
-            self.__editorSyntaxCheckerDialog.start(editor.getFileName(), 
-                                                   unicode(editor.text()))
+                from CheckerPlugins.SyntaxChecker.SyntaxCheckerDialog import \
+                    SyntaxCheckerDialog
+                self.__editorSyntaxCheckerDialog = SyntaxCheckerDialog()
+                self.__editorSyntaxCheckerDialog.show()
+                self.__editorSyntaxCheckerDialog.start(
+                    editor.getFileName() or "Unnamed.py", editor.text())
