@@ -8,12 +8,11 @@ Module implementing the PySvn version control plugin.
 """
 
 import os
-import sys
 
-from PyQt4.QtCore import QString, QVariant
+from PyQt4.QtCore import QObject
 from PyQt4.QtGui import QApplication
 
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
 import Preferences
 from Preferences.Shortcuts import readShortcuts
@@ -25,16 +24,19 @@ name = "PySvn Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = True
-version = "4.4.0"
+version = "5.4.0"
 pluginType = "version_control"
 pluginTypename = "PySvn"
 className = "VcsPySvnPlugin"
 packageName = "__core__"
 shortDescription = "Implements the PySvn version control interface."
-longDescription = """This plugin provides the PySvn version control interface."""
+longDescription = \
+    """This plugin provides the PySvn version control interface."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 def exeDisplayData():
     """
@@ -48,27 +50,28 @@ def exeDisplayData():
             text = os.path.dirname(pysvn.__file__)
         except AttributeError:
             text = "PySvn"
-        version =  ".".join([str(v) for v in pysvn.version])
+        version = ".".join([str(v) for v in pysvn.version])
     except ImportError:
         text = "PySvn"
         version = ""
     
     data = {
-        "programEntry" : False, 
-        "header"       : QApplication.translate("VcsPySvnPlugin",
-                            "Version Control - Subversion (pysvn)"), 
-        "text"         : text, 
-        "version"      : version, 
+        "programEntry": False,
+        "header": QApplication.translate(
+            "VcsPySvnPlugin", "Version Control - Subversion (pysvn)"),
+        "text": text,
+        "version": version,
     }
     
     return data
 
+
 def getVcsSystemIndicator():
     """
     Public function to get the indicators for this version control system.
     
-    @return dictionary with indicator as key and a tuple with the vcs name (string)
-        and vcs display string (QString)
+    @return dictionary with indicator as key and a tuple with the vcs name
+        (string) and vcs display string (string)
     """
     global pluginTypename
     data = {}
@@ -76,55 +79,64 @@ def getVcsSystemIndicator():
     data["_svn"] = (pluginTypename, displayString())
     return data
 
+
 def displayString():
     """
     Public function to get the display string.
     
-    @return display string (QString)
+    @return display string (string)
     """
     try:
-        import pysvn
+        import pysvn        # __IGNORE_WARNING__
         return QApplication.translate('VcsPySvnPlugin', 'Subversion (pysvn)')
     except ImportError:
-        return QString()
+        return ""
 
 subversionCfgPluginObject = None
 
+
 def createConfigurationPage(configDlg):
     """
     Module function to create the configuration page.
     
+    @param configDlg reference to the configuration dialog (QDialog)
     @return reference to the configuration page
     """
     global subversionCfgPluginObject
-    from VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import SubversionPage
+    from VcsPlugins.vcsPySvn.ConfigurationPage.SubversionPage import \
+        SubversionPage
     if subversionCfgPluginObject is None:
         subversionCfgPluginObject = VcsPySvnPlugin(None)
     page = SubversionPage(subversionCfgPluginObject)
     return page
     
+
 def getConfigData():
     """
     Module function returning data as required by the configuration dialog.
     
-    @return dictionary with key "zzz_subversionPage" containing the relevant data
+    @return dictionary with key "zzz_subversionPage" containing the relevant
+    data
     """
     return {
-        "zzz_subversionPage" : \
-            [QApplication.translate("VcsPySvnPlugin", "Subversion"), 
-             os.path.join("VcsPlugins", "vcsPySvn", "icons", 
-                          "preferences-subversion.png"),
-             createConfigurationPage, "vcsPage", None],
+        "zzz_subversionPage":
+        [QApplication.translate("VcsPySvnPlugin", "Subversion"),
+         os.path.join("VcsPlugins", "vcsPySvn", "icons",
+                      "preferences-subversion.png"),
+         createConfigurationPage, "vcsPage", None],
     }
 
+
 def prepareUninstall():
     """
     Module function to prepare for an uninstallation.
     """
-    if not e4App().getObject("PluginManager").isPluginLoaded("PluginVcsSubversion"):
+    if not e5App().getObject("PluginManager").isPluginLoaded(
+            "PluginVcsSubversion"):
         Preferences.Prefs.settings.remove("Subversion")
     
-class VcsPySvnPlugin(object):
+
+class VcsPySvnPlugin(QObject):
     """
     Class implementing the PySvn version control plugin.
     """
@@ -134,22 +146,23 @@ class VcsPySvnPlugin(object):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
+        super().__init__(ui)
         self.__ui = ui
         
         self.__subversionDefaults = {
-            "StopLogOnCopy"  : 1, 
-            "LogLimit"       : 100, 
-            "CommitMessages" : 20, 
+            "StopLogOnCopy": 1,
+            "LogLimit": 20,
+            "CommitMessages": 20,
         }
         
         from VcsPlugins.vcsPySvn.ProjectHelper import SvnProjectHelper
         self.__projectHelperObject = SvnProjectHelper(None, None)
         try:
-            e4App().registerPluginObject(pluginTypename, self.__projectHelperObject, 
-                                         pluginType)
+            e5App().registerPluginObject(
+                pluginTypename, self.__projectHelperObject, pluginType)
         except KeyError:
             pass    # ignore duplicate registration
-        readShortcuts(pluginName = pluginTypename)
+        readShortcuts(pluginName=pluginTypename)
     
     def getProjectHelper(self):
         """
@@ -163,7 +176,7 @@ class VcsPySvnPlugin(object):
         """
         Public method to activate this plugin.
         
-        @return tuple of reference to instantiated viewmanager and 
+        @return tuple of reference to instantiated viewmanager and
             activation status (boolean)
         """
         from VcsPlugins.vcsPySvn.subversion import Subversion
@@ -178,27 +191,32 @@ class VcsPySvnPlugin(object):
     
     def getPreferences(self, key):
         """
-        Public method to retrieve the various refactoring settings.
+        Public method to retrieve the various settings.
         
         @param key the key of the value to get
-        @param prefClass preferences class used as the storage area
         @return the requested refactoring setting
         """
-        if key in ["Commits"]:
-            return Preferences.Prefs.settings.value("Subversion/" + key).toStringList()
+        if key in ["StopLogOnCopy"]:
+            return Preferences.toBool(Preferences.Prefs.settings.value(
+                "Subversion/" + key, self.__subversionDefaults[key]))
+        elif key in ["LogLimit", "CommitMessages"]:
+            return int(Preferences.Prefs.settings.value(
+                "Subversion/" + key,
+                self.__subversionDefaults[key]))
+        elif key in ["Commits"]:
+            return Preferences.toList(Preferences.Prefs.settings.value(
+                "Subversion/" + key))
         else:
-            return Preferences.Prefs.settings.value("Subversion/" + key,
-                QVariant(self.__subversionDefaults[key])).toInt()[0]
+            return Preferences.Prefs.settings.value("Subversion/" + key)
     
     def setPreferences(self, key, value):
         """
-        Public method to store the various refactoring settings.
+        Public method to store the various settings.
         
         @param key the key of the setting to be set
         @param value the value to be set
-        @param prefClass preferences class used as the storage area
         """
-        Preferences.Prefs.settings.setValue("Subversion/" + key, QVariant(value))
+        Preferences.Prefs.settings.setValue("Subversion/" + key, value)
     
     def getServersPath(self):
         """
@@ -220,4 +238,4 @@ class VcsPySvnPlugin(object):
         """
         Public method to prepare for an uninstallation.
         """
-        e4App().unregisterPluginObject(pluginTypename)
+        e5App().unregisterPluginObject(pluginTypename)
