@@ -9,7 +9,7 @@ Module implementing the Tabview view manager plugin.
 
 import os
 
-from PyQt4.QtCore import QT_TRANSLATE_NOOP, QString
+from PyQt4.QtCore import QT_TRANSLATE_NOOP, QObject
 from PyQt4.QtGui import QPixmap
 
 # Start-Of-Header
@@ -17,7 +17,7 @@ name = "Tabview Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
 deactivateable = False
-version = "4.4.0"
+version = "5.4.0"
 pluginType = "viewmanager"
 pluginTypename = "tabview"
 displayString = QT_TRANSLATE_NOOP('VmTabviewPlugin', 'Tabbed View')
@@ -25,9 +25,11 @@ className = "VmTabviewPlugin"
 packageName = "__core__"
 shortDescription = "Implements the Tabview view manager."
 longDescription = """This plugin provides the tabbed view view manager."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 def previewPix():
     """
@@ -35,11 +37,12 @@ def previewPix():
     
     @return preview pixmap (QPixmap)
     """
-    fname = os.path.join(os.path.dirname(__file__), 
+    fname = os.path.join(os.path.dirname(__file__),
                          "ViewManagerPlugins", "Tabview", "preview.png")
     return QPixmap(fname)
     
-class VmTabviewPlugin(object):
+
+class VmTabviewPlugin(QObject):
     """
     Class implementing the Tabview view manager plugin.
     """
@@ -49,13 +52,14 @@ class VmTabviewPlugin(object):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
+        super().__init__(ui)
         self.__ui = ui
 
     def activate(self):
         """
         Public method to activate this plugin.
         
-        @return tuple of reference to instantiated viewmanager and 
+        @return tuple of reference to instantiated viewmanager and
             activation status (boolean)
         """
         from ViewManagerPlugins.Tabview.Tabview import Tabview
