@@ -7,30 +7,28 @@
 Module implementing the QColorDialog wizard plugin.
 """
 
-from PyQt4.QtCore import QObject, SIGNAL, QString
+from PyQt4.QtCore import QObject
 from PyQt4.QtGui import QDialog
 
-from KdeQt.KQApplication import e4App
-from KdeQt import KQMessageBox
-
-from E4Gui.E4Action import E4Action
-
-from WizardPlugins.ColorDialogWizard.ColorDialogWizardDialog import \
-    ColorDialogWizardDialog
+from E5Gui.E5Application import e5App
+from E5Gui.E5Action import E5Action
+from E5Gui import E5MessageBox
 
 # Start-Of-Header
 name = "QColorDialog Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.4.0"
+version = "5.4.0"
 className = "ColorDialogWizard"
 packageName = "__core__"
 shortDescription = "Show the QColorDialog wizard."
 longDescription = """This plugin shows the QColorDialog wizard."""
+pyqtApi = 2
 # End-Of-Header
 
-error = QString("")
+error = ""
+
 
 class ColorDialogWizard(QObject):
     """
@@ -42,7 +40,7 @@ class ColorDialogWizard(QObject):
         
         @param ui reference to the user interface object (UI.UserInterface)
         """
-        QObject.__init__(self, ui)
+        super().__init__(ui)
         self.__ui = ui
 
     def activate(self):
@@ -63,25 +61,26 @@ class ColorDialogWizard(QObject):
         menu = self.__ui.getMenu("wizards")
         if menu:
             menu.removeAction(self.action)
-        self.__ui.removeE4Actions([self.action], 'wizards')
+        self.__ui.removeE5Actions([self.action], 'wizards')
     
     def __initAction(self):
         """
         Private method to initialize the action.
         """
-        self.action = E4Action(self.trUtf8('QColorDialog Wizard'),
-             self.trUtf8('Q&ColorDialog Wizard...'), 0, 0, self,
-             'wizards_qcolordialog')
+        self.action = E5Action(
+            self.trUtf8('QColorDialog Wizard'),
+            self.trUtf8('Q&ColorDialog Wizard...'), 0, 0, self,
+            'wizards_qcolordialog')
         self.action.setStatusTip(self.trUtf8('QColorDialog Wizard'))
         self.action.setWhatsThis(self.trUtf8(
             """<b>QColorDialog Wizard</b>"""
             """<p>This wizard opens a dialog for entering all the parameters"""
-            """ needed to create a QColorDialog. The generated code is inserted"""
-            """ at the current cursor position.</p>"""
+            """ needed to create a QColorDialog. The generated code is"""
+            """ inserted at the current cursor position.</p>"""
         ))
-        self.connect(self.action, SIGNAL('triggered()'), self.__handle)
+        self.action.triggered[()].connect(self.__handle)
         
-        self.__ui.addE4Actions([self.action], 'wizards')
+        self.__ui.addE5Actions([self.action], 'wizards')
 
     def __initMenu(self):
         """
@@ -98,10 +97,12 @@ class ColorDialogWizard(QObject):
         @param editor reference to the current editor
         @return the generated code (string) and a success flag (boolean)
         """
+        from WizardPlugins.ColorDialogWizard.ColorDialogWizardDialog import \
+            ColorDialogWizardDialog
         dlg = ColorDialogWizardDialog(None)
         if dlg.exec_() == QDialog.Accepted:
             line, index = editor.getCursorPosition()
-            indLevel = editor.indentation(line)/editor.indentationWidth()
+            indLevel = editor.indentation(line) // editor.indentationWidth()
             if editor.indentationsUseTabs():
                 indString = '\t'
             else:
@@ -112,12 +113,13 @@ class ColorDialogWizard(QObject):
         
     def __handle(self):
         """
-        Private method to handle the wizards action 
+        Private method to handle the wizards action.
         """
-        editor = e4App().getObject("ViewManager").activeWindow()
+        editor = e5App().getObject("ViewManager").activeWindow()
         
-        if editor == None:
-                KQMessageBox.critical(None, 
+        if editor is None:
+            E5MessageBox.critical(
+                self.__ui,
                 self.trUtf8('No current editor'),
                 self.trUtf8('Please open or create a file first.'))
         else:
@@ -128,4 +130,3 @@ class ColorDialogWizard(QObject):
                 editor.beginUndoAction()
                 editor.insertAt(code, line, index)
                 editor.endUndoAction()
-
