@@ -9,29 +9,27 @@ Module implementing the VCS project helper for Subversion.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
 from VCS.ProjectHelper import VcsProjectHelper
 
-from E4Gui.E4Action import E4Action
+from E5Gui.E5Action import E5Action
 
 import UI.PixmapCache
 
+
 class SvnProjectHelper(VcsProjectHelper):
     """
     Class implementing the VCS project helper for Subversion.
     """
-    def __init__(self, vcsObject, projectObject, parent = None, name = None):
+    def __init__(self, vcsObject, projectObject, parent=None, name=None):
         """
         Constructor
         
         @param vcsObject reference to the vcs object
         @param projectObject reference to the project object
         @param parent parent widget (QWidget)
-        @param name name of this object (string or QString)
+        @param name name of this object (string)
         """
         VcsProjectHelper.__init__(self, vcsObject, projectObject, parent, name)
     
@@ -39,7 +37,7 @@ class SvnProjectHelper(VcsProjectHelper):
         """
         Public method to get a list of all actions.
         
-        @return list of all actions (list of E4Action)
+        @return list of all actions (list of E5Action)
         """
         return self.actions[:]
     
@@ -47,51 +45,59 @@ class SvnProjectHelper(VcsProjectHelper):
         """
         Public method to generate the action objects.
         """
-        self.vcsNewAct = E4Action(self.trUtf8('New from repository'),
-                UI.PixmapCache.getIcon("vcsCheckout.png"),
-                self.trUtf8('&New from repository...'), 0, 0, self, 'subversion_new')
+        self.vcsNewAct = E5Action(
+            self.trUtf8('New from repository'),
+            UI.PixmapCache.getIcon("vcsCheckout.png"),
+            self.trUtf8('&New from repository...'), 0, 0, self,
+            'subversion_new')
         self.vcsNewAct.setStatusTip(self.trUtf8(
             'Create a new project from the VCS repository'
         ))
         self.vcsNewAct.setWhatsThis(self.trUtf8(
             """<b>New from repository</b>"""
-            """<p>This creates a new local project from the VCS repository.</p>"""
+            """<p>This creates a new local project from the VCS"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsNewAct, SIGNAL('triggered()'), self._vcsCheckout)
+        self.vcsNewAct.triggered[()].connect(self._vcsCheckout)
         self.actions.append(self.vcsNewAct)
         
-        self.vcsUpdateAct = E4Action(self.trUtf8('Update from repository'),
-                UI.PixmapCache.getIcon("vcsUpdate.png"),
-                self.trUtf8('&Update from repository'), 0, 0, self,
-                'subversion_update')
+        self.vcsUpdateAct = E5Action(
+            self.trUtf8('Update from repository'),
+            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            self.trUtf8('&Update from repository'), 0, 0, self,
+            'subversion_update')
         self.vcsUpdateAct.setStatusTip(self.trUtf8(
             'Update the local project from the VCS repository'
         ))
         self.vcsUpdateAct.setWhatsThis(self.trUtf8(
             """<b>Update from repository</b>"""
-            """<p>This updates the local project from the VCS repository.</p>"""
+            """<p>This updates the local project from the VCS"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsUpdateAct, SIGNAL('triggered()'), self._vcsUpdate)
+        self.vcsUpdateAct.triggered[()].connect(self._vcsUpdate)
         self.actions.append(self.vcsUpdateAct)
         
-        self.vcsCommitAct = E4Action(self.trUtf8('Commit changes to repository'),
-                UI.PixmapCache.getIcon("vcsCommit.png"),
-                self.trUtf8('&Commit changes to repository...'), 0, 0, self,
-                'subversion_commit')
+        self.vcsCommitAct = E5Action(
+            self.trUtf8('Commit changes to repository'),
+            UI.PixmapCache.getIcon("vcsCommit.png"),
+            self.trUtf8('&Commit changes to repository...'), 0, 0, self,
+            'subversion_commit')
         self.vcsCommitAct.setStatusTip(self.trUtf8(
             'Commit changes to the local project to the VCS repository'
         ))
         self.vcsCommitAct.setWhatsThis(self.trUtf8(
             """<b>Commit changes to repository</b>"""
-            """<p>This commits changes to the local project to the VCS repository.</p>"""
+            """<p>This commits changes to the local project to the VCS"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsCommitAct, SIGNAL('triggered()'), self._vcsCommit)
+        self.vcsCommitAct.triggered[()].connect(self._vcsCommit)
         self.actions.append(self.vcsCommitAct)
         
-        self.vcsLogAct = E4Action(self.trUtf8('Show log'),
-                UI.PixmapCache.getIcon("vcsLog.png"),
-                self.trUtf8('Show &log'),
-                0, 0, self, 'subversion_log')
+        self.vcsLogAct = E5Action(
+            self.trUtf8('Show log'),
+            UI.PixmapCache.getIcon("vcsLog.png"),
+            self.trUtf8('Show &log'),
+            0, 0, self, 'subversion_log')
         self.vcsLogAct.setStatusTip(self.trUtf8(
             'Show the log of the local project'
         ))
@@ -99,87 +105,79 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Show log</b>"""
             """<p>This shows the log of the local project.</p>"""
         ))
-        self.connect(self.vcsLogAct, SIGNAL('triggered()'), self._vcsLog)
+        self.vcsLogAct.triggered[()].connect(self._vcsLog)
         self.actions.append(self.vcsLogAct)
         
-        self.svnLogLimitedAct = E4Action(self.trUtf8('Show limited log'),
-                UI.PixmapCache.getIcon("vcsLog.png"),
-                self.trUtf8('Show limited log'),
-                0, 0, self, 'subversion_log_limited')
-        self.svnLogLimitedAct.setStatusTip(self.trUtf8(
-            'Show a limited log of the local project'
-        ))
-        self.svnLogLimitedAct.setWhatsThis(self.trUtf8(
-            """<b>Show limited log</b>"""
-            """<p>This shows the log of the local project limited to a selectable"""
-            """ number of entries.</p>"""
-        ))
-        self.connect(self.svnLogLimitedAct, SIGNAL('triggered()'), self.__svnLogLimited)
-        self.actions.append(self.svnLogLimitedAct)
-        
-        self.svnLogBrowserAct = E4Action(self.trUtf8('Show log browser'),
-                UI.PixmapCache.getIcon("vcsLog.png"),
-                self.trUtf8('Show log browser'),
-                0, 0, self, 'subversion_log_browser')
+        self.svnLogBrowserAct = E5Action(
+            self.trUtf8('Show log browser'),
+            UI.PixmapCache.getIcon("vcsLog.png"),
+            self.trUtf8('Show log browser'),
+            0, 0, self, 'subversion_log_browser')
         self.svnLogBrowserAct.setStatusTip(self.trUtf8(
             'Show a dialog to browse the log of the local project'
         ))
         self.svnLogBrowserAct.setWhatsThis(self.trUtf8(
             """<b>Show log browser</b>"""
-            """<p>This shows a dialog to browse the log of the local project."""
-            """ A limited number of entries is shown first. More can be"""
-            """ retrieved later on.</p>"""
+            """<p>This shows a dialog to browse the log of the local"""
+            """ project. A limited number of entries is shown first. More"""
+            """ can be retrieved later on.</p>"""
         ))
-        self.connect(self.svnLogBrowserAct, SIGNAL('triggered()'), self.__svnLogBrowser)
+        self.svnLogBrowserAct.triggered[()].connect(self.__svnLogBrowser)
         self.actions.append(self.svnLogBrowserAct)
         
-        self.vcsDiffAct = E4Action(self.trUtf8('Show difference'),
-                UI.PixmapCache.getIcon("vcsDiff.png"),
-                self.trUtf8('Show &difference'),
-                0, 0, self, 'subversion_diff')
+        self.vcsDiffAct = E5Action(
+            self.trUtf8('Show differences'),
+            UI.PixmapCache.getIcon("vcsDiff.png"),
+            self.trUtf8('Show &difference'),
+            0, 0, self, 'subversion_diff')
         self.vcsDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of the local project to the repository'
         ))
         self.vcsDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference</b>"""
-            """<p>This shows the difference of the local project to the repository.</p>"""
+            """<b>Show differences</b>"""
+            """<p>This shows differences of the local project to the"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsDiffAct, SIGNAL('triggered()'), self._vcsDiff)
+        self.vcsDiffAct.triggered[()].connect(self._vcsDiff)
         self.actions.append(self.vcsDiffAct)
         
-        self.svnExtDiffAct = E4Action(self.trUtf8('Show difference (extended)'),
-                UI.PixmapCache.getIcon("vcsDiff.png"),
-                self.trUtf8('Show difference (extended)'),
-                0, 0, self, 'subversion_extendeddiff')
+        self.svnExtDiffAct = E5Action(
+            self.trUtf8('Show differences (extended)'),
+            UI.PixmapCache.getIcon("vcsDiff.png"),
+            self.trUtf8('Show differences (extended)'),
+            0, 0, self, 'subversion_extendeddiff')
         self.svnExtDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of revisions of the project to the repository'
         ))
         self.svnExtDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference (extended)</b>"""
-            """<p>This shows the difference of selectable revisions of the project.</p>"""
+            """<b>Show differences (extended)</b>"""
+            """<p>This shows differences of selectable revisions of"""
+            """ the project.</p>"""
         ))
-        self.connect(self.svnExtDiffAct, SIGNAL('triggered()'), self.__svnExtendedDiff)
+        self.svnExtDiffAct.triggered[()].connect(self.__svnExtendedDiff)
         self.actions.append(self.svnExtDiffAct)
         
-        self.svnUrlDiffAct = E4Action(self.trUtf8('Show difference (URLs)'),
-                UI.PixmapCache.getIcon("vcsDiff.png"),
-                self.trUtf8('Show difference (URLs)'),
-                0, 0, self, 'subversion_urldiff')
+        self.svnUrlDiffAct = E5Action(
+            self.trUtf8('Show differences (URLs)'),
+            UI.PixmapCache.getIcon("vcsDiff.png"),
+            self.trUtf8('Show differences (URLs)'),
+            0, 0, self, 'subversion_urldiff')
         self.svnUrlDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of the project between two repository URLs'
         ))
         self.svnUrlDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference (URLs)</b>"""
-            """<p>This shows the difference of the project between"""
+            """<b>Show differences (URLs)</b>"""
+            """<p>This shows differences of the project between"""
             """ two repository URLs.</p>"""
         ))
-        self.connect(self.svnUrlDiffAct, SIGNAL('triggered()'), self.__svnUrlDiff)
+        self.svnUrlDiffAct.triggered[()].connect(self.__svnUrlDiff)
         self.actions.append(self.svnUrlDiffAct)
         
-        self.vcsStatusAct = E4Action(self.trUtf8('Show status'),
-                UI.PixmapCache.getIcon("vcsStatus.png"),
-                self.trUtf8('Show &status'),
-                0, 0, self, 'subversion_status')
+        self.vcsStatusAct = E5Action(
+            self.trUtf8('Show status'),
+            UI.PixmapCache.getIcon("vcsStatus.png"),
+            self.trUtf8('Show &status'),
+            0, 0, self, 'subversion_status')
         self.vcsStatusAct.setStatusTip(self.trUtf8(
             'Show the status of the local project'
         ))
@@ -187,13 +185,14 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Show status</b>"""
             """<p>This shows the status of the local project.</p>"""
         ))
-        self.connect(self.vcsStatusAct, SIGNAL('triggered()'), self._vcsStatus)
+        self.vcsStatusAct.triggered[()].connect(self._vcsStatus)
         self.actions.append(self.vcsStatusAct)
         
-        self.svnChangeListsAct = E4Action(self.trUtf8('Show change lists'),
-                UI.PixmapCache.getIcon("vcsChangeLists.png"),
-                self.trUtf8('Show change lists'),
-                0, 0, self, 'subversion_changelists')
+        self.svnChangeListsAct = E5Action(
+            self.trUtf8('Show change lists'),
+            UI.PixmapCache.getIcon("vcsChangeLists.png"),
+            self.trUtf8('Show change lists'),
+            0, 0, self, 'subversion_changelists')
         self.svnChangeListsAct.setStatusTip(self.trUtf8(
             'Show the change lists and associated files of the local project'
         ))
@@ -202,13 +201,14 @@ class SvnProjectHelper(VcsProjectHelper):
             """<p>This shows the change lists and associated files of the"""
             """ local project.</p>"""
         ))
-        self.connect(self.svnChangeListsAct, SIGNAL('triggered()'), self.__svnChangeLists)
+        self.svnChangeListsAct.triggered[()].connect(self.__svnChangeLists)
         self.actions.append(self.svnChangeListsAct)
         
-        self.svnRepoInfoAct = E4Action(self.trUtf8('Show repository info'), 
-                UI.PixmapCache.getIcon("vcsRepo.png"),
-                self.trUtf8('Show repository info'),
-                0, 0, self, 'subversion_repoinfo')
+        self.svnRepoInfoAct = E5Action(
+            self.trUtf8('Show repository info'),
+            UI.PixmapCache.getIcon("vcsRepo.png"),
+            self.trUtf8('Show repository info'),
+            0, 0, self, 'subversion_repoinfo')
         self.svnRepoInfoAct.setStatusTip(self.trUtf8(
             'Show some repository related information for the local project'
         ))
@@ -217,13 +217,14 @@ class SvnProjectHelper(VcsProjectHelper):
             """<p>This shows some repository related information for"""
             """ the local project.</p>"""
         ))
-        self.connect(self.svnRepoInfoAct, SIGNAL('triggered()'), self.__svnInfo)
+        self.svnRepoInfoAct.triggered[()].connect(self.__svnInfo)
         self.actions.append(self.svnRepoInfoAct)
         
-        self.vcsTagAct = E4Action(self.trUtf8('Tag in repository'), 
-                UI.PixmapCache.getIcon("vcsTag.png"),
-                self.trUtf8('&Tag in repository...'),
-                0, 0, self, 'subversion_tag')
+        self.vcsTagAct = E5Action(
+            self.trUtf8('Tag in repository'),
+            UI.PixmapCache.getIcon("vcsTag.png"),
+            self.trUtf8('&Tag in repository...'),
+            0, 0, self, 'subversion_tag')
         self.vcsTagAct.setStatusTip(self.trUtf8(
             'Tag the local project in the repository'
         ))
@@ -231,13 +232,14 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Tag in repository</b>"""
             """<p>This tags the local project in the repository.</p>"""
         ))
-        self.connect(self.vcsTagAct, SIGNAL('triggered()'), self._vcsTag)
+        self.vcsTagAct.triggered[()].connect(self._vcsTag)
         self.actions.append(self.vcsTagAct)
         
-        self.vcsExportAct = E4Action(self.trUtf8('Export from repository'), 
-                UI.PixmapCache.getIcon("vcsExport.png"),
-                self.trUtf8('&Export from repository...'),
-                0, 0, self, 'subversion_export')
+        self.vcsExportAct = E5Action(
+            self.trUtf8('Export from repository'),
+            UI.PixmapCache.getIcon("vcsExport.png"),
+            self.trUtf8('&Export from repository...'),
+            0, 0, self, 'subversion_export')
         self.vcsExportAct.setStatusTip(self.trUtf8(
             'Export a project from the repository'
         ))
@@ -245,24 +247,27 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Export from repository</b>"""
             """<p>This exports a project from the repository.</p>"""
         ))
-        self.connect(self.vcsExportAct, SIGNAL('triggered()'), self._vcsExport)
+        self.vcsExportAct.triggered[()].connect(self._vcsExport)
         self.actions.append(self.vcsExportAct)
         
-        self.vcsPropsAct = E4Action(self.trUtf8('Command options'),
-                self.trUtf8('Command &options...'),0,0,self,
-                'subversion_options')
-        self.vcsPropsAct.setStatusTip(self.trUtf8('Show the VCS command options'))
+        self.vcsPropsAct = E5Action(
+            self.trUtf8('Command options'),
+            self.trUtf8('Command &options...'), 0, 0, self,
+            'subversion_options')
+        self.vcsPropsAct.setStatusTip(self.trUtf8(
+            'Show the VCS command options'))
         self.vcsPropsAct.setWhatsThis(self.trUtf8(
             """<b>Command options...</b>"""
             """<p>This shows a dialog to edit the VCS command options.</p>"""
         ))
-        self.connect(self.vcsPropsAct, SIGNAL('triggered()'), self._vcsCommandOptions)
+        self.vcsPropsAct.triggered[()].connect(self._vcsCommandOptions)
         self.actions.append(self.vcsPropsAct)
         
-        self.vcsRevertAct = E4Action(self.trUtf8('Revert changes'),
-                UI.PixmapCache.getIcon("vcsRevert.png"),
-                self.trUtf8('Re&vert changes'),
-                0, 0, self, 'subversion_revert')
+        self.vcsRevertAct = E5Action(
+            self.trUtf8('Revert changes'),
+            UI.PixmapCache.getIcon("vcsRevert.png"),
+            self.trUtf8('Re&vert changes'),
+            0, 0, self, 'subversion_revert')
         self.vcsRevertAct.setStatusTip(self.trUtf8(
             'Revert all changes made to the local project'
         ))
@@ -270,27 +275,30 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Revert changes</b>"""
             """<p>This reverts all changes made to the local project.</p>"""
         ))
-        self.connect(self.vcsRevertAct, SIGNAL('triggered()'), self._vcsRevert)
+        self.vcsRevertAct.triggered[()].connect(self._vcsRevert)
         self.actions.append(self.vcsRevertAct)
         
-        self.vcsMergeAct = E4Action(self.trUtf8('Merge'),
-                UI.PixmapCache.getIcon("vcsMerge.png"),
-                self.trUtf8('Mer&ge changes...'),
-                0, 0, self, 'subversion_merge')
+        self.vcsMergeAct = E5Action(
+            self.trUtf8('Merge'),
+            UI.PixmapCache.getIcon("vcsMerge.png"),
+            self.trUtf8('Mer&ge changes...'),
+            0, 0, self, 'subversion_merge')
         self.vcsMergeAct.setStatusTip(self.trUtf8(
             'Merge changes of a tag/revision into the local project'
         ))
         self.vcsMergeAct.setWhatsThis(self.trUtf8(
             """<b>Merge</b>"""
-            """<p>This merges changes of a tag/revision into the local project.</p>"""
+            """<p>This merges changes of a tag/revision into the local"""
+            """ project.</p>"""
         ))
-        self.connect(self.vcsMergeAct, SIGNAL('triggered()'), self._vcsMerge)
+        self.vcsMergeAct.triggered[()].connect(self._vcsMerge)
         self.actions.append(self.vcsMergeAct)
         
-        self.vcsSwitchAct = E4Action(self.trUtf8('Switch'),
-                UI.PixmapCache.getIcon("vcsSwitch.png"),
-                self.trUtf8('S&witch...'),
-                0, 0, self, 'subversion_switch')
+        self.vcsSwitchAct = E5Action(
+            self.trUtf8('Switch'),
+            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            self.trUtf8('S&witch...'),
+            0, 0, self, 'subversion_switch')
         self.vcsSwitchAct.setStatusTip(self.trUtf8(
             'Switch the local copy to another tag/branch'
         ))
@@ -298,25 +306,28 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Switch</b>"""
             """<p>This switches the local copy to another tag/branch.</p>"""
         ))
-        self.connect(self.vcsSwitchAct, SIGNAL('triggered()'), self._vcsSwitch)
+        self.vcsSwitchAct.triggered[()].connect(self._vcsSwitch)
         self.actions.append(self.vcsSwitchAct)
         
-        self.vcsResolveAct = E4Action(self.trUtf8('Conflicts resolved'),
-                self.trUtf8('Con&flicts resolved'),
-                0, 0, self, 'subversion_resolve')
+        self.vcsResolveAct = E5Action(
+            self.trUtf8('Conflicts resolved'),
+            self.trUtf8('Con&flicts resolved'),
+            0, 0, self, 'subversion_resolve')
         self.vcsResolveAct.setStatusTip(self.trUtf8(
             'Mark all conflicts of the local project as resolved'
         ))
         self.vcsResolveAct.setWhatsThis(self.trUtf8(
             """<b>Conflicts resolved</b>"""
-            """<p>This marks all conflicts of the local project as resolved.</p>"""
+            """<p>This marks all conflicts of the local project as"""
+            """ resolved.</p>"""
         ))
-        self.connect(self.vcsResolveAct, SIGNAL('triggered()'), self.__svnResolve)
+        self.vcsResolveAct.triggered[()].connect(self.__svnResolve)
         self.actions.append(self.vcsResolveAct)
         
-        self.vcsCleanupAct = E4Action(self.trUtf8('Cleanup'),
-                self.trUtf8('Cleanu&p'),
-                0, 0, self, 'subversion_cleanup')
+        self.vcsCleanupAct = E5Action(
+            self.trUtf8('Cleanup'),
+            self.trUtf8('Cleanu&p'),
+            0, 0, self, 'subversion_cleanup')
         self.vcsCleanupAct.setStatusTip(self.trUtf8(
             'Cleanup the local project'
         ))
@@ -324,12 +335,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Cleanup</b>"""
             """<p>This performs a cleanup of the local project.</p>"""
         ))
-        self.connect(self.vcsCleanupAct, SIGNAL('triggered()'), self._vcsCleanup)
+        self.vcsCleanupAct.triggered[()].connect(self._vcsCleanup)
         self.actions.append(self.vcsCleanupAct)
         
-        self.vcsCommandAct = E4Action(self.trUtf8('Execute command'),
-                self.trUtf8('E&xecute command...'),
-                0, 0, self, 'subversion_command')
+        self.vcsCommandAct = E5Action(
+            self.trUtf8('Execute command'),
+            self.trUtf8('E&xecute command...'),
+            0, 0, self, 'subversion_command')
         self.vcsCommandAct.setStatusTip(self.trUtf8(
             'Execute an arbitrary VCS command'
         ))
@@ -337,12 +349,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Execute command</b>"""
             """<p>This opens a dialog to enter an arbitrary VCS command.</p>"""
         ))
-        self.connect(self.vcsCommandAct, SIGNAL('triggered()'), self._vcsCommand)
+        self.vcsCommandAct.triggered[()].connect(self._vcsCommand)
         self.actions.append(self.vcsCommandAct)
         
-        self.svnTagListAct = E4Action(self.trUtf8('List tags'), 
-                self.trUtf8('List tags...'),
-                0, 0, self, 'subversion_list_tags')
+        self.svnTagListAct = E5Action(
+            self.trUtf8('List tags'),
+            self.trUtf8('List tags...'),
+            0, 0, self, 'subversion_list_tags')
         self.svnTagListAct.setStatusTip(self.trUtf8(
             'List tags of the project'
         ))
@@ -350,12 +363,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>List tags</b>"""
             """<p>This lists the tags of the project.</p>"""
         ))
-        self.connect(self.svnTagListAct, SIGNAL('triggered()'), self.__svnTagList)
+        self.svnTagListAct.triggered[()].connect(self.__svnTagList)
         self.actions.append(self.svnTagListAct)
         
-        self.svnBranchListAct = E4Action(self.trUtf8('List branches'), 
-                self.trUtf8('List branches...'),
-                0, 0, self, 'subversion_list_branches')
+        self.svnBranchListAct = E5Action(
+            self.trUtf8('List branches'),
+            self.trUtf8('List branches...'),
+            0, 0, self, 'subversion_list_branches')
         self.svnBranchListAct.setStatusTip(self.trUtf8(
             'List branches of the project'
         ))
@@ -363,12 +377,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>List branches</b>"""
             """<p>This lists the branches of the project.</p>"""
         ))
-        self.connect(self.svnBranchListAct, SIGNAL('triggered()'), self.__svnBranchList)
+        self.svnBranchListAct.triggered[()].connect(self.__svnBranchList)
         self.actions.append(self.svnBranchListAct)
         
-        self.svnListAct = E4Action(self.trUtf8('List repository contents'), 
-                self.trUtf8('List repository contents...'),
-                0, 0, self, 'subversion_contents')
+        self.svnListAct = E5Action(
+            self.trUtf8('List repository contents'),
+            self.trUtf8('List repository contents...'),
+            0, 0, self, 'subversion_contents')
         self.svnListAct.setStatusTip(self.trUtf8(
             'Lists the contents of the repository'
         ))
@@ -376,12 +391,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>List repository contents</b>"""
             """<p>This lists the contents of the repository.</p>"""
         ))
-        self.connect(self.svnListAct, SIGNAL('triggered()'), self.__svnTagList)
+        self.svnListAct.triggered[()].connect(self.__svnTagList)
         self.actions.append(self.svnListAct)
         
-        self.svnPropSetAct = E4Action(self.trUtf8('Set Property'),
-                self.trUtf8('Set Property...'),
-                0, 0, self, 'subversion_property_set')
+        self.svnPropSetAct = E5Action(
+            self.trUtf8('Set Property'),
+            self.trUtf8('Set Property...'),
+            0, 0, self, 'subversion_property_set')
         self.svnPropSetAct.setStatusTip(self.trUtf8(
             'Set a property for the project files'
         ))
@@ -389,12 +405,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Set Property</b>"""
             """<p>This sets a property for the project files.</p>"""
         ))
-        self.connect(self.svnPropSetAct, SIGNAL('triggered()'), self.__svnPropSet)
+        self.svnPropSetAct.triggered[()].connect(self.__svnPropSet)
         self.actions.append(self.svnPropSetAct)
         
-        self.svnPropListAct = E4Action(self.trUtf8('List Properties'),
-                self.trUtf8('List Properties...'),
-                0, 0, self, 'subversion_property_list')
+        self.svnPropListAct = E5Action(
+            self.trUtf8('List Properties'),
+            self.trUtf8('List Properties...'),
+            0, 0, self, 'subversion_property_list')
         self.svnPropListAct.setStatusTip(self.trUtf8(
             'List properties of the project files'
         ))
@@ -402,12 +419,13 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>List Properties</b>"""
             """<p>This lists the properties of the project files.</p>"""
         ))
-        self.connect(self.svnPropListAct, SIGNAL('triggered()'), self.__svnPropList)
+        self.svnPropListAct.triggered[()].connect(self.__svnPropList)
         self.actions.append(self.svnPropListAct)
         
-        self.svnPropDelAct = E4Action(self.trUtf8('Delete Property'),
-                self.trUtf8('Delete Property...'),
-                0, 0, self, 'subversion_property_delete')
+        self.svnPropDelAct = E5Action(
+            self.trUtf8('Delete Property'),
+            self.trUtf8('Delete Property...'),
+            0, 0, self, 'subversion_property_delete')
         self.svnPropDelAct.setStatusTip(self.trUtf8(
             'Delete a property for the project files'
         ))
@@ -415,27 +433,30 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Delete Property</b>"""
             """<p>This deletes a property for the project files.</p>"""
         ))
-        self.connect(self.svnPropDelAct, SIGNAL('triggered()'), self.__svnPropDel)
+        self.svnPropDelAct.triggered[()].connect(self.__svnPropDel)
         self.actions.append(self.svnPropDelAct)
         
-        self.svnRelocateAct = E4Action(self.trUtf8('Relocate'),
-                UI.PixmapCache.getIcon("vcsSwitch.png"),
-                self.trUtf8('Relocate...'),
-                0, 0, self, 'subversion_relocate')
+        self.svnRelocateAct = E5Action(
+            self.trUtf8('Relocate'),
+            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            self.trUtf8('Relocate...'),
+            0, 0, self, 'subversion_relocate')
         self.svnRelocateAct.setStatusTip(self.trUtf8(
             'Relocate the working copy to a new repository URL'
         ))
         self.svnRelocateAct.setWhatsThis(self.trUtf8(
             """<b>Relocate</b>"""
-            """<p>This relocates the working copy to a new repository URL.</p>"""
+            """<p>This relocates the working copy to a new repository"""
+            """ URL.</p>"""
         ))
-        self.connect(self.svnRelocateAct, SIGNAL('triggered()'), self.__svnRelocate)
+        self.svnRelocateAct.triggered[()].connect(self.__svnRelocate)
         self.actions.append(self.svnRelocateAct)
         
-        self.svnRepoBrowserAct = E4Action(self.trUtf8('Repository Browser'),
-                UI.PixmapCache.getIcon("vcsRepoBrowser.png"),
-                self.trUtf8('Repository Browser...'),
-                0, 0, self, 'subversion_repo_browser')
+        self.svnRepoBrowserAct = E5Action(
+            self.trUtf8('Repository Browser'),
+            UI.PixmapCache.getIcon("vcsRepoBrowser.png"),
+            self.trUtf8('Repository Browser...'),
+            0, 0, self, 'subversion_repo_browser')
         self.svnRepoBrowserAct.setStatusTip(self.trUtf8(
             'Show the Repository Browser dialog'
         ))
@@ -443,21 +464,37 @@ class SvnProjectHelper(VcsProjectHelper):
             """<b>Repository Browser</b>"""
             """<p>This shows the Repository Browser dialog.</p>"""
         ))
-        self.connect(self.svnRepoBrowserAct, SIGNAL('triggered()'), self.__svnRepoBrowser)
+        self.svnRepoBrowserAct.triggered[()].connect(self.__svnRepoBrowser)
         self.actions.append(self.svnRepoBrowserAct)
         
-        self.svnConfigAct = E4Action(self.trUtf8('Configure'),
-                self.trUtf8('Configure...'),
-                0, 0, self, 'subversion_configure')
+        self.svnConfigAct = E5Action(
+            self.trUtf8('Configure'),
+            self.trUtf8('Configure...'),
+            0, 0, self, 'subversion_configure')
         self.svnConfigAct.setStatusTip(self.trUtf8(
             'Show the configuration dialog with the Subversion page selected'
         ))
         self.svnConfigAct.setWhatsThis(self.trUtf8(
             """<b>Configure</b>"""
-            """<p>Show the configuration dialog with the Subversion page selected.</p>"""
+            """<p>Show the configuration dialog with the Subversion page"""
+            """ selected.</p>"""
         ))
-        self.connect(self.svnConfigAct, SIGNAL('triggered()'), self.__svnConfigure)
+        self.svnConfigAct.triggered[()].connect(self.__svnConfigure)
         self.actions.append(self.svnConfigAct)
+        
+        self.svnUpgradeAct = E5Action(
+            self.trUtf8('Upgrade'),
+            self.trUtf8('Upgrade...'),
+            0, 0, self, 'subversion_upgrade')
+        self.svnUpgradeAct.setStatusTip(self.trUtf8(
+            'Upgrade the working copy to the current format'
+        ))
+        self.svnUpgradeAct.setWhatsThis(self.trUtf8(
+            """<b>Upgrade</b>"""
+            """<p>Upgrades the working copy to the current format.</p>"""
+        ))
+        self.svnUpgradeAct.triggered[()].connect(self.__svnUpgrade)
+        self.actions.append(self.svnUpgradeAct)
     
     def initMenu(self, menu):
         """
@@ -469,7 +506,7 @@ class SvnProjectHelper(VcsProjectHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")), 
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -490,7 +527,6 @@ class SvnProjectHelper(VcsProjectHelper):
             menu.addAction(self.svnListAct)
         menu.addSeparator()
         menu.addAction(self.vcsLogAct)
-        menu.addAction(self.svnLogLimitedAct)
         menu.addAction(self.svnLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
@@ -516,6 +552,7 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.addSeparator()
         menu.addAction(self.vcsCommandAct)
         menu.addAction(self.svnRepoBrowserAct)
+        menu.addAction(self.svnUpgradeAct)
         menu.addSeparator()
         menu.addAction(self.vcsPropsAct)
         menu.addSeparator()
@@ -559,22 +596,18 @@ class SvnProjectHelper(VcsProjectHelper):
         
     def __svnExtendedDiff(self):
         """
-        Private slot used to perform a svn diff with the selection of revisions.
+        Private slot used to perform a svn diff with the selection of
+        revisions.
         """
         self.vcs.svnExtendedDiff(self.project.ppath)
         
     def __svnUrlDiff(self):
         """
-        Private slot used to perform a svn diff with the selection of repository URLs.
+        Private slot used to perform a svn diff with the selection of
+        repository URLs.
         """
         self.vcs.svnUrlDiff(self.project.ppath)
         
-    def __svnLogLimited(self):
-        """
-        Private slot used to perform a svn log --limit.
-        """
-        self.vcs.svnLogLimited(self.project.ppath)
-        
     def __svnLogBrowser(self):
         """
         Private slot used to browse the log of the current project.
@@ -597,16 +630,23 @@ class SvnProjectHelper(VcsProjectHelper):
         """
         Private slot to open the repository browser.
         """
-        self.vcs.svnRepoBrowser(projectPath = self.project.ppath)
+        self.vcs.svnRepoBrowser(projectPath=self.project.ppath)
         
     def __svnConfigure(self):
         """
         Private slot to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("zzz_subversionPage")
-        
+        e5App().getObject("UserInterface")\
+            .showPreferences("zzz_subversionPage")
+    
     def __svnChangeLists(self):
         """
         Private slot used to show a list of change lists.
         """
         self.vcs.svnShowChangelists(self.project.ppath)
+    
+    def __svnUpgrade(self):
+        """
+        Private slot used to upgrade the working copy format.
+        """
+        self.vcs.svnUpgrade(self.project.ppath)
