@@ -8,30 +8,31 @@ Module implementing a dialog to show the output of the svn blame command.
 """
 
 import os
-import sys
 
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QMutexLocker, Qt
+from PyQt4.QtGui import QHeaderView, QDialog, QDialogButtonBox, QFont, \
+    QTreeWidgetItem
 
-from SvnDialogMixin import SvnDialogMixin
-from Ui_SvnBlameDialog import Ui_SvnBlameDialog
+from .SvnDialogMixin import SvnDialogMixin
+from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
 
 import Utilities
 
+
 class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
     """
     Class implementing a dialog to show the output of the svn blame command.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -74,17 +75,19 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
             annotations = self.client.annotate(fname)
             locker.unlock()
             for annotation in annotations:
-                self.__generateItem(annotation["revision"].number,
-                    annotation["author"], annotation["number"] + 1, annotation["line"])
-        except pysvn.ClientError, e:
+                self.__generateItem(
+                    annotation["revision"].number, annotation["author"],
+                    annotation["number"] + 1, annotation["line"])
+        except pysvn.ClientError as e:
             locker.unlock()
-            self.__showError(e.args[0]+'\n')
+            self.__showError(e.args[0] + '\n')
         self.__finish()
         os.chdir(cwd)
         
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -110,19 +113,19 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
         Private method to resize the list columns.
         """
         self.blameList.header().resizeSections(QHeaderView.ResizeToContents)
-        self.blameList.header().setStretchLastSection(True)
         
     def __generateItem(self, revision, author, lineno, text):
         """
-        Private method to generate a tag item in the taglist.
+        Private method to generate a blame item in the blame list.
         
-        @param revision revision string (integer)
-        @param author author of the tag (string or QString)
-        @param lineno line number (integer)
-        @param text text of the line (string or QString)
+        @param revision revision string (string)
+        @param author author of the change (string)
+        @param lineno linenumber (string)
+        @param text line of text from the annotated file (string)
         """
-        itm = QTreeWidgetItem(self.blameList, 
-            QStringList() << "%d" % revision << author << "%d" % lineno << text)
+        itm = QTreeWidgetItem(
+            self.blameList,
+            ["{0:d}".format(revision), author, "{0:d}".format(lineno), text])
         itm.setTextAlignment(0, Qt.AlignRight)
         itm.setTextAlignment(2, Qt.AlignRight)
         
@@ -130,7 +133,7 @@ class SvnBlameDialog(QDialog, SvnDialogMixin, Ui_SvnBlameDialog):
         """
         Private slot to show an error message.
         
-        @param msg error message to show (string or QString)
+        @param msg error message to show (string)
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
