@@ -9,13 +9,14 @@ Module implementing a dialog to enter the commit message.
 
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, Qt, pyqtSlot
+from PyQt4.QtGui import QWidget, QDialogButtonBox
 
-from Ui_SvnCommitDialog import Ui_SvnCommitDialog
+from .Ui_SvnCommitDialog import Ui_SvnCommitDialog
 
 import Preferences
 
+
 class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
     """
     Class implementing a dialog to enter the commit message.
@@ -23,14 +24,17 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
     @signal accepted() emitted, if the dialog was accepted
     @signal rejected() emitted, if the dialog was rejected
     """
-    def __init__(self, changelists, parent = None):
+    accepted = pyqtSignal()
+    rejected = pyqtSignal()
+    
+    def __init__(self, changelists, parent=None):
         """
         Constructor
         
         @param changelists list of available change lists (list of strings)
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self, parent, Qt.WindowFlags(Qt.Window))
+        super().__init__(parent, Qt.WindowFlags(Qt.Window))
         self.setupUi(self)
         
         if pysvn.svn_version < (1, 5, 0) or pysvn.version < (1, 6, 0):
@@ -44,8 +48,8 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         
         @param evt the event (QShowEvent)
         """
-        self.recentCommitMessages = \
-            Preferences.Prefs.settings.value('Subversion/Commits').toStringList()
+        self.recentCommitMessages = Preferences.toList(
+            Preferences.Prefs.settings.value('Subversion/Commits'))
         self.recentComboBox.clear()
         self.recentComboBox.addItem("")
         self.recentComboBox.addItems(self.recentCommitMessages)
@@ -57,17 +61,18 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         This method has the side effect of saving the 20 most recent
         commit messages for reuse.
         
-        @return the log message (QString)
+        @return the log message (string)
         """
         msg = self.logEdit.toPlainText()
-        if not msg.isEmpty():
-            self.recentCommitMessages.removeAll(msg)
-            self.recentCommitMessages.prepend(msg)
-            no = Preferences.Prefs.settings\
-                .value('Subversion/CommitMessages', QVariant(20)).toInt()[0]
+        if msg:
+            if msg in self.recentCommitMessages:
+                self.recentCommitMessages.remove(msg)
+            self.recentCommitMessages.insert(0, msg)
+            no = int(Preferences.Prefs.settings.value(
+                'Subversion/CommitMessages', 20))
             del self.recentCommitMessages[no:]
-            Preferences.Prefs.settings.setValue('Subversion/Commits', 
-                QVariant(self.recentCommitMessages))
+            Preferences.Prefs.settings.setValue(
+                'Subversion/Commits', self.recentCommitMessages)
         return msg
         
     def hasChangelists(self):
@@ -85,8 +90,8 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         @return tuple containing the changelists (list of strings) and a flag
             indicating to keep changelists (boolean)
         """
-        slists = [unicode(l.text()).strip() for l in self.changeLists.selectedItems()
-                  if unicode(l.text()).strip() != ""]
+        slists = [l.text().strip() for l in self.changeLists.selectedItems()
+                  if l.text().strip() != ""]
         
         if len(slists) == 0:
             return [], False
@@ -107,19 +112,21 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         Private slot called by the buttonBox accepted signal.
         """
         self.close()
-        self.emit(SIGNAL("accepted()"))
+        self.accepted.emit()
         
     def on_buttonBox_rejected(self):
         """
         Private slot called by the buttonBox rejected signal.
         """
         self.close()
-        self.emit(SIGNAL("rejected()"))
+        self.rejected.emit()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_recentComboBox_activated(self, txt):
         """
         Private slot to select a commit message from recent ones.
+        
+        @param txt selected recent commit message (string)
         """
-        if not txt.isEmpty():
+        if txt:
             self.logEdit.setPlainText(txt)
