@@ -9,38 +9,39 @@ Module implementing a dialog to enter the data for a copy operation.
 
 import os.path
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter, E4DirCompleter
-
-from Ui_SvnCopyDialog import Ui_SvnCopyDialog
+from .Ui_SvnCopyDialog import Ui_SvnCopyDialog
 
 import Utilities
 
+
 class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
     """
-    Class implementing a dialog to enter the data for a copy or rename operation.
+    Class implementing a dialog to enter the data for a copy or rename
+    operation.
     """
-    def __init__(self, source, parent = None, move = False, force = False):
+    def __init__(self, source, parent=None, move=False, force=False):
         """
         Constructor
         
-        @param source name of the source file/directory (QString)
+        @param source name of the source file/directory (string)
         @param parent parent widget (QWidget)
         @param move flag indicating a move operation (boolean)
         @param force flag indicating a forced operation (boolean)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.source = source
         if os.path.isdir(self.source):
-            self.targetCompleter = E4DirCompleter(self.targetEdit)
+            self.targetCompleter = E5DirCompleter(self.targetEdit)
         else:
-            self.targetCompleter = E4FileCompleter(self.targetEdit)
+            self.targetCompleter = E5FileCompleter(self.targetEdit)
         
         if move:
             self.setWindowTitle(self.trUtf8('Subversion Move'))
@@ -56,47 +57,45 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         """
         Public method to retrieve the copy data.
         
-        @return the target name (QString) and a flag indicating
+        @return the target name (string) and a flag indicating
             the operation should be enforced (boolean)
         """
-        target = unicode(self.targetEdit.text())
+        target = self.targetEdit.text()
         if not os.path.isabs(target):
-            sourceDir = os.path.dirname(unicode(self.sourceEdit.text()))
+            sourceDir = os.path.dirname(self.sourceEdit.text())
             target = os.path.join(sourceDir, target)
-        return (QString(Utilities.toNativeSeparators(target)),
+        return (Utilities.toNativeSeparators(target),
                 self.forceCheckBox.isChecked())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_dirButton_clicked(self):
         """
-        Private slot to handle the button press for selecting the target via a 
+        Private slot to handle the button press for selecting the target via a
         selection dialog.
         """
         if os.path.isdir(self.source):
-            target = KQFileDialog.getExistingDirectory(\
+            target = E5FileDialog.getExistingDirectory(
                 None,
                 self.trUtf8("Select target"),
                 self.targetEdit.text(),
-                QFileDialog.Options(QFileDialog.ShowDirsOnly))
+                E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         else:
-            target = KQFileDialog.getSaveFileName(\
+            target = E5FileDialog.getSaveFileName(
                 None,
                 self.trUtf8("Select target"),
                 self.targetEdit.text(),
-                QString(),
-                None,
-                QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+                "",
+                E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if not target.isEmpty():
+        if target:
             self.targetEdit.setText(Utilities.toNativeSeparators(target))
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_targetEdit_textChanged(self, txt):
         """
         Private slot to handle changes of the target.
         
-        @param txt contents of the target edit (QString)
+        @param txt contents of the target edit (string)
         """
-        txt = unicode(txt)
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
             os.path.isabs(txt) or os.path.dirname(txt) == "")
