@@ -7,36 +7,34 @@
 Module implementing a dialog to show the output of a pysvn action.
 """
 
-import os
-
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog, QApplication, QDialogButtonBox
 
-from SvnConst import svnNotifyActionMap
+from .SvnConst import svnNotifyActionMap
 
-from SvnDialogMixin import SvnDialogMixin
-from Ui_SvnDialog import Ui_SvnDialog
+from .SvnDialogMixin import SvnDialogMixin
+from .Ui_SvnDialog import Ui_SvnDialog
 
 import Preferences
 
+
 class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
     """
     Class implementing a dialog to show the output of a pysvn action.
     """
-    def __init__(self, text, command, pysvnClient, parent = None, log = ""):
+    def __init__(self, text, command, pysvnClient, parent=None, log=""):
         """
         Constructor
         
-        @param text text to be shown by the label (string or QString)
+        @param text text to be shown by the label (string)
         @param command svn command to be executed (display purposes only)
-            (string or QString)
+            (string)
         @param pysvnClient reference to the pysvn client object (pysvn.Client)
         @keyparam parent parent widget (QWidget)
-        @keyparam log optional log message (string or QString)
+        @keyparam log optional log message (string)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self, log)
         
@@ -60,7 +58,6 @@ class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
         
         self.__hasAddOrDelete = False
         
-        command = unicode(command)
         if command:
             self.resultbox.append(command)
             self.resultbox.append('')
@@ -70,35 +67,40 @@ class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
         
     def _clientNotifyCallback(self, eventDict):
         """
-        Protected method called by the client to send events
+        Protected method called by the client to send events.
         
         @param eventDict dictionary containing the notification event
         """
-        msg = QString()
+        msg = ""
         if eventDict["action"] == pysvn.wc_notify_action.update_completed:
-            msg = self.trUtf8("Revision %1.\n").arg(eventDict["revision"].number)
+            msg = self.trUtf8("Revision {0}.\n").format(
+                eventDict["revision"].number)
         elif eventDict["path"] != "" and \
-             eventDict["action"] in svnNotifyActionMap and \
-             svnNotifyActionMap[eventDict["action"]] is not None:
+            eventDict["action"] in svnNotifyActionMap and \
+                svnNotifyActionMap[eventDict["action"]] is not None:
             mime = eventDict["mime_type"] == "application/octet-stream" and \
-                self.trUtf8(" (binary)") or QString("")
-            msg = self.trUtf8("%1 %2%3\n")\
-                .arg(self.trUtf8(svnNotifyActionMap[eventDict["action"]]))\
-                .arg(eventDict["path"])\
-                .arg(mime)
-            if eventDict["action"] in \
-               [pysvn.wc_notify_action.add, pysvn.wc_notify_action.commit_added, 
-                pysvn.wc_notify_action.commit_deleted, pysvn.wc_notify_action.delete, 
-                pysvn.wc_notify_action.update_add, pysvn.wc_notify_action.update_delete]:
+                self.trUtf8(" (binary)") or ""
+            msg = self.trUtf8("{0} {1}{2}\n")\
+                .format(self.trUtf8(svnNotifyActionMap[eventDict["action"]]),
+                        eventDict["path"],
+                        mime)
+            if '.e4p' in eventDict["path"]:
                 self.__hasAddOrDelete = True
-        if not msg.isEmpty():
+            if eventDict["action"] in [pysvn.wc_notify_action.add,
+                                       pysvn.wc_notify_action.commit_added,
+                                       pysvn.wc_notify_action.commit_deleted,
+                                       pysvn.wc_notify_action.delete,
+                                       pysvn.wc_notify_action.update_add,
+                                       pysvn.wc_notify_action.update_delete]:
+                self.__hasAddOrDelete = True
+        if msg:
             self.showMessage(msg)
         
     def showMessage(self, msg):
         """
         Public slot to show a message.
         
-        @param msg message to show (string or QString)
+        @param msg message to show (string)
         """
         self.resultbox.insertPlainText(msg)
         self.resultbox.ensureCursorVisible()
@@ -108,7 +110,7 @@ class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
         """
         Public slot to show an error message.
         
-        @param msg error message to show (string or QString)
+        @param msg error message to show (string)
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
@@ -117,7 +119,8 @@ class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
         
     def finish(self):
         """
-        Public slot called when the process finished or the user pressed the button.
+        Public slot called when the process finished or the user pressed the
+        button.
         """
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -142,5 +145,7 @@ class SvnDialog(QDialog, SvnDialogMixin, Ui_SvnDialog):
     def hasAddOrDelete(self):
         """
         Public method to check, if the last action contained an add or delete.
+        
+        @return flag indicating the presence of an add or delete (boolean)
         """
         return self.__hasAddOrDelete
