@@ -4,22 +4,23 @@
 #
 
 """
-Module implementing a dialog mixin class providing common callback methods for 
+Module implementing a dialog mixin class providing common callback methods for
 the pysvn client.
 """
 
 from PyQt4.QtGui import QApplication, QDialog, QWidget, QCursor
 
+
 class SvnDialogMixin(object):
     """
-    Class implementing a dialog mixin providing common callback methods for 
+    Class implementing a dialog mixin providing common callback methods for
     the pysvn client.
     """
-    def __init__(self, log = ""):
+    def __init__(self, log=""):
         """
         Constructor
         
-        @param log optional log message (string or QString)
+        @param log optional log message (string)
         """
         self.shouldCancel = False
         self.logMessage = log
@@ -54,12 +55,12 @@ class SvnDialogMixin(object):
         @param may_save flag indicating, that subversion is willing to save
             the answers returned (boolean)
         @return tuple of four values (retcode, username, password, save).
-            Retcode should be True, if username and password should be used 
-            by subversion, username and password contain the relevant data 
+            Retcode should be True, if username and password should be used
+            by subversion, username and password contain the relevant data
             as strings and save is a flag indicating, that username and
             password should be saved.
         """
-        from SvnLoginDialog import SvnLoginDialog
+        from .SvnLoginDialog import SvnLoginDialog
         cursor = QCursor(QApplication.overrideCursor())
         if cursor is not None:
             QApplication.restoreOverrideCursor()
@@ -85,38 +86,36 @@ class SvnDialogMixin(object):
             acceptedFailures should indicate the accepted certificate failures
             and save should be True, if subversion should save the certificate.
         """
-        from KdeQt import KQMessageBox
-        from PyQt4.QtGui import QMessageBox
-        
+        from E5Gui import E5MessageBox
+
         cursor = QCursor(QApplication.overrideCursor())
         if cursor is not None:
             QApplication.restoreOverrideCursor()
         parent = isinstance(self, QWidget) and self or None
-        msgBox = KQMessageBox.KQMessageBox(QMessageBox.Question,
+        msgBox = E5MessageBox.E5MessageBox(
+            E5MessageBox.Question,
             self.trUtf8("Subversion SSL Server Certificate"),
             self.trUtf8("""<p>Accept the following SSL certificate?</p>"""
                         """<table>"""
-                        """<tr><td>Realm:</td><td>%1</td></tr>"""
-                        """<tr><td>Hostname:</td><td>%2</td></tr>"""
-                        """<tr><td>Fingerprint:</td><td>%3</td></tr>"""
-                        """<tr><td>Valid from:</td><td>%4</td></tr>"""
-                        """<tr><td>Valid until:</td><td>%5</td></tr>"""
-                        """<tr><td>Issuer name:</td><td>%6</td></tr>"""
-                        """</table>""")\
-                .arg(trust_dict["realm"])\
-                .arg(trust_dict["hostname"])\
-                .arg(trust_dict["finger_print"])\
-                .arg(trust_dict["valid_from"])\
-                .arg(trust_dict["valid_until"])\
-                .arg(trust_dict["issuer_dname"]),
-            QMessageBox.StandardButtons(QMessageBox.NoButton),
-            parent)
-        permButton = msgBox.addButton(self.trUtf8("&Permanent accept"), 
-                                      QMessageBox.AcceptRole)
-        tempButton = msgBox.addButton(self.trUtf8("&Temporary accept"), 
-                                      QMessageBox.AcceptRole)
-        rejectButton = msgBox.addButton(self.trUtf8("&Reject"), 
-                                        QMessageBox.RejectRole)
+                        """<tr><td>Realm:</td><td>{0}</td></tr>"""
+                        """<tr><td>Hostname:</td><td>{1}</td></tr>"""
+                        """<tr><td>Fingerprint:</td><td>{2}</td></tr>"""
+                        """<tr><td>Valid from:</td><td>{3}</td></tr>"""
+                        """<tr><td>Valid until:</td><td>{4}</td></tr>"""
+                        """<tr><td>Issuer name:</td><td>{5}</td></tr>"""
+                        """</table>""")
+                .format(trust_dict["realm"],
+                        trust_dict["hostname"],
+                        trust_dict["finger_print"],
+                        trust_dict["valid_from"],
+                        trust_dict["valid_until"],
+                        trust_dict["issuer_dname"]),
+            modal=True, parent=parent)
+        permButton = msgBox.addButton(self.trUtf8("&Permanent accept"),
+                                      E5MessageBox.AcceptRole)
+        tempButton = msgBox.addButton(self.trUtf8("&Temporary accept"),
+                                      E5MessageBox.AcceptRole)
+        msgBox.addButton(self.trUtf8("&Reject"), E5MessageBox.RejectRole)
         msgBox.exec_()
         if cursor is not None:
             QApplication.setOverrideCursor(cursor)
@@ -133,14 +132,14 @@ class SvnDialogMixin(object):
         
         @return a flag indicating success and the log message (string)
         """
-        from SvnCommitDialog import SvnCommitDialog
+        from .SvnCommitDialog import SvnCommitDialog
         if self.logMessage:
             return True, self.logMessage
         else:
             # call CommitDialog and get message from there
             dlg = SvnCommitDialog(self)
             if dlg.exec_() == QDialog.Accepted:
-                msg = unicode(dlg.logMessage())
+                msg = dlg.logMessage()
                 if msg:
                     return True, msg
                 else:
