@@ -4,38 +4,40 @@
 #
 
 """
-Module implementing a dialog to show the output of the svn diff command process.
+Module implementing a dialog to show the output of the svn diff command
+process.
 """
 
 import os
-import sys
-import types
 
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QMutexLocker, QFileInfo, QDateTime, Qt, pyqtSlot
+from PyQt4.QtGui import QWidget, QColor, QCursor, QBrush, QApplication, \
+    QTextCursor, QDialogButtonBox
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox, E5FileDialog
 
-from SvnDialogMixin import SvnDialogMixin
-from Ui_SvnDiffDialog import Ui_SvnDiffDialog
+from .SvnDialogMixin import SvnDialogMixin
+from .Ui_SvnDiffDialog import Ui_SvnDiffDialog
 
 import Utilities
+import Preferences
+
 
 class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
     """
     Class implementing a dialog to show the output of the svn diff command.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -45,10 +47,9 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         
         self.vcs = vcs
         
-        if Utilities.isWindowsPlatform():
-            self.contents.setFontFamily("Lucida Console")
-        else:
-            self.contents.setFontFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.contents.setFontFamily(font.family())
+        self.contents.setFontPointSize(font.pointSize())
         
         self.cNormalFormat = self.contents.currentCharFormat()
         self.cAddedFormat = self.contents.currentCharFormat()
@@ -68,12 +69,13 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         
     def __getVersionArg(self, version):
         """
-        Private method to get a pysvn revision object for the given version number.
+        Private method to get a pysvn revision object for the given version
+        number.
         
         @param version revision (integer or string)
         @return revision object (pysvn.Revision)
         """
-        if type(version) == type(1) or type(version) == type(1L):
+        if isinstance(version, int):
             return pysvn.Revision(pysvn.opt_revision_kind.number, version)
         elif version.startswith("{"):
             dateStr = version[1:-1]
@@ -97,7 +99,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         Private method to get a string descripion of the diff summary.
         
         @param summaryKind (pysvn.diff_summarize.summarize_kind)
-        @return one letter string indicating the change type (QString)
+        @return one letter string indicating the change type (string)
         """
         if summaryKind == pysvn.diff_summarize_kind.delete:
             return "D"
@@ -110,14 +112,15 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         else:
             return " "
         
-    def start(self, fn, versions = None, urls = None, summary = False, pegRev = None):
+    def start(self, fn, versions=None, urls=None, summary=False, pegRev=None):
         """
         Public slot to start the svn diff command.
         
         @param fn filename to be diffed (string)
-        @param versions list of versions to be diffed (list of up to 2 integer or None)
+        @param versions list of versions to be diffed (list of up to 2 integer
+            or None)
         @keyparam urls list of repository URLs (list of 2 strings)
-        @keyparam summary flag indicating a summarizing diff 
+        @keyparam summary flag indicating a summarizing diff
             (only valid for URL diffs) (boolean)
         @keyparam pegRev revision number the filename is valid (integer)
         """
@@ -136,6 +139,12 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.contents.clear()
         self.paras = 0
         
+        self.filesCombo.clear()
+        
+        self.__oldFile = ""
+        self.__oldFileLine = -1
+        self.__fileSeparators = []
+        
         if Utilities.hasEnvironmentEntry('TEMP'):
             tmpdir = Utilities.getEnvironmentEntry('TEMP')
         elif Utilities.hasEnvironmentEntry('TMPDIR'):
@@ -149,7 +158,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         elif os.path.exists('/tmp'):
             tmpdir = '/tmp'
         else:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Subversion Diff"),
                 self.trUtf8("""There is no temporary directory available."""))
             return
@@ -177,7 +187,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
             rev1 = self.__getVersionArg("HEAD")
             rev2 = self.__getVersionArg("HEAD")
         
-        if type(fn) is types.ListType:
+        if isinstance(fn, list):
             dname, fnames = self.vcs.splitPathList(fn)
         else:
             dname, fname = self.vcs.splitPath(fn)
@@ -187,41 +197,51 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         cwd = os.getcwd()
         os.chdir(dname)
         try:
-            dname = e4App().getObject('Project').getRelativePath(dname)
+            dname = e5App().getObject('Project').getRelativePath(dname)
             if dname:
                 dname += "/"
             for name in fnames:
-                self.__showError(self.trUtf8("Processing file '%1'...\n").arg(name))
+                self.__showError(
+                    self.trUtf8("Processing file '{0}'...\n").format(name))
                 if urls is not None:
-                    url1 = "%s/%s%s" % (urls[0], dname, name)
-                    url2 = "%s/%s%s" % (urls[1], dname, name)
+                    url1 = "{0}/{1}{2}".format(urls[0], dname, name)
+                    url2 = "{0}/{1}{2}".format(urls[1], dname, name)
                     if summary:
-                        diff_summary = self.client.diff_summarize(\
-                            url1, revision1 = rev1, 
-                            url_or_path2 = url2, revision2 = rev2, 
-                            recurse = recurse)
+                        diff_summary = self.client.diff_summarize(
+                            url1, revision1=rev1,
+                            url_or_path2=url2, revision2=rev2,
+                            recurse=recurse)
                         diff_list = []
                         for diff_sum in diff_summary:
-                            diff_list.append("%s %s" % \
-                                (self.__getDiffSummaryKind(diff_sum['summarize_kind']),
-                                 diff_sum['path']))
+                            diff_list.append("{0} {1}".format(
+                                self.__getDiffSummaryKind(
+                                    diff_sum['summarize_kind']),
+                                diff_sum['path']))
                         diffText = os.linesep.join(diff_list)
                     else:
-                        diffText = self.client.diff(tmpdir, 
-                            url1, revision1 = rev1, 
-                            url_or_path2 = url2, revision2 = rev2, 
-                            recurse = recurse)
+                        diffText = self.client.diff(
+                            tmpdir,
+                            url1, revision1=rev1,
+                            url_or_path2=url2, revision2=rev2,
+                            recurse=recurse)
                 else:
                     if pegRev is not None:
-                        diffText = self.client.diff_peg(tmpdir, name, 
-                            peg_revision = self.__getVersionArg(pegRev), 
-                            revision_start = rev1, revision_end = rev2, recurse = recurse)
+                        diffText = self.client.diff_peg(
+                            tmpdir, name,
+                            peg_revision=self.__getVersionArg(pegRev),
+                            revision_start=rev1, revision_end=rev2,
+                            recurse=recurse)
                     else:
-                        diffText = self.client.diff(tmpdir, name, 
-                            revision1 = rev1, revision2 = rev2, recurse = recurse)
+                        diffText = self.client.diff(
+                            tmpdir, name,
+                            revision1=rev1, revision2=rev2, recurse=recurse)
                 counter = 0
                 for line in diffText.splitlines():
-                    self.__appendText("%s%s" % (line, os.linesep))
+                    if line.startswith("--- ") or \
+                       line.startswith("+++ "):
+                        self.__processFileLine(line)
+                    
+                    self.__appendText("{0}{1}".format(line, os.linesep))
                     counter += 1
                     if counter == 30:
                         # check for cancel every 30 lines
@@ -230,14 +250,14 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
                             break
                 if self._clientCancelCallback():
                     break
-        except pysvn.ClientError, e:
+        except pysvn.ClientError as e:
             self.__showError(e.args[0])
         locker.unlock()
         os.chdir(cwd)
         self.__finish()
         
         if self.paras == 0:
-            self.contents.insertPlainText(\
+            self.contents.insertPlainText(
                 self.trUtf8('There is no difference.'))
             return
         
@@ -249,9 +269,11 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         
         @param line line of text to insert (string)
         """
-        if line.startswith('+') or line.startswith('>') or line.startswith('A '):
+        if line.startswith('+') or line.startswith('>') or \
+                line.startswith('A '):
             format = self.cAddedFormat
-        elif line.startswith('-') or line.startswith('<') or line.startswith('D '):
+        elif line.startswith('-') or line.startswith('<') or \
+                line.startswith('D '):
             format = self.cRemovedFormat
         elif line.startswith('@@'):
             format = self.cLineNoFormat
@@ -265,6 +287,31 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.contents.insertPlainText(line)
         self.paras += 1
         
+    def __extractFileName(self, line):
+        """
+        Private method to extract the file name out of a file separator line.
+        
+        @param line line to be processed (string)
+        @return extracted file name (string)
+        """
+        f = line.split(None, 1)[1]
+        f = f.rsplit(None, 2)[0]
+        return f
+    
+    def __processFileLine(self, line):
+        """
+        Private slot to process a line giving the old/new file.
+        
+        @param line line to be processed (string)
+        """
+        if line.startswith('---'):
+            self.__oldFileLine = self.paras
+            self.__oldFile = self.__extractFileName(line)
+        else:
+            self.__fileSeparators.append(
+                (self.__oldFile, self.__extractFileName(line),
+                 self.__oldFileLine))
+    
     def __finish(self):
         """
         Private slot called when the user pressed the button.
@@ -280,6 +327,15 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         self.contents.setTextCursor(tc)
         self.contents.ensureCursorVisible()
         
+        self.filesCombo.addItem(self.trUtf8("<Start>"), 0)
+        self.filesCombo.addItem(self.trUtf8("<End>"), -1)
+        for oldFile, newFile, pos in sorted(self.__fileSeparators):
+            if oldFile != newFile:
+                self.filesCombo.addItem(
+                    "{0}\n{1}".format(oldFile, newFile), pos)
+            else:
+                self.filesCombo.addItem(oldFile, pos)
+        
         self._cancel()
         
     def on_buttonBox_clicked(self, button):
@@ -295,7 +351,41 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         elif button == self.buttonBox.button(QDialogButtonBox.Save):
             self.on_saveButton_clicked()
         
-    @pyqtSignature("")
+    @pyqtSlot(int)
+    def on_filesCombo_activated(self, index):
+        """
+        Private slot to handle the selection of a file.
+        
+        @param index activated row (integer)
+        """
+        para = self.filesCombo.itemData(index)
+        
+        if para == 0:
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.Start)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+        elif para == -1:
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.End)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+        else:
+            # step 1: move cursor to end
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.End)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+            
+            # step 2: move cursor to desired line
+            tc = self.contents.textCursor()
+            delta = tc.blockNumber() - para
+            tc.movePosition(QTextCursor.PreviousBlock, QTextCursor.MoveAnchor,
+                            delta)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+    
+    @pyqtSlot()
     def on_saveButton_clicked(self):
         """
         Private slot to handle the Save button press.
@@ -303,63 +393,63 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         It saves the diff shown in the dialog to a file in the local
         filesystem.
         """
-        if type(self.filename) is types.ListType:
+        if isinstance(self.filename, list):
             if len(self.filename) > 1:
                 fname = self.vcs.splitPathList(self.filename)[0]
             else:
                 dname, fname = self.vcs.splitPath(self.filename[0])
                 if fname != '.':
-                    fname = "%s.diff" % self.filename[0]
+                    fname = "{0}.diff".format(self.filename[0])
                 else:
                     fname = dname
         else:
             fname = self.vcs.splitPath(self.filename)[0]
         
-        selectedFilter = QString("")
-        fname = KQFileDialog.getSaveFileName(\
+        fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
             self.trUtf8("Save Diff"),
             fname,
             self.trUtf8("Patch Files (*.diff)"),
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+            None,
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if fname.isEmpty():
-            return
+        if not fname:
+            return  # user aborted
         
         ext = QFileInfo(fname).suffix()
-        if ext.isEmpty():
-            ex = selectedFilter.section('(*',1,1).section(')',0,0)
-            if not ex.isEmpty():
-                fname.append(ex)
+        if not ext:
+            ex = selectedFilter.split("(*")[1].split(")")[0]
+            if ex:
+                fname += ex
         if QFileInfo(fname).exists():
-            res = KQMessageBox.warning(self,
+            res = E5MessageBox.yesNo(
+                self,
                 self.trUtf8("Save Diff"),
-                self.trUtf8("<p>The patch file <b>%1</b> already exists.</p>")
-                    .arg(fname),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.Abort | \
-                    QMessageBox.Save),
-                QMessageBox.Abort)
-            if res != QMessageBox.Save:
+                self.trUtf8("<p>The patch file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
+                icon=E5MessageBox.Warning)
+            if not res:
                 return
-        fname = unicode(Utilities.toNativeSeparators(fname))
+        fname = Utilities.toNativeSeparators(fname)
         
+        eol = e5App().getObject("Project").getEolString()
         try:
-            f = open(fname, "wb")
-            f.write(unicode(self.contents.toPlainText()))
+            f = open(fname, "w", encoding="utf-8", newline="")
+            f.write(eol.join(self.contents.toPlainText().splitlines()))
             f.close()
-        except IOError, why:
-            KQMessageBox.critical(self, self.trUtf8('Save Diff'),
-                self.trUtf8('<p>The patch file <b>%1</b> could not be saved.'
-                    '<br>Reason: %2</p>')
-                    .arg(unicode(fname)).arg(str(why)))
+        except IOError as why:
+            E5MessageBox.critical(
+                self, self.trUtf8('Save Diff'),
+                self.trUtf8(
+                    '<p>The patch file <b>{0}</b> could not be saved.'
+                    '<br>Reason: {1}</p>')
+                .format(fname, str(why)))
         
     def __showError(self, msg):
         """
         Private slot to show an error message.
         
-        @param msg error message to show (string or QString)
+        @param msg error message to show (string)
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
