@@ -11,33 +11,34 @@ import os
 
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QMutexLocker, QDate, QRegExp, Qt, pyqtSlot
+from PyQt4.QtGui import QCursor, QHeaderView, QDialog, QApplication, \
+    QDialogButtonBox, QTreeWidgetItem
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from SvnUtilities import formatTime, dateFromTime_t
-from SvnDialogMixin import SvnDialogMixin
-from SvnDiffDialog import SvnDiffDialog
+from .SvnUtilities import formatTime, dateFromTime_t
+from .SvnDialogMixin import SvnDialogMixin
 
-from Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
+from .Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
 
-import UI.PixmapCache
 
 class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
     """
     Class implementing a dialog to browse the log history.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, isFile=False, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
+        @param isFile flag indicating log for a file is to be shown (boolean)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
+        self.setWindowFlags(self.windowFlags() | Qt.WindowMinMaxButtonsHint)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -45,6 +46,9 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(0, Qt.AscendingOrder)
         
+        self.sbsCheckBox.setEnabled(isFile)
+        self.sbsCheckBox.setVisible(isFile)
+        
         self.vcs = vcs
         
         self.__maxDate = QDate()
@@ -55,19 +59,21 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         self.toDate.setDisplayFormat("yyyy-MM-dd")
         self.fromDate.setDate(QDate.currentDate())
         self.toDate.setDate(QDate.currentDate())
-        self.fieldCombo.setCurrentIndex(self.fieldCombo.findText(self.trUtf8("Message")))
-        self.clearRxEditButton.setIcon(UI.PixmapCache.getIcon("clearLeft.png"))
-        self.limitSpinBox.setValue(self.vcs.getPlugin().getPreferences("LogLimit"))
-        self.stopCheckBox.setChecked(self.vcs.getPlugin().getPreferences("StopLogOnCopy"))
+        self.fieldCombo.setCurrentIndex(
+            self.fieldCombo.findText(self.trUtf8("Message")))
+        self.limitSpinBox.setValue(
+            self.vcs.getPlugin().getPreferences("LogLimit"))
+        self.stopCheckBox.setChecked(
+            self.vcs.getPlugin().getPreferences("StopLogOnCopy"))
         
         self.__messageRole = Qt.UserRole
         self.__changesRole = Qt.UserRole + 1
         
         self.flags = {
-            'A' : self.trUtf8('Added'),
-            'D' : self.trUtf8('Deleted'),
-            'M' : self.trUtf8('Modified'),
-            'R' : self.trUtf8('Replaced'),
+            'A': self.trUtf8('Added'),
+            'D': self.trUtf8('Deleted'),
+            'M': self.trUtf8('Modified'),
+            'R': self.trUtf8('Replaced'),
         }
         
         self.diff = None
@@ -105,7 +111,8 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private method to resort the log tree.
         """
-        self.logTree.sortItems(self.logTree.sortColumn(), 
+        self.logTree.sortItems(
+            self.logTree.sortColumn(),
             self.logTree.header().sortIndicatorOrder())
     
     def __resizeColumnsFiles(self):
@@ -120,21 +127,21 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         Private method to resort the changed files tree.
         """
         sortColumn = self.filesTree.sortColumn()
-        self.filesTree.sortItems(1, 
-            self.filesTree.header().sortIndicatorOrder())
-        self.filesTree.sortItems(sortColumn, 
-            self.filesTree.header().sortIndicatorOrder())
+        self.filesTree.sortItems(
+            1, self.filesTree.header().sortIndicatorOrder())
+        self.filesTree.sortItems(
+            sortColumn, self.filesTree.header().sortIndicatorOrder())
     
     def __generateLogItem(self, author, date, message, revision, changedPaths):
         """
         Private method to generate a log tree entry.
         
-        @param author author info (string or QString)
+        @param author author info (string)
         @param date date info (integer)
-        @param message text of the log message (string or QString)
+        @param message text of the log message (string)
         @param revision revision info (string or pysvn.opt_revision_kind)
         @param changedPaths list of pysvn dictionary like objects containing
-            info about the changed files/directories 
+            info about the changed files/directories
         @return reference to the generated item (QTreeWidgetItem)
         """
         if revision == "":
@@ -163,16 +170,17 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             if changedPath["copyfrom_revision"] is None:
                 copyRev = ""
             else:
-                copyRev = "%7d" % changedPath["copyfrom_revision"].number
+                copyRev = "{0:7d}".format(
+                    changedPath["copyfrom_revision"].number)
             change = {
-                "action"            : changedPath["action"], 
-                "path"              : changedPath["path"], 
-                "copyfrom_path"     : copyPath, 
-                "copyfrom_revision" : copyRev, 
+                "action": changedPath["action"],
+                "path": changedPath["path"],
+                "copyfrom_path": copyPath,
+                "copyfrom_revision": copyRev,
             }
             changes.append(change)
-        itm.setData(0, self.__messageRole, QVariant(message))
-        itm.setData(0, self.__changesRole, QVariant(unicode(changes)))
+        itm.setData(0, self.__messageRole, message)
+        itm.setData(0, self.__changesRole, changes)
         
         itm.setTextAlignment(0, Qt.AlignRight)
         itm.setTextAlignment(1, Qt.AlignLeft)
@@ -187,27 +195,25 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         Private method to generate a changed files tree entry.
         
         @param action indicator for the change action ("A", "D" or "M")
-        @param path path of the file in the repository (string or QString)
-        @param copyFrom path the file was copied from (None, string or QString)
-        @param copyRev revision the file was copied from (None, string or QString)
+        @param path path of the file in the repository (string)
+        @param copyFrom path the file was copied from (None, string)
+        @param copyRev revision the file was copied from (None, string)
         @return reference to the generated item (QTreeWidgetItem)
         """
-        itm = QTreeWidgetItem(self.filesTree, QStringList()
-            << self.flags[action] \
-            << path \
-            << copyFrom \
-            << copyRev
+        itm = QTreeWidgetItem(
+            self.filesTree,
+            [self.flags[action], path, copyFrom, copyRev]
         )
         
         itm.setTextAlignment(3, Qt.AlignRight)
         
         return itm
     
-    def __getLogEntries(self, startRev = None):
+    def __getLogEntries(self, startRev=None):
         """
         Private method to retrieve log entries from the repository.
         
-        @param startRev revision number to start from (integer, string or QString)
+        @param startRev revision number to start from (integer, string)
         """
         fetchLimit = 10
         self._reset()
@@ -220,7 +226,8 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             start = pysvn.Revision(pysvn.opt_revision_kind.head)
         else:
             try:
-                start = pysvn.Revision(pysvn.opt_revision_kind.number, int(startRev))
+                start = pysvn.Revision(pysvn.opt_revision_kind.number,
+                                       int(startRev))
             except TypeError:
                 start = pysvn.Revision(pysvn.opt_revision_kind.head)
         
@@ -228,6 +235,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         cwd = os.getcwd()
         os.chdir(self.dname)
         try:
+            nextRev = 0
             fetched = 0
             logs = []
             while fetched < limit:
@@ -235,13 +243,12 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
                 if fetched == 0:
                     revstart = start
                 else:
-                    revstart = pysvn.Revision(\
+                    revstart = pysvn.Revision(
                         pysvn.opt_revision_kind.number, nextRev)
-                allLogs = self.client.log(self.fname, 
-                            revision_start = revstart, 
-                            discover_changed_paths = True,
-                            limit = flimit + 1,
-                            strict_node_history = self.stopCheckBox.isChecked())
+                allLogs = self.client.log(
+                    self.fname, revision_start=revstart,
+                    discover_changed_paths=True, limit=flimit + 1,
+                    strict_node_history=self.stopCheckBox.isChecked())
                 if len(allLogs) <= flimit or self._clientCancelCallback():
                     logs.extend(allLogs)
                     break
@@ -252,10 +259,12 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             locker.unlock()
             
             for log in logs:
-                self.__generateLogItem(log["author"], log["date"], 
-                    log["message"], log["revision"], log['changed_paths'])
+                self.__generateLogItem(
+                    log["author"], log["date"], log["message"],
+                    log["revision"], log['changed_paths'])
                 dt = dateFromTime_t(log["date"])
-                if not self.__maxDate.isValid() and not self.__minDate.isValid():
+                if not self.__maxDate.isValid() and \
+                        not self.__minDate.isValid():
                     self.__maxDate = dt
                     self.__minDate = dt
                 else:
@@ -278,7 +287,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             self.__resizeColumnsLog()
             self.__resortLog()
             self.__filterLogs()
-        except pysvn.ClientError, e:
+        except pysvn.ClientError as e:
             locker.unlock()
             self.__showError(e.args[0])
         os.chdir(cwd)
@@ -320,11 +329,17 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         @param rev2 second revision number (integer)
         @param peg_rev revision number to use as a reference (integer)
         """
-        if self.diff is None:
-            self.diff = SvnDiffDialog(self.vcs)
-        self.diff.show()
-        QApplication.processEvents()
-        self.diff.start(self.filename, [rev1, rev2], pegRev = peg_rev)
+        if self.sbsCheckBox.isEnabled() and self.sbsCheckBox.isChecked():
+            self.vcs.svnSbsDiff(self.filename,
+                                revisions=(str(rev1), str(rev2)))
+        else:
+            if self.diff is None:
+                from .SvnDiffDialog import SvnDiffDialog
+                self.diff = SvnDiffDialog(self.vcs)
+            self.diff.show()
+            self.diff.raise_()
+            QApplication.processEvents()
+            self.diff.start(self.filename, [rev1, rev2], pegRev=peg_rev)
     
     def on_buttonBox_clicked(self, button):
         """
@@ -338,7 +353,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             self.cancelled = True
             self.__finish()
     
-    @pyqtSignature("QTreeWidgetItem*, QTreeWidgetItem*")
+    @pyqtSlot(QTreeWidgetItem, QTreeWidgetItem)
     def on_logTree_currentItemChanged(self, current, previous):
         """
         Private slot called, when the current item of the log tree changes.
@@ -346,28 +361,31 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         @param current reference to the new current item (QTreeWidgetItem)
         @param previous reference to the old current item (QTreeWidgetItem)
         """
-        self.messageEdit.setPlainText(current.data(0, self.__messageRole).toString())
+        self.messageEdit.setPlainText(current.data(0, self.__messageRole))
         
         self.filesTree.clear()
-        changes = eval(unicode(current.data(0, self.__changesRole).toString()))
+        changes = current.data(0, self.__changesRole)
         if len(changes) > 0:
             for change in changes:
-                self.__generateFileItem(change["action"], change["path"], 
+                self.__generateFileItem(
+                    change["action"], change["path"],
                     change["copyfrom_path"], change["copyfrom_revision"])
             self.__resizeColumnsFiles()
             self.__resortFiles()
         
-        self.diffPreviousButton.setEnabled(\
-            current != self.logTree.topLevelItem(self.logTree.topLevelItemCount() - 1))
+        self.diffPreviousButton.setEnabled(
+            current != self.logTree.topLevelItem(
+                self.logTree.topLevelItemCount() - 1))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_logTree_itemSelectionChanged(self):
         """
         Private slot called, when the selection has changed.
         """
-        self.diffRevisionsButton.setEnabled(len(self.logTree.selectedItems()) == 2)
+        self.diffRevisionsButton.setEnabled(
+            len(self.logTree.selectedItems()) == 2)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_nextButton_clicked(self):
         """
         Private slot to handle the Next button.
@@ -375,7 +393,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         if self.__lastRev > 1:
             self.__getLogEntries(self.__lastRev - 1)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffPreviousButton_clicked(self):
         """
         Private slot to handle the Diff to Previous button.
@@ -392,7 +410,8 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             return
         rev2 = int(itm.text(0))
         
-        itm = self.logTree.topLevelItem(self.logTree.indexOfTopLevelItem(itm) + 1)
+        itm = self.logTree.topLevelItem(
+            self.logTree.indexOfTopLevelItem(itm) + 1)
         if itm is None:
             self.diffPreviousButton.setEnabled(False)
             return
@@ -400,7 +419,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         
         self.__diffRevisions(rev1, rev2, peg_rev)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffRevisionsButton_clicked(self):
         """
         Private slot to handle the Compare Revisions button.
@@ -425,13 +444,14 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         Private slot to show an error message.
         
-        @param msg error message to show (string or QString)
+        @param msg error message to show (string)
         """
-        KQMessageBox.critical(self,
+        E5MessageBox.critical(
+            self,
             self.trUtf8("Subversion Error"),
             msg)
     
-    @pyqtSignature("QDate")
+    @pyqtSlot(QDate)
     def on_fromDate_dateChanged(self, date):
         """
         Private slot called, when the from date changes.
@@ -440,7 +460,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         self.__filterLogs()
     
-    @pyqtSignature("QDate")
+    @pyqtSlot(QDate)
     def on_toDate_dateChanged(self, date):
         """
         Private slot called, when the from date changes.
@@ -449,21 +469,21 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         """
         self.__filterLogs()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_fieldCombo_activated(self, txt):
         """
         Private slot called, when a new filter field is selected.
         
-        @param txt text of the selected field (QString)
+        @param txt text of the selected field (string)
         """
         self.__filterLogs()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_rxEdit_textChanged(self, txt):
         """
         Private slot called, when a filter expression is entered.
         
-        @param txt filter expression (QString)
+        @param txt filter expression (string)
         """
         self.__filterLogs()
     
@@ -481,8 +501,9 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             elif txt == self.trUtf8("Revision"):
                 fieldIndex = 0
                 txt = self.rxEdit.text()
-                if txt.startsWith("^"):
-                    searchRx = QRegExp("^\s*%s" % txt[1:], Qt.CaseInsensitive)
+                if txt.startswith("^"):
+                    searchRx = QRegExp(
+                        "^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
                 else:
                     searchRx = QRegExp(txt, Qt.CaseInsensitive)
             else:
@@ -493,7 +514,7 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             for topIndex in range(self.logTree.topLevelItemCount()):
                 topItem = self.logTree.topLevelItem(topIndex)
                 if topItem.text(2) <= to_ and topItem.text(2) >= from_ and \
-                   topItem.text(fieldIndex).contains(searchRx):
+                   searchRx.indexIn(topItem.text(fieldIndex)) > -1:
                     topItem.setHidden(False)
                     if topItem is currentItem:
                         self.on_logTree_currentItemChanged(topItem, None)
@@ -503,19 +524,14 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
                         self.messageEdit.clear()
                         self.filesTree.clear()
     
-    @pyqtSignature("")
-    def on_clearRxEditButton_clicked(self):
-        """
-        Private slot called by a click of the clear RX edit button.
-        """
-        self.rxEdit.clear()
-    
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_stopCheckBox_clicked(self, checked):
         """
-        Private slot called, when the stop on copy/move checkbox is clicked
+        Private slot called, when the stop on copy/move checkbox is clicked.
+        
+        @param checked flag indicating the check box state (boolean)
         """
-        self.vcs.getPlugin().setPreferences("StopLogOnCopy", 
+        self.vcs.getPlugin().setPreferences("StopLogOnCopy",
                                             int(self.stopCheckBox.isChecked()))
         self.nextButton.setEnabled(True)
         self.limitSpinBox.setEnabled(True)
