@@ -9,13 +9,14 @@ Module implementing the login dialog for pysvn.
 
 from PyQt4.QtGui import QDialog
 
-from Ui_SvnLoginDialog import Ui_SvnLoginDialog
+from .Ui_SvnLoginDialog import Ui_SvnLoginDialog
+
 
 class SvnLoginDialog(QDialog, Ui_SvnLoginDialog):
     """
     Class implementing the login dialog for pysvn.
     """
-    def __init__(self, realm, username, may_save, parent = None):
+    def __init__(self, realm, username, may_save, parent=None):
         """
         Constructor
         
@@ -23,12 +24,14 @@ class SvnLoginDialog(QDialog, Ui_SvnLoginDialog):
         @param username username as supplied by subversion (string)
         @param may_save flag indicating, that subversion is willing to save
             the answers returned (boolean)
+        @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.realmLabel.setText(self.trUtf8("<b>Enter login data for realm %1.</b>")\
-                                .arg(realm))
+        self.realmLabel.setText(
+            self.trUtf8("<b>Enter login data for realm {0}.</b>")
+            .format(realm))
         self.usernameEdit.setText(username)
         self.saveCheckBox.setEnabled(may_save)
         if not may_save:
@@ -40,6 +43,6 @@ class SvnLoginDialog(QDialog, Ui_SvnLoginDialog):
         
         @return tuple of three values (username, password, save)
         """
-        return (str(self.usernameEdit.text()),
-               str(self.passwordEdit.text()),
-               self.saveCheckBox.isChecked())
+        return (self.usernameEdit.text(),
+                self.passwordEdit.text(),
+                self.saveCheckBox.isChecked())
