@@ -7,26 +7,30 @@
 Module implementing a dialog to enter the data for a merge operation.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QRegExp
+from PyQt4.QtGui import QDialog, QDialogButtonBox
+
+from .Ui_SvnMergeDialog import Ui_SvnMergeDialog
 
-from Ui_SvnMergeDialog import Ui_SvnMergeDialog
 
 class SvnMergeDialog(QDialog, Ui_SvnMergeDialog):
     """
     Class implementing a dialog to enter the data for a merge operation.
     """
-    def __init__(self, mergelist1, mergelist2, targetlist, force = False, parent = None):
+    def __init__(self, mergelist1, mergelist2, targetlist, force=False,
+                 parent=None):
         """
         Constructor
         
-        @param mergelist1 list of previously entered URLs/revisions (QStringList)
-        @param mergelist2 list of previously entered URLs/revisions (QStringList)
-        @param targetlist list of previously entered targets (QStringList)
+        @param mergelist1 list of previously entered URLs/revisions
+            (list of strings)
+        @param mergelist2 list of previously entered URLs/revisions
+            (list of strings)
+        @param targetlist list of previously entered targets (list of strings)
         @param force flag indicating a forced merge (boolean)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
        
         self.forceCheckBox.setChecked(force)
@@ -47,39 +51,41 @@ class SvnMergeDialog(QDialog, Ui_SvnMergeDialog):
     def __enableOkButton(self):
         """
         Private method used to enable/disable the OK-button.
-        
-        @param text ignored
         """
         self.okButton.setDisabled(
-            self.tag1Combo.currentText().isEmpty() or \
-            self.tag2Combo.currentText().isEmpty() or \
-            not ((self.rx_url.exactMatch(self.tag1Combo.currentText()) and \
-                  self.rx_url.exactMatch(self.tag2Combo.currentText())) or \
-                 (self.rx_rev.exactMatch(self.tag1Combo.currentText()) and \
+            self.tag1Combo.currentText() == "" or
+            self.tag2Combo.currentText() == "" or
+            not ((self.rx_url.exactMatch(self.tag1Combo.currentText()) and
+                  self.rx_url.exactMatch(self.tag2Combo.currentText())) or
+                 (self.rx_rev.exactMatch(self.tag1Combo.currentText()) and
                   self.rx_rev.exactMatch(self.tag2Combo.currentText()))
-                )
-            )
+                 )
+        )
         
     def on_tag1Combo_editTextChanged(self, text):
         """
         Private slot to handle the tag1Combo editTextChanged signal.
+        
+        @param text text of the combo (string)
         """
         self.__enableOkButton()
         
     def on_tag2Combo_editTextChanged(self, text):
         """
         Private slot to handle the tag2Combo editTextChanged signal.
+        
+        @param text text of the combo (string)
         """
         self.__enableOkButton()
         
     def getParameters(self):
         """
-        Public method to retrieve the tag data.
+        Public method to retrieve the merge data.
         
         @return tuple naming two tag names or two revisions, a target and
-            a flag indicating a forced merge (QString, QString, QString, boolean)
+            a flag indicating a forced merge (string, string, string, boolean)
         """
-        return (self.tag1Combo.currentText(), 
+        return (self.tag1Combo.currentText(),
                 self.tag2Combo.currentText(),
                 self.targetCombo.currentText(),
                 self.forceCheckBox.isChecked())
