@@ -7,23 +7,23 @@
 Module implementing a dialog to enter the data to relocate the workspace.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog
+
+from .Ui_SvnRelocateDialog import Ui_SvnRelocateDialog
 
-from Ui_SvnRelocateDialog import Ui_SvnRelocateDialog
 
 class SvnRelocateDialog(QDialog, Ui_SvnRelocateDialog):
     """
     Class implementing a dialog to enter the data to relocate the workspace.
     """
-    def __init__(self, currUrl, parent = None):
+    def __init__(self, currUrl, parent=None):
         """
         Constructor
         
-        @param currUrl current repository URL (string or QString)
+        @param currUrl current repository URL (string)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.currUrlLabel.setText(currUrl)
@@ -36,4 +36,4 @@ class SvnRelocateDialog(QDialog, Ui_SvnRelocateDialog):
         @return the new repository URL (string) and an indication, if
             the relocate is inside the repository (boolean)
         """
-        return unicode(self.newUrlEdit.text()), self.insideCheckBox.isChecked()
+        return self.newUrlEdit.text(), self.insideCheckBox.isChecked()
