@@ -11,26 +11,25 @@ import os
 
 import pysvn
 
-from PyQt4.QtCore import QRegExp, QStringList, QString
-
 from VCS.StatusMonitorThread import VcsStatusMonitorThread
 
 import Preferences
 
+
 class SvnStatusMonitorThread(VcsStatusMonitorThread):
     """
     Class implementing the VCS status monitor thread class for Subversion.
     """
-    def __init__(self, interval, projectDir, vcs, parent = None):
+    def __init__(self, interval, project, vcs, parent=None):
         """
         Constructor
         
         @param interval new interval in seconds (integer)
-        @param projectDir project directory to monitor (string or QString)
+        @param project reference to the project object (Project)
         @param vcs reference to the version control object
         @param parent reference to the parent object (QObject)
         """
-        VcsStatusMonitorThread.__init__(self, interval, projectDir, vcs, parent)
+        VcsStatusMonitorThread.__init__(self, interval, project, vcs, parent)
     
     def _performMonitor(self):
         """
@@ -50,8 +49,8 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
             <li>" " path is back at normal</li>
         </ul>
         
-        @return tuple of flag indicating successful operation (boolean) and 
-            a status message in case of non successful operation (QString)
+        @return tuple of flag indicating successful operation (boolean) and
+            a status message in case of non successful operation (string)
         """
         self.shouldUpdate = False
         
@@ -63,12 +62,11 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
             self.__clientSslServerTrustPromptCallback
         
         cwd = os.getcwd()
-        os.chdir(unicode(self.projectDir))
+        os.chdir(self.projectDir)
         try:
-            allFiles = client.status('.', recurse = True, get_all = True, 
-                                          ignore = True, 
-                                          update = \
-                                            not Preferences.getVCS("MonitorLocalStatus"))
+            allFiles = client.status(
+                '.', recurse=True, get_all=True, ignore=True,
+                update=not Preferences.getVCS("MonitorLocalStatus"))
             states = {}
             for file in allFiles:
                 uptodate = True
@@ -84,37 +82,39 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
                     status = "U"
                     self.shouldUpdate = True
                 elif file.text_status == pysvn.wc_status_kind.conflicted or \
-                   file.prop_status == pysvn.wc_status_kind.conflicted:
+                        file.prop_status == pysvn.wc_status_kind.conflicted:
                     status = "Z"
                 elif file.text_status == pysvn.wc_status_kind.deleted or \
-                   file.prop_status == pysvn.wc_status_kind.deleted:
+                        file.prop_status == pysvn.wc_status_kind.deleted:
                     status = "O"
                 elif file.text_status == pysvn.wc_status_kind.modified or \
-                   file.prop_status == pysvn.wc_status_kind.modified:
+                        file.prop_status == pysvn.wc_status_kind.modified:
                     status = "M"
                 elif file.text_status == pysvn.wc_status_kind.added or \
-                   file.prop_status == pysvn.wc_status_kind.added:
+                        file.prop_status == pysvn.wc_status_kind.added:
                     status = "A"
                 elif file.text_status == pysvn.wc_status_kind.replaced or \
-                   file.prop_status == pysvn.wc_status_kind.replaced:
+                        file.prop_status == pysvn.wc_status_kind.replaced:
                     status = "R"
                 if status:
                     states[file.path] = status
                     try:
                         if self.reportedStates[file.path] != status:
-                            self.statusList.append("%s %s" % (status, file.path))
+                            self.statusList.append(
+                                "{0} {1}".format(status, file.path))
                     except KeyError:
-                        self.statusList.append("%s %s" % (status, file.path))
-            for name in self.reportedStates.keys():
+                        self.statusList.append(
+                            "{0} {1}".format(status, file.path))
+            for name in list(self.reportedStates.keys()):
                 if name not in states:
-                    self.statusList.append("  %s" % name)
+                    self.statusList.append("  {0}".format(name))
             self.reportedStates = states
             res = True
-            statusStr = \
-                self.trUtf8("Subversion status checked successfully (using pysvn)")
-        except pysvn.ClientError, e:
+            statusStr = self.trUtf8(
+                "Subversion status checked successfully (using pysvn)")
+        except pysvn.ClientError as e:
             res = False
-            statusStr = QString(e.args[0])
+            statusStr = e.args[0]
         os.chdir(cwd)
         return res, statusStr
     
@@ -127,8 +127,8 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
         @param may_save flag indicating, that subversion is willing to save
             the answers returned (boolean)
         @return tuple of four values (retcode, username, password, save).
-            Retcode should be True, if username and password should be used 
-            by subversion, username and password contain the relevant data 
+            Retcode should be True, if username and password should be used
+            by subversion, username and password contain the relevant data
             as strings and save is a flag indicating, that username and
             password should be saved. Always returns (False, "", "", False).
         """
