@@ -11,28 +11,31 @@ import os
 
 import pysvn
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QMutexLocker, QRegExp, Qt
+from PyQt4.QtGui import QHeaderView, QLineEdit, QDialog, QInputDialog, \
+    QApplication, QDialogButtonBox, QTreeWidgetItem
 
-from KdeQt import KQMessageBox, KQInputDialog
+from E5Gui import E5MessageBox
 
-from SvnUtilities import formatTime
+from .SvnUtilities import formatTime
 
-from SvnDialogMixin import SvnDialogMixin
-from Ui_SvnTagBranchListDialog import Ui_SvnTagBranchListDialog
+from .SvnDialogMixin import SvnDialogMixin
+from .Ui_SvnTagBranchListDialog import Ui_SvnTagBranchListDialog
 
-class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog):
+
+class SvnTagBranchListDialog(QDialog, SvnDialogMixin,
+                             Ui_SvnTagBranchListDialog):
     """
     Class implementing a dialog to show a list of tags or branches.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         SvnDialogMixin.__init__(self)
         
@@ -52,13 +55,14 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         self.client.callback_ssl_server_trust_prompt = \
             self._clientSslServerTrustPromptCallback
         
-    def start(self, path, tags = True):
+    def start(self, path, tags=True):
         """
         Public slot to start the svn status command.
         
         @param path name of directory to be listed (string)
         @param tags flag indicating a list of tags is requested
                 (False = branches, True = tags)
+        @return flag indicating success (boolean)
         """
         self.errorGroup.hide()
         
@@ -71,11 +75,13 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         
         reposURL = self.vcs.svnGetReposName(dname)
         if reposURL is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Subversion Error"),
-                self.trUtf8("""The URL of the project repository could not be"""
-                    """ retrieved from the working copy. The list operation will"""
-                    """ be aborted"""))
+                self.trUtf8(
+                    """The URL of the project repository could not be"""
+                    """ retrieved from the working copy. The list operation"""
+                    """ will be aborted"""))
             self.close()
             return False
         
@@ -83,49 +89,54 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
             # determine the base path of the project in the repository
             rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
             if not rx_base.exactMatch(reposURL):
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Subversion Error"),
-                    self.trUtf8("""The URL of the project repository has an"""
+                    self.trUtf8(
+                        """The URL of the project repository has an"""
                         """ invalid format. The list operation will"""
                         """ be aborted"""))
                 return False
             
-            reposRoot = unicode(rx_base.cap(1))
+            reposRoot = rx_base.cap(1)
             
             if tags:
-                path = "%s/tags" % reposRoot
+                path = "{0}/tags".format(reposRoot)
             else:
-                path = "%s/branches" % reposRoot
+                path = "{0}/branches".format(reposRoot)
         else:
-            reposPath, ok = KQInputDialog.getText(\
+            reposPath, ok = QInputDialog.getText(
                 self,
                 self.trUtf8("Subversion List"),
-                self.trUtf8("Enter the repository URL containing the tags or branches"),
+                self.trUtf8("Enter the repository URL containing the"
+                            " tags or branches"),
                 QLineEdit.Normal,
                 self.vcs.svnNormalizeURL(reposURL))
             if not ok:
                 self.close()
                 return False
-            if reposPath.isEmpty():
-                KQMessageBox.critical(None,
+            if not reposPath:
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Subversion List"),
-                    self.trUtf8("""The repository URL is empty. Aborting..."""))
+                    self.trUtf8(
+                        """The repository URL is empty. Aborting..."""))
                 self.close()
                 return False
-            path = unicode(reposPath)
+            path = reposPath
         
         locker = QMutexLocker(self.vcs.vcsExecutionMutex)
-        self.tagsList = QStringList()
+        self.tagsList = []
         cwd = os.getcwd()
         os.chdir(dname)
         try:
-            entries = self.client.list(path, recurse = False)
+            entries = self.client.list(path, recurse=False)
             for dirent, lock in entries:
                 if dirent["path"] != path:
                     name = dirent["path"].replace(path + '/', "")
-                    self.__generateItem(dirent["created_rev"].number, 
-                                        dirent["last_author"], 
-                                        formatTime(dirent["time"]), 
+                    self.__generateItem(dirent["created_rev"].number,
+                                        dirent["last_author"],
+                                        formatTime(dirent["time"]),
                                         name)
                     if self.vcs.otherData["standardLayout"]:
                         self.tagsList.append(name)
@@ -134,12 +145,13 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
                     if self._clientCancelCallback():
                         break
             res = True
-        except pysvn.ClientError, e:
+        except pysvn.ClientError as e:
             self.__showError(e.args[0])
             res = False
         except AttributeError:
-            self.__showError(\
-                self.trUtf8("The installed version of PySvn should be 1.4.0 or better."))
+            self.__showError(
+                self.trUtf8("The installed version of PySvn should be"
+                            " 1.4.0 or better."))
             res = False
         locker.unlock()
         self.__finish()
@@ -148,7 +160,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -174,7 +187,7 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         """
         Private slot to show an error message.
         
-        @param msg error message to show (string or QString)
+        @param msg error message to show (string)
         """
         self.errorGroup.show()
         self.errors.insertPlainText(msg)
@@ -184,7 +197,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         """
         Private method to resort the tree.
         """
-        self.tagList.sortItems(self.tagList.sortColumn(), 
+        self.tagList.sortItems(
+            self.tagList.sortColumn(),
             self.tagList.header().sortIndicatorOrder())
         
     def __resizeColumns(self):
@@ -199,9 +213,9 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         Private method to generate a tag item in the taglist.
         
         @param revision revision number (integer)
-        @param author author of the tag (string or QString)
-        @param date date of the tag (string or QString)
-        @param name name (path) of the tag (string or QString)
+        @param author author of the tag (string)
+        @param date date of the tag (string)
+        @param name name (path) of the tag (string)
         """
         itm = QTreeWidgetItem(self.tagList)
         itm.setData(0, Qt.DisplayRole, revision)
@@ -214,6 +228,6 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         """
         Public method to get the taglist of the last run.
         
-        @return list of tags (QStringList)
+        @return list of tags (list of strings)
         """
         return self.tagsList
