@@ -7,53 +7,55 @@
 Module implementing a dialog to enter the data for a tagging operation.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
+
+from .Ui_SvnTagDialog import Ui_SvnTagDialog
 
-from Ui_SvnTagDialog import Ui_SvnTagDialog
 
 class SvnTagDialog(QDialog, Ui_SvnTagDialog):
     """
     Class implementing a dialog to enter the data for a tagging operation.
     """
-    def __init__(self, taglist, reposURL, standardLayout, parent = None):
+    def __init__(self, taglist, reposURL, standardLayout, parent=None):
         """
         Constructor
         
-        @param taglist list of previously entered tags (QStringList)
-        @param reposURL repository path (QString or string) or None
-        @param standardLayout flag indicating the layout of the 
+        @param taglist list of previously entered tags (list of strings)
+        @param reposURL repository path (string) or None
+        @param standardLayout flag indicating the layout of the
             repository (boolean)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
        
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         self.okButton.setEnabled(False)
         
         self.tagCombo.clear()
-        self.tagCombo.addItems(taglist)
+        self.tagCombo.addItems(sorted(taglist))
         
-        if reposURL is not None and reposURL is not QString():
+        if reposURL is not None and reposURL != "":
             self.tagCombo.setEditText(reposURL)
         
         if not standardLayout:
             self.TagActionGroup.setEnabled(False)
         
+    @pyqtSlot(str)
     def on_tagCombo_editTextChanged(self, text):
         """
         Private method used to enable/disable the OK-button.
         
-        @param text ignored
+        @param text tag name entered in the combo (string)
         """
-        self.okButton.setDisabled(text.isEmpty())
+        self.okButton.setDisabled(text == "")
     
     def getParameters(self):
         """
         Public method to retrieve the tag data.
         
-        @return tuple of QString and int (tag, tag operation)
+        @return tuple of string and int (tag, tag operation)
         """
         tag = self.tagCombo.currentText()
         tagOp = 0
