@@ -7,26 +7,27 @@
 Module implementing some common utility functions for the pysvn package.
 """
 
-import sys
 import os
 
 from PyQt4.QtCore import QDateTime, Qt
 
 import Utilities
 
-from Config import DefaultConfig, DefaultIgnores
+from .Config import DefaultConfig, DefaultIgnores
+
 
 def formatTime(seconds):
     """
     Module function to return a formatted time string.
     
     @param seconds time in seconds since epoch to be formatted (float or long)
-    @return formatted time string (QString)
+    @return formatted time string (string)
     """
-    return QDateTime.fromTime_t(long(seconds))\
+    return QDateTime.fromTime_t(int(seconds))\
                     .toTimeSpec(Qt.LocalTime)\
                     .toString("yyyy-MM-dd hh:mm:ss")
 
+
 def dateFromTime_t(seconds):
     """
     Module function to return the date.
@@ -34,7 +35,8 @@ def dateFromTime_t(seconds):
     @param seconds time in seconds since epoch to be formatted (float or long)
     @return date (QDate)
     """
-    return QDateTime.fromTime_t(long(seconds)).toTimeSpec(Qt.LocalTime).date()
+    return QDateTime.fromTime_t(int(seconds)).toTimeSpec(Qt.LocalTime).date()
+
 
 def getServersPath():
     """
@@ -49,6 +51,7 @@ def getServersPath():
         homedir = Utilities.getHomeDir()
         return os.path.join(homedir, ".subversion", "servers")
 
+
 def getConfigPath():
     """
     Module function to get the filename of the config file.
@@ -62,6 +65,7 @@ def getConfigPath():
         homedir = Utilities.getHomeDir()
         return os.path.join(homedir, ".subversion", "config")
 
+
 def createDefaultConfig():
     """
     Module function to create a default config file suitable for eric.
@@ -78,6 +82,7 @@ def createDefaultConfig():
     except IOError:
         pass
 
+
 def amendConfig():
     """
     Module function to amend the config file.
