@@ -7,12 +7,12 @@
 Module implementing the Subversion configuration page.
 """
 
-from PyQt4.QtCore import pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 
-from QScintilla.MiniEditor import MiniEditor
+from Preferences.ConfigurationPages.ConfigurationPageBase import \
+    ConfigurationPageBase
+from .Ui_SubversionPage import Ui_SubversionPage
 
-from Preferences.ConfigurationPages.ConfigurationPageBase import ConfigurationPageBase
-from Ui_SubversionPage import Ui_SubversionPage
 
 class SubversionPage(ConfigurationPageBase, Ui_SubversionPage):
     """
@@ -24,7 +24,7 @@ class SubversionPage(ConfigurationPageBase, Ui_SubversionPage):
         
         @param plugin reference to the plugin object
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("SubversionPage")
         
@@ -32,29 +32,33 @@ class SubversionPage(ConfigurationPageBase, Ui_SubversionPage):
         
         # set initial values
         self.logSpinBox.setValue(self.__plugin.getPreferences("LogLimit"))
-        self.commitSpinBox.setValue(self.__plugin.getPreferences("CommitMessages"))
+        self.commitSpinBox.setValue(
+            self.__plugin.getPreferences("CommitMessages"))
         
     def save(self):
         """
         Public slot to save the Subversion configuration.
         """
         self.__plugin.setPreferences("LogLimit", self.logSpinBox.value())
-        self.__plugin.setPreferences("CommitMessages", self.commitSpinBox.value())
+        self.__plugin.setPreferences(
+            "CommitMessages", self.commitSpinBox.value())
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_configButton_clicked(self):
         """
         Private slot to edit the Subversion config file.
         """
+        from QScintilla.MiniEditor import MiniEditor
         cfgFile = self.__plugin.getConfigPath()
         editor = MiniEditor(cfgFile, "Properties", self)
         editor.show()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_serversButton_clicked(self):
         """
         Private slot to edit the Subversion servers file.
         """
+        from QScintilla.MiniEditor import MiniEditor
         serversFile = self.__plugin.getServersPath()
         editor = MiniEditor(serversFile, "Properties", self)
         editor.show()
