@@ -7,30 +7,32 @@
 Module implementing a dialog to show the output of the svn blame command.
 """
 
-import sys
+import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QTimer, QProcess, Qt, pyqtSlot
+from PyQt4.QtGui import QHeaderView, QLineEdit, QDialog, QDialogButtonBox, \
+    QFont, QTreeWidgetItem
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from Ui_SvnBlameDialog import Ui_SvnBlameDialog
+from .Ui_SvnBlameDialog import Ui_SvnBlameDialog
 
 import Preferences
 import Utilities
 
+
 class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
     """
     Class implementing a dialog to show the output of the svn blame command.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
@@ -47,14 +49,11 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
             font.setFamily("Monospace")
         self.blameList.setFont(font)
         
-        self.__ioEncoding = str(Preferences.getSystem("IOEncoding"))
+        self.__ioEncoding = Preferences.getSystem("IOEncoding")
         
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
     def closeEvent(self, e):
         """
@@ -65,7 +64,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
@@ -85,43 +84,45 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         
         self.process.kill()
         
-        args = QStringList()
+        args = []
         args.append('blame')
         self.vcs.addArguments(args, self.vcs.options['global'])
         args.append(fname)
         
-        
         self.process.setWorkingDirectory(dname)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         else:
             self.inputGroup.setEnabled(True)
             self.inputGroup.show()
         
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(
+            Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
@@ -155,19 +156,18 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         Private method to resize the list columns.
         """
         self.blameList.header().resizeSections(QHeaderView.ResizeToContents)
-        self.blameList.header().setStretchLastSection(True)
         
     def __generateItem(self, revision, author, text):
         """
-        Private method to generate a tag item in the taglist.
+        Private method to generate a blame item in the blame list.
         
-        @param revision revision string (string or QString)
-        @param author author of the tag (string or QString)
-        @param date date of the tag (string or QString)
-        @param name name (path) of the tag (string or QString)
+        @param revision revision string (string)
+        @param author author of the change (string)
+        @param text line of text from the annotated file (string)
         """
-        itm = QTreeWidgetItem(self.blameList, 
-            QStringList() << revision << author << "%d" % self.lineno << text)
+        itm = QTreeWidgetItem(
+            self.blameList,
+            [revision, author, "{0:d}".format(self.lineno), text])
         self.lineno += 1
         itm.setTextAlignment(0, Qt.AlignRight)
         itm.setTextAlignment(2, Qt.AlignRight)
@@ -182,7 +182,8 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            s = unicode(self.process.readLine(), self.__ioEncoding, 'replace').strip()
+            s = str(self.process.readLine(), self.__ioEncoding, 'replace')\
+                .strip()
             rev, s = s.split(None, 1)
             try:
                 author, text = s.split(' ', 1)
@@ -200,7 +201,9 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         """
         if self.process is not None:
             self.errorGroup.show()
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
         
@@ -215,13 +218,13 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -230,7 +233,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -252,4 +255,4 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
             self.intercept = False
             evt.accept()
             return
-        QDialog.keyPressEvent(self, evt)
+        super().keyPressEvent(evt)
