@@ -4,35 +4,38 @@
 #
 
 """
-Module implementing a dialog to show the output of the svn diff command process.
+Module implementing a dialog to show the output of the svn diff command
+process.
 """
 
 import os
-import sys
-import types
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QTimer, QFileInfo, QProcess, pyqtSlot, Qt
+from PyQt4.QtGui import QWidget, QColor, QLineEdit, QBrush, QTextCursor, \
+    QDialogButtonBox
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox, E5FileDialog
 
-from Ui_SvnDiffDialog import Ui_SvnDiffDialog
+from .Ui_SvnDiffDialog import Ui_SvnDiffDialog
 
 import Utilities
+import Preferences
+
 
 class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
     """
-    Class implementing a dialog to show the output of the svn diff command process.
+    Class implementing a dialog to show the output of the svn diff command
+    process.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(False)
@@ -41,10 +44,9 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.process = QProcess()
         self.vcs = vcs
         
-        if Utilities.isWindowsPlatform():
-            self.contents.setFontFamily("Lucida Console")
-        else:
-            self.contents.setFontFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.contents.setFontFamily(font.family())
+        self.contents.setFontPointSize(font.pointSize())
         
         self.cNormalFormat = self.contents.currentCharFormat()
         self.cAddedFormat = self.contents.currentCharFormat()
@@ -54,12 +56,9 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.cLineNoFormat = self.contents.currentCharFormat()
         self.cLineNoFormat.setBackground(QBrush(QColor(255, 220, 168)))
         
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
     def closeEvent(self, e):
         """
@@ -70,7 +69,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
@@ -87,14 +86,15 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         else:
             return str(version)
         
-    def start(self, fn, versions = None, urls = None, summary = False):
+    def start(self, fn, versions=None, urls=None, summary=False):
         """
         Public slot to start the svn diff command.
         
         @param fn filename to be diffed (string)
-        @param versions list of versions to be diffed (list of up to 2 QString or None)
+        @param versions list of versions to be diffed (list of up to 2 strings
+            or None)
         @keyparam urls list of repository URLs (list of 2 strings)
-        @keyparam summary flag indicating a summarizing diff 
+        @keyparam summary flag indicating a summarizing diff
             (only valid for URL diffs) (boolean)
         """
         self.errorGroup.hide()
@@ -107,7 +107,13 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.contents.clear()
         self.paras = 0
         
-        args = QStringList()
+        self.filesCombo.clear()
+        
+        self.__oldFile = ""
+        self.__oldFileLine = -1
+        self.__fileSeparators = []
+        
+        args = []
         args.append('diff')
         self.vcs.addArguments(args, self.vcs.options['global'])
         self.vcs.addArguments(args, self.vcs.options['diff'])
@@ -126,7 +132,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             if rev1 is not None or rev2 is not None:
                 args.append('-r')
                 if rev1 is not None and rev2 is not None:
-                    args.append('%s:%s' % (rev1, rev2))
+                    args.append('{0}:{1}'.format(rev1, rev2))
                 elif rev2 is None:
                     args.append(rev1)
                 elif rev1 is None:
@@ -137,14 +143,14 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             if summary:
                 args.append("--summarize")
                 self.summaryPath = urls[0]
-            args.append("--old=%s" % urls[0])
-            args.append("--new=%s" % urls[1])
-            if type(fn) is types.ListType:
+            args.append("--old={0}".format(urls[0]))
+            args.append("--new={0}".format(urls[1]))
+            if isinstance(fn, list):
                 dname, fnames = self.vcs.splitPathList(fn)
             else:
                 dname, fname = self.vcs.splitPath(fn)
                 fnames = [fname]
-            project = e4App().getObject('Project')
+            project = e5App().getObject('Project')
             if dname == project.getProjectPath():
                 path = ""
             else:
@@ -154,7 +160,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             for fname in fnames:
                 args.append(path + fname)
         else:
-            if type(fn) is types.ListType:
+            if isinstance(fn, list):
                 dname, fnames = self.vcs.splitPathList(fn)
                 self.vcs.addArguments(args, fnames)
             else:
@@ -164,16 +170,17 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.process.setWorkingDirectory(dname)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         
     def __procFinished(self, exitCode, exitStatus):
         """
@@ -186,24 +193,34 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.inputGroup.hide()
         
         if self.paras == 0:
-            self.contents.insertPlainText(\
+            self.contents.insertPlainText(
                 self.trUtf8('There is no difference.'))
             return
             
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(
+            Qt.OtherFocusReason)
         
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.Start)
         self.contents.setTextCursor(tc)
         self.contents.ensureCursorVisible()
         
+        self.filesCombo.addItem(self.trUtf8("<Start>"), 0)
+        self.filesCombo.addItem(self.trUtf8("<End>"), -1)
+        for oldFile, newFile, pos in sorted(self.__fileSeparators):
+            if oldFile != newFile:
+                self.filesCombo.addItem(
+                    "{0}\n{1}".format(oldFile, newFile), pos)
+            else:
+                self.filesCombo.addItem(oldFile, pos)
+        
     def __appendText(self, txt, format):
         """
         Private method to append text to the end of the contents pane.
         
-        @param txt text to insert (QString)
+        @param txt text to insert (string)
         @param format text format to be used (QTextCharFormat)
         """
         tc = self.contents.textCursor()
@@ -212,9 +229,34 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.contents.setCurrentCharFormat(format)
         self.contents.insertPlainText(txt)
         
+    def __extractFileName(self, line):
+        """
+        Private method to extract the file name out of a file separator line.
+        
+        @param line line to be processed (string)
+        @return extracted file name (string)
+        """
+        f = line.split(None, 1)[1]
+        f = f.rsplit(None, 2)[0]
+        return f
+    
+    def __processFileLine(self, line):
+        """
+        Private slot to process a line giving the old/new file.
+        
+        @param line line to be processed (string)
+        """
+        if line.startswith('---'):
+            self.__oldFileLine = self.paras
+            self.__oldFile = self.__extractFileName(line)
+        else:
+            self.__fileSeparators.append(
+                (self.__oldFile, self.__extractFileName(line),
+                 self.__oldFileLine))
+    
     def __readStdout(self):
         """
-        Private slot to handle the readyReadStandardOutput signal. 
+        Private slot to handle the readyReadStandardOutput signal.
         
         It reads the output of the process, formats it and inserts it into
         the contents pane.
@@ -222,15 +264,22 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            line = QString(self.process.readLine())
+            line = str(self.process.readLine(),
+                       Preferences.getSystem("IOEncoding"),
+                       'replace')
             if self.summaryPath:
                 line = line.replace(self.summaryPath + '/', '')
-                line = line.split(" ", QString.SkipEmptyParts).join(" ")
-            if line.startsWith('+') or line.startsWith('>') or line.startsWith('A '):
+                line = " ".join(line.split())
+            if line.startswith("--- ") or line.startswith("+++ "):
+                    self.__processFileLine(line)
+                
+            if line.startswith('+') or line.startswith('>') or \
+                    line.startswith('A '):
                 format = self.cAddedFormat
-            elif line.startsWith('-') or line.startsWith('<') or line.startsWith('D '):
+            elif line.startswith('-') or line.startswith('<') or \
+                    line.startswith('D '):
                 format = self.cRemovedFormat
-            elif line.startsWith('@@'):
+            elif line.startswith('@@'):
                 format = self.cLineNoFormat
             else:
                 format = self.cNormalFormat
@@ -246,7 +295,9 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         """
         if self.process is not None:
             self.errorGroup.show()
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
         
@@ -259,7 +310,41 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         if button == self.buttonBox.button(QDialogButtonBox.Save):
             self.on_saveButton_clicked()
         
-    @pyqtSignature("")
+    @pyqtSlot(int)
+    def on_filesCombo_activated(self, index):
+        """
+        Private slot to handle the selection of a file.
+        
+        @param index activated row (integer)
+        """
+        para = self.filesCombo.itemData(index)
+        
+        if para == 0:
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.Start)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+        elif para == -1:
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.End)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+        else:
+            # step 1: move cursor to end
+            tc = self.contents.textCursor()
+            tc.movePosition(QTextCursor.End)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+            
+            # step 2: move cursor to desired line
+            tc = self.contents.textCursor()
+            delta = tc.blockNumber() - para
+            tc.movePosition(QTextCursor.PreviousBlock, QTextCursor.MoveAnchor,
+                            delta)
+            self.contents.setTextCursor(tc)
+            self.contents.ensureCursorVisible()
+    
+    @pyqtSlot()
     def on_saveButton_clicked(self):
         """
         Private slot to handle the Save button press.
@@ -267,57 +352,57 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         It saves the diff shown in the dialog to a file in the local
         filesystem.
         """
-        if type(self.filename) is types.ListType:
+        if isinstance(self.filename, list):
             if len(self.filename) > 1:
                 fname = self.vcs.splitPathList(self.filename)[0]
             else:
                 dname, fname = self.vcs.splitPath(self.filename[0])
                 if fname != '.':
-                    fname = "%s.diff" % self.filename[0]
+                    fname = "{0}.diff".format(self.filename[0])
                 else:
                     fname = dname
         else:
             fname = self.vcs.splitPath(self.filename)[0]
         
-        selectedFilter = QString("")
-        fname = KQFileDialog.getSaveFileName(\
+        fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
             self.trUtf8("Save Diff"),
             fname,
             self.trUtf8("Patch Files (*.diff)"),
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+            None,
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if fname.isEmpty():
-            return
+        if not fname:
+            return  # user aborted
         
         ext = QFileInfo(fname).suffix()
-        if ext.isEmpty():
-            ex = selectedFilter.section('(*',1,1).section(')',0,0)
-            if not ex.isEmpty():
-                fname.append(ex)
+        if not ext:
+            ex = selectedFilter.split("(*")[1].split(")")[0]
+            if ex:
+                fname += ex
         if QFileInfo(fname).exists():
-            res = KQMessageBox.warning(self,
+            res = E5MessageBox.yesNo(
+                self,
                 self.trUtf8("Save Diff"),
-                self.trUtf8("<p>The patch file <b>%1</b> already exists.</p>")
-                    .arg(fname),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.Abort | \
-                    QMessageBox.Save),
-                QMessageBox.Abort)
-            if res != QMessageBox.Save:
+                self.trUtf8("<p>The patch file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
+                icon=E5MessageBox.Warning)
+            if not res:
                 return
-        fname = unicode(Utilities.toNativeSeparators(fname))
+        fname = Utilities.toNativeSeparators(fname)
         
+        eol = e5App().getObject("Project").getEolString()
         try:
-            f = open(fname, "wb")
-            f.write(unicode(self.contents.toPlainText()))
+            f = open(fname, "w", encoding="utf-8", newline="")
+            f.write(eol.join(self.contents.toPlainText().splitlines()))
             f.close()
-        except IOError, why:
-            KQMessageBox.critical(self, self.trUtf8('Save Diff'),
-                self.trUtf8('<p>The patch file <b>%1</b> could not be saved.'
-                    '<br>Reason: %2</p>')
-                    .arg(unicode(fname)).arg(str(why)))
+        except IOError as why:
+            E5MessageBox.critical(
+                self, self.trUtf8('Save Diff'),
+                self.trUtf8(
+                    '<p>The patch file <b>{0}</b> could not be saved.'
+                    '<br>Reason: {1}</p>')
+                .format(fname, str(why)))
         
     def on_passwordCheckBox_toggled(self, isOn):
         """
@@ -330,13 +415,13 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -345,7 +430,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -367,4 +452,4 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             self.intercept = False
             evt.accept()
             return
-        QWidget.keyPressEvent(self, evt)
+        super().keyPressEvent(evt)
