@@ -9,32 +9,32 @@ Module implementing a dialog to browse the log history.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QTimer, QDate, QProcess, QRegExp, Qt, pyqtSlot
+from PyQt4.QtGui import QCursor, QHeaderView, QLineEdit, QDialog, \
+    QApplication, QDialogButtonBox, QTreeWidgetItem
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from SvnDiffDialog import SvnDiffDialog
-
-from Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
-
-import UI.PixmapCache
+from .Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
 
 import Preferences
 
+
 class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
     """
     Class implementing a dialog to browse the log history.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, isFile=False, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
+        @param isFile flag indicating log for a file is to be shown (boolean)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
+        self.setWindowFlags(self.windowFlags() | Qt.WindowMinMaxButtonsHint)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
@@ -42,6 +42,9 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(0, Qt.AscendingOrder)
         
+        self.sbsCheckBox.setEnabled(isFile)
+        self.sbsCheckBox.setVisible(isFile)
+        
         self.vcs = vcs
         
         self.__maxDate = QDate()
@@ -52,46 +55,48 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.toDate.setDisplayFormat("yyyy-MM-dd")
         self.fromDate.setDate(QDate.currentDate())
         self.toDate.setDate(QDate.currentDate())
-        self.fieldCombo.setCurrentIndex(self.fieldCombo.findText(self.trUtf8("Message")))
-        self.clearRxEditButton.setIcon(UI.PixmapCache.getIcon("clearLeft.png"))
-        self.limitSpinBox.setValue(self.vcs.getPlugin().getPreferences("LogLimit"))
-        self.stopCheckBox.setChecked(self.vcs.getPlugin().getPreferences("StopLogOnCopy"))
+        self.fieldCombo.setCurrentIndex(
+            self.fieldCombo.findText(self.trUtf8("Message")))
+        self.limitSpinBox.setValue(
+            self.vcs.getPlugin().getPreferences("LogLimit"))
+        self.stopCheckBox.setChecked(
+            self.vcs.getPlugin().getPreferences("StopLogOnCopy"))
         
         self.__messageRole = Qt.UserRole
         self.__changesRole = Qt.UserRole + 1
         
         self.process = QProcess()
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.rx_sep1 = QRegExp('\\-+\\s*')
         self.rx_sep2 = QRegExp('=+\\s*')
-        self.rx_rev1 = QRegExp('rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+        self.rx_rev1 = QRegExp(
+            'rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "rev" followed by one or more decimals followed by a colon followed
-        # anything up to " | " (twice) followed by one or more decimals followed
-        # by anything
-        self.rx_rev2 = QRegExp('r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+        # anything up to " | " (twice) followed by one or more decimals
+        # followed by anything
+        self.rx_rev2 = QRegExp(
+            'r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "r" followed by one or more decimals followed by " | " followed
-        # anything up to " | " (twice) followed by one or more decimals followed
-        # by anything
-        self.rx_flags1 = QRegExp(r"""   ([ADM])\s(.*)\s+\(\w+\s+(.*):([0-9]+)\)\s*""")
+        # anything up to " | " (twice) followed by one or more decimals
+        # followed by anything
+        self.rx_flags1 = QRegExp(
+            r"""   ([ADM])\s(.*)\s+\(\w+\s+(.*):([0-9]+)\)\s*""")
         # three blanks followed by A or D or M followed by path followed by
         # path copied from followed by copied from revision
         self.rx_flags2 = QRegExp('   ([ADM]) (.*)\\s*')
         # three blanks followed by A or D or M followed by path
         
         self.flags = {
-            'A' : self.trUtf8('Added'),
-            'D' : self.trUtf8('Deleted'),
-            'M' : self.trUtf8('Modified'),
-            'R' : self.trUtf8('Replaced'),
+            'A': self.trUtf8('Added'),
+            'D': self.trUtf8('Deleted'),
+            'M': self.trUtf8('Modified'),
+            'R': self.trUtf8('Replaced'),
         }
         
-        self.buf = QStringList()        # buffer for stdout
+        self.buf = []        # buffer for stdout
         self.diff = None
         self.__started = False
         self.__lastRev = 0
@@ -105,7 +110,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
@@ -121,7 +126,8 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         """
         Private method to resort the log tree.
         """
-        self.logTree.sortItems(self.logTree.sortColumn(), 
+        self.logTree.sortItems(
+            self.logTree.sortColumn(),
             self.logTree.header().sortIndicatorOrder())
     
     def __resizeColumnsFiles(self):
@@ -136,35 +142,35 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         Private method to resort the changed files tree.
         """
         sortColumn = self.filesTree.sortColumn()
-        self.filesTree.sortItems(1, 
-            self.filesTree.header().sortIndicatorOrder())
-        self.filesTree.sortItems(sortColumn, 
-            self.filesTree.header().sortIndicatorOrder())
+        self.filesTree.sortItems(
+            1, self.filesTree.header().sortIndicatorOrder())
+        self.filesTree.sortItems(
+            sortColumn, self.filesTree.header().sortIndicatorOrder())
     
     def __generateLogItem(self, author, date, message, revision, changedPaths):
         """
         Private method to generate a log tree entry.
         
-        @param author author info (string or QString)
-        @param date date info (string or QString)
-        @param message text of the log message (QStringList)
-        @param revision revision info (string or QString)
+        @param author author info (string)
+        @param date date info (string)
+        @param message text of the log message (list of strings)
+        @param revision revision info (string)
         @param changedPaths list of dictionary objects containing
-            info about the changed files/directories 
+            info about the changed files/directories
         @return reference to the generated item (QTreeWidgetItem)
         """
-        msg = QStringList()
+        msg = []
         for line in message:
-            msg.append(line.trimmed())
+            msg.append(line.strip())
         
         itm = QTreeWidgetItem(self.logTree)
         itm.setData(0, Qt.DisplayRole, int(revision))
         itm.setData(1, Qt.DisplayRole, author)
         itm.setData(2, Qt.DisplayRole, date)
-        itm.setData(3, Qt.DisplayRole, msg.join(" "))
+        itm.setData(3, Qt.DisplayRole, " ".join(msg))
         
-        itm.setData(0, self.__messageRole, QVariant(message))
-        itm.setData(0, self.__changesRole, QVariant(repr(changedPaths)))
+        itm.setData(0, self.__messageRole, message)
+        itm.setData(0, self.__changesRole, changedPaths)
         
         itm.setTextAlignment(0, Qt.AlignRight)
         itm.setTextAlignment(1, Qt.AlignLeft)
@@ -184,27 +190,27 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         Private method to generate a changed files tree entry.
         
         @param action indicator for the change action ("A", "D" or "M")
-        @param path path of the file in the repository (string or QString)
-        @param copyFrom path the file was copied from (None, string or QString)
-        @param copyRev revision the file was copied from (None, string or QString)
+        @param path path of the file in the repository (string)
+        @param copyFrom path the file was copied from (None, string)
+        @param copyRev revision the file was copied from (None, string)
         @return reference to the generated item (QTreeWidgetItem)
         """
-        itm = QTreeWidgetItem(self.filesTree, QStringList()
-            << self.flags[action] \
-            << path \
-            << copyFrom \
-            << copyRev
-        )
+        itm = QTreeWidgetItem(self.filesTree, [
+            self.flags[action],
+            path,
+            copyFrom,
+            copyRev,
+        ])
         
         itm.setTextAlignment(3, Qt.AlignRight)
         
         return itm
     
-    def __getLogEntries(self, startRev = None):
+    def __getLogEntries(self, startRev=None):
         """
         Private method to retrieve log entries from the repository.
         
-        @param startRev revision number to start from (integer, string or QString)
+        @param startRev revision number to start from (integer, string)
         """
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(True)
@@ -217,20 +223,20 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.intercept = False
         self.process.kill()
         
-        self.buf = QStringList()
+        self.buf = []
         self.cancelled = False
         self.errors.clear()
         
-        args = QStringList()
+        args = []
         args.append('log')
         self.vcs.addArguments(args, self.vcs.options['global'])
         self.vcs.addArguments(args, self.vcs.options['log'])
         args.append('--verbose')
         args.append('--limit')
-        args.append('%d' % self.limitSpinBox.value())
+        args.append('{0:d}'.format(self.limitSpinBox.value()))
         if startRev is not None:
             args.append('--revision')
-            args.append('%s:0' % startRev)
+            args.append('{0}:0'.format(startRev))
         if self.stopCheckBox.isChecked():
             args.append('--stop-on-copy')
         args.append(self.fname)
@@ -241,16 +247,17 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.inputGroup.show()
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
     
     def start(self, fn):
         """
@@ -258,6 +265,9 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         
         @param fn filename to show the log for (string)
         """
+        self.errorGroup.hide()
+        QApplication.processEvents()
+        
         self.filename = fn
         self.dname, self.fname = self.vcs.splitPath(fn)
         
@@ -280,12 +290,13 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
     
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         QApplication.restoreOverrideCursor()
@@ -301,48 +312,48 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         """
         Private method to process the buffered output of the svn log command.
         """
-        ioEncoding = str(Preferences.getSystem("IOEncoding"))
-        
         noEntries = 0
-        log = {"message" : QStringList()}
+        log = {"message": []}
         changedPaths = []
         for s in self.buf:
             if self.rx_rev1.exactMatch(s):
                 log["revision"] = self.rx_rev.cap(1)
-                log["author"]   = self.rx_rev.cap(2)
-                log["date"]     = self.rx_rev.cap(3)
+                log["author"] = self.rx_rev.cap(2)
+                log["date"] = self.rx_rev.cap(3)
                 # number of lines is ignored
             elif self.rx_rev2.exactMatch(s):
                 log["revision"] = self.rx_rev2.cap(1)
-                log["author"]   = self.rx_rev2.cap(2)
-                log["date"]     = self.rx_rev2.cap(3)
+                log["author"] = self.rx_rev2.cap(2)
+                log["date"] = self.rx_rev2.cap(3)
                 # number of lines is ignored
             elif self.rx_flags1.exactMatch(s):
-                changedPaths.append({\
-                    "action"            : 
-                        unicode(self.rx_flags1.cap(1).trimmed(), ioEncoding, 'replace'), 
-                    "path"              : 
-                        unicode(self.rx_flags1.cap(2).trimmed(), ioEncoding, 'replace'), 
-                    "copyfrom_path"     : 
-                        unicode(self.rx_flags1.cap(3).trimmed(), ioEncoding, 'replace'), 
-                    "copyfrom_revision" : 
-                        unicode(self.rx_flags1.cap(4).trimmed(), ioEncoding, 'replace'), 
+                changedPaths.append({
+                    "action":
+                    self.rx_flags1.cap(1).strip(),
+                    "path":
+                    self.rx_flags1.cap(2).strip(),
+                    "copyfrom_path":
+                    self.rx_flags1.cap(3).strip(),
+                    "copyfrom_revision":
+                    self.rx_flags1.cap(4).strip(),
                 })
             elif self.rx_flags2.exactMatch(s):
-                changedPaths.append({\
-                    "action"            : 
-                        unicode(self.rx_flags2.cap(1).trimmed(), ioEncoding, 'replace'), 
-                    "path"              : 
-                        unicode(self.rx_flags2.cap(2).trimmed(), ioEncoding, 'replace'), 
-                    "copyfrom_path"     : "", 
-                    "copyfrom_revision" : "", 
+                changedPaths.append({
+                    "action":
+                    self.rx_flags2.cap(1).strip(),
+                    "path":
+                    self.rx_flags2.cap(2).strip(),
+                    "copyfrom_path": "",
+                    "copyfrom_revision": "",
                 })
             elif self.rx_sep1.exactMatch(s) or self.rx_sep2.exactMatch(s):
                 if len(log) > 1:
-                    self.__generateLogItem(log["author"], log["date"], 
-                        log["message"], log["revision"], changedPaths)
+                    self.__generateLogItem(
+                        log["author"], log["date"], log["message"],
+                        log["revision"], changedPaths)
                     dt = QDate.fromString(log["date"], Qt.ISODate)
-                    if not self.__maxDate.isValid() and not self.__minDate.isValid():
+                    if not self.__maxDate.isValid() and \
+                            not self.__minDate.isValid():
                         self.__maxDate = dt
                         self.__minDate = dt
                     else:
@@ -351,10 +362,10 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
                         if self.__minDate > dt:
                             self.__minDate = dt
                     noEntries += 1
-                    log = {"message" : QStringList()}
+                    log = {"message": []}
                     changedPaths = []
             else:
-                if s.trimmed().endsWith(":") or s.trimmed().isEmpty():
+                if s.strip().endswith(":") or not s.strip():
                     continue
                 else:
                     log["message"].append(s)
@@ -382,14 +393,16 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
     
     def __readStdout(self):
         """
-        Private slot to handle the readyReadStandardOutput signal. 
+        Private slot to handle the readyReadStandardOutput signal.
         
         It reads the output of the process and inserts it into a buffer.
         """
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            line = QString(self.process.readLine())
+            line = str(self.process.readLine(),
+                       Preferences.getSystem("IOEncoding"),
+                       'replace')
             self.buf.append(line)
     
     def __readStderr(self):
@@ -400,7 +413,10 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         error pane.
         """
         if self.process is not None:
-            s = QString(self.process.readAllStandardError())
+            self.errorGroup.show()
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
     
@@ -411,12 +427,16 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         @param rev1 first revision number (integer)
         @param rev2 second revision number (integer)
         """
-        if self.diff:
-            self.diff.close()
-            del self.diff
-        self.diff = SvnDiffDialog(self.vcs)
-        self.diff.show()
-        self.diff.start(self.filename, [rev1, rev2])
+        if self.sbsCheckBox.isEnabled() and self.sbsCheckBox.isChecked():
+            self.vcs.svnSbsDiff(self.filename,
+                                revisions=(str(rev1), str(rev2)))
+        else:
+            if self.diff is None:
+                from .SvnDiffDialog import SvnDiffDialog
+                self.diff = SvnDiffDialog(self.vcs)
+            self.diff.show()
+            self.diff.raise_()
+            self.diff.start(self.filename, [rev1, rev2])
     
     def on_buttonBox_clicked(self, button):
         """
@@ -430,7 +450,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
             self.cancelled = True
             self.__finish()
     
-    @pyqtSignature("QTreeWidgetItem*, QTreeWidgetItem*")
+    @pyqtSlot(QTreeWidgetItem, QTreeWidgetItem)
     def on_logTree_currentItemChanged(self, current, previous):
         """
         Private slot called, when the current item of the log tree changes.
@@ -439,29 +459,32 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         @param previous reference to the old current item (QTreeWidgetItem)
         """
         self.messageEdit.clear()
-        for line in current.data(0, self.__messageRole).toStringList():
-            self.messageEdit.append(line.trimmed())
+        for line in current.data(0, self.__messageRole):
+            self.messageEdit.append(line.strip())
         
         self.filesTree.clear()
-        changes = eval(unicode(current.data(0, self.__changesRole).toString()))
+        changes = current.data(0, self.__changesRole)
         if len(changes) > 0:
             for change in changes:
-                self.__generateFileItem(change["action"], change["path"], 
-                    change["copyfrom_path"], change["copyfrom_revision"])
+                self.__generateFileItem(
+                    change["action"], change["path"], change["copyfrom_path"],
+                    change["copyfrom_revision"])
             self.__resizeColumnsFiles()
             self.__resortFiles()
         
-        self.diffPreviousButton.setEnabled(\
-            current != self.logTree.topLevelItem(self.logTree.topLevelItemCount() - 1))
+        self.diffPreviousButton.setEnabled(
+            current != self.logTree.topLevelItem(
+                self.logTree.topLevelItemCount() - 1))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_logTree_itemSelectionChanged(self):
         """
         Private slot called, when the selection has changed.
         """
-        self.diffRevisionsButton.setEnabled(len(self.logTree.selectedItems()) == 2)
+        self.diffRevisionsButton.setEnabled(
+            len(self.logTree.selectedItems()) == 2)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_nextButton_clicked(self):
         """
         Private slot to handle the Next button.
@@ -469,7 +492,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         if self.__lastRev > 1:
             self.__getLogEntries(self.__lastRev - 1)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffPreviousButton_clicked(self):
         """
         Private slot to handle the Diff to Previous button.
@@ -480,7 +503,8 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
             return
         rev2 = int(itm.text(0))
         
-        itm = self.logTree.topLevelItem(self.logTree.indexOfTopLevelItem(itm) + 1)
+        itm = self.logTree.topLevelItem(
+            self.logTree.indexOfTopLevelItem(itm) + 1)
         if itm is None:
             self.diffPreviousButton.setEnabled(False)
             return
@@ -488,7 +512,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         
         self.__diffRevisions(rev1, rev2)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffRevisionsButton_clicked(self):
         """
         Private slot to handle the Compare Revisions button.
@@ -503,7 +527,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         
         self.__diffRevisions(min(rev1, rev2), max(rev1, rev2))
     
-    @pyqtSignature("QDate")
+    @pyqtSlot(QDate)
     def on_fromDate_dateChanged(self, date):
         """
         Private slot called, when the from date changes.
@@ -512,7 +536,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         """
         self.__filterLogs()
     
-    @pyqtSignature("QDate")
+    @pyqtSlot(QDate)
     def on_toDate_dateChanged(self, date):
         """
         Private slot called, when the from date changes.
@@ -521,21 +545,21 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         """
         self.__filterLogs()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_fieldCombo_activated(self, txt):
         """
         Private slot called, when a new filter field is selected.
         
-        @param txt text of the selected field (QString)
+        @param txt text of the selected field (string)
         """
         self.__filterLogs()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_rxEdit_textChanged(self, txt):
         """
         Private slot called, when a filter expression is entered.
         
-        @param txt filter expression (QString)
+        @param txt filter expression (string)
         """
         self.__filterLogs()
     
@@ -553,8 +577,9 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
             elif txt == self.trUtf8("Revision"):
                 fieldIndex = 0
                 txt = self.rxEdit.text()
-                if txt.startsWith("^"):
-                    searchRx = QRegExp("^\s*%s" % txt[1:], Qt.CaseInsensitive)
+                if txt.startswith("^"):
+                    searchRx = QRegExp(
+                        "^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
                 else:
                     searchRx = QRegExp(txt, Qt.CaseInsensitive)
             else:
@@ -565,7 +590,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
             for topIndex in range(self.logTree.topLevelItemCount()):
                 topItem = self.logTree.topLevelItem(topIndex)
                 if topItem.text(2) <= to_ and topItem.text(2) >= from_ and \
-                   topItem.text(fieldIndex).contains(searchRx):
+                   searchRx.indexIn(topItem.text(fieldIndex)) > -1:
                     topItem.setHidden(False)
                     if topItem is currentItem:
                         self.on_logTree_currentItemChanged(topItem, None)
@@ -575,20 +600,15 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
                         self.messageEdit.clear()
                         self.filesTree.clear()
     
-    @pyqtSignature("")
-    def on_clearRxEditButton_clicked(self):
-        """
-        Private slot called by a click of the clear RX edit button.
-        """
-        self.rxEdit.clear()
-    
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_stopCheckBox_clicked(self, checked):
         """
-        Private slot called, when the stop on copy/move checkbox is clicked
+        Private slot called, when the stop on copy/move checkbox is clicked.
+        
+        @param checked flag indicating the checked state (boolean)
         """
-        self.vcs.getPlugin().setPreferences("StopLogOnCopy", 
-                                            int(self.stopCheckBox.isChecked()))
+        self.vcs.getPlugin().setPreferences("StopLogOnCopy",
+                                            self.stopCheckBox.isChecked())
         self.nextButton.setEnabled(True)
         self.limitSpinBox.setEnabled(True)
     
@@ -603,13 +623,13 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -617,8 +637,9 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         else:
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
+        self.errorGroup.show()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -640,4 +661,4 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
             self.intercept = False
             evt.accept()
             return
-        QWidget.keyPressEvent(self, evt)
+        super().keyPressEvent(evt)
