@@ -8,33 +8,36 @@ Module implementing a dialog to show the output of the svn log command process.
 """
 
 import os
-import sys
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QTimer, QByteArray, QProcess, QRegExp, QUrl, pyqtSlot
+from PyQt4.QtGui import QWidget, QLineEdit, QApplication, QTextCursor, \
+    QDialogButtonBox
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from Ui_SvnLogDialog import Ui_SvnLogDialog
-from SvnDiffDialog import SvnDiffDialog
+from .Ui_SvnLogDialog import Ui_SvnLogDialog
 
 import Utilities
+import Preferences
+
 
 class SvnLogDialog(QWidget, Ui_SvnLogDialog):
     """
-    Class implementing a dialog to show the output of the svn log command process.
+    Class implementing a dialog to show the output of the svn log command
+    process.
     
-    The dialog is nonmodal. Clicking a link in the upper text pane shows 
+    The dialog is nonmodal. Clicking a link in the upper text pane shows
     a diff of the versions.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, isFile=False, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
+        @param isFile flag indicating log for a file is to be shown (boolean)
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
@@ -42,45 +45,46 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         self.process = QProcess()
         self.vcs = vcs
         
-        self.contents.setHtml(\
+        self.contents.setHtml(
             self.trUtf8('<b>Processing your request, please wait...</b>'))
         
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
-        self.connect(self.contents, SIGNAL('anchorClicked(const QUrl&)'),
-            self.__sourceChanged)
+        self.contents.anchorClicked.connect(self.__sourceChanged)
         
         self.rx_sep = QRegExp('\\-+\\s*')
         self.rx_sep2 = QRegExp('=+\\s*')
-        self.rx_rev = QRegExp('rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+        self.rx_rev = QRegExp(
+            'rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "rev" followed by one or more decimals followed by a colon followed
-        # anything up to " | " (twice) followed by one or more decimals followed
-        # by anything
-        self.rx_rev2 = QRegExp('r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
+        # anything up to " | " (twice) followed by one or more decimals
+        # followed by anything
+        self.rx_rev2 = QRegExp(
+            'r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "r" followed by one or more decimals followed by " | " followed
-        # anything up to " | " (twice) followed by one or more decimals followed
-        # by anything
+        # anything up to " | " (twice) followed by one or more decimals
+        # followed by anything
         self.rx_flags = QRegExp('   ([ADM])( .*)\\s*')
         # three blanks followed by A or D or M
         self.rx_changed = QRegExp('Changed .*\\s*')
         
         self.flags = {
-            'A' : self.trUtf8('Added'),
-            'D' : self.trUtf8('Deleted'),
-            'M' : self.trUtf8('Modified')
+            'A': self.trUtf8('Added'),
+            'D': self.trUtf8('Deleted'),
+            'M': self.trUtf8('Modified')
         }
         
-        self.revisions = QStringList()  # stack of remembered revisions
+        self.revisions = []  # stack of remembered revisions
         self.revString = self.trUtf8('revision')
         
-        self.buf = QStringList()        # buffer for stdout
+        self.buf = []        # buffer for stdout
         self.diff = None
         
+        self.sbsCheckBox.setEnabled(isFile)
+        self.sbsCheckBox.setVisible(isFile)
+        
     def closeEvent(self, e):
         """
         Private slot implementing a close event handler.
@@ -90,12 +94,12 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
         
-    def start(self, fn, noEntries = 0):
+    def start(self, fn, noEntries=0):
         """
         Public slot to start the cvs log command.
         
@@ -111,7 +115,7 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         
         self.process.kill()
         
-        args = QStringList()
+        args = []
         args.append('log')
         self.vcs.addArguments(args, self.vcs.options['global'])
         self.vcs.addArguments(args, self.vcs.options['log'])
@@ -125,15 +129,16 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         self.process.setWorkingDirectory(self.dname)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         
     def __procFinished(self, exitCode, exitStatus):
         """
@@ -164,7 +169,7 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
                 rev_match = True
             
             if rev_match:
-                dstr = QString('<b>%1 %2</b>').arg(self.revString).arg(ver)
+                dstr = '<b>{0} {1}</b>'.format(self.revString, ver)
                 try:
                     lv = self.revisions[lvers]
                     lvers += 1
@@ -174,42 +179,40 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
                     query = QByteArray()
                     query.append(lv).append('_').append(ver)
                     url.setEncodedQuery(query)
-                    dstr.append(' [<a href="')\
-                        .append(url.toString())\
-                        .append('" name="')\
-                        .append(query)\
-                        .append('">')\
-                        .append(self.trUtf8('diff to %1').arg(lv))\
-                        .append('</a>]')
+                    dstr += ' [<a href="{0}" name="{1}">{2}</a>]'.format(
+                        url.toString(),
+                        query,
+                        self.trUtf8('diff to {0}').format(lv),
+                    )
                 except IndexError:
                     pass
-                dstr.append('<br />\n')
+                dstr += '<br />\n'
                 self.contents.insertHtml(dstr)
                 
-                dstr = self.trUtf8('<i>author: %1</i><br />\n').arg(author)
+                dstr = self.trUtf8('<i>author: {0}</i><br />\n').format(author)
                 self.contents.insertHtml(dstr)
                 
-                dstr = self.trUtf8('<i>date: %1</i><br />\n').arg(date)
+                dstr = self.trUtf8('<i>date: {0}</i><br />\n').format(date)
                 self.contents.insertHtml(dstr)
             
             elif self.rx_sep.exactMatch(s) or self.rx_sep2.exactMatch(s):
                 self.contents.insertHtml('<hr />\n')
             
             elif self.rx_flags.exactMatch(s):
-                dstr = QString(self.flags[str(self.rx_flags.cap(1))])
-                dstr.append(self.rx_flags.cap(2))
-                dstr.append('<br />\n')
+                dstr = self.flags[self.rx_flags.cap(1)]
+                dstr += self.rx_flags.cap(2)
+                dstr += '<br />\n'
                 self.contents.insertHtml(dstr)
             
             elif self.rx_changed.exactMatch(s):
-                dstr = QString('<br />%1<br />\n').arg(s)
+                dstr = '<br />{0}<br />\n'.format(s)
                 self.contents.insertHtml(dstr)
             
             else:
-                if s.isEmpty():
+                if s == "":
                     s = self.contents.insertHtml('<br />\n')
                 else:
-                    self.contents.insertHtml(Utilities.html_encode(unicode(s)))
+                    self.contents.insertHtml(Utilities.html_encode(s))
                     self.contents.insertHtml('<br />\n')
         
         tc = self.contents.textCursor()
@@ -219,14 +222,16 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         
     def __readStdout(self):
         """
-        Private slot to handle the readyReadStandardOutput signal. 
+        Private slot to handle the readyReadStandardOutput signal.
         
         It reads the output of the process and inserts it into a buffer.
         """
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            line = QString(self.process.readLine())
+            line = str(self.process.readLine(),
+                       Preferences.getSystem("IOEncoding"),
+                       'replace')
             self.buf.append(line)
             if self.rx_rev.exactMatch(line):
                 ver = self.rx_rev.cap(1)
@@ -246,7 +251,9 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         """
         if self.process is not None:
             self.errorGroup.show()
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
         
@@ -257,22 +264,25 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         @param url the url that was clicked (QUrl)
         """
         self.contents.setSource(QUrl(''))
-        filename = unicode(url.path())
+        filename = url.path()
         if Utilities.isWindowsPlatform():
             if filename.startswith("/"):
                 filename = filename[1:]
-        ver = QString(url.encodedQuery())
-        v1 = ver.section('_', 0, 0)
-        v2 = ver.section('_', 1, 1)
-        if v1.isEmpty() or v2.isEmpty():
+        ver = bytes(url.encodedQuery()).decode()
+        v1 = ver.split('_')[0]
+        v2 = ver.split('_')[1]
+        if v1 == "" or v2 == "":
             return
         self.contents.scrollToAnchor(ver)
         
-        if self.diff:
-            del self.diff
-        self.diff = SvnDiffDialog(self.vcs)
-        self.diff.show()
-        self.diff.start(filename, [v1, v2])
+        if self.sbsCheckBox.isEnabled() and self.sbsCheckBox.isChecked():
+            self.vcs.svnSbsDiff(filename, revisions=(v1, v2))
+        else:
+            if self.diff is None:
+                from .SvnDiffDialog import SvnDiffDialog
+                self.diff = SvnDiffDialog(self.vcs)
+            self.diff.show()
+            self.diff.start(filename, [v1, v2])
         
     def on_passwordCheckBox_toggled(self, isOn):
         """
@@ -285,13 +295,13 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -300,7 +310,7 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -322,4 +332,4 @@ class SvnLogDialog(QWidget, Ui_SvnLogDialog):
             self.intercept = False
             evt.accept()
             return
-        QWidget.keyPressEvent(self, evt)
+        super().keyPressEvent(evt)
