@@ -4,96 +4,122 @@
 #
 
 """
-Module implementing the Subversion Options Dialog for a new project from the repository.
+Module implementing the Subversion Options Dialog for a new project from the
+repository.
 """
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4DirCompleter
-
-from SvnRepoBrowserDialog import SvnRepoBrowserDialog
-from Ui_SvnNewProjectOptionsDialog import Ui_SvnNewProjectOptionsDialog
-from Config import ConfigSvnProtocols
+from .Ui_SvnNewProjectOptionsDialog import Ui_SvnNewProjectOptionsDialog
+from .Config import ConfigSvnProtocols
 
 import Utilities
 import Preferences
 
+
 class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
     """
-    Class implementing the Options Dialog for a new project from the repository.
+    Class implementing the Options Dialog for a new project from the
+    repository.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the version control object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.vcsDirectoryCompleter = E4DirCompleter(self.vcsUrlEdit)
-        self.vcsProjectDirCompleter = E4DirCompleter(self.vcsProjectDirEdit)
+        self.vcsDirectoryCompleter = E5DirCompleter(self.vcsUrlEdit)
+        self.vcsProjectDirCompleter = E5DirCompleter(self.vcsProjectDirEdit)
         
         self.protocolCombo.addItems(ConfigSvnProtocols)
         
         self.vcs = vcs
         
         hd = Utilities.toNativeSeparators(QDir.homePath())
-        hd = os.path.join(unicode(hd), 'subversionroot')
+        hd = os.path.join(hd, 'subversionroot')
         self.vcsUrlEdit.setText(hd)
         
-        self.localPath = unicode(hd)
+        self.localPath = hd
         self.networkPath = "localhost/"
         self.localProtocol = True
         
-        self.vcsProjectDirEdit.setText(Utilities.toNativeSeparators(
-            Preferences.getMultiProject("Workspace") or Utilities.getHomeDir()))
+        ipath = Preferences.getMultiProject("Workspace") or \
+            Utilities.getHomeDir()
+        self.__initPaths = [
+            Utilities.fromNativeSeparators(ipath),
+            Utilities.fromNativeSeparators(ipath) + "/",
+        ]
+        self.vcsProjectDirEdit.setText(
+            Utilities.toNativeSeparators(self.__initPaths[0]))
         
-    @pyqtSignature("")
+        self.resize(self.width(), self.minimumSizeHint().height())
+        
+        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
+    
+    @pyqtSlot(str)
+    def on_vcsProjectDirEdit_textChanged(self, txt):
+        """
+        Private slot to handle a change of the project directory.
+        
+        @param txt name of the project directory (string)
+        """
+        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
+            bool(txt) and
+            Utilities.fromNativeSeparators(txt) not in self.__initPaths)
+        
+    @pyqtSlot()
     def on_vcsUrlButton_clicked(self):
         """
         Private slot to display a selection dialog.
         """
         if self.protocolCombo.currentText() == "file://":
-            directory = KQFileDialog.getExistingDirectory(\
+            directory = E5FileDialog.getExistingDirectory(
                 self,
                 self.trUtf8("Select Repository-Directory"),
                 self.vcsUrlEdit.text(),
-                QFileDialog.Options(QFileDialog.ShowDirsOnly))
+                E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-            if not directory.isEmpty():
-                self.vcsUrlEdit.setText(Utilities.toNativeSeparators(directory))
+            if directory:
+                self.vcsUrlEdit.setText(
+                    Utilities.toNativeSeparators(directory))
         else:
-            dlg = SvnRepoBrowserDialog(self.vcs, mode = "select", parent = self)
-            dlg.start(self.protocolCombo.currentText() + self.vcsUrlEdit.text())
+            from .SvnRepoBrowserDialog import SvnRepoBrowserDialog
+            dlg = SvnRepoBrowserDialog(self.vcs, mode="select", parent=self)
+            dlg.start(
+                self.protocolCombo.currentText() + self.vcsUrlEdit.text())
             if dlg.exec_() == QDialog.Accepted:
                 url = dlg.getSelectedUrl()
-                if not url.isEmpty():
-                    protocol = url.section("://", 0, 0)
-                    path = url.section("://", 1, 1)
-                    self.protocolCombo.setCurrentIndex(\
+                if url:
+                    protocol = url.split("://")[0]
+                    path = url.split("://")[1]
+                    self.protocolCombo.setCurrentIndex(
                         self.protocolCombo.findText(protocol + "://"))
                     self.vcsUrlEdit.setText(path)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_projectDirButton_clicked(self):
         """
         Private slot to display a directory selection dialog.
         """
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select Project Directory"),
             self.vcsProjectDirEdit.text(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         
-        if not directory.isEmpty():
-            self.vcsProjectDirEdit.setText(Utilities.toNativeSeparators(directory))
+        if directory:
+            self.vcsProjectDirEdit.setText(
+                Utilities.toNativeSeparators(directory))
         
     def on_layoutCheckBox_toggled(self, checked):
         """
@@ -106,19 +132,21 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         if not checked:
             self.vcsTagEdit.clear()
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_protocolCombo_activated(self, protocol):
         """
         Private slot to switch the status of the directory selection button.
+        
+        @param protocol selected protocol (string)
         """
-        if str(protocol) == "file://":
-            self.networkPath = unicode(self.vcsUrlEdit.text())
+        if protocol == "file://":
+            self.networkPath = self.vcsUrlEdit.text()
             self.vcsUrlEdit.setText(self.localPath)
             self.vcsUrlLabel.setText(self.trUtf8("Pat&h:"))
             self.localProtocol = True
         else:
             if self.localProtocol:
-                self.localPath = unicode(self.vcsUrlEdit.text())
+                self.localPath = self.vcsUrlEdit.text()
                 self.vcsUrlEdit.setText(self.networkPath)
                 self.vcsUrlLabel.setText(self.trUtf8("&URL:"))
                 self.localProtocol = False
@@ -128,9 +156,9 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         """
         Private slot to handle changes of the URL.
         
-        @param txt current text of the line edit (QString)
+        @param txt current text of the line edit (string)
         """
-        enable = not txt.contains("://")
+        enable = "://" not in txt
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(enable)
         
     def getData(self):
@@ -140,11 +168,11 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         @return a tuple of a string (project directory) and a dictionary
             containing the data entered.
         """
-        scheme = str(self.protocolCombo.currentText())
-        url = unicode(self.vcsUrlEdit.text())
+        scheme = self.protocolCombo.currentText()
+        url = self.vcsUrlEdit.text()
         vcsdatadict = {
-            "url" : '%s%s' % (scheme, url),
-            "tag" : unicode(self.vcsTagEdit.text()),
-            "standardLayout" : self.layoutCheckBox.isChecked(),
+            "url": '{0}{1}'.format(scheme, url),
+            "tag": self.vcsTagEdit.text(),
+            "standardLayout": self.layoutCheckBox.isChecked(),
         }
-        return (unicode(self.vcsProjectDirEdit.text()), vcsdatadict)
+        return (self.vcsProjectDirEdit.text(), vcsdatadict)
