@@ -4,30 +4,30 @@
 #
 
 """
-Module implementing a dialog to enter options used to start a project in the VCS.
+Module implementing a dialog to enter options used to start a project in
+the VCS.
 """
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4DirCompleter
-
-from SvnRepoBrowserDialog import SvnRepoBrowserDialog
-from Ui_SvnOptionsDialog import Ui_SvnOptionsDialog
-from Config import ConfigSvnProtocols
+from .Ui_SvnOptionsDialog import Ui_SvnOptionsDialog
+from .Config import ConfigSvnProtocols
 
 import Utilities
 
+
 class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
     """
     Class implementing a dialog to enter options used to start a project in the
     repository.
     """
-    def __init__(self, vcs, project, parent = None):
+    def __init__(self, vcs, project, parent=None):
         """
         Constructor
         
@@ -35,64 +35,69 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         @param project reference to the project object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.vcsDirectoryCompleter = E4DirCompleter(self.vcsUrlEdit)
+        self.vcsDirectoryCompleter = E5DirCompleter(self.vcsUrlEdit)
         
         self.project = project
         
         self.protocolCombo.addItems(ConfigSvnProtocols)
         
         hd = Utilities.toNativeSeparators(QDir.homePath())
-        hd = os.path.join(unicode(hd), 'subversionroot')
+        hd = os.path.join(hd, 'subversionroot')
         self.vcsUrlEdit.setText(hd)
         
         self.vcs = vcs
         
-        self.localPath = unicode(hd)
+        self.localPath = hd
         self.networkPath = "localhost/"
         self.localProtocol = True
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_vcsUrlButton_clicked(self):
         """
         Private slot to display a selection dialog.
         """
         if self.protocolCombo.currentText() == "file://":
-            directory = KQFileDialog.getExistingDirectory(\
+            directory = E5FileDialog.getExistingDirectory(
                 self,
                 self.trUtf8("Select Repository-Directory"),
                 self.vcsUrlEdit.text(),
-                QFileDialog.Options(QFileDialog.ShowDirsOnly))
+                E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-            if not directory.isEmpty():
-                self.vcsUrlEdit.setText(Utilities.toNativeSeparators(directory))
+            if directory:
+                self.vcsUrlEdit.setText(
+                    Utilities.toNativeSeparators(directory))
         else:
-            dlg = SvnRepoBrowserDialog(self.vcs, mode = "select", parent = self)
-            dlg.start(self.protocolCombo.currentText() + self.vcsUrlEdit.text())
+            from .SvnRepoBrowserDialog import SvnRepoBrowserDialog
+            dlg = SvnRepoBrowserDialog(self.vcs, mode="select", parent=self)
+            dlg.start(
+                self.protocolCombo.currentText() + self.vcsUrlEdit.text())
             if dlg.exec_() == QDialog.Accepted:
                 url = dlg.getSelectedUrl()
-                if not url.isEmpty():
-                    protocol = url.section("://", 0, 0)
-                    path = url.section("://", 1, 1)
-                    self.protocolCombo.setCurrentIndex(\
+                if url:
+                    protocol = url.split("://")[0]
+                    path = url.split("://")[1]
+                    self.protocolCombo.setCurrentIndex(
                         self.protocolCombo.findText(protocol + "://"))
                     self.vcsUrlEdit.setText(path)
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_protocolCombo_activated(self, protocol):
         """
         Private slot to switch the status of the directory selection button.
+        
+        @param protocol selected protocol (string)
         """
-        if str(protocol) == "file://":
-            self.networkPath = unicode(self.vcsUrlEdit.text())
+        if protocol == "file://":
+            self.networkPath = self.vcsUrlEdit.text()
             self.vcsUrlEdit.setText(self.localPath)
             self.vcsUrlLabel.setText(self.trUtf8("Pat&h:"))
             self.localProtocol = True
         else:
             if self.localProtocol:
-                self.localPath = unicode(self.vcsUrlEdit.text())
+                self.localPath = self.vcsUrlEdit.text()
                 self.vcsUrlEdit.setText(self.networkPath)
                 self.vcsUrlLabel.setText(self.trUtf8("&URL:"))
                 self.localProtocol = False
@@ -102,9 +107,9 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         """
         Private slot to handle changes of the URL.
         
-        @param txt current text of the line edit (QString)
+        @param txt current text of the line edit (string)
         """
-        enable = not txt.contains("://")
+        enable = "://" not in txt
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(enable)
         
     def getData(self):
@@ -113,11 +118,11 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         
         @return a dictionary containing the data entered
         """
-        scheme = str(self.protocolCombo.currentText())
-        url = unicode(self.vcsUrlEdit.text())
+        scheme = self.protocolCombo.currentText()
+        url = self.vcsUrlEdit.text()
         vcsdatadict = {
-            "url" : '%s%s' % (scheme, url),
-            "message" : unicode(self.vcsLogEdit.text()),
-            "standardLayout" : self.layoutCheckBox.isChecked(),
+            "url": '{0}{1}'.format(scheme, url),
+            "message": self.vcsLogEdit.text(),
+            "standardLayout": self.layoutCheckBox.isChecked(),
         }
         return vcsdatadict
