@@ -4,30 +4,33 @@
 #
 
 """
-Module implementing a dialog to show the output of the svn proplist command process.
+Module implementing a dialog to show the output of the svn proplist command
+process.
 """
 
-import types
+from PyQt4.QtCore import QTimer, QProcess, QProcessEnvironment, QRegExp, Qt
+from PyQt4.QtGui import QWidget, QHeaderView, QDialogButtonBox, QTreeWidgetItem
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from E5Gui import E5MessageBox
 
-from KdeQt import KQMessageBox
+from .Ui_SvnPropListDialog import Ui_SvnPropListDialog
+
+import Preferences
 
-from Ui_SvnPropListDialog import Ui_SvnPropListDialog
 
 class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
     """
-    Class implementing a dialog to show the output of the svn proplist command process.
+    Class implementing a dialog to show the output of the svn proplist command
+    process.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
@@ -42,24 +45,22 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         self.propsList.headerItem().setText(self.propsList.columnCount(), "")
         self.propsList.header().setSortIndicator(0, Qt.AscendingOrder)
         
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
         self.rx_path = QRegExp(r"Properties on '([^']+)':\s*")
         self.rx_prop = QRegExp(r"  (.*) *: *(.*)[\r\n]")
         self.lastPath = None
         self.lastProp = None
-        self.propBuffer = QString('')
+        self.propBuffer = ""
         
     def __resort(self):
         """
         Private method to resort the tree.
         """
-        self.propsList.sortItems(self.propsList.sortColumn(), 
+        self.propsList.sortItems(
+            self.propsList.sortColumn(),
             self.propsList.header().sortIndicatorOrder())
         
     def __resizeColumns(self):
@@ -73,12 +74,11 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         """
         Private method to generate a properties item in the properties list.
         
-        @param path file/directory name the property applies to (string or QString)
-        @param propName name of the property (string or QString)
-        @param propValue value of the property (string or QString)
+        @param path file/directory name the property applies to (string)
+        @param propName name of the property (string)
+        @param propValue value of the property (string)
         """
-        QTreeWidgetItem(self.propsList,
-            QStringList() << path << propName << propValue.trimmed())
+        QTreeWidgetItem(self.propsList, [path, propName, propValue.strip()])
         
     def closeEvent(self, e):
         """
@@ -89,12 +89,12 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
         
-    def start(self, fn, recursive = False):
+    def start(self, fn, recursive=False):
         """
         Public slot to start the svn status command.
         
@@ -105,13 +105,13 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         
         self.process.kill()
         
-        args = QStringList()
+        args = []
         args.append('proplist')
         self.vcs.addArguments(args, self.vcs.options['global'])
         args.append('--verbose')
         if recursive:
             args.append('--recursive')
-        if type(fn) is types.ListType:
+        if isinstance(fn, list):
             dname, fnames = self.vcs.splitPathList(fn)
             self.vcs.addArguments(args, fnames)
         else:
@@ -121,23 +121,25 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         self.process.setWorkingDirectory(dname)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
@@ -184,21 +186,25 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            s = QString(self.process.readLine())
+            s = str(self.process.readLine(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             if self.rx_path.exactMatch(s):
                 if self.lastProp:
-                    self.__generateItem(self.lastPath, self.lastProp, self.propBuffer)
+                    self.__generateItem(
+                        self.lastPath, self.lastProp, self.propBuffer)
                 self.lastPath = self.rx_path.cap(1)
                 self.lastProp = None
-                self.propBuffer = QString('')
+                self.propBuffer = ""
             elif self.rx_prop.exactMatch(s):
                 if self.lastProp:
-                    self.__generateItem(self.lastPath, self.lastProp, self.propBuffer)
+                    self.__generateItem(
+                        self.lastPath, self.lastProp, self.propBuffer)
                 self.lastProp = self.rx_prop.cap(1)
                 self.propBuffer = self.rx_prop.cap(2)
             else:
-                self.propBuffer.append(' ')
-                self.propBuffer.append(s)
+                self.propBuffer += ' '
+                self.propBuffer += s
         
     def __readStderr(self):
         """
@@ -209,6 +215,8 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         """
         if self.process is not None:
             self.errorGroup.show()
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
