@@ -7,44 +7,44 @@
 Module implementing a dialog to enter the data for a new property.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from Ui_SvnPropSetDialog import Ui_SvnPropSetDialog
+from .Ui_SvnPropSetDialog import Ui_SvnPropSetDialog
 
 import Utilities
 
+
 class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
     """
     Class implementing a dialog to enter the data for a new property.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.propFileCompleter = E4FileCompleter(self.propFileEdit)
+        self.propFileCompleter = E5FileCompleter(self.propFileEdit)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fileButton_clicked(self):
         """
         Private slot called by pressing the file selection button.
         """
-        fn = KQFileDialog.getOpenFileName(\
+        fn = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select file for property"),
             self.propFileEdit.text(),
-            QString())
+            "")
         
-        if not fn.isEmpty():
+        if fn:
             self.propFileEdit.setText(Utilities.toNativeSeparators(fn))
         
     def getData(self):
@@ -53,9 +53,10 @@ class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
         
         @return tuple of three values giving the property name, a flag
             indicating a file was selected and the text of the property
-            or the selected filename. (QString, boolean, QString)
+            or the selected filename. (string, boolean, string)
         """
         if self.fileRadioButton.isChecked():
             return (self.propNameEdit.text(), True, self.propFileEdit.text())
         else:
-            return (self.propNameEdit.text(), False, self.propTextEdit.toPlainText())
+            return (self.propNameEdit.text(), False,
+                    self.propTextEdit.toPlainText())
