@@ -9,22 +9,24 @@ Module implementing the subversion repository browser dialog.
 
 import os
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from PyQt4.QtGui import QCursor, QHeaderView, QLineEdit, QDialog, \
+    QApplication, QDialogButtonBox, QTreeWidgetItem
+from PyQt4.QtCore import QTimer, QProcess, QRegExp, Qt, pyqtSlot
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from Ui_SvnRepoBrowserDialog import Ui_SvnRepoBrowserDialog
+from .Ui_SvnRepoBrowserDialog import Ui_SvnRepoBrowserDialog
 
 import UI.PixmapCache
 
 import Preferences
 
+
 class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
     """
     Class implementing the subversion repository browser dialog.
     """
-    def __init__(self, vcs, mode = "browse", parent = None):
+    def __init__(self, vcs, mode="browse", parent=None):
         """
         Constructor
         
@@ -32,7 +34,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         @param mode mode of the dialog (string, "browse" or "select")
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.repoTree.headerItem().setText(self.repoTree.columnCount(), "")
@@ -56,10 +58,12 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         self.__ignoreExpand = False
         self.intercept = False
         
-        self.__rx_dir = \
-            QRegExp(r"""\s*([0-9]+)\s+(\w+)\s+((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
-        self.__rx_file = \
-            QRegExp(r"""\s*([0-9]+)\s+(\w+)\s+([0-9]+)\s((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
+        self.__rx_dir = QRegExp(
+            r"""\s*([0-9]+)\s+(\w+)\s+"""
+            r"""((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
+        self.__rx_file = QRegExp(
+            r"""\s*([0-9]+)\s+(\w+)\s+([0-9]+)\s"""
+            r"""((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
     
     def closeEvent(self, e):
         """
@@ -70,7 +74,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
@@ -79,7 +83,8 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         """
         Private method to resort the tree.
         """
-        self.repoTree.sortItems(self.repoTree.sortColumn(), 
+        self.repoTree.sortItems(
+            self.repoTree.sortColumn(),
             self.repoTree.header().sortIndicatorOrder())
     
     def __resizeColumns(self):
@@ -89,19 +94,18 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         self.repoTree.header().resizeSections(QHeaderView.ResizeToContents)
         self.repoTree.header().setStretchLastSection(True)
     
-    def __generateItem(self, repopath, revision, author, size, date, 
-            nodekind, url):
+    def __generateItem(self, repopath, revision, author, size, date,
+                       nodekind, url):
         """
         Private method to generate a tree item in the repository tree.
         
-        @param parent parent of the item to be created (QTreeWidget or QTreeWidgetItem)
-        @param repopath path of the item (string or QString)
-        @param revision revision info (string or QString)
-        @param author author info (string or QString)
-        @param size size info (string or QString)
-        @param date date info (string or QString)
+        @param repopath path of the item (string)
+        @param revision revision info (string)
+        @param author author info (string)
+        @param size size info (string)
+        @param date date info (string)
         @param nodekind node kind info (string, "dir" or "file")
-        @param url url of the entry (string or QString)
+        @param url url of the entry (string)
         @return reference to the generated item (QTreeWidgetItem)
         """
         path = repopath
@@ -128,7 +132,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         elif nodekind == "file":
             itm.setIcon(0, self.__fileIcon)
         
-        itm.setData(0, self.__urlRole, QVariant(url))
+        itm.setData(0, self.__urlRole, url)
         
         itm.setTextAlignment(0, Qt.AlignLeft)
         itm.setTextAlignment(1, Qt.AlignRight)
@@ -142,52 +146,56 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         """
         Private method to get the repository root using the svn info command.
         
-        @param url the repository URL to browser (string or QString)
+        @param url the repository URL to browser (string)
         @return repository root (string)
         """
-        ioEncoding = str(Preferences.getSystem("IOEncoding"))
+        ioEncoding = Preferences.getSystem("IOEncoding")
         repoRoot = None
         
         process = QProcess()
         
-        args = QStringList()
+        args = []
         args.append('info')
         self.vcs.addArguments(args, self.vcs.options['global'])
         args.append('--xml')
         args.append(url)
         
         process.start('svn', args)
-        procStarted = process.waitForStarted()
+        procStarted = process.waitForStarted(5000)
         if procStarted:
             finished = process.waitForFinished(30000)
             if finished:
                 if process.exitCode() == 0:
-                    output = unicode(process.readAllStandardOutput(), 
-                                     ioEncoding, 'replace')
+                    output = str(process.readAllStandardOutput(), ioEncoding,
+                                 'replace')
                     for line in output.splitlines():
                         line = line.strip()
                         if line.startswith('<root>'):
-                            repoRoot = line.replace('<root>', '').replace('</root>', '')
+                            repoRoot = line.replace('<root>', '')\
+                                .replace('</root>', '')
                             break
                 else:
-                    error = QString(process.readAllStandardError())
+                    error = str(process.readAllStandardError(),
+                                Preferences.getSystem("IOEncoding"),
+                                'replace')
                     self.errors.insertPlainText(error)
                     self.errors.ensureCursorVisible()
         else:
             QApplication.restoreOverrideCursor()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         return repoRoot
     
-    def __listRepo(self, url, parent = None):
+    def __listRepo(self, url, parent=None):
         """
         Private method to perform the svn list command.
         
-        @param url the repository URL to browser (string or QString)
+        @param url the repository URL to browse (string)
         @param parent reference to the item, the data should be appended to
             (QTreeWidget or QTreeWidgetItem)
         """
@@ -207,14 +215,16 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
                 self.__finish()
                 return
             self.__ignoreExpand = True
-            itm = self.__generateItem(repoRoot, "", "", "", "", "dir", repoRoot)
+            itm = self.__generateItem(
+                repoRoot, "", "", "", "", "dir", repoRoot)
             itm.setExpanded(True)
             self.parentItem = itm
             urlPart = repoRoot
-            for element in unicode(url).replace(repoRoot, "").split("/"):
+            for element in url.replace(repoRoot, "").split("/"):
                 if element:
-                    urlPart = "%s/%s" % (urlPart, element)
-                    itm = self.__generateItem(element, "", "", "", "", "dir", urlPart)
+                    urlPart = "{0}/{1}".format(urlPart, element)
+                    itm = self.__generateItem(
+                        element, "", "", "", "", "dir", urlPart)
                     itm.setExpanded(True)
                     self.parentItem = itm
             itm.setExpanded(False)
@@ -228,14 +238,11 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.process.kill()
         else:
             self.process = QProcess()
-            self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-                self.__procFinished)
-            self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-                self.__readStdout)
-            self.connect(self.process, SIGNAL('readyReadStandardError()'),
-                self.__readStderr)
+            self.process.finished.connect(self.__procFinished)
+            self.process.readyReadStandardOutput.connect(self.__readStdout)
+            self.process.readyReadStandardError.connect(self.__readStderr)
         
-        args = QStringList()
+        args = []
         args.append('list')
         self.vcs.addArguments(args, self.vcs.options['global'])
         if '--verbose' not in self.vcs.options['global']:
@@ -243,17 +250,18 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         args.append(url)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.__finish()
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         else:
             self.inputGroup.setEnabled(True)
             self.inputGroup.show()
@@ -262,38 +270,37 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         """
         Private method to normalite the url.
         
-        @param url the url to normalize (string or QString)
-        @return normalized URL (QString)
+        @param url the url to normalize (string)
+        @return normalized URL (string)
         """
-        url_ = QString(url)
-        if url_.endsWith("/"):
-            return url_[:-1]
-        return url_
+        if url.endswith("/"):
+            return url[:-1]
+        return url
     
     def start(self, url):
         """
         Public slot to start the svn info command.
         
-        @param url the repository URL to browser (string or QString)
+        @param url the repository URL to browser (string)
         """
         self.url = ""
         
         self.urlCombo.addItem(self.__normalizeUrl(url))
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_urlCombo_currentIndexChanged(self, text):
         """
         Private slot called, when a new repository URL is entered or selected.
         
-        @param text the text of the current item (QString)
+        @param text the text of the current item (string)
         """
         url = self.__normalizeUrl(text)
         if url != self.url:
-            self.url = QString(url)
+            self.url = url
             self.repoTree.clear()
             self.__listRepo(url)
     
-    @pyqtSignature("QTreeWidgetItem*")
+    @pyqtSlot(QTreeWidgetItem)
     def on_repoTree_itemExpanded(self, item):
         """
         Private slot called when an item is expanded.
@@ -301,10 +308,10 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         @param item reference to the item to be expanded (QTreeWidgetItem)
         """
         if not self.__ignoreExpand:
-            url = item.data(0, self.__urlRole).toString()
+            url = item.data(0, self.__urlRole)
             self.__listRepo(url, item)
     
-    @pyqtSignature("QTreeWidgetItem*")
+    @pyqtSlot(QTreeWidgetItem)
     def on_repoTree_itemCollapsed(self, item):
         """
         Private slot called when an item is collapsed.
@@ -314,7 +321,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         for child in item.takeChildren():
             del child
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_repoTree_itemSelectionChanged(self):
         """
         Private slot called when the selection changes.
@@ -329,28 +336,29 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         if self.focusWidget() == self.urlCombo:
             return
         
-        QDialog.accept(self)
+        super().accept()
     
     def getSelectedUrl(self):
         """
         Public method to retrieve the selected repository URL.
         
-        @return the selected repository URL (QString)
+        @return the selected repository URL (string)
         """
         items = self.repoTree.selectedItems()
         if len(items) == 1:
-            return items[0].data(0, self.__urlRole).toString()
+            return items[0].data(0, self.__urlRole)
         else:
-            return QString()
+            return ""
     
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         self.inputGroup.setEnabled(False)
@@ -380,13 +388,15 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.process.setReadChannel(QProcess.StandardOutput)
             
             while self.process.canReadLine():
-                s = QString(self.process.readLine())
+                s = str(self.process.readLine(),
+                        Preferences.getSystem("IOEncoding"),
+                        'replace')
                 if self.__rx_dir.exactMatch(s):
                     revision = self.__rx_dir.cap(1)
                     author = self.__rx_dir.cap(2)
                     date = self.__rx_dir.cap(3)
-                    name = self.__rx_dir.cap(4).trimmed()
-                    if name.endsWith("/"):
+                    name = self.__rx_dir.cap(4).strip()
+                    if name.endswith("/"):
                         name = name[:-1]
                     size = ""
                     nodekind = "dir"
@@ -395,12 +405,13 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
                     author = self.__rx_file.cap(2)
                     size = self.__rx_file.cap(3)
                     date = self.__rx_file.cap(4)
-                    name = self.__rx_file.cap(5).trimmed()
+                    name = self.__rx_file.cap(5).strip()
                     nodekind = "file"
                 else:
                     continue
-                url = "%s/%s" % (self.repoUrl, name)
-                self.__generateItem(name, revision, author, size, date, nodekind, url)
+                url = "{0}/{1}".format(self.repoUrl, name)
+                self.__generateItem(
+                    name, revision, author, size, date, nodekind, url)
    
     def __readStderr(self):
         """
@@ -410,7 +421,9 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         error pane.
         """
         if self.process is not None:
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
     
@@ -425,13 +438,13 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -440,7 +453,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -462,5 +475,4 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.intercept = False
             evt.accept()
             return
-        QWidget.keyPressEvent(self, evt)
-        
+        super().keyPressEvent(evt)
