@@ -7,33 +7,34 @@
 Module implementing the VCS status monitor thread class for Subversion.
 """
 
-from PyQt4.QtCore import QRegExp, QProcess, QStringList, QString
+from PyQt4.QtCore import QRegExp, QProcess
 
 from VCS.StatusMonitorThread import VcsStatusMonitorThread
 
 import Preferences
 
+
 class SvnStatusMonitorThread(VcsStatusMonitorThread):
     """
     Class implementing the VCS status monitor thread class for Subversion.
     """
-    def __init__(self, interval, projectDir, vcs, parent = None):
+    def __init__(self, interval, project, vcs, parent=None):
         """
         Constructor
         
         @param interval new interval in seconds (integer)
-        @param projectDir project directory to monitor (string or QString)
+        @param project reference to the project object (Project)
         @param vcs reference to the version control object
         @param parent reference to the parent object (QObject)
         """
-        VcsStatusMonitorThread.__init__(self, interval, projectDir, vcs, parent)
+        VcsStatusMonitorThread.__init__(self, interval, project, vcs, parent)
         
-        self.__ioEncoding = str(Preferences.getSystem("IOEncoding"))
+        self.__ioEncoding = Preferences.getSystem("IOEncoding")
         
         self.rx_status1 = \
             QRegExp('(.{8,9})\\s+([0-9-]+)\\s+(.+)\\s*')
-        self.rx_status2 = \
-            QRegExp('(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+(\\S+)\\s+(.+)\\s*')
+        self.rx_status2 = QRegExp(
+            '(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+(\\S+)\\s+(.+)\\s*')
     
     def _performMonitor(self):
         """
@@ -53,13 +54,13 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
             <li>" " path is back at normal</li>
         </ul>
         
-        @return tuple of flag indicating successful operation (boolean) and 
-            a status message in case of non successful operation (QString)
+        @return tuple of flag indicating successful operation (boolean) and
+            a status message in case of non successful operation (string)
         """
         self.shouldUpdate = False
         
         process = QProcess()
-        args = QStringList()
+        args = []
         args.append('status')
         if not Preferences.getVCS("MonitorLocalStatus"):
             args.append('--show-updates')
@@ -67,20 +68,20 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
         args.append('.')
         process.setWorkingDirectory(self.projectDir)
         process.start('svn', args)
-        procStarted = process.waitForStarted()
+        procStarted = process.waitForStarted(5000)
         if procStarted:
             finished = process.waitForFinished(300000)
             if finished and process.exitCode() == 0:
-                output = \
-                    unicode(process.readAllStandardOutput(), self.__ioEncoding, 'replace')
+                output = str(process.readAllStandardOutput(),
+                             self.__ioEncoding, 'replace')
                 states = {}
                 for line in output.splitlines():
                     if self.rx_status1.exactMatch(line):
-                        flags = str(self.rx_status1.cap(1))
-                        path = self.rx_status1.cap(3).trimmed()
+                        flags = self.rx_status1.cap(1)
+                        path = self.rx_status1.cap(3).strip()
                     elif self.rx_status2.exactMatch(line):
-                        flags = str(self.rx_status2.cap(1))
-                        path = self.rx_status2.cap(5).trimmed()
+                        flags = self.rx_status2.cap(1)
+                        path = self.rx_status2.cap(5).strip()
                     else:
                         continue
                     if flags[0] in "ACDMR" or \
@@ -95,24 +96,30 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
                             status = "O"
                         if status == "U":
                             self.shouldUpdate = True
-                        name = unicode(path)
+                        name = path
                         states[name] = status
                         try:
                             if self.reportedStates[name] != status:
-                                self.statusList.append("%s %s" % (status, name))
+                                self.statusList.append(
+                                    "{0} {1}".format(status, name))
                         except KeyError:
-                            self.statusList.append("%s %s" % (status, name))
-                for name in self.reportedStates.keys():
+                            self.statusList.append(
+                                "{0} {1}".format(status, name))
+                for name in list(self.reportedStates.keys()):
                     if name not in states:
-                        self.statusList.append("  %s" % name)
+                        self.statusList.append("  {0}".format(name))
                 self.reportedStates = states
-                return True, \
-                       self.trUtf8("Subversion status checked successfully (using svn)")
+                return True, self.trUtf8(
+                    "Subversion status checked successfully (using svn)")
             else:
                 process.kill()
                 process.waitForFinished()
-                return False, QString(process.readAllStandardError())
+                return False, \
+                    str(process.readAllStandardError(),
+                        Preferences.getSystem("IOEncoding"),
+                        'replace')
         else:
             process.kill()
             process.waitForFinished()
-            return False, self.trUtf8("Could not start the Subversion process.")
+            return False, self.trUtf8(
+                "Could not start the Subversion process.")
