@@ -7,32 +7,32 @@
 Module implementing a dialog to enter the data for a switch operation.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog
+
+from .Ui_SvnSwitchDialog import Ui_SvnSwitchDialog
 
-from Ui_SvnSwitchDialog import Ui_SvnSwitchDialog
 
 class SvnSwitchDialog(QDialog, Ui_SvnSwitchDialog):
     """
     Class implementing a dialog to enter the data for a switch operation.
     """
-    def __init__(self, taglist, reposURL, standardLayout, parent = None):
+    def __init__(self, taglist, reposURL, standardLayout, parent=None):
         """
         Constructor
         
-        @param taglist list of previously entered tags (QStringList)
-        @param reposURL repository path (QString or string) or None
-        @param standardLayout flag indicating the layout of the 
+        @param taglist list of previously entered tags (list of strings)
+        @param reposURL repository path (string) or None
+        @param standardLayout flag indicating the layout of the
             repository (boolean)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
        
         self.tagCombo.clear()
-        self.tagCombo.addItems(taglist)
+        self.tagCombo.addItems(sorted(taglist))
         
-        if reposURL is not None and reposURL is not QString():
+        if reposURL is not None and reposURL != "":
             self.tagCombo.setEditText(reposURL)
             
         if not standardLayout:
@@ -42,7 +42,7 @@ class SvnSwitchDialog(QDialog, Ui_SvnSwitchDialog):
         """
         Public method to retrieve the tag data.
         
-        @return tuple of QString and int (tag, tag type)
+        @return tuple of string and int (tag, tag type)
         """
         tag = self.tagCombo.currentText()
         tagType = 0
@@ -50,7 +50,6 @@ class SvnSwitchDialog(QDialog, Ui_SvnSwitchDialog):
             tagType = 1
         elif self.branchButton.isChecked():
             tagType = 2
-        if tag.isEmpty():
+        if not tag:
             tagType = 4
         return (tag, tagType)
-
