@@ -7,25 +7,31 @@
 Module implementing a dialog to show a list of tags or branches.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+import os
 
-from KdeQt import KQMessageBox, KQInputDialog
+from PyQt4.QtCore import QTimer, QProcess, QRegExp, Qt, pyqtSlot
+from PyQt4.QtGui import QHeaderView, QLineEdit, QDialog, QInputDialog, \
+    QDialogButtonBox, QTreeWidgetItem
+
+from E5Gui import E5MessageBox
+
+from .Ui_SvnTagBranchListDialog import Ui_SvnTagBranchListDialog
+
+import Preferences
 
-from Ui_SvnTagBranchListDialog import Ui_SvnTagBranchListDialog
 
 class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
     """
     Class implementing a dialog to show a list of tags or branches.
     """
-    def __init__(self, vcs, parent = None):
+    def __init__(self, vcs, parent=None):
         """
         Constructor
         
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
@@ -39,15 +45,13 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         self.tagList.headerItem().setText(self.tagList.columnCount(), "")
         self.tagList.header().setSortIndicator(3, Qt.AscendingOrder)
         
-        self.connect(self.process, SIGNAL('finished(int, QProcess::ExitStatus)'),
-            self.__procFinished)
-        self.connect(self.process, SIGNAL('readyReadStandardOutput()'),
-            self.__readStdout)
-        self.connect(self.process, SIGNAL('readyReadStandardError()'),
-            self.__readStderr)
+        self.process.finished.connect(self.__procFinished)
+        self.process.readyReadStandardOutput.connect(self.__readStdout)
+        self.process.readyReadStandardError.connect(self.__readStderr)
         
-        self.rx_list = \
-            QRegExp(r"""\w*\s*(\d+)\s+(\w+)\s+\d*\s*((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)/\s*""")
+        self.rx_list = QRegExp(
+            r"""\w*\s*(\d+)\s+(\w+)\s+\d*\s*"""
+            r"""((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)/\s*""")
         
     def closeEvent(self, e):
         """
@@ -58,7 +62,7 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         e.accept()
@@ -69,9 +73,10 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         
         @param path name of directory to be listed (string)
         @param tags flag indicating a list of tags is requested
-                (False = branches, True = tags)
-        @param tagsList reference to string list receiving the tags (QStringList)
-        @param allsTagsLisr reference to string list all tags (QStringList)
+            (False = branches, True = tags)
+        @param tagsList reference to string list receiving the tags
+            (list of strings)
+        @param allTagsList reference to string list all tags (list of strings)
         """
         self.errorGroup.hide()
         
@@ -88,15 +93,17 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         
         reposURL = self.vcs.svnGetReposName(dname)
         if reposURL is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Subversion Error"),
-                self.trUtf8("""The URL of the project repository could not be"""
-                    """ retrieved from the working copy. The list operation will"""
-                    """ be aborted"""))
+                self.trUtf8(
+                    """The URL of the project repository could not be"""
+                    """ retrieved from the working copy. The list operation"""
+                    """ will be aborted"""))
             self.close()
             return
         
-        args = QStringList()
+        args = []
         args.append('list')
         self.vcs.addArguments(args, self.vcs.options['global'])
         args.append('--verbose')
@@ -105,70 +112,78 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
             # determine the base path of the project in the repository
             rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
             if not rx_base.exactMatch(reposURL):
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Subversion Error"),
-                    self.trUtf8("""The URL of the project repository has an"""
+                    self.trUtf8(
+                        """The URL of the project repository has an"""
                         """ invalid format. The list operation will"""
                         """ be aborted"""))
                 return
             
-            reposRoot = unicode(rx_base.cap(1))
+            reposRoot = rx_base.cap(1)
             
             if tags:
-                args.append("%s/tags" % reposRoot)
+                args.append("{0}/tags".format(reposRoot))
             else:
-                args.append("%s/branches" % reposRoot)
+                args.append("{0}/branches".format(reposRoot))
             self.path = None
         else:
-            reposPath, ok = KQInputDialog.getText(\
+            reposPath, ok = QInputDialog.getText(
                 self,
                 self.trUtf8("Subversion List"),
-                self.trUtf8("Enter the repository URL containing the tags or branches"),
+                self.trUtf8("Enter the repository URL containing the tags"
+                            " or branches"),
                 QLineEdit.Normal,
                 self.vcs.svnNormalizeURL(reposURL))
             if not ok:
                 self.close()
                 return
-            if reposPath.isEmpty():
-                KQMessageBox.critical(None,
+            if not reposPath:
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Subversion List"),
-                    self.trUtf8("""The repository URL is empty. Aborting..."""))
+                    self.trUtf8("""The repository URL is empty."""
+                                """ Aborting..."""))
                 self.close()
                 return
             args.append(reposPath)
-            self.path = unicode(reposPath)
+            self.path = reposPath
         
         self.process.setWorkingDirectory(dname)
         
         self.process.start('svn', args)
-        procStarted = self.process.waitForStarted()
+        procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg('svn'))
+                ).format('svn'))
         else:
             self.inputGroup.setEnabled(True)
             self.inputGroup.show()
         
     def __finish(self):
         """
-        Private slot called when the process finished or the user pressed the button.
+        Private slot called when the process finished or the user pressed the
+        button.
         """
         if self.process is not None and \
            self.process.state() != QProcess.NotRunning:
             self.process.terminate()
-            QTimer.singleShot(2000, self.process, SLOT('kill()'))
+            QTimer.singleShot(2000, self.process.kill)
             self.process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(
+            Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
@@ -202,7 +217,8 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         """
         Private method to resort the tree.
         """
-        self.tagList.sortItems(self.tagList.sortColumn(), 
+        self.tagList.sortItems(
+            self.tagList.sortColumn(),
             self.tagList.header().sortIndicatorOrder())
         
     def __resizeColumns(self):
@@ -216,10 +232,10 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         """
         Private method to generate a tag item in the taglist.
         
-        @param revision revision string (string or QString)
-        @param author author of the tag (string or QString)
-        @param date date of the tag (string or QString)
-        @param name name (path) of the tag (string or QString)
+        @param revision revision string (string)
+        @param author author of the tag (string)
+        @param date date of the tag (string)
+        @param name name (path) of the tag (string)
         """
         itm = QTreeWidgetItem(self.tagList)
         itm.setData(0, Qt.DisplayRole, int(revision))
@@ -238,9 +254,11 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         self.process.setReadChannel(QProcess.StandardOutput)
         
         while self.process.canReadLine():
-            s = QString(self.process.readLine())
+            s = str(self.process.readLine(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             if self.rx_list.exactMatch(s):
-                rev = "%6s" % unicode(self.rx_list.cap(1))
+                rev = "{0:6}".format(self.rx_list.cap(1))
                 author = self.rx_list.cap(2)
                 date = self.rx_list.cap(3)
                 path = self.rx_list.cap(4)
@@ -263,7 +281,9 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         """
         if self.process is not None:
             self.errorGroup.show()
-            s = QString(self.process.readAllStandardError())
+            s = str(self.process.readAllStandardError(),
+                    Preferences.getSystem("IOEncoding"),
+                    'replace')
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
         
@@ -278,13 +298,13 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         else:
             self.input.setEchoMode(QLineEdit.Normal)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sendButton_clicked(self):
         """
         Private slot to send the input to the subversion process.
         """
         input = self.input.text()
-        input.append(os.linesep)
+        input += os.linesep
         
         if self.passwordCheckBox.isChecked():
             self.errors.insertPlainText(os.linesep)
@@ -293,7 +313,7 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.process.write(input.toLocal8Bit())
+        self.process.write(input)
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -315,4 +335,4 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
             self.intercept = False
             evt.accept()
             return
-        QDialog.keyPressEvent(self, evt)
+        super().keyPressEvent(evt)
