@@ -9,15 +9,18 @@ Module implementing the listspace viewmanager class.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, QFileInfo, QEvent, Qt
+from PyQt4.QtGui import QStackedWidget, QSplitter, QListWidget, \
+    QListWidgetItem, QSizePolicy, QMenu, QApplication
 
 from ViewManager.ViewManager import ViewManager
 
 import QScintilla.Editor
+from QScintilla.Editor import Editor
 
 import UI.PixmapCache
 
+
 class StackedWidget(QStackedWidget):
     """
     Class implementing a custimized StackedWidget.
@@ -28,18 +31,20 @@ class StackedWidget(QStackedWidget):
         
         @param parent parent widget (QWidget)
         """
-        QStackedWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setAttribute(Qt.WA_DeleteOnClose, True)
         
         self.editors = []
         
-    def addWidget(self, editor):
+    def addWidget(self, assembly):
         """
         Overwritten method to add a new widget.
         
-        @param editor the editor object to be added (QScintilla.Editor.Editor)
+        @param assembly editor assembly object to be added
+            (QScintilla.EditorAssembly.EditorAssembly)
         """
-        QStackedWidget.addWidget(self, editor)
+        editor = assembly.getEditor()
+        super().addWidget(assembly)
         if not editor in self.editors:
             self.editors.append(editor)
         
@@ -49,9 +54,21 @@ class StackedWidget(QStackedWidget):
         
         @param widget widget to be removed (QWidget)
         """
-        QStackedWidget.removeWidget(self, widget)
         if isinstance(widget, QScintilla.Editor.Editor):
             self.editors.remove(widget)
+            widget = widget.parent()
+        super().removeWidget(widget)
+        
+    def currentWidget(self):
+        """
+        Public method to get a reference to the current editor.
+        
+        @return reference to the current editor (Editor)
+        """
+        widget = super().currentWidget()
+        if widget is not None:
+            widget = widget.getEditor()
+        return widget
         
     def setCurrentWidget(self, widget):
         """
@@ -62,7 +79,8 @@ class StackedWidget(QStackedWidget):
         if isinstance(widget, QScintilla.Editor.Editor):
             self.editors.remove(widget)
             self.editors.insert(0, widget)
-        QStackedWidget.setCurrentWidget(self, widget)
+            widget = widget.parent()
+        super().setCurrentWidget(widget)
         
     def setCurrentIndex(self, index):
         """
@@ -108,26 +126,68 @@ class StackedWidget(QStackedWidget):
         
     def firstEditor(self):
         """
-        Public method to retrieve the first editor in the list of managed editors.
+        Public method to retrieve the first editor in the list of managed
+            editors.
         
         @return first editor in list (QScintilla.Editor.Editor)
         """
         return len(self.editors) and self.editors[0] or None
 
+
 class Listspace(QSplitter, ViewManager):
     """
     Class implementing the listspace viewmanager class.
     
-    @signal changeCaption(string) emitted if a change of the caption is necessary
-    @signal editorChanged(string) emitted when the current editor has changed
+    @signal changeCaption(str) emitted if a change of the caption is necessary
+    @signal editorChanged(str) emitted when the current editor has changed
+    @signal editorChangedEd(Editor) emitted when the current editor has changed
+    @signal lastEditorClosed() emitted after the last editor window was closed
+    @signal editorOpened(str) emitted after an editor window was opened
+    @signal editorOpenedEd(Editor) emitted after an editor window was opened
+    @signal editorClosed(str) emitted just before an editor window gets closed
+    @signal editorClosedEd(Editor) emitted just before an editor window gets
+        closed
+    @signal editorSaved(str) emitted after an editor window was saved
+    @signal checkActions(Editor) emitted when some actions should be checked
+        for their status
+    @signal cursorChanged(Editor) emitted after the cursor position of the
+        active window has changed
+    @signal breakpointToggled(Editor) emitted when a breakpoint is toggled.
+    @signal bookmarkToggled(Editor) emitted when a bookmark is toggled.
+    @signal syntaxerrorToggled(Editor) emitted when a syntax error is toggled.
+    @signal previewStateChanged(bool) emitted to signal a change in the
+        preview state
+    @signal editorLanguageChanged(Editor) emitted to signal a change of an
+        editors language
+    @signal editorTextChanged(Editor) emitted to signal a change of an
+        editor's text
+    @signal editorLineChanged(str,int) emitted to signal a change of an
+        editor's current line (line is given one based)
     """
+    changeCaption = pyqtSignal(str)
+    editorChanged = pyqtSignal(str)
+    editorChangedEd = pyqtSignal(Editor)
+    lastEditorClosed = pyqtSignal()
+    editorOpened = pyqtSignal(str)
+    editorOpenedEd = pyqtSignal(Editor)
+    editorClosed = pyqtSignal(str)
+    editorClosedEd = pyqtSignal(Editor)
+    editorSaved = pyqtSignal(str)
+    checkActions = pyqtSignal(Editor)
+    cursorChanged = pyqtSignal(Editor)
+    breakpointToggled = pyqtSignal(Editor)
+    bookmarkToggled = pyqtSignal(Editor)
+    syntaxerrorToggled = pyqtSignal(Editor)
+    previewStateChanged = pyqtSignal(bool)
+    editorLanguageChanged = pyqtSignal(Editor)
+    editorTextChanged = pyqtSignal(Editor)
+    editorLineChanged = pyqtSignal(str, int)
+    
     def __init__(self, parent):
         """
         Constructor
         
         @param parent parent widget (QWidget)
-        @param ui reference to the main user interface
-        @param dbs reference to the debug server object
         """
         self.stacks = []
         
@@ -140,12 +200,8 @@ class Listspace(QSplitter, ViewManager):
         self.viewlist.setSizePolicy(policy)
         self.addWidget(self.viewlist)
         self.viewlist.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self.viewlist, SIGNAL("itemActivated(QListWidgetItem*)"),
-                     self.__showSelectedView)
-        self.connect(self.viewlist, SIGNAL("itemClicked(QListWidgetItem*)"),
-                     self.__showSelectedView)
-        self.connect(self.viewlist, SIGNAL("customContextMenuRequested(const QPoint &)"),
-                     self.__showMenu)
+        self.viewlist.currentRowChanged.connect(self.__showSelectedView)
+        self.viewlist.customContextMenuRequested.connect(self.__showMenu)
         
         self.stackArea = QSplitter(self)
         self.addWidget(self.stackArea)
@@ -154,46 +210,81 @@ class Listspace(QSplitter, ViewManager):
         self.stackArea.addWidget(stack)
         self.stacks.append(stack)
         self.currentStack = stack
-        self.connect(stack, SIGNAL('currentChanged(int)'),
-            self.__currentChanged)
+        stack.currentChanged.connect(self.__currentChanged)
         stack.installEventFilter(self)
-        self.setSizes([int(self.width() * 0.2), int(self.width() * 0.8)]) # 20% for viewlist
+        self.setSizes([int(self.width() * 0.2), int(self.width() * 0.8)])
+        # 20% for viewlist, 80% for the editors
         self.__inRemoveView = False
         
         self.__initMenu()
         self.contextMenuEditor = None
+        self.contextMenuIndex = -1
         
     def __initMenu(self):
         """
         Private method to initialize the viewlist context menu.
         """
         self.__menu = QMenu(self)
-        self.__menu.addAction(UI.PixmapCache.getIcon("close.png"),
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("tabClose.png"),
             self.trUtf8('Close'), self.__contextMenuClose)
-        self.__menu.addAction(self.trUtf8('Close All'), self.__contextMenuCloseAll)
+        self.closeOthersMenuAct = self.__menu.addAction(
+            UI.PixmapCache.getIcon("tabCloseOther.png"),
+            self.trUtf8("Close Others"),
+            self.__contextMenuCloseOthers)
+        self.__menu.addAction(
+            self.trUtf8('Close All'), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
-        self.saveMenuAct = \
-            self.__menu.addAction(UI.PixmapCache.getIcon("fileSave.png"),
+        self.saveMenuAct = self.__menu.addAction(
+            UI.PixmapCache.getIcon("fileSave.png"),
             self.trUtf8('Save'), self.__contextMenuSave)
-        self.__menu.addAction(UI.PixmapCache.getIcon("fileSaveAs.png"),
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("fileSaveAs.png"),
             self.trUtf8('Save As...'), self.__contextMenuSaveAs)
-        self.__menu.addAction(UI.PixmapCache.getIcon("fileSaveAll.png"),
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("fileSaveAll.png"),
             self.trUtf8('Save All'), self.__contextMenuSaveAll)
         self.__menu.addSeparator()
-        self.__menu.addAction(UI.PixmapCache.getIcon("print.png"),
+        self.openRejectionsMenuAct = self.__menu.addAction(
+            self.trUtf8("Open 'rejection' file"),
+            self.__contextMenuOpenRejections)
+        self.__menu.addSeparator()
+        self.__menu.addAction(
+            UI.PixmapCache.getIcon("print.png"),
             self.trUtf8('Print'), self.__contextMenuPrintFile)
+        self.__menu.addSeparator()
+        self.copyPathAct = self.__menu.addAction(
+            self.trUtf8("Copy Path to Clipboard"),
+            self.__contextMenuCopyPathToClipboard)
         
     def __showMenu(self, point):
         """
-        Private slot to handle the customContextMenuRequested signal of the viewlist.
+        Private slot to handle the customContextMenuRequested signal of
+        the viewlist.
+        
+        @param point position to open the menu at (QPoint)
         """
         if self.editors:
             itm = self.viewlist.itemAt(point)
             if itm is not None:
                 row = self.viewlist.row(itm)
                 self.contextMenuEditor = self.editors[row]
+                self.contextMenuIndex = row
                 if self.contextMenuEditor:
-                    self.saveMenuAct.setEnabled(self.contextMenuEditor.isModified())
+                    self.saveMenuAct.setEnabled(
+                        self.contextMenuEditor.isModified())
+                    fileName = self.contextMenuEditor.getFileName()
+                    self.copyPathAct.setEnabled(bool(fileName))
+                    if fileName:
+                        rej = "{0}.rej".format(fileName)
+                        self.openRejectionsMenuAct.setEnabled(
+                            os.path.exists(rej))
+                    else:
+                        self.openRejectionsMenuAct.setEnabled(False)
+                    
+                    self.closeOthersMenuAct.setEnabled(
+                        self.viewlist.count() > 1)
+                    
                     self.__menu.popup(self.viewlist.mapToGlobal(point))
         
     def canCascade(self):
@@ -234,7 +325,7 @@ class Listspace(QSplitter, ViewManager):
         
     def _removeAllViews(self):
         """
-        Protected method to remove all views (i.e. windows)
+        Protected method to remove all views (i.e. windows).
         """
         self.viewlist.clear()
         for win in self.editors:
@@ -246,7 +337,7 @@ class Listspace(QSplitter, ViewManager):
         
     def _removeView(self, win):
         """
-        Protected method to remove a view (i.e. window)
+        Protected method to remove a view (i.e. window).
         
         @param win editor window to be removed
         """
@@ -269,95 +360,114 @@ class Listspace(QSplitter, ViewManager):
             else:
                 return
         stack.setCurrentWidget(stack.firstEditor())
-        self._showView(self.editors[ind])
+        self._showView(self.editors[ind].parent())
         
         aw = self.activeWindow()
         fn = aw and aw.getFileName() or None
         if fn:
-            self.emit(SIGNAL('changeCaption'), unicode(fn))
-            self.emit(SIGNAL('editorChanged'), unicode(fn))
+            self.changeCaption.emit(fn)
+            self.editorChanged.emit(fn)
+            self.editorLineChanged.emit(fn, aw.getCursorPosition()[0] + 1)
         else:
-            self.emit(SIGNAL('changeCaption'), "")
+            self.changeCaption.emit("")
+        self.editorChangedEd.emit(aw)
         
-    def _addView(self, win, fn = None, noName = ""):
+    def _addView(self, win, fn=None, noName=""):
         """
-        Protected method to add a view (i.e. window)
+        Protected method to add a view (i.e. window).
         
-        @param win editor window to be added
-        @param fn filename of this editor
-        @param noName name to be used for an unnamed editor (string or QString)
+        @param win editor assembly to be added
+        @param fn filename of this editor (string)
+        @param noName name to be used for an unnamed editor (string)
         """
+        editor = win.getEditor()
         if fn is None:
-            if not unicode(noName):
+            if not noName:
                 self.untitledCount += 1
-                noName = self.trUtf8("Untitled %1").arg(self.untitledCount)
+                noName = self.trUtf8("Untitled {0}").format(self.untitledCount)
             self.viewlist.addItem(noName)
-            win.setNoName(noName)
+            editor.setNoName(noName)
         else:
             txt = os.path.basename(fn)
             if not QFileInfo(fn).isWritable():
-                txt = self.trUtf8("%1 (ro)").arg(txt)
+                txt = self.trUtf8("{0} (ro)").format(txt)
             itm = QListWidgetItem(txt)
             itm.setToolTip(fn)
             self.viewlist.addItem(itm)
         self.currentStack.addWidget(win)
         self.currentStack.setCurrentWidget(win)
-        self.connect(win, SIGNAL('captionChanged'),
-            self.__captionChange)
+        editor.captionChanged.connect(self.__captionChange)
+        editor.cursorLineChanged.connect(self.__cursorLineChanged)
         
-        index = self.editors.index(win)
+        index = self.editors.index(editor)
         self.viewlist.setCurrentRow(index)
-        win.setFocus()
+        editor.setFocus()
         if fn:
-            self.emit(SIGNAL('changeCaption'), unicode(fn))
-            self.emit(SIGNAL('editorChanged'), unicode(fn))
+            self.changeCaption.emit(fn)
+            self.editorChanged.emit(fn)
+            self.editorLineChanged.emit(fn, editor.getCursorPosition()[0] + 1)
         else:
-            self.emit(SIGNAL('changeCaption'), "")
+            self.changeCaption.emit("")
+        self.editorChangedEd.emit(editor)
         
     def __captionChange(self, cap, editor):
         """
-        Private method to handle caption change signals from the editor. 
+        Private method to handle caption change signals from the editor.
         
         Updates the listwidget text to reflect the new caption information.
         
-        @param cap Caption for the editor
+        @param cap Caption for the editor (string)
         @param editor Editor to update the caption for
         """
         fn = editor.getFileName()
         if fn:
             self.setEditorName(editor, fn)
         
-    def _showView(self, win, fn = None):
+    def __cursorLineChanged(self, lineno):
         """
-        Protected method to show a view (i.e. window)
+        Private slot to handle a change of the current editor's cursor line.
         
-        @param win editor window to be shown
-        @param fn filename of this editor
+        @param lineno line number of the current editor's cursor (zero based)
         """
+        editor = self.sender()
+        if editor:
+            fn = editor.getFileName()
+            if fn:
+                self.editorLineChanged.emit(fn, lineno + 1)
+        
+    def _showView(self, win, fn=None):
+        """
+        Protected method to show a view (i.e. window).
+        
+        @param win editor assembly to be shown
+        @param fn filename of this editor (string)
+        """
+        editor = win.getEditor()
         for stack in self.stacks:
-            if stack.hasEditor(win):
+            if stack.hasEditor(editor):
                 stack.setCurrentWidget(win)
                 self.currentStack = stack
                 break
-        index = self.editors.index(win)
+        index = self.editors.index(editor)
         self.viewlist.setCurrentRow(index)
-        win.setFocus()
-        fn = win.getFileName()
+        editor.setFocus()
+        fn = editor.getFileName()
         if fn:
-            self.emit(SIGNAL('changeCaption'), unicode(fn))
-            self.emit(SIGNAL('editorChanged'), unicode(fn))
+            self.changeCaption.emit(fn)
+            self.editorChanged.emit(fn)
+            self.editorLineChanged.emit(fn, editor.getCursorPosition()[0] + 1)
         else:
-            self.emit(SIGNAL('changeCaption'), "")
+            self.changeCaption.emit("")
+        self.editorChangedEd.emit(editor)
         
-    def __showSelectedView(self, itm):
+    def __showSelectedView(self, row):
         """
-        Private slot called to show a view selected in the list by a mouse click.
+        Private slot called to show a view selected in the list.
         
-        @param itm item clicked on (QListWidgetItem)
+        @param row row number of the item clicked on (integer)
         """
-        if itm:
-            row = self.viewlist.row(itm)
-            self._showView(self.editors[row])
+        if row != -1:
+            self._showView(self.editors[row].parent())
             self._checkActions(self.editors[row])
         
     def activeWindow(self):
@@ -378,7 +488,8 @@ class Listspace(QSplitter, ViewManager):
         
     def _initWindowActions(self):
         """
-        Protected method to define the user interface actions for window handling.
+        Protected method to define the user interface actions for window
+        handling.
         """
         pass
         
@@ -387,19 +498,20 @@ class Listspace(QSplitter, ViewManager):
         Change the displayed name of the editor.
         
         @param editor editor window to be changed
-        @param newName new name to be shown (string or QString)
+        @param newName new name to be shown (string)
         """
-        currentRow = self.viewlist.currentRow()
-        index = self.editors.index(editor)
-        txt = os.path.basename(unicode(newName))
-        if not QFileInfo(newName).isWritable():
-            txt = self.trUtf8("%1 (ro)").arg(txt)
-        itm = self.viewlist.item(index)
-        itm.setText(txt)
-        itm.setToolTip(newName)
-        self.viewlist.setCurrentRow(currentRow)
-        self.emit(SIGNAL('changeCaption'), unicode(newName))
-        
+        if newName:
+            currentRow = self.viewlist.currentRow()
+            index = self.editors.index(editor)
+            txt = os.path.basename(newName)
+            if not QFileInfo(newName).isWritable():
+                txt = self.trUtf8("{0} (ro)").format(txt)
+            itm = self.viewlist.item(index)
+            itm.setText(txt)
+            itm.setToolTip(newName)
+            self.viewlist.setCurrentRow(currentRow)
+            self.changeCaption.emit(newName)
+            
     def _modificationStatusChanged(self, m, editor):
         """
         Protected slot to handle the modificationStatusChanged signal.
@@ -410,11 +522,17 @@ class Listspace(QSplitter, ViewManager):
         currentRow = self.viewlist.currentRow()
         index = self.editors.index(editor)
         if m:
-            self.viewlist.item(index).setIcon(UI.PixmapCache.getIcon("fileModified.png"))
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("fileModified.png"))
         elif editor.hasSyntaxErrors():
-            self.viewlist.item(index).setIcon(UI.PixmapCache.getIcon("syntaxError.png"))
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("syntaxError.png"))
+        elif editor.hasWarnings():
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("warning.png"))
         else:
-            self.viewlist.item(index).setIcon(UI.PixmapCache.getIcon("empty.png"))
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("empty.png"))
         self.viewlist.setCurrentRow(currentRow)
         self._checkActions(editor)
         
@@ -427,9 +545,17 @@ class Listspace(QSplitter, ViewManager):
         currentRow = self.viewlist.currentRow()
         index = self.editors.index(editor)
         if editor.hasSyntaxErrors():
-            self.viewlist.item(index).setIcon(UI.PixmapCache.getIcon("syntaxError.png"))
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("syntaxError.png"))
+        elif editor.hasWarnings():
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("warning.png"))
+        elif editor.isModified():
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("fileModified.png"))
         else:
-            self.viewlist.item(index).setIcon(UI.PixmapCache.getIcon("empty.png"))
+            self.viewlist.item(index).setIcon(
+                UI.PixmapCache.getIcon("empty.png"))
         self.viewlist.setCurrentRow(currentRow)
         
         ViewManager._syntaxErrorToggled(self, editor)
@@ -443,14 +569,14 @@ class Listspace(QSplitter, ViewManager):
         self.stackArea.addWidget(stack)
         self.stacks.append(stack)
         self.currentStack = stack
-        self.connect(stack, SIGNAL('currentChanged(int)'),
-            self.__currentChanged)
+        stack.currentChanged.connect(self.__currentChanged)
         stack.installEventFilter(self)
         if self.stackArea.orientation() == Qt.Horizontal:
             size = self.stackArea.width()
         else:
             size = self.stackArea.height()
-        self.stackArea.setSizes([int(size/len(self.stacks))] * len(self.stacks))
+        self.stackArea.setSizes(
+            [int(size / len(self.stacks))] * len(self.stacks))
         self.splitRemoveAct.setEnabled(True)
         self.nextSplitAct.setEnabled(True)
         self.prevSplitAct.setEnabled(True)
@@ -485,6 +611,14 @@ class Listspace(QSplitter, ViewManager):
         
         return False
         
+    def getSplitOrientation(self):
+        """
+        Public method to get the orientation of the split view.
+        
+        @return orientation of the split (Qt.Horizontal or Qt.Vertical)
+        """
+        return self.stackArea.orientation()
+        
     def setSplitOrientation(self, orientation):
         """
         Public method used to set the orientation of the split view.
@@ -533,14 +667,24 @@ class Listspace(QSplitter, ViewManager):
         
     def __contextMenuClose(self):
         """
-        Private method to close the selected tab.
+        Private method to close the selected editor.
         """
         if self.contextMenuEditor:
             self.closeEditorWindow(self.contextMenuEditor)
         
+    def __contextMenuCloseOthers(self):
+        """
+        Private method to close the other editors.
+        """
+        index = self.contextMenuIndex
+        for i in list(range(self.viewlist.count() - 1, index, -1)) + \
+                list(range(index - 1, -1, -1)):
+            editor = self.editors[i]
+            self.closeEditorWindow(editor)
+        
     def __contextMenuCloseAll(self):
         """
-        Private method to close all tabs.
+        Private method to close all editors.
         """
         savedEditors = self.editors[:]
         for editor in savedEditors:
@@ -548,31 +692,54 @@ class Listspace(QSplitter, ViewManager):
         
     def __contextMenuSave(self):
         """
-        Private method to save the selected tab.
+        Private method to save the selected editor.
         """
         if self.contextMenuEditor:
             self.saveEditorEd(self.contextMenuEditor)
         
     def __contextMenuSaveAs(self):
         """
-        Private method to save the selected tab to a new file.
+        Private method to save the selected editor to a new file.
         """
         if self.contextMenuEditor:
             self.saveAsEditorEd(self.contextMenuEditor)
         
     def __contextMenuSaveAll(self):
         """
-        Private method to save all tabs.
+        Private method to save all editors.
         """
         self.saveEditorsList(self.editors)
         
+    def __contextMenuOpenRejections(self):
+        """
+        Private slot to open a rejections file associated with the selected
+        editor.
+        """
+        if self.contextMenuEditor:
+            fileName = self.contextMenuEditor.getFileName()
+            if fileName:
+                rej = "{0}.rej".format(fileName)
+                if os.path.exists(rej):
+                    self.openSourceFile(rej)
+        
     def __contextMenuPrintFile(self):
         """
-        Private method to print the selected tab.
+        Private method to print the selected editor.
         """
         if self.contextMenuEditor:
             self.printEditor(self.contextMenuEditor)
         
+    def __contextMenuCopyPathToClipboard(self):
+        """
+        Private method to copy the file name of the selected editor to the
+        clipboard.
+        """
+        if self.contextMenuEditor:
+            fn = self.contextMenuEditor.getFileName()
+            if fn:
+                cb = QApplication.clipboard()
+                cb.setText(fn)
+        
     def __currentChanged(self, index):
         """
         Private slot to handle the currentChanged signal.
@@ -590,11 +757,14 @@ class Listspace(QSplitter, ViewManager):
         editor.setFocus()
         fn = editor.getFileName()
         if fn:
-            self.emit(SIGNAL('changeCaption'), unicode(fn))
+            self.changeCaption.emit(fn)
             if not self.__inRemoveView:
-                self.emit(SIGNAL('editorChanged'), unicode(fn))
+                self.editorChanged.emit(fn)
+                self.editorLineChanged.emit(
+                    fn, editor.getCursorPosition()[0] + 1)
         else:
-            self.emit(SIGNAL('changeCaption'), "")
+            self.changeCaption.emit("")
+        self.editorChangedEd.emit(editor)
         
         cindex = self.editors.index(editor)
         self.viewlist.setCurrentRow(cindex)
@@ -629,10 +799,13 @@ class Listspace(QSplitter, ViewManager):
                 aw.setFocus()
                 fn = aw.getFileName()
                 if fn:
-                    self.emit(SIGNAL('changeCaption'), unicode(fn))
+                    self.changeCaption.emit(fn)
                     if switched:
-                        self.emit(SIGNAL('editorChanged'), unicode(fn))
+                        self.editorChanged.emit(fn)
+                        self.editorLineChanged.emit(
+                            fn, aw.getCursorPosition()[0] + 1)
                 else:
-                    self.emit(SIGNAL('changeCaption'), "")
+                    self.changeCaption.emit("")
+                self.editorChangedEd.emit(aw)
         
         return False
