@@ -9,10 +9,11 @@ Module implementing the font dialog wizard dialog.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QFontDialog
+
+from .Ui_FontDialogWizardDialog import Ui_FontDialogWizardDialog
 
-from Ui_FontDialogWizardDialog import Ui_FontDialogWizardDialog
 
 class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
     """
@@ -27,11 +28,11 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.bTest = \
-            self.buttonBox.addButton(self.trUtf8("Test"), QDialogButtonBox.ActionRole)
+        self.bTest = self.buttonBox.addButton(
+            self.trUtf8("Test"), QDialogButtonBox.ActionRole)
         
         self.font = None
         
@@ -44,7 +45,7 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
         if button == self.bTest:
             self.on_bTest_clicked()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_bTest_clicked(self):
         """
         Private method to test the selected options.
@@ -58,18 +59,18 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
         """
         Private slot to handle the textChanged signal of eVariable.
         
-        @param text the new text (QString)
+        @param text the new text (string)
         """
-        if text.isEmpty():
+        if not text:
             self.bTest.setEnabled(True)
         else:
             self.bTest.setEnabled(False)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fontButton_clicked(self):
         """
-        Private slot to handle the button press to select a font via a font selection 
-        dialog.
+        Private slot to handle the button press to select a font via a
+        font selection dialog.
         """
         if self.font is None:
             font, ok = QFontDialog.getFont()
@@ -91,16 +92,41 @@ class FontDialogWizardDialog(QDialog, Ui_FontDialogWizardDialog):
         # calculate our indentation level and the indentation string
         il = indLevel + 1
         istring = il * indString
+        estring = os.linesep + indLevel * indString
+        
+        # generate the code
+        resvar = self.eResultVar.text()
+        if not resvar:
+            resvar = "font"
+        title = self.eCaption.text()
+        if self.parentSelf.isChecked():
+            parent = "self"
+        elif self.parentNone.isChecked():
+            parent = "None"
+        elif self.parentOther.isChecked():
+            parent = self.parentEdit.text()
+            if parent == "":
+                parent = "None"
+        
+        code = '{0}, ok = QFontDialog.getFont('.format(resvar)
+        if self.eVariable.text() or self.font is not None:
+            if title or parent != "None":
+                code += '{0}{1}'.format(os.linesep, istring)
+            if not self.eVariable.text():
+                if self.font is not None:
+                    code += 'QFont("{0}", {1:d}, {2:d}, {3:d})'.format(
+                        self.font.family(), self.font.pointSize(),
+                        self.font.weight(), self.font.italic())
+            else:
+                code += self.eVariable.text()
+            if title:
+                code += ',{0}{1}{2}'.format(
+                    os.linesep, istring, parent)
+                code += ',{0}{1}self.trUtf8("{2}")'.format(
+                    os.linesep, istring, title)
+            elif parent != "None":
+                code += ',{0}{1}{2}'.format(
+                    os.linesep, istring, parent)
+        code += '){0}'.format(estring)
         
-        # now generate the code
-        code = 'QFontDialog.getFont('
-        if self.eVariable.text().isEmpty():
-            if self.font is not None:
-                code += 'QFont("%s", %d, %d, %d)' % \
-                    (self.font.family(), self.font.pointSize(),
-                    self.font.weight(), self.font.italic())
-        else:
-            code += str(self.eVariable.text())
-        code += ')%s' % os.linesep
-            
         return code
