@@ -7,47 +7,54 @@
 Module implementing a dialog for entering character classes.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QRegExp
+from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
+    QLineEdit, QPushButton, QDialog, QScrollArea, QComboBox, QVBoxLayout, \
+    QRegExpValidator, QLabel
 
-from Ui_PyRegExpWizardCharactersDialog import Ui_PyRegExpWizardCharactersDialog
+from .Ui_PyRegExpWizardCharactersDialog import \
+    Ui_PyRegExpWizardCharactersDialog
 
 
-class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog):
+class PyRegExpWizardCharactersDialog(
+        QDialog, Ui_PyRegExpWizardCharactersDialog):
     """
     Class implementing a dialog for entering character classes.
     """
     specialChars = {
-        4 : "\\a",
-        5 : "\\f",
-        6 : "\\n",
-        7 : "\\r",
-        8 : "\\t",
-        9 : "\\v"
+        4: "\\a",
+        5: "\\f",
+        6: "\\n",
+        7: "\\r",
+        8: "\\t",
+        9: "\\v"
     }
     
     predefinedClasses = ["\\s", "\\S", "\\w", "\\W", "\\d", "\\D"]
     
-    def __init__(self,parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.comboItems = QStringList()
+        self.comboItems = []
+        self.singleComboItems = []      # these are in addition to the above
         self.comboItems.append(self.trUtf8("Normal character"))
-        self.comboItems.append(self.trUtf8("Unicode character in hexadecimal notation"))
-        self.comboItems.append(self.trUtf8("Unicode character in octal notation"))
-        self.comboItems.append(self.trUtf8("---"))
-        self.comboItems.append(self.trUtf8("Bell character (\\a)"))
-        self.comboItems.append(self.trUtf8("Page break (\\f)"))
-        self.comboItems.append(self.trUtf8("Line feed (\\n)"))
-        self.comboItems.append(self.trUtf8("Carriage return (\\r)"))
-        self.comboItems.append(self.trUtf8("Horizontal tabulator (\\t)"))
-        self.comboItems.append(self.trUtf8("Vertical tabulator (\\v)"))
+        self.comboItems.append(
+            self.trUtf8("Unicode character in hexadecimal notation"))
+        self.comboItems.append(
+            self.trUtf8("Unicode character in octal notation"))
+        self.singleComboItems.append(self.trUtf8("---"))
+        self.singleComboItems.append(self.trUtf8("Bell character (\\a)"))
+        self.singleComboItems.append(self.trUtf8("Page break (\\f)"))
+        self.singleComboItems.append(self.trUtf8("Line feed (\\n)"))
+        self.singleComboItems.append(self.trUtf8("Carriage return (\\r)"))
+        self.singleComboItems.append(self.trUtf8("Horizontal tabulator (\\t)"))
+        self.singleComboItems.append(self.trUtf8("Vertical tabulator (\\v)"))
         
         self.charValidator = QRegExpValidator(QRegExp(".{0,1}"), self)
         self.hexValidator = QRegExpValidator(QRegExp("[0-9a-fA-F]{0,4}"), self)
@@ -57,7 +64,7 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         self.singlesBoxLayout = QVBoxLayout(self.singlesBox)
         self.singlesBoxLayout.setObjectName("singlesBoxLayout")
         self.singlesBoxLayout.setSpacing(6)
-        self.singlesBoxLayout.setMargin(6)
+        self.singlesBoxLayout.setContentsMargins(6, 6, 6, 6)
         self.singlesBox.setLayout(self.singlesBoxLayout)
         self.singlesView = QScrollArea(self.singlesBox)
         self.singlesView.setObjectName("singlesView")
@@ -67,30 +74,31 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         self.singlesView.setWidget(self.singlesItemsBox)
         self.singlesItemsBox.setObjectName("singlesItemsBox")
         self.singlesItemsBoxLayout = QVBoxLayout(self.singlesItemsBox)
-        self.singlesItemsBoxLayout.setMargin(6)
+        self.singlesItemsBoxLayout.setContentsMargins(6, 6, 6, 6)
         self.singlesItemsBoxLayout.setSpacing(6)
         self.singlesItemsBox.setLayout(self.singlesItemsBoxLayout)
         self.singlesEntries = []
         self.__addSinglesLine()
         
         hlayout0 = QHBoxLayout()
-        hlayout0.setMargin(0)
+        hlayout0.setContentsMargins(0, 0, 0, 0)
         hlayout0.setSpacing(6)
         hlayout0.setObjectName("hlayout0")
-        self.moreSinglesButton = QPushButton(self.trUtf8("Additional Entries"),
-            self.singlesBox)
+        self.moreSinglesButton = QPushButton(
+            self.trUtf8("Additional Entries"), self.singlesBox)
         self.moreSinglesButton.setObjectName("moreSinglesButton")
         hlayout0.addWidget(self.moreSinglesButton)
-        hspacer0 = QSpacerItem(30,20,QSizePolicy.Expanding,QSizePolicy.Minimum)
+        hspacer0 = QSpacerItem(
+            30, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         hlayout0.addItem(hspacer0)
         self.singlesBoxLayout.addLayout(hlayout0)
-        self.connect(self.moreSinglesButton, SIGNAL("clicked()"), self.__addSinglesLine)
+        self.moreSinglesButton.clicked[()].connect(self.__addSinglesLine)
         
         # generate dialog part for character ranges
         self.rangesBoxLayout = QVBoxLayout(self.rangesBox)
         self.rangesBoxLayout.setObjectName("rangesBoxLayout")
         self.rangesBoxLayout.setSpacing(6)
-        self.rangesBoxLayout.setMargin(6)
+        self.rangesBoxLayout.setContentsMargins(6, 6, 6, 6)
         self.rangesBox.setLayout(self.rangesBoxLayout)
         self.rangesView = QScrollArea(self.rangesBox)
         self.rangesView.setObjectName("rangesView")
@@ -100,24 +108,25 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         self.rangesView.setWidget(self.rangesItemsBox)
         self.rangesItemsBox.setObjectName("rangesItemsBox")
         self.rangesItemsBoxLayout = QVBoxLayout(self.rangesItemsBox)
-        self.rangesItemsBoxLayout.setMargin(6)
+        self.rangesItemsBoxLayout.setContentsMargins(6, 6, 6, 6)
         self.rangesItemsBoxLayout.setSpacing(6)
         self.rangesItemsBox.setLayout(self.rangesItemsBoxLayout)
         self.rangesEntries = []
         self.__addRangesLine()
         
         hlayout1 = QHBoxLayout()
-        hlayout1.setMargin(0)
+        hlayout1.setContentsMargins(0, 0, 0, 0)
         hlayout1.setSpacing(6)
         hlayout1.setObjectName("hlayout1")
-        self.moreRangesButton = QPushButton(self.trUtf8("Additional Entries"),
-            self.rangesBox)
+        self.moreRangesButton = QPushButton(
+            self.trUtf8("Additional Entries"), self.rangesBox)
         self.moreSinglesButton.setObjectName("moreRangesButton")
         hlayout1.addWidget(self.moreRangesButton)
-        hspacer1 = QSpacerItem(30,20,QSizePolicy.Expanding,QSizePolicy.Minimum)
+        hspacer1 = QSpacerItem(
+            30, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         hlayout1.addItem(hspacer1)
         self.rangesBoxLayout.addLayout(hlayout1)
-        self.connect(self.moreRangesButton, SIGNAL("clicked()"), self.__addRangesLine)
+        self.moreRangesButton.clicked[()].connect(self.__addRangesLine)
         
     def __addSinglesLine(self):
         """
@@ -125,12 +134,13 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         """
         hbox = QWidget(self.singlesItemsBox)
         hboxLayout = QHBoxLayout(hbox)
-        hboxLayout.setMargin(0)
+        hboxLayout.setContentsMargins(0, 0, 0, 0)
         hboxLayout.setSpacing(6)
         hbox.setLayout(hboxLayout)
         cb1 = QComboBox(hbox)
         cb1.setEditable(False)
         cb1.addItems(self.comboItems)
+        cb1.addItems(self.singleComboItems)
         hboxLayout.addWidget(cb1)
         le1 = QLineEdit(hbox)
         le1.setValidator(self.charValidator)
@@ -138,14 +148,15 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         cb2 = QComboBox(hbox)
         cb2.setEditable(False)
         cb2.addItems(self.comboItems)
+        cb2.addItems(self.singleComboItems)
         hboxLayout.addWidget(cb2)
         le2 = QLineEdit(hbox)
         le2.setValidator(self.charValidator)
         hboxLayout.addWidget(le2)
         self.singlesItemsBoxLayout.addWidget(hbox)
         
-        self.connect(cb1, SIGNAL('activated(int)'), self.__singlesCharTypeSelected)
-        self.connect(cb2, SIGNAL('activated(int)'), self.__singlesCharTypeSelected)
+        cb1.activated[int].connect(self.__singlesCharTypeSelected)
+        cb2.activated[int].connect(self.__singlesCharTypeSelected)
         hbox.show()
         
         self.singlesItemsBox.adjustSize()
@@ -159,36 +170,32 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         """
         hbox = QWidget(self.rangesItemsBox)
         hboxLayout = QHBoxLayout(hbox)
-        hboxLayout.setMargin(0)
+        hboxLayout.setContentsMargins(0, 0, 0, 0)
         hboxLayout.setSpacing(6)
         hbox.setLayout(hboxLayout)
-        l1 = QLabel(self.trUtf8("Between:"), hbox)
-        hboxLayout.addWidget(l1)
         cb1 = QComboBox(hbox)
         cb1.setEditable(False)
         cb1.addItems(self.comboItems)
         hboxLayout.addWidget(cb1)
+        l1 = QLabel(self.trUtf8("Between:"), hbox)
+        hboxLayout.addWidget(l1)
         le1 = QLineEdit(hbox)
         le1.setValidator(self.charValidator)
         hboxLayout.addWidget(le1)
         l2 = QLabel(self.trUtf8("And:"), hbox)
         hboxLayout.addWidget(l2)
-        cb2 = QComboBox(hbox)
-        cb2.setEditable(False)
-        cb2.addItems(self.comboItems)
-        hboxLayout.addWidget(cb2)
         le2 = QLineEdit(hbox)
         le2.setValidator(self.charValidator)
         hboxLayout.addWidget(le2)
         self.rangesItemsBoxLayout.addWidget(hbox)
         
-        self.connect(cb1, SIGNAL('activated(int)'), self.__rangesCharTypeSelected)
-        self.connect(cb2, SIGNAL('activated(int)'), self.__rangesCharTypeSelected)
+        cb1.activated[int].connect(self.__rangesCharTypeSelected)
+        
         hbox.show()
         
         self.rangesItemsBox.adjustSize()
         
-        self.rangesEntries.append([cb1, le1, cb2, le2])
+        self.rangesEntries.append([cb1, le1, le2])
         
     def __performSelectedAction(self, index, lineedit):
         """
@@ -211,7 +218,8 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         
     def __singlesCharTypeSelected(self, index):
         """
-        Private slot to handle the activated(int) signal of the single chars combo boxes.
+        Private slot to handle the activated(int) signal of the single chars
+        combo boxes.
         
         @param index selected list index (integer)
         """
@@ -219,10 +227,12 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         for entriesList in self.singlesEntries:
             if combo == entriesList[0]:
                 self.__performSelectedAction(index, entriesList[1])
+                break
         
     def __rangesCharTypeSelected(self, index):
         """
-        Private slot to handle the activated(int) signal of the char ranges combo boxes.
+        Private slot to handle the activated(int) signal of the char ranges
+        combo boxes.
         
         @param index selected list index (integer)
         """
@@ -230,8 +240,8 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         for entriesList in self.rangesEntries:
             if combo == entriesList[0]:
                 self.__performSelectedAction(index, entriesList[1])
-            elif combo == entriesList[2]:
-                self.__performSelectedAction(index, entriesList[3])
+                self.__performSelectedAction(index, entriesList[2])
+                break
         
     def __formatCharacter(self, index, char):
         """
@@ -244,9 +254,9 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         if index == 0:
             return char
         elif index == 1:
-            return "\\x%s" % char.lower()
+            return "\\x{0}".format(char.lower())
         elif index == 2:
-            return "\\0%s" % char
+            return "\\0{0}".format(char)
         else:
             try:
                 return self.specialChars[index]
@@ -282,25 +292,28 @@ class PyRegExpWizardCharactersDialog(QDialog, Ui_PyRegExpWizardCharactersDialog)
         # single characters
         for entrieslist in self.singlesEntries:
             index = entrieslist[0].currentIndex()
-            char = unicode(entrieslist[1].text())
+            char = entrieslist[1].text()
             regexp += self.__formatCharacter(index, char)
         
         # character ranges
         for entrieslist in self.rangesEntries:
-            if entrieslist[1].text().isEmpty() or \
-               entrieslist[3].text().isEmpty():
+            if entrieslist[1].text() == "" or \
+               entrieslist[2].text() == "":
                 continue
             index = entrieslist[0].currentIndex()
-            char = unicode(entrieslist[1].text())
-            regexp += "%s-" % self.__formatCharacter(index, char)
-            index = entrieslist[2].currentIndex()
-            char = unicode(entrieslist[3].text())
-            regexp += self.__formatCharacter(index, char)
+            char1 = entrieslist[1].text()
+            char2 = entrieslist[2].text()
+            regexp += "{0}-{1}".format(
+                self.__formatCharacter(index, char1),
+                self.__formatCharacter(index, char2))
         
         if regexp:
-            if len(regexp) == 2 and regexp in self.predefinedClasses:
+            if (len(regexp) == 2 and
+                (regexp in self.predefinedClasses or
+                 regexp in self.specialChars)) or \
+               len(regexp) == 1:
                 return regexp
             else:
-                return "[%s]" % regexp
+                return "[{0}]".format(regexp)
         else:
             return ""
