@@ -7,37 +7,36 @@
 Module implementing the Python re wizard dialog.
 """
 
-import sys
 import os
 import re
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QFileInfo, pyqtSlot
+from PyQt4.QtGui import QWidget, QDialog, QInputDialog, QApplication, \
+    QClipboard, QTextCursor, QDialogButtonBox, QVBoxLayout, QTableWidgetItem
 
-from KdeQt import KQMessageBox, KQInputDialog, KQFileDialog
-from KdeQt.KQMainWindow import KQMainWindow
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
-from Ui_PyRegExpWizardDialog import Ui_PyRegExpWizardDialog
-
-from PyRegExpWizardRepeatDialog import PyRegExpWizardRepeatDialog
-from PyRegExpWizardCharactersDialog import PyRegExpWizardCharactersDialog
+from .Ui_PyRegExpWizardDialog import Ui_PyRegExpWizardDialog
 
 import UI.PixmapCache
 
 import Utilities
+import Preferences
+
 
 class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
     """
     Class implementing the Python re wizard dialog.
     """
-    def __init__(self, parent = None, fromEric = True):
+    def __init__(self, parent=None, fromEric=True):
         """
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric4
+        @param fromEric flag indicating a call from within eric5
         """
-        QWidget.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         # initialize icons of the tool buttons
@@ -48,62 +47,72 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         self.nonGroupButton.setIcon(UI.PixmapCache.getIcon("nongroup.png"))
         self.groupButton.setIcon(UI.PixmapCache.getIcon("group.png"))
         self.namedGroupButton.setIcon(UI.PixmapCache.getIcon("namedgroup.png"))
-        self.namedReferenceButton.setIcon(UI.PixmapCache.getIcon("namedreference.png"))
+        self.namedReferenceButton.setIcon(
+            UI.PixmapCache.getIcon("namedreference.png"))
         self.altnButton.setIcon(UI.PixmapCache.getIcon("altn.png"))
         self.beglineButton.setIcon(UI.PixmapCache.getIcon("begline.png"))
         self.endlineButton.setIcon(UI.PixmapCache.getIcon("endline.png"))
-        self.wordboundButton.setIcon(UI.PixmapCache.getIcon("wordboundary.png"))
-        self.nonwordboundButton.setIcon(UI.PixmapCache.getIcon("nonwordboundary.png"))
-        self.poslookaheadButton.setIcon(UI.PixmapCache.getIcon("poslookahead.png"))
-        self.neglookaheadButton.setIcon(UI.PixmapCache.getIcon("neglookahead.png"))
-        self.poslookbehindButton.setIcon(UI.PixmapCache.getIcon("poslookbehind.png"))
-        self.neglookbehindButton.setIcon(UI.PixmapCache.getIcon("neglookbehind.png"))
+        self.wordboundButton.setIcon(
+            UI.PixmapCache.getIcon("wordboundary.png"))
+        self.nonwordboundButton.setIcon(
+            UI.PixmapCache.getIcon("nonwordboundary.png"))
+        self.poslookaheadButton.setIcon(
+            UI.PixmapCache.getIcon("poslookahead.png"))
+        self.neglookaheadButton.setIcon(
+            UI.PixmapCache.getIcon("neglookahead.png"))
+        self.poslookbehindButton.setIcon(
+            UI.PixmapCache.getIcon("poslookbehind.png"))
+        self.neglookbehindButton.setIcon(
+            UI.PixmapCache.getIcon("neglookbehind.png"))
         self.undoButton.setIcon(UI.PixmapCache.getIcon("editUndo.png"))
         self.redoButton.setIcon(UI.PixmapCache.getIcon("editRedo.png"))
         
         self.namedGroups = re.compile(r"""\(?P<([^>]+)>""").findall
         
-        self.saveButton = \
-            self.buttonBox.addButton(self.trUtf8("Save"), QDialogButtonBox.ActionRole)
-        self.saveButton.setToolTip(self.trUtf8("Save the regular expression to a file"))
-        self.loadButton = \
-            self.buttonBox.addButton(self.trUtf8("Load"), QDialogButtonBox.ActionRole)
-        self.loadButton.setToolTip(self.trUtf8("Load a regular expression from a file"))
-        self.validateButton = \
-            self.buttonBox.addButton(self.trUtf8("Validate"), QDialogButtonBox.ActionRole)
-        self.validateButton.setToolTip(self.trUtf8("Validate the regular expression"))
-        self.executeButton = \
-            self.buttonBox.addButton(self.trUtf8("Execute"), QDialogButtonBox.ActionRole)
-        self.executeButton.setToolTip(self.trUtf8("Execute the regular expression"))
-        self.nextButton = \
-            self.buttonBox.addButton(self.trUtf8("Next match"), 
-                                     QDialogButtonBox.ActionRole)
-        self.nextButton.setToolTip(\
+        self.saveButton = self.buttonBox.addButton(
+            self.trUtf8("Save"), QDialogButtonBox.ActionRole)
+        self.saveButton.setToolTip(
+            self.trUtf8("Save the regular expression to a file"))
+        self.loadButton = self.buttonBox.addButton(
+            self.trUtf8("Load"), QDialogButtonBox.ActionRole)
+        self.loadButton.setToolTip(
+            self.trUtf8("Load a regular expression from a file"))
+        self.validateButton = self.buttonBox.addButton(
+            self.trUtf8("Validate"), QDialogButtonBox.ActionRole)
+        self.validateButton.setToolTip(
+            self.trUtf8("Validate the regular expression"))
+        self.executeButton = self.buttonBox.addButton(
+            self.trUtf8("Execute"), QDialogButtonBox.ActionRole)
+        self.executeButton.setToolTip(
+            self.trUtf8("Execute the regular expression"))
+        self.nextButton = self.buttonBox.addButton(
+            self.trUtf8("Next match"), QDialogButtonBox.ActionRole)
+        self.nextButton.setToolTip(
             self.trUtf8("Show the next match of the regular expression"))
         self.nextButton.setEnabled(False)
         
         if fromEric:
-            self.buttonBox.button(QDialogButtonBox.Close).hide()
+            self.buttonBox.setStandardButtons(
+                QDialogButtonBox.Cancel | QDialogButtonBox.Ok)
             self.copyButton = None
         else:
-            self.copyButton = \
-                self.buttonBox.addButton(self.trUtf8("Copy"), QDialogButtonBox.ActionRole)
-            self.copyButton.setToolTip(\
+            self.copyButton = self.buttonBox.addButton(
+                self.trUtf8("Copy"), QDialogButtonBox.ActionRole)
+            self.copyButton.setToolTip(
                 self.trUtf8("Copy the regular expression to the clipboard"))
-            self.buttonBox.button(QDialogButtonBox.Ok).hide()
-            self.buttonBox.button(QDialogButtonBox.Cancel).hide()
+            self.buttonBox.setStandardButtons(QDialogButtonBox.Close)
             self.variableLabel.hide()
             self.variableLineEdit.hide()
             self.variableLine.hide()
             self.importCheckBox.hide()
             self.regexpTextEdit.setFocus()
 
-    def __insertString(self, s, steps = 0):
+    def __insertString(self, s, steps=0):
         """
         Private method to insert a string into line edit and move cursor.
         
         @param s string to be inserted into the regexp line edit
-            (string or QString)
+            (string)
         @param steps number of characters to move the cursor (integer).
             Negative steps moves cursor back, positives forward.
         """
@@ -119,42 +128,42 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 tc.movePosition(act)
         self.regexpTextEdit.setTextCursor(tc)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_commentButton_clicked(self):
         """
         Private slot to handle the comment toolbutton.
         """
         self.__insertString("(?#)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_anycharButton_clicked(self):
         """
         Private slot to handle the any character toolbutton.
         """
         self.__insertString(".")
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_nonGroupButton_clicked(self):
         """
         Private slot to handle the non group toolbutton.
         """
         self.__insertString("(?:)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_groupButton_clicked(self):
         """
         Private slot to handle the group toolbutton.
         """
         self.__insertString("()", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_namedGroupButton_clicked(self):
         """
         Private slot to handle the named group toolbutton.
         """
         self.__insertString("(?P<>)", -2)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_namedReferenceButton_clicked(self):
         """
         Private slot to handle the named reference toolbutton.
@@ -162,116 +171,118 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         # determine cursor position as length into text
         length = self.regexpTextEdit.textCursor().position()
         
-        # only present group names that occur before the current cursor position
-        regex = unicode(self.regexpTextEdit.toPlainText().left(length))
+        # only present group names that occur before the
+        # current cursor position
+        regex = self.regexpTextEdit.toPlainText()[:length]
         names = self.namedGroups(regex)
         if not names:
-            KQMessageBox.information(None,
+            E5MessageBox.information(
+                self,
                 self.trUtf8("Named reference"),
                 self.trUtf8("""No named groups have been defined yet."""))
             return
-            
-        qs = QStringList()
-        for name in names:
-            qs.append(name)
-        groupName, ok = KQInputDialog.getItem(\
-            None,
+        
+        groupName, ok = QInputDialog.getItem(
+            self,
             self.trUtf8("Named reference"),
             self.trUtf8("Select group name:"),
-            qs,
+            names,
             0, True)
-        if ok and not groupName.isEmpty():
-            self.__insertString("(?P=%s)" % groupName)
+        if ok and groupName:
+            self.__insertString("(?P={0})".format(groupName))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_altnButton_clicked(self):
         """
         Private slot to handle the alternatives toolbutton.
         """
         self.__insertString("(|)", -2)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_beglineButton_clicked(self):
         """
         Private slot to handle the begin line toolbutton.
         """
         self.__insertString("^")
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_endlineButton_clicked(self):
         """
         Private slot to handle the end line toolbutton.
         """
         self.__insertString("$")
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_wordboundButton_clicked(self):
         """
         Private slot to handle the word boundary toolbutton.
         """
         self.__insertString("\\b")
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_nonwordboundButton_clicked(self):
         """
         Private slot to handle the non word boundary toolbutton.
         """
         self.__insertString("\\B")
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_poslookaheadButton_clicked(self):
         """
         Private slot to handle the positive lookahead toolbutton.
         """
         self.__insertString("(?=)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_neglookaheadButton_clicked(self):
         """
         Private slot to handle the negative lookahead toolbutton.
         """
         self.__insertString("(?!)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_poslookbehindButton_clicked(self):
         """
         Private slot to handle the positive lookbehind toolbutton.
         """
         self.__insertString("(?<=)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_neglookbehindButton_clicked(self):
         """
         Private slot to handle the negative lookbehind toolbutton.
         """
         self.__insertString("(?<!)", -1)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_repeatButton_clicked(self):
         """
         Private slot to handle the repeat toolbutton.
         """
+        from .PyRegExpWizardRepeatDialog import PyRegExpWizardRepeatDialog
         dlg = PyRegExpWizardRepeatDialog(self)
         if dlg.exec_() == QDialog.Accepted:
             self.__insertString(dlg.getRepeat())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_charButton_clicked(self):
         """
         Private slot to handle the characters toolbutton.
         """
+        from .PyRegExpWizardCharactersDialog import \
+            PyRegExpWizardCharactersDialog
         dlg = PyRegExpWizardCharactersDialog(self)
         if dlg.exec_() == QDialog.Accepted:
             self.__insertString(dlg.getCharacters())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_undoButton_clicked(self):
         """
         Private slot to handle the undo action.
         """
         self.regexpTextEdit.document().undo()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_redoButton_clicked(self):
         """
         Private slot to handle the redo action.
@@ -297,91 +308,93 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         elif self.copyButton and button == self.copyButton:
             self.on_copyButton_clicked()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_saveButton_clicked(self):
         """
         Private slot to save the regexp to a file.
         """
-        selectedFilter = QString("")
-        fname = KQFileDialog.getSaveFileName(\
+        fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
             self.trUtf8("Save regular expression"),
-            QString(),
+            "",
             self.trUtf8("RegExp Files (*.rx);;All Files (*)"),
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
-        if not fname.isEmpty():
+            None,
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
+        if fname:
             ext = QFileInfo(fname).suffix()
-            if ext.isEmpty():
-                ex = selectedFilter.section('(*', 1, 1).section(')', 0, 0)
-                if not ex.isEmpty():
-                    fname.append(ex)
+            if not ext:
+                ex = selectedFilter.split("(*")[1].split(")")[0]
+                if ex:
+                    fname += ex
             if QFileInfo(fname).exists():
-                res = KQMessageBox.warning(self,
+                res = E5MessageBox.yesNo(
+                    self,
                     self.trUtf8("Save regular expression"),
-                    self.trUtf8("<p>The file <b>%1</b> already exists.</p>")
-                        .arg(fname),
-                    QMessageBox.StandardButtons(\
-                        QMessageBox.Abort | \
-                        QMessageBox.Save),
-                    QMessageBox.Abort)
-                if res == QMessageBox.Abort or res == QMessageBox.Cancel:
+                    self.trUtf8("<p>The file <b>{0}</b> already exists."
+                                " Overwrite it?</p>").format(fname),
+                    icon=E5MessageBox.Warning)
+                if not res:
                     return
             
             try:
-                f=open(unicode(Utilities.toNativeSeparators(fname)), "wb")
-                f.write(unicode(self.regexpTextEdit.toPlainText()))
+                f = open(
+                    Utilities.toNativeSeparators(fname), "w", encoding="utf-8")
+                f.write(self.regexpTextEdit.toPlainText())
                 f.close()
-            except IOError, err:
-                KQMessageBox.information(self,
+            except IOError as err:
+                E5MessageBox.information(
+                    self,
                     self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                    self.trUtf8("""<p>The regular expression could not"""
+                                """ be saved.</p><p>Reason: {0}</p>""")
+                    .format(str(err)))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_loadButton_clicked(self):
         """
         Private slot to load a regexp from a file.
         """
-        fname = KQFileDialog.getOpenFileName(\
+        fname = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Load regular expression"),
-            QString(),
-            self.trUtf8("RegExp Files (*.rx);;All Files (*)"),
-            None)
-        if not fname.isEmpty():
+            "",
+            self.trUtf8("RegExp Files (*.rx);;All Files (*)"))
+        if fname:
             try:
-                f=open(unicode(Utilities.toNativeSeparators(fname)), "rb")
+                f = open(
+                    Utilities.toNativeSeparators(fname), "r", encoding="utf-8")
                 regexp = f.read()
                 f.close()
                 self.regexpTextEdit.setPlainText(regexp)
-            except IOError, err:
-                KQMessageBox.information(self,
+            except IOError as err:
+                E5MessageBox.information(
+                    self,
                     self.trUtf8("Save regular expression"),
-                    self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                    self.trUtf8("""<p>The regular expression could not"""
+                                """ be saved.</p><p>Reason: {0}</p>""")
+                    .format(str(err)))
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_copyButton_clicked(self):
         """
         Private slot to copy the regexp string into the clipboard.
         
-        This slot is only available, if not called from within eric4.
+        This slot is only available, if not called from within eric5.
         """
         escaped = self.regexpTextEdit.toPlainText()
-        if not escaped.isEmpty():
+        if escaped:
             escaped = escaped.replace("\\", "\\\\")
             cb = QApplication.clipboard()
             cb.setText(escaped, QClipboard.Clipboard)
             if cb.supportsSelection():
                 cb.setText(escaped, QClipboard.Selection)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_validateButton_clicked(self):
         """
         Private slot to validate the entered regexp.
         """
-        regex = unicode(self.regexpTextEdit.toPlainText())
+        regex = self.regexpTextEdit.toPlainText()
         if regex:
             try:
                 flags = 0
@@ -402,27 +415,32 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                     if self.unicodeCheckBox.isChecked():
                         flags |= re.ASCII
                 re.compile(regex, flags)
-                KQMessageBox.information(None,
-                    self.trUtf8(""),
+                E5MessageBox.information(
+                    self,
+                    self.trUtf8("Validation"),
                     self.trUtf8("""The regular expression is valid."""))
-            except re.error, e:
-                KQMessageBox.critical(None,
+            except re.error as e:
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: %1""")
-                        .arg(str(e)))
+                    self.trUtf8("""Invalid regular expression: {0}""")
+                    .format(str(e)))
                 return
             except IndexError:
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: missing group name"""))
+                    self.trUtf8("""Invalid regular expression: missing"""
+                                """ group name"""))
                 return
         else:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Error"),
                 self.trUtf8("""A regular expression must be given."""))
 
-    @pyqtSignature("")
-    def on_executeButton_clicked(self, startpos = 0):
+    @pyqtSlot()
+    def on_executeButton_clicked(self, startpos=0):
         """
         Private slot to execute the entered regexp on the test text.
         
@@ -431,8 +449,8 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         
         @param startpos starting position for the regexp matching
         """
-        regex = unicode(self.regexpTextEdit.toPlainText())
-        text = unicode(self.textTextEdit.toPlainText())
+        regex = self.regexpTextEdit.toPlainText()
+        text = self.textTextEdit.toPlainText()
         if regex and text:
             try:
                 flags = 0
@@ -467,48 +485,63 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 self.resultTable.setColumnCount(3)
                 self.resultTable.setRowCount(0)
                 self.resultTable.setRowCount(OFFSET)
-                self.resultTable.setItem(row, 0, QTableWidgetItem(self.trUtf8("Regexp")))
-                self.resultTable.setItem(row, 1, QTableWidgetItem(regex))
+                self.resultTable.setItem(
+                    row, 0, QTableWidgetItem(self.trUtf8("Regexp")))
+                self.resultTable.setItem(
+                    row, 1, QTableWidgetItem(regex))
                 
                 if matchobj is not None:
                     offset = matchobj.start()
                     self.lastMatchEnd = matchobj.end()
                     self.nextButton.setEnabled(True)
                     row += 1
-                    self.resultTable.setItem(row, 0, 
+                    self.resultTable.setItem(
+                        row, 0,
                         QTableWidgetItem(self.trUtf8("Offset")))
-                    self.resultTable.setItem(row, 1, 
-                        QTableWidgetItem(QString.number(matchobj.start(0))))
+                    self.resultTable.setItem(
+                        row, 1,
+                        QTableWidgetItem("{0:d}".format(matchobj.start(0))))
                     
                     row += 1
-                    self.resultTable.setItem(row, 0, 
+                    self.resultTable.setItem(
+                        row, 0,
                         QTableWidgetItem(self.trUtf8("Captures")))
-                    self.resultTable.setItem(row, 1, 
-                        QTableWidgetItem(QString.number(captures)))
+                    self.resultTable.setItem(
+                        row, 1,
+                        QTableWidgetItem("{0:d}".format(captures)))
                     row += 1
-                    self.resultTable.setItem(row, 1, 
+                    self.resultTable.setItem(
+                        row, 1,
                         QTableWidgetItem(self.trUtf8("Text")))
-                    self.resultTable.setItem(row, 2, 
+                    self.resultTable.setItem(
+                        row, 2,
                         QTableWidgetItem(self.trUtf8("Characters")))
                     
                     row += 1
-                    self.resultTable.setItem(row, 0, 
+                    self.resultTable.setItem(
+                        row, 0,
                         QTableWidgetItem(self.trUtf8("Match")))
-                    self.resultTable.setItem(row, 1, 
+                    self.resultTable.setItem(
+                        row, 1,
                         QTableWidgetItem(matchobj.group(0)))
-                    self.resultTable.setItem(row, 2, 
-                        QTableWidgetItem(QString.number(len(matchobj.group(0)))))
+                    self.resultTable.setItem(
+                        row, 2,
+                        QTableWidgetItem(
+                            "{0:d}".format(len(matchobj.group(0)))))
                     
                     for i in range(1, captures + 1):
                         if matchobj.group(i) is not None:
                             row += 1
                             self.resultTable.insertRow(row)
-                            self.resultTable.setItem(row, 0, 
-                                QTableWidgetItem(self.trUtf8("Capture #%1").arg(i)))
-                            self.resultTable.setItem(row, 1, 
-                                QTableWidgetItem(matchobj.group(i)))
-                            self.resultTable.setItem(row, 2, 
-                                QTableWidgetItem(QString.number(len(matchobj.group(i)))))
+                            self.resultTable.setItem(
+                                row, 0,
+                                QTableWidgetItem(
+                                    self.trUtf8("Capture #{0}").format(i)))
+                            self.resultTable.setItem(
+                                row, 1, QTableWidgetItem(matchobj.group(i)))
+                            self.resultTable.setItem(
+                                row, 2, QTableWidgetItem(
+                                    "{0:d}".format(len(matchobj.group(i)))))
                     
                     # highlight the matched text
                     tc = self.textTextEdit.textCursor()
@@ -520,10 +553,12 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                     self.resultTable.setRowCount(2)
                     row += 1
                     if startpos > 0:
-                        self.resultTable.setItem(row, 0, 
+                        self.resultTable.setItem(
+                            row, 0,
                             QTableWidgetItem(self.trUtf8("No more matches")))
                     else:
-                        self.resultTable.setItem(row, 0, 
+                        self.resultTable.setItem(
+                            row, 0,
                             QTableWidgetItem(self.trUtf8("No matches")))
                     
                     # remove the highlight
@@ -535,37 +570,42 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 self.resultTable.resizeRowsToContents()
                 self.resultTable.verticalHeader().hide()
                 self.resultTable.horizontalHeader().hide()
-            except re.error, e:
-                KQMessageBox.critical(None,
+            except re.error as e:
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: %1""")
-                        .arg(str(e)))
+                    self.trUtf8("""Invalid regular expression: {0}""")
+                    .format(str(e)))
                 return
             except IndexError:
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Error"),
-                    self.trUtf8("""Invalid regular expression: missing group name"""))
+                    self.trUtf8("""Invalid regular expression: missing"""
+                                """ group name"""))
                 return
         else:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Error"),
-                self.trUtf8("""A regular expression and a text must be given."""))
+                self.trUtf8("""A regular expression and a text must be"""
+                            """ given."""))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_nextButton_clicked(self):
         """
         Private slot to find the next match.
         """
         self.on_executeButton_clicked(self.lastMatchEnd)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_regexpTextEdit_textChanged(self):
         """
         Private slot called when the regexp changes.
         """
         self.nextButton.setEnabled(False)
         
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_py2Button_toggled(self, checked):
         """
         Private slot called when the Python version was selected.
@@ -573,7 +613,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         @param checked state of the Python 2 button (boolean)
         """
         # set the checkboxes
-        self.localeCheckBox.setHidden(not checked)
+        self.localeCheckBox.setEnabled(checked)
         if checked:
             self.unicodeCheckBox.setText(self.trUtf8("Unicode"))
         else:
@@ -601,13 +641,14 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         # calculate the indentation string
         istring = indLevel * indString
         i1string = (indLevel + 1) * indString
+        estring = os.linesep + indLevel * indString
         
         # now generate the code
-        reVar = unicode(self.variableLineEdit.text())
+        reVar = self.variableLineEdit.text()
         if not reVar:
             reVar = "regexp"
             
-        regexp = unicode(self.regexpTextEdit.toPlainText())
+        regexp = self.regexpTextEdit.toPlainText()
         
         flags = []
         if not self.caseSensitiveCheckBox.isChecked():
@@ -630,40 +671,43 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         
         code = ''
         if self.importCheckBox.isChecked():
-            code += 'import re%s%s' % (os.linesep, istring)
-        code += '%s = re.compile(r"""%s"""' % \
-            (reVar, regexp.replace('"', '\\"'))
+            code += 'import re{0}{1}'.format(os.linesep, istring)
+        code += '{0} = re.compile('.format(reVar)
+        code += '{0}{1}r"""{2}"""'.format(
+            os.linesep, i1string, regexp.replace('"', '\\"'))
         if flags:
-            code += ', \\%s%s%s' % (os.linesep, i1string, flags)
-        code += ')%s' % os.linesep
+            code += ',{0}{1}{2}'.format(os.linesep, i1string, flags)
+        code += '){0}'.format(estring)
         return code
 
+
 class PyRegExpWizardDialog(QDialog):
     """
     Class for the dialog variant.
     """
-    def __init__(self, parent = None, fromEric = True):
+    def __init__(self, parent=None, fromEric=True):
         """
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric4
+        @param fromEric flag indicating a call from within eric5
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setModal(fromEric)
         self.setSizeGripEnabled(True)
         
         self.__layout = QVBoxLayout(self)
-        self.__layout.setMargin(0)
+        self.__layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(self.__layout)
         
         self.cw = PyRegExpWizardWidget(self, fromEric)
         size = self.cw.size()
         self.__layout.addWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
+        self.cw.buttonBox.accepted[()].connect(self.accept)
+        self.cw.buttonBox.rejected[()].connect(self.reject)
     
     def getCode(self, indLevel, indString):
         """
@@ -675,21 +719,26 @@ class PyRegExpWizardDialog(QDialog):
         """
         return self.cw.getCode(indLevel, indString)
 
-class PyRegExpWizardWindow(KQMainWindow):
+
+class PyRegExpWizardWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
-        self.cw = PyRegExpWizardWidget(self, fromEric = False)
+        super().__init__(parent)
+        self.cw = PyRegExpWizardWidget(self, fromEric=False)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
+        self.setWindowTitle(self.cw.windowTitle())
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.close)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
+        self.setStyle(
+            Preferences.getUI("Style"), Preferences.getUI("StyleSheet"))
+        
+        self.cw.buttonBox.accepted[()].connect(self.close)
+        self.cw.buttonBox.rejected[()].connect(self.close)
