@@ -7,28 +7,28 @@
 Module implementing a dialog for entering repeat counts.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog
 
-from Ui_PyRegExpWizardRepeatDialog import Ui_PyRegExpWizardRepeatDialog
+from .Ui_PyRegExpWizardRepeatDialog import Ui_PyRegExpWizardRepeatDialog
 
 
 class PyRegExpWizardRepeatDialog(QDialog, Ui_PyRegExpWizardRepeatDialog):
     """
     Class implementing a dialog for entering repeat counts.
     """
-    def __init__(self,parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.unlimitedButton.setChecked(True)
         
-    @pyqtSignature("int")
+    @pyqtSlot(int)
     def on_lowerSpin_valueChanged(self, value):
         """
         Private slot to handle the lowerSpin valueChanged signal.
@@ -38,7 +38,7 @@ class PyRegExpWizardRepeatDialog(QDialog, Ui_PyRegExpWizardRepeatDialog):
         if self.upperSpin.value() < value:
             self.upperSpin.setValue(value)
         
-    @pyqtSignature("int")
+    @pyqtSlot(int)
     def on_upperSpin_valueChanged(self, value):
         """
         Private slot to handle the upperSpin valueChanged signal.
@@ -66,17 +66,17 @@ class PyRegExpWizardRepeatDialog(QDialog, Ui_PyRegExpWizardRepeatDialog):
             if reps == 1:
                 return "+" + minimal
             else:
-                return "{%d,}%s" % (reps, minimal)
+                return "{{{0:d},}}{1}".format(reps, minimal)
         elif self.maxButton.isChecked():
             reps = self.maxSpin.value()
             if reps == 1:
                 return "?" + minimal
             else:
-                return "{,%d}%s" % (reps, minimal)
+                return "{{,{0:d}}}{1}".format(reps, minimal)
         elif self.exactButton.isChecked():
             reps = self.exactSpin.value()
-            return "{%d}%s" % (reps, minimal)
+            return "{{{0:d}}}{1}".format(reps, minimal)
         elif self.betweenButton.isChecked():
             repsMin = self.lowerSpin.value()
             repsMax = self.upperSpin.value()
-            return "{%d,%d}%s" % (repsMin, repsMax, minimal)
+            return "{{{0:d},{1:d}}}{2}".format(repsMin, repsMax, minimal)
