@@ -7,28 +7,28 @@
 Module implementing a dialog for entering repeat counts.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog
 
-from Ui_QRegExpWizardRepeatDialog import Ui_QRegExpWizardRepeatDialog
+from .Ui_QRegExpWizardRepeatDialog import Ui_QRegExpWizardRepeatDialog
 
 
 class QRegExpWizardRepeatDialog(QDialog, Ui_QRegExpWizardRepeatDialog):
     """
     Class implementing a dialog for entering repeat counts.
     """
-    def __init__(self,parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.unlimitedButton.setChecked(True)
         
-    @pyqtSignature("int")
+    @pyqtSlot(int)
     def on_lowerSpin_valueChanged(self, value):
         """
         Private slot to handle the lowerSpin valueChanged signal.
@@ -38,7 +38,7 @@ class QRegExpWizardRepeatDialog(QDialog, Ui_QRegExpWizardRepeatDialog):
         if self.upperSpin.value() < value:
             self.upperSpin.setValue(value)
         
-    @pyqtSignature("int")
+    @pyqtSlot(int)
     def on_upperSpin_valueChanged(self, value):
         """
         Private slot to handle the upperSpin valueChanged signal.
@@ -61,17 +61,17 @@ class QRegExpWizardRepeatDialog(QDialog, Ui_QRegExpWizardRepeatDialog):
             if reps == 1:
                 return "+"
             else:
-                return "{%d,}" % reps
+                return "{{{0:d},}}".format(reps)
         elif self.maxButton.isChecked():
             reps = self.maxSpin.value()
             if reps == 1:
                 return "?"
             else:
-                return "{,%d}" % reps
+                return "{{,{0:d}}}".format(reps)
         elif self.exactButton.isChecked():
             reps = self.exactSpin.value()
-            return "{%d}" % reps
+            return "{{{0:d}}}".format(reps)
         elif self.betweenButton.isChecked():
             repsMin = self.lowerSpin.value()
             repsMax = self.upperSpin.value()
-            return "{%d,%d}" % (repsMin, repsMax)
+            return "{{{0:d},{1:d}}}".format(repsMin, repsMax)
