@@ -7,15 +7,12 @@
 Module implementing the Application configuration page.
 """
 
-import os
-
-from PyQt4.QtCore import QVariant, pyqtSignature
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_ApplicationPage import Ui_ApplicationPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_ApplicationPage import Ui_ApplicationPage
 
 import Preferences
 
+
 class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
     """
     Class implementing the Application configuration page.
@@ -24,14 +21,14 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("ApplicationPage")
         
         # set initial values
-        self.singleApplicationCheckBox.setChecked(\
+        self.singleApplicationCheckBox.setChecked(
             Preferences.getUI("SingleApplicationMode"))
-        self.splashScreenCheckBox.setChecked(\
+        self.splashScreenCheckBox.setChecked(
             Preferences.getUI("ShowSplash"))
         
         openOnStartup = Preferences.getUI("OpenOnStartup")
@@ -68,10 +65,12 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
         """
         Public slot to save the Application configuration.
         """
-        Preferences.setUI("SingleApplicationMode",
-            int(self.singleApplicationCheckBox.isChecked()))
-        Preferences.setUI("ShowSplash",
-            int(self.splashScreenCheckBox.isChecked()))
+        Preferences.setUI(
+            "SingleApplicationMode",
+            self.singleApplicationCheckBox.isChecked())
+        Preferences.setUI(
+            "ShowSplash",
+            self.splashScreenCheckBox.isChecked())
         
         if self.noOpenRadioButton.isChecked():
             openOnStartup = 0
@@ -97,17 +96,21 @@ class ApplicationPage(ConfigurationPageBase, Ui_ApplicationPage):
             period = 4
         Preferences.setUI("PerformVersionCheck", period)
         
-        Preferences.setUser("UseSystemEmailClient", 
-            int(self.systemEmailClientCheckBox.isChecked()))
+        Preferences.setUser(
+            "UseSystemEmailClient",
+            self.systemEmailClientCheckBox.isChecked())
         
-        Preferences.setUI("CheckErrorLog", 
-            int(self.errorlogCheckBox.isChecked()))
+        Preferences.setUI(
+            "CheckErrorLog",
+            self.errorlogCheckBox.isChecked())
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = ApplicationPage()
     return page
