@@ -7,18 +7,18 @@
 Module implementing the Corba configuration page.
 """
 
-from PyQt4.QtCore import QDir, QString, pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_CorbaPage import Ui_CorbaPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_CorbaPage import Ui_CorbaPage
 
 import Preferences
 import Utilities
 
+
 class CorbaPage(ConfigurationPageBase, Ui_CorbaPage):
     """
     Class implementing the Corba configuration page.
@@ -27,11 +27,11 @@ class CorbaPage(ConfigurationPageBase, Ui_CorbaPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("CorbaPage")
         
-        self.idlCompleter = E4FileCompleter(self.idlEdit)
+        self.idlCompleter = E5FileCompleter(self.idlEdit)
         
         # set initial values
         self.idlEdit.setText(Preferences.getCorba("omniidl"))
@@ -42,25 +42,27 @@ class CorbaPage(ConfigurationPageBase, Ui_CorbaPage):
         """
         Preferences.setCorba("omniidl", self.idlEdit.text())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_idlButton_clicked(self):
         """
         Private slot to handle the IDL compiler selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select IDL compiler"),
             self.idlEdit.text(),
-            QString())
-            
-        if not file.isNull():
+            "")
+        
+        if file:
             self.idlEdit.setText(Utilities.toNativeSeparators(file))
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = CorbaPage()
     return page
