@@ -9,21 +9,21 @@ Module implementing the Debugger General configuration page.
 
 import socket
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4.QtNetwork import *
+from PyQt4.QtCore import QRegExp, pyqtSlot
+from PyQt4.QtGui import QLineEdit, QInputDialog
+from PyQt4.QtNetwork import QNetworkInterface, QAbstractSocket, QHostAddress
 
-from KdeQt import KQInputDialog, KQMessageBox
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
+from E5Gui import E5MessageBox
 
-from E4Gui.E4Completers import E4FileCompleter, E4DirCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_DebuggerGeneralPage import Ui_DebuggerGeneralPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_DebuggerGeneralPage import Ui_DebuggerGeneralPage
 
 import Preferences
 import Utilities
 
+
 class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
     """
     Class implementing the Debugger General configuration page.
@@ -32,42 +32,45 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("DebuggerGeneralPage")
         
         t = self.execLineEdit.whatsThis()
-        if not t.isEmpty():
-            t.append(Utilities.getPercentReplacementHelp())
+        if t:
+            t += Utilities.getPercentReplacementHelp()
             self.execLineEdit.setWhatsThis(t)
         
         try:
-            backends = e4App().getObject("DebugServer").getSupportedLanguages()
+            backends = e5App().getObject("DebugServer").getSupportedLanguages()
             for backend in sorted(backends):
                 self.passiveDbgBackendCombo.addItem(backend)
         except KeyError:
             self.passiveDbgGroup.setEnabled(False)
         
         t = self.consoleDbgEdit.whatsThis()
-        if not t.isEmpty():
-            t.append(Utilities.getPercentReplacementHelp())
+        if t:
+            t += Utilities.getPercentReplacementHelp()
             self.consoleDbgEdit.setWhatsThis(t)
         
-        self.consoleDbgCompleter = E4FileCompleter(self.consoleDbgEdit)
-        self.dbgTranslationLocalCompleter = E4DirCompleter(self.dbgTranslationLocalEdit)
+        self.consoleDbgCompleter = E5FileCompleter(self.consoleDbgEdit)
+        self.dbgTranslationLocalCompleter = E5DirCompleter(
+            self.dbgTranslationLocalEdit)
         
         # set initial values
-        interfaces = QStringList()
+        interfaces = []
         networkInterfaces = QNetworkInterface.allInterfaces()
         for networkInterface in networkInterfaces:
             addressEntries = networkInterface.addressEntries()
             if len(addressEntries) > 0:
                 for addressEntry in addressEntries:
-                    if ":" in addressEntry.ip().toString() and not socket.has_ipv6:
+                    if ":" in addressEntry.ip().toString() and \
+                            not socket.has_ipv6:
                         continue    # IPv6 not supported by Python
-                    interfaces.append(QString("%1 (%2)")\
-                                      .arg(networkInterface.name())\
-                                      .arg(addressEntry.ip().toString()))
+                    interfaces.append(
+                        "{0} ({1})".format(
+                            networkInterface.humanReadableName(),
+                            addressEntry.ip().toString()))
         self.interfacesCombo.addItems(interfaces)
         interface = Preferences.getDebugger("NetworkInterface")
         if not socket.has_ipv6:
@@ -81,23 +84,28 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
             self.all6InterfacesButton.setChecked(True)
         else:
             self.selectedInterfaceButton.setChecked(True)
-            index = interfaces.indexOf(QRegExp(QString(".*%1.*").arg(interface)))
+            index = -1
+            for i in range(len(interfaces)):
+                if QRegExp(".*{0}.*".format(interface))\
+                        .exactMatch(interfaces[i]):
+                    index = i
+                    break
             self.interfacesCombo.setCurrentIndex(index)
         
-        self.allowedHostsList.addItems(\
+        self.allowedHostsList.addItems(
             Preferences.getDebugger("AllowedHosts"))
         
-        self.remoteCheckBox.setChecked(\
+        self.remoteCheckBox.setChecked(
             Preferences.getDebugger("RemoteDbgEnabled"))
-        self.hostLineEdit.setText(\
+        self.hostLineEdit.setText(
             Preferences.getDebugger("RemoteHost"))
-        self.execLineEdit.setText(\
+        self.execLineEdit.setText(
             Preferences.getDebugger("RemoteExecution"))
         
         if self.passiveDbgGroup.isEnabled():
-            self.passiveDbgCheckBox.setChecked(\
+            self.passiveDbgCheckBox.setChecked(
                 Preferences.getDebugger("PassiveDbgEnabled"))
-            self.passiveDbgPortSpinBox.setValue(\
+            self.passiveDbgPortSpinBox.setValue(
                 Preferences.getDebugger("PassiveDbgPort"))
             index = self.passiveDbgBackendCombo.findText(
                 Preferences.getDebugger("PassiveDbgType"))
@@ -105,49 +113,55 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
                 index = 0
             self.passiveDbgBackendCombo.setCurrentIndex(index)
         
-        self.debugEnvironReplaceCheckBox.setChecked(\
+        self.debugEnvironReplaceCheckBox.setChecked(
             Preferences.getDebugger("DebugEnvironmentReplace"))
-        self.debugEnvironEdit.setText(\
+        self.debugEnvironEdit.setText(
             Preferences.getDebugger("DebugEnvironment"))
-        self.automaticResetCheckBox.setChecked(\
+        self.automaticResetCheckBox.setChecked(
             Preferences.getDebugger("AutomaticReset"))
-        self.debugAutoSaveScriptsCheckBox.setChecked(\
+        self.debugAutoSaveScriptsCheckBox.setChecked(
             Preferences.getDebugger("Autosave"))
-        self.consoleDbgCheckBox.setChecked(\
+        self.consoleDbgCheckBox.setChecked(
             Preferences.getDebugger("ConsoleDbgEnabled"))
-        self.consoleDbgEdit.setText(\
+        self.consoleDbgEdit.setText(
             Preferences.getDebugger("ConsoleDbgCommand"))
-        self.dbgPathTranslationCheckBox.setChecked(\
+        self.dbgPathTranslationCheckBox.setChecked(
             Preferences.getDebugger("PathTranslation"))
-        self.dbgTranslationRemoteEdit.setText(\
+        self.dbgTranslationRemoteEdit.setText(
             Preferences.getDebugger("PathTranslationRemote"))
-        self.dbgTranslationLocalEdit.setText(\
+        self.dbgTranslationLocalEdit.setText(
             Preferences.getDebugger("PathTranslationLocal"))
-        self.debugThreeStateBreakPoint.setChecked(\
+        self.debugThreeStateBreakPoint.setChecked(
             Preferences.getDebugger("ThreeStateBreakPoints"))
-        self.dontShowClientExitCheckBox.setChecked(\
+        self.dontShowClientExitCheckBox.setChecked(
             Preferences.getDebugger("SuppressClientExit"))
-        self.exceptionBreakCheckBox.setChecked(\
+        self.exceptionBreakCheckBox.setChecked(
             Preferences.getDebugger("BreakAlways"))
-        self.autoViewSourcecodeCheckBox.setChecked(\
+        self.autoViewSourcecodeCheckBox.setChecked(
             Preferences.getDebugger("AutoViewSourceCode"))
         
     def save(self):
         """
         Public slot to save the Debugger General (1) configuration.
         """
-        Preferences.setDebugger("RemoteDbgEnabled", 
-            int(self.remoteCheckBox.isChecked()))
-        Preferences.setDebugger("RemoteHost", 
+        Preferences.setDebugger(
+            "RemoteDbgEnabled",
+            self.remoteCheckBox.isChecked())
+        Preferences.setDebugger(
+            "RemoteHost",
             self.hostLineEdit.text())
-        Preferences.setDebugger("RemoteExecution", 
+        Preferences.setDebugger(
+            "RemoteExecution",
             self.execLineEdit.text())
         
-        Preferences.setDebugger("PassiveDbgEnabled", 
-            int(self.passiveDbgCheckBox.isChecked()))
-        Preferences.setDebugger("PassiveDbgPort", 
+        Preferences.setDebugger(
+            "PassiveDbgEnabled",
+            self.passiveDbgCheckBox.isChecked())
+        Preferences.setDebugger(
+            "PassiveDbgPort",
             self.passiveDbgPortSpinBox.value())
-        Preferences.setDebugger("PassiveDbgType", 
+        Preferences.setDebugger(
+            "PassiveDbgType",
             self.passiveDbgBackendCombo.currentText())
         
         if self.allInterfacesButton.isChecked():
@@ -156,43 +170,56 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
             Preferences.setDebugger("NetworkInterface", "allv6")
         else:
             interface = self.interfacesCombo.currentText()
-            interface = interface.section("(", 1, 1).section(")", 0, 0)
-            if interface.isEmpty():
+            interface = interface.split("(")[1].split(")")[0]
+            if not interface:
                 Preferences.setDebugger("NetworkInterface", "all")
             else:
                 Preferences.setDebugger("NetworkInterface", interface)
         
-        allowedHosts = QStringList()
+        allowedHosts = []
         for row in range(self.allowedHostsList.count()):
             allowedHosts.append(self.allowedHostsList.item(row).text())
         Preferences.setDebugger("AllowedHosts", allowedHosts)
         
-        Preferences.setDebugger("DebugEnvironmentReplace", 
-            int(self.debugEnvironReplaceCheckBox.isChecked()))
-        Preferences.setDebugger("DebugEnvironment", 
+        Preferences.setDebugger(
+            "DebugEnvironmentReplace",
+            self.debugEnvironReplaceCheckBox.isChecked())
+        Preferences.setDebugger(
+            "DebugEnvironment",
             self.debugEnvironEdit.text())
-        Preferences.setDebugger("AutomaticReset", 
-            int(self.automaticResetCheckBox.isChecked()))
-        Preferences.setDebugger("Autosave", 
-            int(self.debugAutoSaveScriptsCheckBox.isChecked()))
-        Preferences.setDebugger("ConsoleDbgEnabled", 
-            int(self.consoleDbgCheckBox.isChecked()))
-        Preferences.setDebugger("ConsoleDbgCommand", 
+        Preferences.setDebugger(
+            "AutomaticReset",
+            self.automaticResetCheckBox.isChecked())
+        Preferences.setDebugger(
+            "Autosave",
+            self.debugAutoSaveScriptsCheckBox.isChecked())
+        Preferences.setDebugger(
+            "ConsoleDbgEnabled",
+            self.consoleDbgCheckBox.isChecked())
+        Preferences.setDebugger(
+            "ConsoleDbgCommand",
             self.consoleDbgEdit.text())
-        Preferences.setDebugger("PathTranslation", 
-            int(self.dbgPathTranslationCheckBox.isChecked()))
-        Preferences.setDebugger("PathTranslationRemote",
-            unicode(self.dbgTranslationRemoteEdit.text()))
-        Preferences.setDebugger("PathTranslationLocal",
-            unicode(self.dbgTranslationLocalEdit.text()))
-        Preferences.setDebugger("ThreeStateBreakPoints",
-            int(self.debugThreeStateBreakPoint.isChecked()))
-        Preferences.setDebugger("SuppressClientExit",
-            int(self.dontShowClientExitCheckBox.isChecked()))
-        Preferences.setDebugger("BreakAlways",
-            int(self.exceptionBreakCheckBox.isChecked()))
-        Preferences.setDebugger("AutoViewSourceCode",
-            int(self.autoViewSourcecodeCheckBox.isChecked()))
+        Preferences.setDebugger(
+            "PathTranslation",
+            self.dbgPathTranslationCheckBox.isChecked())
+        Preferences.setDebugger(
+            "PathTranslationRemote",
+            self.dbgTranslationRemoteEdit.text())
+        Preferences.setDebugger(
+            "PathTranslationLocal",
+            self.dbgTranslationLocalEdit.text())
+        Preferences.setDebugger(
+            "ThreeStateBreakPoints",
+            self.debugThreeStateBreakPoint.isChecked())
+        Preferences.setDebugger(
+            "SuppressClientExit",
+            self.dontShowClientExitCheckBox.isChecked())
+        Preferences.setDebugger(
+            "BreakAlways",
+            self.exceptionBreakCheckBox.isChecked())
+        Preferences.setDebugger(
+            "AutoViewSourceCode",
+            self.autoViewSourcecodeCheckBox.isChecked())
         
     def on_allowedHostsList_currentItemChanged(self, current, previous):
         """
@@ -204,62 +231,70 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
         self.editAllowedHostButton.setEnabled(current is not None)
         self.deleteAllowedHostButton.setEnabled(current is not None)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addAllowedHostButton_clicked(self):
         """
         Private slot called to add a new allowed host.
         """
-        allowedHost, ok = KQInputDialog.getText(\
+        allowedHost, ok = QInputDialog.getText(
             None,
             self.trUtf8("Add allowed host"),
             self.trUtf8("Enter the IP address of an allowed host"),
             QLineEdit.Normal)
-        if ok and not allowedHost.isEmpty():
+        if ok and allowedHost:
             if QHostAddress(allowedHost).protocol() in \
                [QAbstractSocket.IPv4Protocol, QAbstractSocket.IPv6Protocol]:
                 self.allowedHostsList.addItem(allowedHost)
             else:
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Add allowed host"),
-                    self.trUtf8("""<p>The entered address <b>%1</b> is not"""
-                        """ a valid IP v4 or IP v6 address. Aborting...</p>""")\
-                        .arg(allowedHost))
+                    self.trUtf8(
+                        """<p>The entered address <b>{0}</b> is not"""
+                        """ a valid IP v4 or IP v6 address."""
+                        """ Aborting...</p>""")
+                    .format(allowedHost))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteAllowedHostButton_clicked(self):
         """
         Private slot called to delete an allowed host.
         """
         self.allowedHostsList.takeItem(self.allowedHostsList.currentRow())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_editAllowedHostButton_clicked(self):
         """
         Private slot called to edit an allowed host.
         """
         allowedHost = self.allowedHostsList.currentItem().text()
-        allowedHost, ok = KQInputDialog.getText(\
+        allowedHost, ok = QInputDialog.getText(
             None,
             self.trUtf8("Edit allowed host"),
             self.trUtf8("Enter the IP address of an allowed host"),
             QLineEdit.Normal,
             allowedHost)
-        if ok and not allowedHost.isEmpty():
+        if ok and allowedHost:
             if QHostAddress(allowedHost).protocol() in \
                [QAbstractSocket.IPv4Protocol, QAbstractSocket.IPv6Protocol]:
                 self.allowedHostsList.currentItem().setText(allowedHost)
             else:
-                KQMessageBox.critical(None,
+                E5MessageBox.critical(
+                    self,
                     self.trUtf8("Edit allowed host"),
-                    self.trUtf8("""<p>The entered address <b>%1</b> is not"""
-                        """ a valid IP v4 or IP v6 address. Aborting...</p>""")\
-                        .arg(allowedHost))
+                    self.trUtf8(
+                        """<p>The entered address <b>{0}</b> is not"""
+                        """ a valid IP v4 or IP v6 address."""
+                        """ Aborting...</p>""")
+                    .format(allowedHost))
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = DebuggerGeneralPage()
     return page
