@@ -7,18 +7,18 @@
 Module implementing the Debugger Python3 configuration page.
 """
 
-from PyQt4.QtCore import QDir, QString, pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_DebuggerPython3Page import Ui_DebuggerPython3Page
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_DebuggerPython3Page import Ui_DebuggerPython3Page
 
 import Preferences
 import Utilities
 
+
 class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
     """
     Class implementing the Debugger Python3 configuration page.
@@ -27,15 +27,17 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("DebuggerPython3Page")
         
-        self.interpreterCompleter = E4FileCompleter(self.interpreterEdit)
-        self.debugClientCompleter = E4FileCompleter(self.debugClientEdit)
+        self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
+        self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
         
         # set initial values
-        self.interpreterEdit.setText(\
+        self.customPyCheckBox.setChecked(
+            Preferences.getDebugger("CustomPython3Interpreter"))
+        self.interpreterEdit.setText(
             Preferences.getDebugger("Python3Interpreter"))
         dct = Preferences.getDebugger("DebugClientType3")
         if dct == "standard":
@@ -57,7 +59,11 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         """
         Public slot to save the Debugger Python configuration.
         """
-        Preferences.setDebugger("Python3Interpreter", 
+        Preferences.setDebugger(
+            "CustomPython3Interpreter",
+            self.customPyCheckBox.isChecked())
+        Preferences.setDebugger(
+            "Python3Interpreter",
             self.interpreterEdit.text())
         if self.standardButton.isChecked():
             dct = "standard"
@@ -66,50 +72,56 @@ class DebuggerPython3Page(ConfigurationPageBase, Ui_DebuggerPython3Page):
         else:
             dct = "custom"
         Preferences.setDebugger("DebugClientType3", dct)
-        Preferences.setDebugger("DebugClient3", 
+        Preferences.setDebugger(
+            "DebugClient3",
             self.debugClientEdit.text())
-        Preferences.setDebugger("Python3Redirect", 
-            int(self.pyRedirectCheckBox.isChecked()))
-        Preferences.setDebugger("Python3NoEncoding", 
-            int(self.pyNoEncodingCheckBox.isChecked()))
-        Preferences.setDebugger("Python3Extensions", 
+        Preferences.setDebugger(
+            "Python3Redirect",
+            self.pyRedirectCheckBox.isChecked())
+        Preferences.setDebugger(
+            "Python3NoEncoding",
+            self.pyNoEncodingCheckBox.isChecked())
+        Preferences.setDebugger(
+            "Python3Extensions",
             self.sourceExtensionsEdit.text())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_interpreterButton_clicked(self):
         """
         Private slot to handle the Python interpreter selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select Python interpreter for Debug Client"),
             self.interpreterEdit.text(),
-            QString())
+            "")
             
-        if not file.isEmpty():
-            self.interpreterEdit.setText(\
+        if file:
+            self.interpreterEdit.setText(
                 Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_debugClientButton_clicked(self):
         """
         Private slot to handle the Debug Client selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             None,
             self.trUtf8("Select Debug Client"),
             self.debugClientEdit.text(),
             self.trUtf8("Python Files (*.py *.py3)"))
             
-        if not file.isEmpty():
-            self.debugClientEdit.setText(\
+        if file:
+            self.debugClientEdit.setText(
                 Utilities.toNativeSeparators(file))
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = DebuggerPython3Page()
     return page
