@@ -7,18 +7,18 @@
 Module implementing the Debugger Python configuration page.
 """
 
-from PyQt4.QtCore import QDir, QString, pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_DebuggerPythonPage import Ui_DebuggerPythonPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_DebuggerPythonPage import Ui_DebuggerPythonPage
 
 import Preferences
 import Utilities
 
+
 class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
     """
     Class implementing the Debugger Python configuration page.
@@ -27,17 +27,15 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("DebuggerPythonPage")
         
-        self.interpreterCompleter = E4FileCompleter(self.interpreterEdit)
-        self.debugClientCompleter = E4FileCompleter(self.debugClientEdit)
+        self.interpreterCompleter = E5FileCompleter(self.interpreterEdit)
+        self.debugClientCompleter = E5FileCompleter(self.debugClientEdit)
         
         # set initial values
-        self.customPyCheckBox.setChecked(\
-            Preferences.getDebugger("CustomPythonInterpreter"))
-        self.interpreterEdit.setText(\
+        self.interpreterEdit.setText(
             Preferences.getDebugger("PythonInterpreter"))
         dct = Preferences.getDebugger("DebugClientType")
         if dct == "standard":
@@ -46,11 +44,11 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
             self.threadedButton.setChecked(True)
         else:
             self.customButton.setChecked(True)
-        self.debugClientEdit.setText(\
+        self.debugClientEdit.setText(
             Preferences.getDebugger("DebugClient"))
-        self.pyRedirectCheckBox.setChecked(\
+        self.pyRedirectCheckBox.setChecked(
             Preferences.getDebugger("PythonRedirect"))
-        self.pyNoEncodingCheckBox.setChecked(\
+        self.pyNoEncodingCheckBox.setChecked(
             Preferences.getDebugger("PythonNoEncoding"))
         self.sourceExtensionsEdit.setText(
             Preferences.getDebugger("PythonExtensions"))
@@ -59,9 +57,8 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         """
         Public slot to save the Debugger Python configuration.
         """
-        Preferences.setDebugger("CustomPythonInterpreter", 
-            int(self.customPyCheckBox.isChecked()))
-        Preferences.setDebugger("PythonInterpreter", 
+        Preferences.setDebugger(
+            "PythonInterpreter",
             self.interpreterEdit.text())
         if self.standardButton.isChecked():
             dct = "standard"
@@ -70,50 +67,56 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
         else:
             dct = "custom"
         Preferences.setDebugger("DebugClientType", dct)
-        Preferences.setDebugger("DebugClient", 
+        Preferences.setDebugger(
+            "DebugClient",
             self.debugClientEdit.text())
-        Preferences.setDebugger("PythonRedirect", 
-            int(self.pyRedirectCheckBox.isChecked()))
-        Preferences.setDebugger("PythonNoEncoding", 
-            int(self.pyNoEncodingCheckBox.isChecked()))
-        Preferences.setDebugger("PythonExtensions", 
+        Preferences.setDebugger(
+            "PythonRedirect",
+            self.pyRedirectCheckBox.isChecked())
+        Preferences.setDebugger(
+            "PythonNoEncoding",
+            self.pyNoEncodingCheckBox.isChecked())
+        Preferences.setDebugger(
+            "PythonExtensions",
             self.sourceExtensionsEdit.text())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_interpreterButton_clicked(self):
         """
         Private slot to handle the Python interpreter selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select Python interpreter for Debug Client"),
             self.interpreterEdit.text(),
-            QString())
+            "")
             
-        if not file.isEmpty():
-            self.interpreterEdit.setText(\
+        if file:
+            self.interpreterEdit.setText(
                 Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_debugClientButton_clicked(self):
         """
         Private slot to handle the Debug Client selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             None,
             self.trUtf8("Select Debug Client"),
             self.debugClientEdit.text(),
-            self.trUtf8("Python Files (*.py)"))
+            self.trUtf8("Python Files (*.py *.py2)"))
             
-        if not file.isEmpty():
-            self.debugClientEdit.setText(\
+        if file:
+            self.debugClientEdit.setText(
                 Utilities.toNativeSeparators(file))
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = DebuggerPythonPage()
     return page
