@@ -9,12 +9,13 @@ Module implementing the QScintilla Calltips configuration page.
 
 from PyQt4.Qsci import QsciScintilla
 
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_EditorCalltipsQScintillaPage import Ui_EditorCalltipsQScintillaPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_EditorCalltipsQScintillaPage import Ui_EditorCalltipsQScintillaPage
 
 import Preferences
 
-class EditorCalltipsQScintillaPage(ConfigurationPageBase, 
+
+class EditorCalltipsQScintillaPage(ConfigurationPageBase,
                                    Ui_EditorCalltipsQScintillaPage):
     """
     Class implementing the QScintilla Calltips configuration page.
@@ -23,7 +24,7 @@ class EditorCalltipsQScintillaPage(ConfigurationPageBase,
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("EditorCalltipsQScintillaPage")
         
@@ -41,20 +42,22 @@ class EditorCalltipsQScintillaPage(ConfigurationPageBase,
         Public slot to save the EditorCalltips configuration.
         """
         if self.ctNoContextButton.isChecked():
-            Preferences.setEditor("CallTipsStyle", 
-                                  QsciScintilla.CallTipsNoContext)
+            Preferences.setEditor(
+                "CallTipsStyle", QsciScintilla.CallTipsNoContext)
         elif self.ctNoAutoCompletionButton.isChecked():
-            Preferences.setEditor("CallTipsStyle", 
-                                  QsciScintilla.CallTipsNoAutoCompletionContext)
+            Preferences.setEditor(
+                "CallTipsStyle", QsciScintilla.CallTipsNoAutoCompletionContext)
         elif self.ctContextButton.isChecked():
-            Preferences.setEditor("CallTipsStyle", 
-                                  QsciScintilla.CallTipsContext)
+            Preferences.setEditor(
+                "CallTipsStyle", QsciScintilla.CallTipsContext)
+
 
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = EditorCalltipsQScintillaPage()
     return page
