@@ -11,14 +11,15 @@ import os
 
 from pygments.lexers import get_all_lexers
 
-from PyQt4.QtCore import Qt, QStringList, pyqtSignature, QString
+from PyQt4.QtCore import Qt, pyqtSlot, qVersion
 from PyQt4.QtGui import QHeaderView, QTreeWidgetItem
 
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_EditorHighlightersPage import Ui_EditorHighlightersPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_EditorHighlightersPage import Ui_EditorHighlightersPage
 
 import Preferences
 
+
 class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
     """
     Class implementing the Editor Highlighter Associations configuration page.
@@ -29,13 +30,17 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         
         @param lexers reference to the lexers dictionary
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("EditorHighlightersPage")
         
-        self.editorLexerList.headerItem().setText(self.editorLexerList.columnCount(), "")
+        self.editorLexerList.headerItem().setText(
+            self.editorLexerList.columnCount(), "")
         header = self.editorLexerList.header()
-        header.setResizeMode(QHeaderView.ResizeToContents)
+        if qVersion() >= "5.0.0":
+            header.setSectionResizeMode(QHeaderView.ResizeToContents)
+        else:
+            header.setResizeMode(QHeaderView.ResizeToContents)
         header.setSortIndicator(0, Qt.AscendingOrder)
         
         try:
@@ -45,18 +50,15 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         
         self.extras = ["-----------", self.trUtf8("Alternative")]
         languages = [''] + sorted(lexers.keys()) + self.extras
-        for lang in languages:
-            self.editorLexerCombo.addItem(lang)
+        self.editorLexerCombo.addItems(languages)
         
         pygmentsLexers = [''] + sorted([l[0] for l in get_all_lexers()])
-        for pygmentsLexer in pygmentsLexers:
-            self.pygmentsLexerCombo.addItem(pygmentsLexer)
+        self.pygmentsLexerCombo.addItems(pygmentsLexers)
         
         # set initial values
         lexerAssocs = Preferences.getEditorLexerAssocs()
-        for ext in lexerAssocs.keys():
-            QTreeWidgetItem(self.editorLexerList, 
-                QStringList() << ext << lexerAssocs[ext])
+        for ext in lexerAssocs:
+            QTreeWidgetItem(self.editorLexerList, [ext, lexerAssocs[ext]])
         self.editorLexerList.sortByColumn(0, Qt.AscendingOrder)
         
     def save(self):
@@ -64,51 +66,51 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         Public slot to save the Editor Highlighter Associations configuration.
         """
         lexerAssocs = {}
-        for index in range(\
-            self.editorLexerList.topLevelItemCount()):
+        for index in range(
+                self.editorLexerList.topLevelItemCount()):
             itm = self.editorLexerList.topLevelItem(index)
-            lexerAssocs[unicode(itm.text(0))] = unicode(itm.text(1))
+            lexerAssocs[itm.text(0)] = itm.text(1)
         Preferences.setEditorLexerAssocs(lexerAssocs)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addLexerButton_clicked(self):
         """
         Private slot to add the lexer association displayed to the list.
         """
         ext = self.editorFileExtEdit.text()
-        if ext.startsWith(self.extsep):
+        if ext.startswith(self.extsep):
             ext.replace(self.extsep, "")
         lexer = self.editorLexerCombo.currentText()
         if lexer in self.extras:
             pygmentsLexer = self.pygmentsLexerCombo.currentText()
-            if pygmentsLexer.isEmpty():
+            if not pygmentsLexer:
                 lexer = pygmentsLexer
             else:
-                lexer = QString("Pygments|%1").arg(pygmentsLexer)
-        if not ext.isEmpty() and not lexer.isEmpty():
-            itmList = self.editorLexerList.findItems(\
+                lexer = "Pygments|{0}".format(pygmentsLexer)
+        if ext and lexer:
+            itmList = self.editorLexerList.findItems(
                 ext, Qt.MatchFlags(Qt.MatchExactly), 0)
             if itmList:
                 index = self.editorLexerList.indexOfTopLevelItem(itmList[0])
                 itm = self.editorLexerList.takeTopLevelItem(index)
                 del itm
-            itm = QTreeWidgetItem(self.editorLexerList, 
-                QStringList() << ext << lexer)
+            QTreeWidgetItem(self.editorLexerList, [ext, lexer])
             self.editorFileExtEdit.clear()
             self.editorLexerCombo.setCurrentIndex(0)
             self.pygmentsLexerCombo.setCurrentIndex(0)
-            self.editorLexerList.sortItems(self.editorLexerList.sortColumn(), 
+            self.editorLexerList.sortItems(
+                self.editorLexerList.sortColumn(),
                 self.editorLexerList.header().sortIndicatorOrder())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteLexerButton_clicked(self):
         """
-        Private slot to delete the currently selected lexer association of the list.
+        Private slot to delete the currently selected lexer association of the
+        list.
         """
         itmList = self.editorLexerList.selectedItems()
         if itmList:
-            index = self.editorLexerList.indexOfTopLevelItem(\
-                        itmList[0])
+            index = self.editorLexerList.indexOfTopLevelItem(itmList[0])
             itm = self.editorLexerList.takeTopLevelItem(index)
             del itm
             
@@ -118,10 +120,12 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         
     def on_editorLexerList_itemClicked(self, itm, column):
         """
-        Private slot to handle the clicked signal of the lexer association list.
+        Private slot to handle the clicked signal of the lexer association
+        list.
         
         @param itm reference to the selecte item (QTreeWidgetItem)
-        @param column column the item was clicked or activated (integer) (ignored)
+        @param column column the item was clicked or activated (integer)
+            (ignored)
         """
         if itm is None:
             self.editorFileExtEdit.clear()
@@ -130,8 +134,8 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         else:
             self.editorFileExtEdit.setText(itm.text(0))
             lexer = itm.text(1)
-            if lexer.startsWith("Pygments|"):
-                pygmentsLexer = lexer.section("|", 1)
+            if lexer.startswith("Pygments|"):
+                pygmentsLexer = lexer.split("|")[1]
                 pygmentsIndex = self.pygmentsLexerCombo.findText(pygmentsLexer)
                 lexer = self.trUtf8("Alternative")
             else:
@@ -142,17 +146,21 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
         
     def on_editorLexerList_itemActivated(self, itm, column):
         """
-        Private slot to handle the activated signal of the lexer association list.
+        Private slot to handle the activated signal of the lexer association
+        list.
         
         @param itm reference to the selecte item (QTreeWidgetItem)
-        @param column column the item was clicked or activated (integer) (ignored)
+        @param column column the item was clicked or activated (integer)
+            (ignored)
         """
         self.on_editorLexerList_itemClicked(itm, column)
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_editorLexerCombo_currentIndexChanged(self, text):
         """
         Private slot to handle the selection of a lexer.
+        
+        @param text text of the lexer combo (string)
         """
         if text in self.extras:
             self.pygmentsLexerCombo.setEnabled(True)
@@ -161,11 +169,13 @@ class EditorHighlightersPage(ConfigurationPageBase, Ui_EditorHighlightersPage):
             self.pygmentsLexerCombo.setEnabled(False)
             self.pygmentsLabel.setEnabled(False)
 
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = EditorHighlightersPage(dlg.getLexers())
     return page
