@@ -7,33 +7,27 @@
 Module implementing the Editor Highlighting Styles configuration page.
 """
 
-import os
-import cStringIO
+from PyQt4.QtCore import pyqtSlot, Qt, QFileInfo, QFile, QIODevice
+from PyQt4.QtGui import QPalette, QColorDialog, QFontDialog, \
+    QInputDialog, QFont, QMenu
 
-from PyQt4.QtCore import QString, QStringList, pyqtSignature, QFileInfo, QVariant
-from PyQt4.QtGui import QPalette, QFileDialog, QMenu, QFont
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
 
-from KdeQt import KQColorDialog, KQFontDialog, KQInputDialog, KQFileDialog, KQMessageBox
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_EditorHighlightingStylesPage import Ui_EditorHighlightingStylesPage
-
-from E4XML.XMLUtilities import make_parser
-from E4XML.XMLErrorHandler import XMLErrorHandler, XMLFatalParseError
-from E4XML.XMLEntityResolver import XMLEntityResolver
-from E4XML.HighlightingStylesWriter import HighlightingStylesWriter
-from E4XML.HighlightingStylesHandler import HighlightingStylesHandler
+from E5Gui import E5MessageBox, E5FileDialog
 
 import Preferences
 
-class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingStylesPage):
+
+class EditorHighlightingStylesPage(ConfigurationPageBase,
+                                   Ui_EditorHighlightingStylesPage):
     """
     Class implementing the Editor Highlighting Styles configuration page.
     """
-    FAMILYONLY    = 0
-    SIZEONLY      = 1
+    FAMILYONLY = 0
+    SIZEONLY = 1
     FAMILYANDSIZE = 2
-    FONT          = 99
+    FONT = 99
     
     def __init__(self, lexers):
         """
@@ -41,79 +35,101 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         
         @param lexers reference to the lexers dictionary
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("EditorHighlightingStylesPage")
         
         self.__fontButtonMenu = QMenu()
         act = self.__fontButtonMenu.addAction(self.trUtf8("Font"))
-        act.setData(QVariant(self.FONT))
+        act.setData(self.FONT)
         self.__fontButtonMenu.addSeparator()
-        act = self.__fontButtonMenu.addAction(self.trUtf8("Family and Size only"))
-        act.setData(QVariant(self.FAMILYANDSIZE))
+        act = self.__fontButtonMenu.addAction(
+            self.trUtf8("Family and Size only"))
+        act.setData(self.FAMILYANDSIZE)
         act = self.__fontButtonMenu.addAction(self.trUtf8("Family only"))
-        act.setData(QVariant(self.FAMILYONLY))
+        act.setData(self.FAMILYONLY)
         act = self.__fontButtonMenu.addAction(self.trUtf8("Size only"))
-        act.setData(QVariant(self.SIZEONLY))
+        act.setData(self.SIZEONLY)
         self.__fontButtonMenu.triggered.connect(self.__fontButtonMenuTriggered)
         self.fontButton.setMenu(self.__fontButtonMenu)
         
         self.__allFontsButtonMenu = QMenu()
         act = self.__allFontsButtonMenu.addAction(self.trUtf8("Font"))
-        act.setData(QVariant(self.FONT))
+        act.setData(self.FONT)
         self.__allFontsButtonMenu.addSeparator()
-        act = self.__allFontsButtonMenu.addAction(self.trUtf8("Family and Size only"))
-        act.setData(QVariant(self.FAMILYANDSIZE))
+        act = self.__allFontsButtonMenu.addAction(
+            self.trUtf8("Family and Size only"))
+        act.setData(self.FAMILYANDSIZE)
         act = self.__allFontsButtonMenu.addAction(self.trUtf8("Family only"))
-        act.setData(QVariant(self.FAMILYONLY))
+        act.setData(self.FAMILYONLY)
         act = self.__allFontsButtonMenu.addAction(self.trUtf8("Size only"))
-        act.setData(QVariant(self.SIZEONLY))
-        self.__allFontsButtonMenu.triggered.connect(self.__allFontsButtonMenuTriggered)
+        act.setData(self.SIZEONLY)
+        self.__allFontsButtonMenu.triggered.connect(
+            self.__allFontsButtonMenuTriggered)
         self.allFontsButton.setMenu(self.__allFontsButtonMenu)
         
         self.lexer = None
         self.lexers = lexers
         
         # set initial values
-        languages = [''] + self.lexers.keys()
-        languages.sort()
-        for lang in languages:
-            self.lexerLanguageComboBox.addItem(lang)
-        self.on_lexerLanguageComboBox_activated(QString(''))
+        languages = sorted([''] + list(self.lexers.keys()))
+        self.lexerLanguageComboBox.addItems(languages)
+        self.on_lexerLanguageComboBox_activated("")
         
     def save(self):
         """
         Public slot to save the Editor Highlighting Styles configuration.
         """
-        for lexer in self.lexers.values():
+        for lexer in list(self.lexers.values()):
             lexer.writeSettings(Preferences.Prefs.settings, "Scintilla")
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_lexerLanguageComboBox_activated(self, language):
         """
         Private slot to fill the style combo of the source page.
         
-        @param language The lexer language (string or QString)
+        @param language The lexer language (string)
         """
         self.styleElementList.clear()
         self.styleGroup.setEnabled(False)
         self.lexer = None
         
-        self.exportCurrentButton.setEnabled(not language.isEmpty())
-        self.importCurrentButton.setEnabled(not language.isEmpty())
+        self.exportCurrentButton.setEnabled(language != "")
+        self.importCurrentButton.setEnabled(language != "")
         
-        if language.isEmpty():
+        if not language:
             return
         
         try:
-            self.lexer = self.lexers[unicode(language)]
+            self.lexer = self.lexers[language]
         except KeyError:
             return
         
         self.styleGroup.setEnabled(True)
         self.styleElementList.addItems(self.lexer.styles)
+        self.__styleAllItems()
         self.styleElementList.setCurrentRow(0)
         
+    def __styleAllItems(self):
+        """
+        Private method to style all items of the style element list.
+        """
+        for row in range(self.styleElementList.count()):
+            style = self.lexer.ind2style[row]
+            colour = self.lexer.color(style)
+            paper = self.lexer.paper(style)
+            font = self.lexer.font(style)
+            eolfill = self.lexer.eolFill(style)
+            
+            itm = self.styleElementList.item(row)
+            itm.setFont(font)
+            itm.setBackground(paper)
+            itm.setForeground(colour)
+            if eolfill:
+                itm.setCheckState(Qt.Checked)
+            else:
+                itm.setCheckState(Qt.Unchecked)
+        
     def on_styleElementList_currentRowChanged(self, index):
         """
         Private method to set up the style element part of the source page.
@@ -138,13 +154,13 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         self.sampleText.repaint()
         self.eolfillCheckBox.setChecked(eolfill)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_foregroundButton_clicked(self):
         """
-        Private method used to select the foreground colour of the selected style 
-        and lexer.
+        Private method used to select the foreground colour of the selected
+        style and lexer.
         """
-        colour = KQColorDialog.getColor(self.lexer.color(self.style))
+        colour = QColorDialog.getColor(self.lexer.color(self.style))
         if colour.isValid():
             pl = self.sampleText.palette()
             pl.setColor(QPalette.Text, colour)
@@ -152,18 +168,21 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             self.sampleText.repaint()
             if len(self.styleElementList.selectedItems()) > 1:
                 for selItem in self.styleElementList.selectedItems():
-                    style = self.lexer.ind2style[self.styleElementList.row(selItem)]
+                    style = self.lexer.ind2style[
+                        self.styleElementList.row(selItem)]
                     self.lexer.setColor(colour, style)
+                    selItem.setForeground(colour)
             else:
                 self.lexer.setColor(colour, self.style)
+                self.styleElementList.currentItem().setForeground(colour)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_backgroundButton_clicked(self):
         """
-        Private method used to select the background colour of the selected style 
-        and lexer.
+        Private method used to select the background colour of the selected
+        style and lexer.
         """
-        colour = KQColorDialog.getColor(self.lexer.paper(self.style))
+        colour = QColorDialog.getColor(self.lexer.paper(self.style))
         if colour.isValid():
             pl = self.sampleText.palette()
             pl.setColor(QPalette.Base, colour)
@@ -171,31 +190,36 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             self.sampleText.repaint()
             if len(self.styleElementList.selectedItems()) > 1:
                 for selItem in self.styleElementList.selectedItems():
-                    style = self.lexer.ind2style[self.styleElementList.row(selItem)]
+                    style = self.lexer.ind2style[
+                        self.styleElementList.row(selItem)]
                     self.lexer.setPaper(colour, style)
+                    selItem.setBackground(colour)
             else:
                 self.lexer.setPaper(colour, self.style)
+                self.styleElementList.currentItem().setBackground(colour)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_allBackgroundColoursButton_clicked(self):
         """
-        Private method used to select the background colour of all styles of a 
+        Private method used to select the background colour of all styles of a
         selected lexer.
         """
-        colour = KQColorDialog.getColor(self.lexer.paper(self.style))
+        colour = QColorDialog.getColor(self.lexer.paper(self.style))
         if colour.isValid():
             pl = self.sampleText.palette()
             pl.setColor(QPalette.Base, colour)
             self.sampleText.setPalette(pl)
             self.sampleText.repaint()
-            for style in self.lexer.ind2style.values():
+            for style in list(self.lexer.ind2style.values()):
                 self.lexer.setPaper(colour, style)
+            self.__styleAllItems()
         
     def __changeFont(self, doAll, familyOnly, sizeOnly):
         """
         Private slot to change the highlighter font.
         
-        @param doAll flag indicating to change the font for all styles (boolean)
+        @param doAll flag indicating to change the font for all styles
+            (boolean)
         @param familyOnly flag indicating to set the font family only (boolean)
         @param sizeOnly flag indicating to set the font size only (boolean
         """
@@ -205,7 +229,8 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             
             @param font font to be set (QFont)
             @param style style to set the font for (integer)
-            @param familyOnly flag indicating to set the font family only (boolean)
+            @param familyOnly flag indicating to set the font family only
+                (boolean)
             @param sizeOnly flag indicating to set the font size only (boolean
             """
             if familyOnly or sizeOnly:
@@ -223,7 +248,8 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             Local function to set the font of the sample text.
             
             @param font font to be set (QFont)
-            @param familyOnly flag indicating to set the font family only (boolean)
+            @param familyOnly flag indicating to set the font family only
+                (boolean)
             @param sizeOnly flag indicating to set the font size only (boolean
             """
             if familyOnly or sizeOnly:
@@ -236,18 +262,24 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             else:
                 self.sampleText.setFont(font)
         
-        font, ok = KQFontDialog.getFont(self.lexer.font(self.style))
+        font, ok = QFontDialog.getFont(self.lexer.font(self.style))
         if ok:
             setSampleFont(font, familyOnly, sizeOnly)
             if doAll:
                 for style in list(self.lexer.ind2style.values()):
                     setFont(font, style, familyOnly, sizeOnly)
+                self.__styleAllItems()
             elif len(self.styleElementList.selectedItems()) > 1:
                 for selItem in self.styleElementList.selectedItems():
-                    style = self.lexer.ind2style[self.styleElementList.row(selItem)]
+                    style = self.lexer.ind2style[
+                        self.styleElementList.row(selItem)]
                     setFont(font, style, familyOnly, sizeOnly)
+                    itmFont = self.lexer.font(style)
+                    selItem.setFont(itmFont)
             else:
                 setFont(font, self.style, familyOnly, sizeOnly)
+                itmFont = self.lexer.font(self.style)
+                self.styleElementList.currentItem().setFont(itmFont)
         
     def __fontButtonMenuTriggered(self, act):
         """
@@ -258,8 +290,8 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         if act is None:
             return
         
-        familyOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.SIZEONLY]
+        familyOnly = act.data() in [self.FAMILYANDSIZE, self.FAMILYONLY]
+        sizeOnly = act.data() in [self.FAMILYANDSIZE, self.SIZEONLY]
         self.__changeFont(False, familyOnly, sizeOnly)
         
     def __allFontsButtonMenuTriggered(self, act):
@@ -271,58 +303,68 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         if act is None:
             return
         
-        familyOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.SIZEONLY]
+        familyOnly = act.data() in [self.FAMILYANDSIZE, self.FAMILYONLY]
+        sizeOnly = act.data() in [self.FAMILYANDSIZE, self.SIZEONLY]
         self.__changeFont(True, familyOnly, sizeOnly)
         
-    def on_eolfillCheckBox_toggled(self, b):
+    def on_eolfillCheckBox_toggled(self, on):
         """
-        Private method used to set the eolfill for the selected style and lexer.
+        Private method used to set the eolfill for the selected style and
+        lexer.
         
-        @param b Flag indicating enabled or disabled state.
+        @param on flag indicating enabled or disabled state (boolean)
         """
-        self.lexer.setEolFill(b, self.style)
+        self.lexer.setEolFill(on, self.style)
+        checkState = Qt.Checked if on else Qt.Unchecked
+        self.styleElementList.currentItem().setCheckState(checkState)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_allEolFillButton_clicked(self):
         """
-        Private method used to set the eolfill for all styles of a selected lexer.
+        Private method used to set the eolfill for all styles of a selected
+        lexer.
         """
         on = self.trUtf8("Enabled")
         off = self.trUtf8("Disabled")
-        selection, ok = KQInputDialog.getItem(\
+        selection, ok = QInputDialog.getItem(
             self,
             self.trUtf8("Fill to end of line"),
             self.trUtf8("Select fill to end of line for all styles"),
-            QStringList() << on << off, 
+            [on, off],
             0, False)
         if ok:
             enabled = selection == on
             self.eolfillCheckBox.setChecked(enabled)
-            for style in self.lexer.ind2style.values():
+            for style in list(self.lexer.ind2style.values()):
                 self.lexer.setEolFill(enabled, style)
+            self.__styleAllItems()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_defaultButton_clicked(self):
         """
         Private method to set the current style to its default values.
         """
         if len(self.styleElementList.selectedItems()) > 1:
             for selItem in self.styleElementList.selectedItems():
-                style = self.lexer.ind2style[self.styleElementList.row(selItem)]
+                style = self.lexer.ind2style[
+                    self.styleElementList.row(selItem)]
                 self.__setToDefault(style)
         else:
             self.__setToDefault(self.style)
-        self.on_styleElementList_currentRowChanged(self.styleElementList.currentRow())
+        self.on_styleElementList_currentRowChanged(
+            self.styleElementList.currentRow())
+        self.__styleAllItems()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_allDefaultButton_clicked(self):
         """
         Private method to set all styles to their default values.
         """
-        for style in self.lexer.ind2style.values():
+        for style in list(self.lexer.ind2style.values()):
             self.__setToDefault(style)
-        self.on_styleElementList_currentRowChanged(self.styleElementList.currentRow())
+        self.on_styleElementList_currentRowChanged(
+            self.styleElementList.currentRow())
+        self.__styleAllItems()
         
     def __setToDefault(self, style):
         """
@@ -335,33 +377,33 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         self.lexer.setFont(self.lexer.defaultFont(style), style)
         self.lexer.setEolFill(self.lexer.defaultEolFill(style), style)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_importCurrentButton_clicked(self):
         """
         Private slot to import the styles of the current lexer.
         """
-        self.__importStyles({self.lexer.language() : self.lexer})
+        self.__importStyles({self.lexer.language(): self.lexer})
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_exportCurrentButton_clicked(self):
         """
         Private slot to export the styles of the current lexer.
         """
         self.__exportStyles([self.lexer])
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_importAllButton_clicked(self):
         """
         Private slot to import the styles of all lexers.
         """
         self.__importStyles(self.lexers)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_exportAllButton_clicked(self):
         """
         Private slot to export the styles of all lexers.
         """
-        self.__exportStyles(self.lexers.values())
+        self.__exportStyles(list(self.lexers.values()))
         
     def __exportStyles(self, lexers):
         """
@@ -369,113 +411,71 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         
         @param lexers list of lexer objects for which to export the styles
         """
-        selectedFilter = QString("")
-        fn = KQFileDialog.getSaveFileName(\
+        fn, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
             self.trUtf8("Export Highlighting Styles"),
-            QString(),
-            self.trUtf8("eric4 highlighting styles file (*.e4h)"),
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+            "",
+            self.trUtf8("Highlighting styles file (*.e4h)"),
+            "",
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if fn.isEmpty():
+        if not fn:
             return
         
         ext = QFileInfo(fn).suffix()
-        if ext.isEmpty():
-            ex = selectedFilter.section('(*', 1, 1).section(')', 0, 0)
-            if not ex.isEmpty():
-                fn.append(ex)
-        fn = unicode(fn)
+        if not ext:
+            ex = selectedFilter.split("(*")[1].split(")")[0]
+            if ex:
+                fn += ex
         
-        try:
-            f = open(fn, "wb")
+        f = QFile(fn)
+        if f.open(QIODevice.WriteOnly):
+            from E5XML.HighlightingStylesWriter import HighlightingStylesWriter
             HighlightingStylesWriter(f, lexers).writeXML()
             f.close()
-        except IOError, err:
-            KQMessageBox.critical(self,
+        else:
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Export Highlighting Styles"),
-                self.trUtf8("""<p>The highlighting styles could not be exported"""
-                            """ to file <b>%1</b>.</p><p>Reason: %2</p>""")\
-                    .arg(fn)\
-                    .arg(str(err))
+                self.trUtf8(
+                    """<p>The highlighting styles could not be exported"""
+                    """ to file <b>{0}</b>.</p><p>Reason: {1}</p>""")
+                .format(fn, f.errorString())
             )
         
     def __importStyles(self, lexers):
         """
         Private method to import the styles of the given lexers.
         
-        @param lexers dictionary of lexer objects for which to import the styles
+        @param lexers dictionary of lexer objects for which to import the
+            styles
         """
-        fn = KQFileDialog.getOpenFileName(\
+        fn = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Import Highlighting Styles"),
-            QString(),
-            self.trUtf8("eric4 highlighting styles file (*.e4h)"),
-            None)
+            "",
+            self.trUtf8("Highlighting styles file (*.e4h)"))
         
-        if fn.isEmpty():
+        if not fn:
             return
         
-        fn = unicode(fn)
-        
-        try:
-            f = open(fn, "rb")
-            try:
-                line = f.readline()
-                dtdLine = f.readline()
-            finally:
-                f.close()
-        except IOError, err:
-            KQMessageBox.critical(self,
+        f = QFile(fn)
+        if f.open(QIODevice.ReadOnly):
+            from E5XML.HighlightingStylesReader import HighlightingStylesReader
+            reader = HighlightingStylesReader(f, lexers)
+            reader.readXML()
+            f.close()
+        else:
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Import Highlighting Styles"),
-                self.trUtf8("""<p>The highlighting styles could not be read"""
-                            """ from file <b>%1</b>.</p><p>Reason: %2</p>""")\
-                    .arg(fn)\
-                    .arg(str(err))
+                self.trUtf8(
+                    """<p>The highlighting styles could not be read"""
+                    """ from file <b>{0}</b>.</p><p>Reason: {1}</p>""")
+                .format(fn, f.errorString())
             )
             return
         
-        validating = dtdLine.startswith("<!DOCTYPE")
-        parser = make_parser(validating)
-        handler = HighlightingStylesHandler(lexers)
-        er = XMLEntityResolver()
-        eh = XMLErrorHandler()
-        
-        parser.setContentHandler(handler)
-        parser.setEntityResolver(er)
-        parser.setErrorHandler(eh)
-        
-        try:
-            f = open(fn, "rb")
-            try:
-                try:
-                    parser.parse(f)
-                except UnicodeEncodeError:
-                    f.seek(0)
-                    buf = cStringIO.StringIO(f.read())
-                    parser.parse(buf)
-            finally:
-                f.close()
-        except IOError, err:
-            KQMessageBox.critical(self,
-                self.trUtf8("Import Highlighting Styles"),
-                self.trUtf8("""<p>The highlighting styles could not be read"""
-                            """ from file <b>%1</b>.</p><p>Reason: %2</p>""")\
-                    .arg(fn)\
-                    .arg(str(err))
-            )
-            return
-        except XMLFatalParseError:
-            KQMessageBox.critical(self,
-                self.trUtf8("Import Highlighting Styles"),
-                self.trUtf8("""<p>The highlighting styles file <b>%1</b>"""
-                            """ has invalid contents.</p>""").arg(fn))
-            eh.showParseMessages()
-            return
-        
-        eh.showParseMessages()
-        
         if self.lexer:
             colour = self.lexer.color(self.style)
             paper = self.lexer.paper(self.style)
@@ -489,13 +489,15 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             self.sampleText.setPalette(pl)
             self.sampleText.repaint()
             self.eolfillCheckBox.setChecked(eolfill)
+            
+            self.__styleAllItems()
         
     def saveState(self):
         """
         Public method to save the current state of the widget.
         
-        @return array containing the index of the selected lexer language (integer)
-            and the index of the selected lexer entry (integer)
+        @return array containing the index of the selected lexer language
+            (integer) and the index of the selected lexer entry (integer)
         """
         savedState = [
             self.lexerLanguageComboBox.currentIndex(),
@@ -510,14 +512,17 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         @param state state data generated by saveState
         """
         self.lexerLanguageComboBox.setCurrentIndex(state[0])
-        self.on_lexerLanguageComboBox_activated(self.lexerLanguageComboBox.currentText())
+        self.on_lexerLanguageComboBox_activated(
+            self.lexerLanguageComboBox.currentText())
         self.styleElementList.setCurrentRow(state[1])
 
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = EditorHighlightingStylesPage(dlg.getLexers())
     return page
