@@ -7,22 +7,20 @@
 Module implementing the Editor Spellchecking configuration page.
 """
 
-from PyQt4.QtCore import pyqtSignature
-from PyQt4.QtGui import QPixmap, QIcon
+from PyQt4.QtCore import pyqtSlot
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_EditorSpellCheckingPage import Ui_EditorSpellCheckingPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_EditorSpellCheckingPage import Ui_EditorSpellCheckingPage
 
 import Preferences
 import Utilities
 
-from QScintilla.SpellChecker import SpellChecker
 
-class EditorSpellCheckingPage(ConfigurationPageBase, Ui_EditorSpellCheckingPage):
+class EditorSpellCheckingPage(ConfigurationPageBase,
+                              Ui_EditorSpellCheckingPage):
     """
     Class implementing the Editor Spellchecking configuration page.
     """
@@ -30,12 +28,11 @@ class EditorSpellCheckingPage(ConfigurationPageBase, Ui_EditorSpellCheckingPage)
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("EditorSpellCheckingPage")
         
-        self.editorColours = {}
-        
+        from QScintilla.SpellChecker import SpellChecker
         languages = sorted(SpellChecker.getAvailableLanguages())
         self.defaultLanguageCombo.addItems(languages)
         if languages:
@@ -43,8 +40,8 @@ class EditorSpellCheckingPage(ConfigurationPageBase, Ui_EditorSpellCheckingPage)
         else:
             self.spellingFrame.setEnabled(False)
         
-        self.pwlFileCompleter = E4FileCompleter(self.pwlEdit, showHidden = True)
-        self.pelFileCompleter = E4FileCompleter(self.pelEdit, showHidden = True)
+        self.pwlFileCompleter = E5FileCompleter(self.pwlEdit, showHidden=True)
+        self.pelFileCompleter = E5FileCompleter(self.pelEdit, showHidden=True)
         
         # set initial values
         self.checkingEnabledCheckBox.setChecked(
@@ -59,87 +56,86 @@ class EditorSpellCheckingPage(ConfigurationPageBase, Ui_EditorSpellCheckingPage)
         self.minimumWordSizeSlider.setValue(
             Preferences.getEditor("SpellCheckingMinWordSize"))
         
-        self.editorColours["SpellingMarkers"] = \
-            self.initColour("SpellingMarkers", self.spellingMarkerButton, 
-                Preferences.getEditorColour)
+        self.initColour(
+            "SpellingMarkers", self.spellingMarkerButton,
+            Preferences.getEditorColour, hasAlpha=True)
         
-        self.pwlEdit.setText(Preferences.getEditor("SpellCheckingPersonalWordList"))
-        self.pelEdit.setText(Preferences.getEditor("SpellCheckingPersonalExcludeList"))
+        self.pwlEdit.setText(
+            Preferences.getEditor("SpellCheckingPersonalWordList"))
+        self.pelEdit.setText(
+            Preferences.getEditor("SpellCheckingPersonalExcludeList"))
         
         if self.spellingFrame.isEnabled():
-            self.enabledCheckBox.setChecked(\
+            self.enabledCheckBox.setChecked(
                 Preferences.getEditor("AutoSpellCheckingEnabled"))
         else:
             self.enabledCheckBox.setChecked(False)  # not available
-        self.chunkSizeSpinBox.setValue(Preferences.getEditor("AutoSpellCheckChunkSize"))
+        self.chunkSizeSpinBox.setValue(
+            Preferences.getEditor("AutoSpellCheckChunkSize"))
         
     def save(self):
         """
         Public slot to save the Editor Search configuration.
         """
-        Preferences.setEditor("SpellCheckingEnabled", 
-            int(self.checkingEnabledCheckBox.isChecked()))
+        Preferences.setEditor(
+            "SpellCheckingEnabled", self.checkingEnabledCheckBox.isChecked())
         
-        Preferences.setEditor("SpellCheckingDefaultLanguage", 
+        Preferences.setEditor(
+            "SpellCheckingDefaultLanguage",
             self.defaultLanguageCombo.currentText())
         
-        Preferences.setEditor("SpellCheckStringsOnly", 
-            int(self.stringsOnlyCheckBox.isChecked()))
-        Preferences.setEditor("SpellCheckingMinWordSize", 
-            self.minimumWordSizeSlider.value())
+        Preferences.setEditor(
+            "SpellCheckStringsOnly", self.stringsOnlyCheckBox.isChecked())
+        Preferences.setEditor(
+            "SpellCheckingMinWordSize", self.minimumWordSizeSlider.value())
         
-        for key in self.editorColours.keys():
-            Preferences.setEditorColour(key, self.editorColours[key])
+        self.saveColours(Preferences.setEditorColour)
         
-        Preferences.setEditor("SpellCheckingPersonalWordList", self.pwlEdit.text())
-        Preferences.setEditor("SpellCheckingPersonalExcludeList", self.pelEdit.text())
+        Preferences.setEditor(
+            "SpellCheckingPersonalWordList", self.pwlEdit.text())
+        Preferences.setEditor(
+            "SpellCheckingPersonalExcludeList", self.pelEdit.text())
         
-        Preferences.setEditor("AutoSpellCheckingEnabled", 
-            int(self.enabledCheckBox.isChecked()))
-        Preferences.setEditor("AutoSpellCheckChunkSize", self.chunkSizeSpinBox.value())
-        
-    @pyqtSignature("")
-    def on_spellingMarkerButton_clicked(self):
-        """
-        Private slot to set the colour of the spelling markers.
-        """
-        self.editorColours["SpellingMarkers"] = \
-            self.selectColour(self.spellingMarkerButton, 
-                self.editorColours["SpellingMarkers"])
+        Preferences.setEditor(
+            "AutoSpellCheckingEnabled", self.enabledCheckBox.isChecked())
+        Preferences.setEditor(
+            "AutoSpellCheckChunkSize", self.chunkSizeSpinBox.value())
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pwlButton_clicked(self):
         """
         Private method to select the personal word list file.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select personal word list"),
             self.pwlEdit.text(),
             self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
             
-        if not file.isEmpty():
+        if file:
             self.pwlEdit.setText(Utilities.toNativeSeparators(file))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pelButton_clicked(self):
         """
         Private method to select the personal exclude list file.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select personal exclude list"),
             self.pelEdit.text(),
             self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
             
-        if not file.isEmpty():
+        if file:
             self.pelEdit.setText(Utilities.toNativeSeparators(file))
 
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = EditorSpellCheckingPage()
     return page
