@@ -7,13 +7,14 @@
 Module implementing the Printer configuration page.
 """
 
-from PyQt4.QtCore import pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_GraphicsPage import Ui_GraphicsPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_GraphicsPage import Ui_GraphicsPage
 
 import Preferences
 
+
 class GraphicsPage(ConfigurationPageBase, Ui_GraphicsPage):
     """
     Class implementing the Printer configuration page.
@@ -22,7 +23,7 @@ class GraphicsPage(ConfigurationPageBase, Ui_GraphicsPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("GraphicsPage")
         
@@ -36,12 +37,13 @@ class GraphicsPage(ConfigurationPageBase, Ui_GraphicsPage):
         """
         Preferences.setGraphics("Font", self.graphicsFont)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_graphicsFontButton_clicked(self):
         """
         Private method used to select the font for the graphics items.
         """
-        self.graphicsFont = self.selectFont(self.graphicsFontSample, self.graphicsFont)
+        self.graphicsFont = self.selectFont(self.graphicsFontSample,
+                                            self.graphicsFont)
         
     def polishPage(self):
         """
@@ -49,11 +51,13 @@ class GraphicsPage(ConfigurationPageBase, Ui_GraphicsPage):
         """
         self.graphicsFontSample.setFont(self.graphicsFont)
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = GraphicsPage()
     return page
