@@ -7,19 +7,19 @@
 Module implementing the Help Viewers configuration page.
 """
 
-from PyQt4.QtCore import QDir, QString, pyqtSignature
+from PyQt4.QtCore import pyqtSlot
 from PyQt4.QtGui import QButtonGroup
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_HelpViewersPage import Ui_HelpViewersPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_HelpViewersPage import Ui_HelpViewersPage
 
 import Preferences
 import Utilities
 
+
 class HelpViewersPage(ConfigurationPageBase, Ui_HelpViewersPage):
     """
     Class implementing the Help Viewers configuration page.
@@ -28,7 +28,7 @@ class HelpViewersPage(ConfigurationPageBase, Ui_HelpViewersPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("HelpViewersPage")
         
@@ -38,7 +38,7 @@ class HelpViewersPage(ConfigurationPageBase, Ui_HelpViewersPage):
         self.helpViewerGroup.addButton(self.webBrowserButton)
         self.helpViewerGroup.addButton(self.customViewerButton)
         
-        self.customViewerCompleter = E4FileCompleter(self.customViewerEdit)
+        self.customViewerCompleter = E5FileCompleter(self.customViewerEdit)
         
         # set initial values
         hvId = Preferences.getHelp("HelpViewerType")
@@ -50,7 +50,7 @@ class HelpViewersPage(ConfigurationPageBase, Ui_HelpViewersPage):
             self.webBrowserButton.setChecked(True)
         else:
             self.customViewerButton.setChecked(True)
-        self.customViewerEdit.setText(\
+        self.customViewerEdit.setText(
             Preferences.getHelp("CustomViewer"))
         
     def save(self):
@@ -66,70 +66,73 @@ class HelpViewersPage(ConfigurationPageBase, Ui_HelpViewersPage):
         elif self.customViewerButton.isChecked():
             hvId = 4
         Preferences.setHelp("HelpViewerType", hvId)
-        Preferences.setHelp("CustomViewer",
+        Preferences.setHelp(
+            "CustomViewer",
             self.customViewerEdit.text())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_customViewerSelectionButton_clicked(self):
         """
         Private slot to handle the custom viewer selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select Custom Viewer"),
             self.customViewerEdit.text(),
-            QString())
+            "")
         
-        if not file.isNull():
+        if file:
             self.customViewerEdit.setText(Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_webbrowserButton_clicked(self):
         """
         Private slot to handle the Web browser selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select Web-Browser"),
             self.webbrowserEdit.text(),
-            QString())
+            "")
         
-        if not file.isNull():
+        if file:
             self.webbrowserEdit.setText(Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pdfviewerButton_clicked(self):
         """
         Private slot to handle the PDF viewer selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select PDF-Viewer"),
             self.pdfviewerEdit.text(),
-            QString())
+            "")
         
-        if not file.isNull():
+        if file:
             self.pdfviewerEdit.setText(Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_chmviewerButton_clicked(self):
         """
         Private slot to handle the CHM viewer selection.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select CHM-Viewer"),
             self.chmviewerEdit.text(),
-            QString())
+            "")
         
-        if not file.isNull():
+        if file:
             self.chmviewerEdit.setText(Utilities.toNativeSeparators(file))
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = HelpViewersPage()
     return page
