@@ -10,9 +10,9 @@ Module implementing a dialog to preview the contents of an icon directory.
 import os.path
 
 from PyQt4.QtGui import QListWidgetItem, QDialog, QIcon
-from PyQt4.QtCore import QDir, QStringList
+from PyQt4.QtCore import QDir
 
-from Ui_IconsPreviewDialog import Ui_IconsPreviewDialog
+from .Ui_IconsPreviewDialog import Ui_IconsPreviewDialog
 
 
 class IconsPreviewDialog(QDialog, Ui_IconsPreviewDialog):
@@ -24,12 +24,13 @@ class IconsPreviewDialog(QDialog, Ui_IconsPreviewDialog):
         Constructor
         
         @param parent parent widget (QWidget)
-        @param dirName name of directory to show
+        @param dirName name of directory to show (string)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         dir = QDir(dirName)
-        for icon in dir.entryList(QStringList() << "*.png"):
-            QListWidgetItem(QIcon(os.path.join(unicode(dirName), unicode(icon))), 
+        for icon in dir.entryList(["*.png"]):
+            QListWidgetItem(
+                QIcon(os.path.join(dirName, icon)),
                 icon, self.iconView)
