@@ -10,21 +10,20 @@ Module implementing the Interface configuration page.
 import glob
 import os
 
-from PyQt4.QtCore import pyqtSignature, QVariant, QTranslator, QString, qVersion
+from PyQt4.QtCore import pyqtSlot, QTranslator
 from PyQt4.QtGui import QStyleFactory
 
-from E4Gui.E4Completers import E4FileCompleter
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_InterfacePage import Ui_InterfacePage
-
-from KdeQt import KQFileDialog
-import KdeQt
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_InterfacePage import Ui_InterfacePage
 
 import Preferences
 import Utilities
 
-from eric4config import getConfig
+from eric5config import getConfig
+
 
 class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
     """
@@ -34,13 +33,11 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("InterfacePage")
         
-        self.styleSheetCompleter = E4FileCompleter(self.styleSheetEdit)
-        
-        self.uiColours = {}
+        self.styleSheetCompleter = E5FileCompleter(self.styleSheetEdit)
         
         # set initial values
         self.__populateStyleCombo()
@@ -52,14 +49,17 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             Preferences.getUI("BrowsersHideNonPublic"))
         self.uiBrowsersSortByOccurrenceCheckBox.setChecked(
             Preferences.getUI("BrowsersListContentsByOccurrence"))
-        self.fileFiltersEdit.setText(Preferences.getUI("BrowsersFileFilters"))
+        self.uiBrowsersShowHiddenCheckBox.setChecked(
+            Preferences.getUI("BrowsersListHiddenFiles"))
+        self.fileFiltersEdit.setText(
+            Preferences.getUI("BrowsersFileFilters"))
         
         self.lvAutoRaiseCheckBox.setChecked(
             Preferences.getUI("LogViewerAutoRaise"))
         
         self.uiCaptionShowsFilenameGroupBox.setChecked(
             Preferences.getUI("CaptionShowsFilename"))
-        self.filenameLengthSpinBox.setValue(\
+        self.filenameLengthSpinBox.setValue(
             Preferences.getUI("CaptionFilenameLength"))
         self.styleSheetEdit.setText(Preferences.getUI("StyleSheet"))
         
@@ -81,14 +81,10 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             self.brTopButton.setChecked(True)
         
         layout = Preferences.getUILayout()
-        if layout[0] == "DockWindows":
+        if layout[0] == "Sidebars":
             index = 0
-        elif layout[0] == "FloatingWindows":
-            index = 1
         elif layout[0] == "Toolboxes":
-            index = 2
-        elif layout[0] == "Sidebars":
-            index = 3
+            index = 1
         else:
             index = 0   # default for bad values
         self.layoutComboBox.setCurrentIndex(index)
@@ -103,24 +99,13 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         else:
             self.projectEmbeddedFileBrowserButton.setChecked(True)
         
-        if qVersion() < '4.5.0':
-            self.tabsGroupBox.setEnabled(False)
-            self.tabsCloseButtonCheckBox.setChecked(True)
-        else:
-            self.tabsGroupBox.setEnabled(True)
-            self.tabsCloseButtonCheckBox.setChecked(
-                Preferences.getUI("SingleCloseButton"))
+        self.tabsGroupBox.setEnabled(True)
+        self.tabsCloseButtonCheckBox.setChecked(
+            Preferences.getUI("SingleCloseButton"))
         
-        if Utilities.isMacPlatform() or Utilities.isWindowsPlatform():
-            self.uiKdeDialogsCheckBox.setChecked(False)
-            self.dialogsGroupBox.hide()
-        else:
-            self.uiKdeDialogsCheckBox.setChecked(\
-                Preferences.getUI("UseKDEDialogs"))
-        
-        self.uiColours["LogStdErrColour"] = \
-            self.initColour("LogStdErrColour", self.stderrTextColourButton, 
-                Preferences.getUI)
+        self.initColour(
+            "LogStdErrColour", self.stderrTextColourButton,
+            Preferences.getUI)
         
         self.delaySpinBox.setValue(Preferences.getUI("SidebarDelay"))
         
@@ -130,43 +115,58 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         """
         # save the style settings
         styleIndex = self.styleComboBox.currentIndex()
-        style = self.styleComboBox.itemData(styleIndex).toString()
+        style = self.styleComboBox.itemData(styleIndex)
         Preferences.setUI("Style", style)
         
         # save the other UI related settings
-        Preferences.setUI("BrowsersListFoldersFirst",
-            int(self.uiBrowsersListFoldersFirstCheckBox.isChecked()))
-        Preferences.setUI("BrowsersHideNonPublic",
-            int(self.uiBrowsersHideNonPublicCheckBox.isChecked()))
-        Preferences.setUI("BrowsersListContentsByOccurrence", 
-            int(self.uiBrowsersSortByOccurrenceCheckBox.isChecked()))
-        Preferences.setUI("BrowsersFileFilters",
+        Preferences.setUI(
+            "BrowsersListFoldersFirst",
+            self.uiBrowsersListFoldersFirstCheckBox.isChecked())
+        Preferences.setUI(
+            "BrowsersHideNonPublic",
+            self.uiBrowsersHideNonPublicCheckBox.isChecked())
+        Preferences.setUI(
+            "BrowsersListContentsByOccurrence",
+            self.uiBrowsersSortByOccurrenceCheckBox.isChecked())
+        Preferences.setUI(
+            "BrowsersListHiddenFiles",
+            self.uiBrowsersShowHiddenCheckBox.isChecked())
+        Preferences.setUI(
+            "BrowsersFileFilters",
             self.fileFiltersEdit.text())
         
-        Preferences.setUI("LogViewerAutoRaise", 
-            int(self.lvAutoRaiseCheckBox.isChecked()))
-        Preferences.setUI("CaptionShowsFilename",
-            int(self.uiCaptionShowsFilenameGroupBox.isChecked()))
-        Preferences.setUI("CaptionFilenameLength",
+        Preferences.setUI(
+            "LogViewerAutoRaise",
+            self.lvAutoRaiseCheckBox.isChecked())
+        Preferences.setUI(
+            "CaptionShowsFilename",
+            self.uiCaptionShowsFilenameGroupBox.isChecked())
+        Preferences.setUI(
+            "CaptionFilenameLength",
             self.filenameLengthSpinBox.value())
-        Preferences.setUI("StyleSheet",
+        Preferences.setUI(
+            "StyleSheet",
             self.styleSheetEdit.text())
         
         # save the dockarea corner settings
-        Preferences.setUI("TopLeftByLeft", 
-            int(self.tlLeftButton.isChecked()))
-        Preferences.setUI("BottomLeftByLeft", 
-            int(self.blLeftButton.isChecked()))
-        Preferences.setUI("TopRightByRight", 
-            int(self.trRightButton.isChecked()))
-        Preferences.setUI("BottomRightByRight", 
-            int(self.brRightButton.isChecked()))
+        Preferences.setUI(
+            "TopLeftByLeft",
+            self.tlLeftButton.isChecked())
+        Preferences.setUI(
+            "BottomLeftByLeft",
+            self.blLeftButton.isChecked())
+        Preferences.setUI(
+            "TopRightByRight",
+            self.trRightButton.isChecked())
+        Preferences.setUI(
+            "BottomRightByRight",
+            self.brRightButton.isChecked())
         
         # save the language settings
         uiLanguageIndex = self.languageComboBox.currentIndex()
         if uiLanguageIndex:
-            uiLanguage = unicode(\
-                self.languageComboBox.itemData(uiLanguageIndex).toString())
+            uiLanguage = \
+                self.languageComboBox.itemData(uiLanguageIndex)
         else:
             uiLanguage = None
         Preferences.setUILanguage(uiLanguage)
@@ -183,70 +183,61 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         else:
             layout3 = 2
         if self.layoutComboBox.currentIndex() == 0:
-            layout1 = "DockWindows"
-        elif self.layoutComboBox.currentIndex() == 1:
-            layout1 = "FloatingWindows"
-        elif self.layoutComboBox.currentIndex() == 2:
-            layout1 = "Toolboxes"
-        elif self.layoutComboBox.currentIndex() == 3:
             layout1 = "Sidebars"
+        elif self.layoutComboBox.currentIndex() == 1:
+            layout1 = "Toolboxes"
         else:
-            layout1 = "DockWindows"
+            layout1 = "Sidebars"    # just in case
         layout = (layout1, layout2, layout3)
         Preferences.setUILayout(layout)
         
-        Preferences.setUI("SingleCloseButton", 
-            int(self.tabsCloseButtonCheckBox.isChecked()))
-        
-        Preferences.setUI("UseKDEDialogs",
-            int(self.uiKdeDialogsCheckBox.isChecked()))
+        Preferences.setUI(
+            "SingleCloseButton",
+            self.tabsCloseButtonCheckBox.isChecked())
         
         Preferences.setUI("SidebarDelay", self.delaySpinBox.value())
         
-        for key in self.uiColours.keys():
-            Preferences.setUI(key, self.uiColours[key])
+        self.saveColours(Preferences.setUI)
         
     def __populateStyleCombo(self):
         """
         Private method to populate the style combo box.
         """
         curStyle = Preferences.getUI("Style")
-        styles = QStyleFactory.keys()
-        styles.sort()
-        self.styleComboBox.addItem(self.trUtf8('System'), QVariant("System"))
+        styles = sorted(list(QStyleFactory.keys()))
+        self.styleComboBox.addItem(self.trUtf8('System'), "System")
         for style in styles:
-            self.styleComboBox.addItem(style, QVariant(style))
-        currentIndex = self.styleComboBox.findData(QVariant(curStyle))
+            self.styleComboBox.addItem(style, style)
+        currentIndex = self.styleComboBox.findData(curStyle)
         if currentIndex == -1:
             currentIndex = 0
         self.styleComboBox.setCurrentIndex(currentIndex)
         
     def __populateLanguageCombo(self):
         """
-        Private method to initialize the language combobox of the Interface 
+        Private method to initialize the language combobox of the Interface
         configuration page.
         """
         self.languageComboBox.clear()
         
-        fnlist = glob.glob("eric4_*.qm") + \
-            glob.glob(os.path.join(getConfig('ericTranslationsDir'), "eric4_*.qm")) + \
-            glob.glob(os.path.join(Utilities.getConfigDir(), "eric4_*.qm"))
+        fnlist = glob.glob("eric5_*.qm") + \
+            glob.glob(os.path.join(
+                getConfig('ericTranslationsDir'), "eric5_*.qm")) + \
+            glob.glob(os.path.join(Utilities.getConfigDir(), "eric5_*.qm"))
         locales = {}
         for fn in fnlist:
             locale = os.path.basename(fn)[6:-3]
-            if not locales.has_key(locale):
+            if locale not in locales:
                 translator = QTranslator()
                 translator.load(fn)
-                locales[locale] = \
-                    translator.translate("InterfacePage", "English", 
-                                         "Translate this with your language") + \
-                    QString(" (%1)").arg(locale)
-        localeList = locales.keys()
-        localeList.sort()
-        
+                locales[locale] = translator.translate(
+                    "InterfacePage", "English",
+                    "Translate this with your language") + \
+                    " ({0})".format(locale)
+        localeList = sorted(list(locales.keys()))
         try:
-            uiLanguage = unicode(Preferences.getUILanguage())
-            if uiLanguage == "None":
+            uiLanguage = Preferences.getUILanguage()
+            if uiLanguage == "None" or uiLanguage is None:
                 currentIndex = 0
             elif uiLanguage == "System":
                 currentIndex = 1
@@ -256,49 +247,42 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             currentIndex = 0
         self.languageComboBox.clear()
         
-        self.languageComboBox.addItem("English (default)", QVariant("None"))
-        self.languageComboBox.addItem(self.trUtf8('System'), QVariant("System"))
+        self.languageComboBox.addItem("English (default)", "None")
+        self.languageComboBox.addItem(self.trUtf8('System'), "System")
         for locale in localeList:
-            self.languageComboBox.addItem(locales[locale], QVariant(locale))
+            self.languageComboBox.addItem(locales[locale], locale)
         self.languageComboBox.setCurrentIndex(currentIndex)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_styleSheetButton_clicked(self):
         """
         Private method to select the style sheet file via a dialog.
         """
-        file = KQFileDialog.getOpenFileName(\
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select style sheet file"),
             self.styleSheetEdit.text(),
-            self.trUtf8("Qt Style Sheets (*.qss);;Cascading Style Sheets (*.css);;"
-                        "All files (*)"),
-            None)
+            self.trUtf8(
+                "Qt Style Sheets (*.qss);;Cascading Style Sheets (*.css);;"
+                "All files (*)"))
         
-        if not file.isEmpty():
+        if file:
             self.styleSheetEdit.setText(Utilities.toNativeSeparators(file))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_resetLayoutButton_clicked(self):
         """
-        Private method to reset layout to factory defaults
+        Private method to reset layout to factory defaults.
         """
         Preferences.resetLayout()
-        
-    @pyqtSignature("")
-    def on_stderrTextColourButton_clicked(self):
-        """
-        Private slot to set the foreground colour of the caret.
-        """
-        self.uiColours["LogStdErrColour"] = \
-            self.selectColour(self.stderrTextColourButton, 
-                self.uiColours["LogStdErrColour"])
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = InterfacePage()
     return page
