@@ -7,12 +7,13 @@
 Module implementing the Python configuration page.
 """
 
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_PythonPage import Ui_PythonPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_PythonPage import Ui_PythonPage
 
 import Preferences
 from Utilities import supportedCodecs
 
+
 class PythonPage(ConfigurationPageBase, Ui_PythonPage):
     """
     Class implementing the Python configuration page.
@@ -21,7 +22,7 @@ class PythonPage(ConfigurationPageBase, Ui_PythonPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("PythonPage")
         
@@ -29,10 +30,10 @@ class PythonPage(ConfigurationPageBase, Ui_PythonPage):
         self.ioEncodingComboBox.addItems(sorted(supportedCodecs))
         
         # set initial values
-        index = self.stringEncodingComboBox.findText(\
+        index = self.stringEncodingComboBox.findText(
             Preferences.getSystem("StringEncoding"))
         self.stringEncodingComboBox.setCurrentIndex(index)
-        index = self.ioEncodingComboBox.findText(\
+        index = self.ioEncodingComboBox.findText(
             Preferences.getSystem("IOEncoding"))
         self.ioEncodingComboBox.setCurrentIndex(index)
         
@@ -46,26 +47,30 @@ class PythonPage(ConfigurationPageBase, Ui_PythonPage):
         """
         Public slot to save the Python configuration.
         """
-        enc = unicode(self.stringEncodingComboBox.currentText())
+        enc = self.stringEncodingComboBox.currentText()
         if not enc:
             enc = "utf-8"
         Preferences.setSystem("StringEncoding", enc)
         
-        enc = unicode(self.ioEncodingComboBox.currentText())
+        enc = self.ioEncodingComboBox.currentText()
         if not enc:
             enc = "utf-8"
         Preferences.setSystem("IOEncoding", enc)
         
-        Preferences.setDebugger("PythonExtensions", 
+        Preferences.setDebugger(
+            "PythonExtensions",
             self.py2ExtensionsEdit.text())
-        Preferences.setDebugger("Python3Extensions", 
+        Preferences.setDebugger(
+            "Python3Extensions",
             self.py3ExtensionsEdit.text())
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = PythonPage()
     return page
