@@ -7,19 +7,15 @@
 Module implementing the Viewmanager configuration page.
 """
 
-import os
+from PyQt4.QtCore import pyqtSlot
 
-from PyQt4.QtCore import QStringList, pyqtSignature,  QVariant
-from PyQt4.QtGui import QPixmap
+from E5Gui.E5Application import e5App
 
-from KdeQt.KQApplication import e4App
-
-from ConfigurationPageBase import ConfigurationPageBase
-from Ui_ViewmanagerPage import Ui_ViewmanagerPage
+from .ConfigurationPageBase import ConfigurationPageBase
+from .Ui_ViewmanagerPage import Ui_ViewmanagerPage
 
 import Preferences
 
-from eric4config import getConfig
 
 class ViewmanagerPage(ConfigurationPageBase, Ui_ViewmanagerPage):
     """
@@ -29,27 +25,28 @@ class ViewmanagerPage(ConfigurationPageBase, Ui_ViewmanagerPage):
         """
         Constructor
         """
-        ConfigurationPageBase.__init__(self)
+        super().__init__()
         self.setupUi(self)
         self.setObjectName("ViewmanagerPage")
         
         # set initial values
-        self.pluginManager = e4App().getObject("PluginManager")
-        self.viewmanagers = self.pluginManager.getPluginDisplayStrings("viewmanager")
+        self.pluginManager = e5App().getObject("PluginManager")
+        self.viewmanagers = \
+            self.pluginManager.getPluginDisplayStrings("viewmanager")
         self.windowComboBox.clear()
         currentVm = Preferences.getViewManager()
         
-        keys = self.viewmanagers.keys()
-        keys.sort()
+        keys = sorted(self.viewmanagers.keys())
         for key in keys:
-            self.windowComboBox.addItem(self.trUtf8(self.viewmanagers[key]), 
-                                        QVariant(key))
-        currentIndex = self.windowComboBox.findText(\
+            self.windowComboBox.addItem(
+                self.trUtf8(self.viewmanagers[key]), key)
+        currentIndex = self.windowComboBox.findText(
             self.trUtf8(self.viewmanagers[currentVm]))
         self.windowComboBox.setCurrentIndex(currentIndex)
         self.on_windowComboBox_activated(currentIndex)
         
-        self.tabViewGroupBox.setTitle(self.trUtf8(self.viewmanagers["tabview"]))
+        self.tabViewGroupBox.setTitle(
+            self.trUtf8(self.viewmanagers["tabview"]))
         
         self.filenameLengthSpinBox.setValue(
             Preferences.getUI("TabViewManagerFilenameLength"))
@@ -62,35 +59,41 @@ class ViewmanagerPage(ConfigurationPageBase, Ui_ViewmanagerPage):
         """
         Public slot to save the Viewmanager configuration.
         """
-        vm = unicode(\
-            self.windowComboBox.itemData(self.windowComboBox.currentIndex()).toString())
+        vm = self.windowComboBox.itemData(
+            self.windowComboBox.currentIndex())
         Preferences.setViewManager(vm)
-        Preferences.setUI("TabViewManagerFilenameLength",
+        Preferences.setUI(
+            "TabViewManagerFilenameLength",
             self.filenameLengthSpinBox.value())
-        Preferences.setUI("TabViewManagerFilenameOnly",
-            int(self.filenameOnlyCheckBox.isChecked()))
-        Preferences.setUI("RecentNumber", 
+        Preferences.setUI(
+            "TabViewManagerFilenameOnly",
+            self.filenameOnlyCheckBox.isChecked())
+        Preferences.setUI(
+            "RecentNumber",
             self.recentFilesSpinBox.value())
         
-    @pyqtSignature("int")
+    @pyqtSlot(int)
     def on_windowComboBox_activated(self, index):
         """
         Private slot to show a preview of the selected workspace view type.
         
         @param index index of selected workspace view type (integer)
         """
-        workspace = unicode(\
-            self.windowComboBox.itemData(self.windowComboBox.currentIndex()).toString())
-        pixmap = self.pluginManager.getPluginPreviewPixmap("viewmanager", workspace)
+        workspace = \
+            self.windowComboBox.itemData(self.windowComboBox.currentIndex())
+        pixmap = \
+            self.pluginManager.getPluginPreviewPixmap("viewmanager", workspace)
         
         self.previewPixmap.setPixmap(pixmap)
         self.tabViewGroupBox.setEnabled(workspace == "tabview")
     
+
 def create(dlg):
     """
     Module function to create the configuration page.
     
     @param dlg reference to the configuration dialog
+    @return reference to the instantiated page (ConfigurationPageBase)
     """
     page = ViewmanagerPage()
     return page
