@@ -7,17 +7,13 @@
 Module implementing a special QextScintilla lexer to handle the preferences.
 """
 
-import sys
-
-from PyQt4.QtCore import *
 from PyQt4.QtGui import QColor, QFont, QApplication
-from PyQt4.Qsci import QsciLexer, QsciScintilla
-
-import QScintilla.Lexers
+from PyQt4.Qsci import QsciLexer
 
 import Preferences
 import Globals
 
+
 class PreferencesLexerError(Exception):
     """
     Class defining a special error for the PreferencesLexer class.
@@ -26,9 +22,9 @@ class PreferencesLexerError(Exception):
         """
         Constructor
         """
-        self._errorMessage = \
-            QApplication.translate("PreferencesLexerError", 
-                "Unspecific PreferencesLexer error.")
+        self._errorMessage = QApplication.translate(
+            "PreferencesLexerError",
+            "Unspecific PreferencesLexer error.")
         
     def __repr__(self):
         """
@@ -36,7 +32,7 @@ class PreferencesLexerError(Exception):
         
         @return string representing the error message
         """
-        return unicode(self._errorMessage)
+        return repr(self._errorMessage)
         
     def __str__(self):
         """
@@ -44,7 +40,8 @@ class PreferencesLexerError(Exception):
         
         @return string representing the error message
         """
-        return str(self._errorMessage)
+        return self._errorMessage
+
 
 class PreferencesLexerLanguageError(PreferencesLexerError):
     """
@@ -53,24 +50,29 @@ class PreferencesLexerLanguageError(PreferencesLexerError):
     def __init__(self, language):
         """
         Constructor
+        
+        @param language lexer language (string)
         """
         PreferencesLexerError.__init__(self)
-        self._errorMessage = \
-            QApplication.translate("PreferencesLexerError",
-                'Unsupported Lexer Language: %1').arg(language)
+        self._errorMessage = QApplication.translate(
+            "PreferencesLexerError",
+            'Unsupported Lexer Language: {0}').format(language)
+
 
 class PreferencesLexer(QsciLexer):
-    """ 
+    """
     Subclass of QsciLexer to implement preferences specific lexer methods.
     """
     def __init__(self, language, parent=None):
         """
         Constructor
         
-        @param language The lexer language. (string or QString)
+        @param language The lexer language. (string)
         @param parent The parent widget of this lexer. (QextScintilla)
+        @exception PreferencesLexerLanguageError raised to indicate an invalid
+            lexer language
         """
-        QsciLexer.__init__(self, parent)
+        super().__init__(parent)
         
         # These default font families are taken from QScintilla
         if Globals.isWindowsPlatform():
@@ -81,7 +83,7 @@ class PreferencesLexer(QsciLexer):
             self.__defaultFontFamily = "Bitstream Vera Sans Mono"
         
         # instantiate a lexer object for the given language
-        language = unicode(language)
+        import QScintilla.Lexers
         lex = QScintilla.Lexers.getLexer(language)
         if lex is None:
             raise PreferencesLexerLanguageError(language)
@@ -97,7 +99,7 @@ class PreferencesLexer(QsciLexer):
         self.defaultFonts = {}
         self.descriptions = {}
         self.ind2style = {}
-        self.styles = QStringList()
+        self.styles = []
         
         # fill local store with default values from lexer
         # and built up styles list and conversion table from index to style
@@ -106,7 +108,7 @@ class PreferencesLexer(QsciLexer):
         index = 0
         for i in range(128):
             desc = lex.description(i)
-            if not desc.isEmpty():
+            if desc:
                 self.descriptions[i] = desc
                 self.styles.append(desc)
                 
@@ -127,14 +129,10 @@ class PreferencesLexer(QsciLexer):
                 self.ind2style[index] = i
                 index += 1
         
-        self.connect(self, SIGNAL("colorChanged (const QColor&, int)"), 
-                     self.setColor)
-        self.connect(self, SIGNAL("eolFillChanged (bool, int)"), 
-                     self.setEolFill)
-        self.connect(self, SIGNAL("fontChanged (const QFont&, int)"), 
-                     self.setFont)
-        self.connect(self, SIGNAL("paperChanged (const QColor&, int )"), 
-                     self.setPaper)
+        self.colorChanged.connect(self.setColor)
+        self.eolFillChanged.connect(self.setEolFill)
+        self.fontChanged.connect(self.setFont)
+        self.paperChanged.connect(self.setPaper)
         
         # read the last stored values from preferences file
         self.readSettings(Preferences.Prefs.settings, "Scintilla")
@@ -260,9 +258,9 @@ class PreferencesLexer(QsciLexer):
         Public method to get a descriptive string for a style.
         
         @param style the style number (int)
-        @return description of the style (QString)
+        @return description of the style (string)
         """
-        if self.descriptions.has_key(style):
+        if style in self.descriptions:
             return self.descriptions[style]
         else:
-            return QString()
+            return ""
