@@ -7,82 +7,82 @@
 Module implementing a dialog to add files of a directory to the project.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4DirCompleter
-
-from Ui_AddDirectoryDialog import Ui_AddDirectoryDialog
+from .Ui_AddDirectoryDialog import Ui_AddDirectoryDialog
 
 import Utilities
 
+
 class AddDirectoryDialog(QDialog, Ui_AddDirectoryDialog):
     """
     Class implementing a dialog to add files of a directory to the project.
     """
-    def __init__(self, pro, filter = 'source', parent = None, name = None, 
-                 startdir = None):
+    def __init__(self, pro, filter='source', parent=None, name=None,
+                 startdir=None):
         """
         Constructor
         
         @param pro reference to the project object
-        @param filter file type filter (string or QString)
+        @param filter file type filter (string)
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
         @param startdir start directory for the selection dialog
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
-        self.sourceDirCompleter = E4DirCompleter(self.sourceDirEdit)
-        self.targetDirCompleter = E4DirCompleter(self.targetDirEdit)
+        self.sourceDirCompleter = E5DirCompleter(self.sourceDirEdit)
+        self.targetDirCompleter = E5DirCompleter(self.targetDirEdit)
         
         self.ppath = pro.ppath
         self.targetDirEdit.setText(self.ppath)
         self.startdir = startdir
-        self.on_filterComboBox_highlighted(QString('(*.py)')) # enable all dialog elements
-        filter = unicode(filter)
+        self.on_filterComboBox_highlighted('(*.py)')
+        # enable all dialog elements
         if filter == 'source':  # it is a source file
-            self.filterComboBox.addItem(self.trUtf8("Source Files"), 
-                                        QVariant("SOURCES"))
+            self.filterComboBox.addItem(
+                self.trUtf8("Source Files"), "SOURCES")
         elif filter == 'form':
-            self.filterComboBox.addItem(self.trUtf8("Forms Files"), 
-                                        QVariant("FORMS"))
+            self.filterComboBox.addItem(
+                self.trUtf8("Forms Files"), "FORMS")
         elif filter == 'resource':
-            self.filterComboBox.addItem(self.trUtf8("Resource Files"), 
-                                        QVariant("RESOURCES"))
+            self.filterComboBox.addItem(
+                self.trUtf8("Resource Files"), "RESOURCES")
         elif filter == 'interface':
-            self.filterComboBox.addItem(self.trUtf8("Interface Files"), 
-                                        QVariant("INTERFACES"))
+            self.filterComboBox.addItem(
+                self.trUtf8("Interface Files"), "INTERFACES")
         elif filter == 'others':
-            self.filterComboBox.addItem(self.trUtf8("Other Files (*)"), 
-                                        QVariant("OTHERS"))
-            self.on_filterComboBox_highlighted(QString('(*)'))
+            self.filterComboBox.addItem(
+                self.trUtf8("Other Files (*)"), "OTHERS")
+            self.on_filterComboBox_highlighted('(*)')
         else:
-            self.filterComboBox.addItem(self.trUtf8("Source Files"), 
-                                        QVariant("SOURCES"))
-            self.filterComboBox.addItem(self.trUtf8("Forms Files"), 
-                                        QVariant("FORMS"))
-            self.filterComboBox.addItem(self.trUtf8("Resource Files"), 
-                                        QVariant("RESOURCES"))
-            self.filterComboBox.addItem(self.trUtf8("Interface Files"), 
-                                        QVariant("INTERFACES"))
-            self.filterComboBox.addItem(self.trUtf8("Other Files (*)"), 
-                                        QVariant("OTHERS"))
+            self.filterComboBox.addItem(
+                self.trUtf8("Source Files"), "SOURCES")
+            self.filterComboBox.addItem(
+                self.trUtf8("Forms Files"), "FORMS")
+            self.filterComboBox.addItem(
+                self.trUtf8("Resource Files"), "RESOURCES")
+            self.filterComboBox.addItem(
+                self.trUtf8("Interface Files"), "INTERFACES")
+            self.filterComboBox.addItem(
+                self.trUtf8("Other Files (*)"), "OTHERS")
         self.filterComboBox.setCurrentIndex(0)
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_filterComboBox_highlighted(self, fileType):
         """
         Private slot to handle the selection of a file type.
         
-        @param fileType the selected file type (QString)
+        @param fileType the selected file type (string)
         """
-        if fileType.endsWith('(*)'):
+        if fileType.endswith('(*)'):
             self.targetDirLabel.setEnabled(False)
             self.targetDirEdit.setEnabled(False)
             self.targetDirButton.setEnabled(False)
@@ -98,36 +98,35 @@ class AddDirectoryDialog(QDialog, Ui_AddDirectoryDialog):
         Private slot to display a directory selection dialog.
         
         @param textEdit field for the display of the selected directory name
-                (QLineEdit)
+            (QLineEdit)
         """
         startdir = textEdit.text()
-        if startdir.isEmpty() and self.startdir is not None:
+        if not startdir and self.startdir is not None:
             startdir = self.startdir
         
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select directory"),
-            startdir,
-            QFileDialog.Options(QFileDialog.Option(0)))
+            startdir)
         
-        if not directory.isEmpty():
+        if directory:
             textEdit.setText(Utilities.toNativeSeparators(directory))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_sourceDirButton_clicked(self):
         """
         Private slot to handle the source dir button press.
         """
         self.__dirDialog(self.sourceDirEdit)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_targetDirButton_clicked(self):
         """
         Private slot to handle the target dir button press.
         """
         self.__dirDialog(self.targetDirEdit)
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_sourceDirEdit_textChanged(self, dir):
         """
         Private slot to handle the source dir text changed.
@@ -137,9 +136,9 @@ class AddDirectoryDialog(QDialog, Ui_AddDirectoryDialog):
         It is assumed, that the user wants to add a bunch of files to
         the project in place.
         
-        @param dir the text of the source directory line edit
+        @param dir the text of the source directory line edit (string)
         """
-        if dir.startsWith(self.ppath):
+        if dir.startswith(self.ppath):
             self.targetDirEdit.setText(dir)
         
     def getData(self):
@@ -151,8 +150,9 @@ class AddDirectoryDialog(QDialog, Ui_AddDirectoryDialog):
             a flag indicating a recursive add
         """
         filetype = \
-            self.filterComboBox.itemData(self.filterComboBox.currentIndex()).toString()
-        return (unicode(filetype),
-            unicode(Utilities.toNativeSeparators(self.sourceDirEdit.text())), 
-            unicode(Utilities.toNativeSeparators(self.targetDirEdit.text())),
+            self.filterComboBox.itemData(self.filterComboBox.currentIndex())
+        return (
+            filetype,
+            Utilities.toNativeSeparators(self.sourceDirEdit.text()),
+            Utilities.toNativeSeparators(self.targetDirEdit.text()),
             self.recursiveCheckBox.isChecked())
