@@ -7,23 +7,23 @@
 Module implementing a dialog to add a new language to the project.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog
+
+from .Ui_AddLanguageDialog import Ui_AddLanguageDialog
 
-from Ui_AddLanguageDialog import Ui_AddLanguageDialog
 
 class AddLanguageDialog(QDialog, Ui_AddLanguageDialog):
     """
     Class implementing a dialog to add a new language to the project.
     """
-    def __init__(self, parent = None, name = None):
+    def __init__(self, parent=None, name=None):
         """
         Constructor
         
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
@@ -32,6 +32,6 @@ class AddLanguageDialog(QDialog, Ui_AddLanguageDialog):
         """
         Public method to retrieve the selected language.
         
-        @return the selected language (QString)
+        @return the selected language (string)
         """
         return self.languageCombo.currentText()
