@@ -4,72 +4,72 @@
 #
 
 """
-Module implementing a dialog to ente the data for a new dialog class file.
+Module implementing a dialog to enter the data for a new dialog class file.
 """
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, pyqtSlot
+from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4DirCompleter
+from .Ui_NewDialogClassDialog import Ui_NewDialogClassDialog
 
-from Ui_NewDialogClassDialog import Ui_NewDialogClassDialog
 
 class NewDialogClassDialog(QDialog, Ui_NewDialogClassDialog):
     """
     Class implementing a dialog to ente the data for a new dialog class file.
     """
-    def __init__(self, defaultClassName, defaultFile, defaultPath, parent = None):
+    def __init__(self, defaultClassName, defaultFile, defaultPath,
+                 parent=None):
         """
         Constructor
         
-        @param defaultClassName proposed name for the new class (string or QString)
-        @param defaultFile proposed name for the source file (string or QString)
-        @param defaultPath default path for the new file (string or QString)
+        @param defaultClassName proposed name for the new class (string)
+        @param defaultFile proposed name for the source file (string)
+        @param defaultPath default path for the new file (string)
         @param parent parent widget if the dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         self.okButton.setEnabled(False)
         
-        self.pathnameCompleter = E4DirCompleter(self.pathnameEdit)
+        self.pathnameCompleter = E5DirCompleter(self.pathnameEdit)
         
         self.classnameEdit.setText(defaultClassName)
         self.filenameEdit.setText(defaultFile)
         self.pathnameEdit.setText(QDir.toNativeSeparators(defaultPath))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pathButton_clicked(self):
         """
         Private slot called to open a directory selection dialog.
         """
-        path = KQFileDialog.getExistingDirectory(\
+        path = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select source directory"),
-            QDir.fromNativeSeparators(self.pathnameEdit.text()),
-            QFileDialog.Options(QFileDialog.Option(0)))
-        if not path.isEmpty():
+            QDir.fromNativeSeparators(self.pathnameEdit.text()))
+        if path:
             self.pathnameEdit.setText(QDir.toNativeSeparators(path))
         
     def __enableOkButton(self):
         """
         Private slot to set the enable state of theok button.
         """
-        self.okButton.setEnabled(\
-            not self.classnameEdit.text().isEmpty() and \
-            not self.filenameEdit.text().isEmpty() and \
-            not self.pathnameEdit.text().isEmpty())
+        self.okButton.setEnabled(
+            self.classnameEdit.text() != "" and
+            self.filenameEdit.text() != "" and
+            self.pathnameEdit.text() != "")
         
     def on_classnameEdit_textChanged(self, text):
         """
         Private slot called, when thext of the classname edit has changed.
         
-        @param text changed text (QString)
+        @param text changed text (string)
         """
         self.__enableOkButton()
         
@@ -77,7 +77,7 @@ class NewDialogClassDialog(QDialog, Ui_NewDialogClassDialog):
         """
         Private slot called, when thext of the filename edit has changed.
         
-        @param text changed text (QString)
+        @param text changed text (string)
         """
         self.__enableOkButton()
         
@@ -85,7 +85,7 @@ class NewDialogClassDialog(QDialog, Ui_NewDialogClassDialog):
         """
         Private slot called, when thext of the pathname edit has changed.
         
-        @param text changed text (QString)
+        @param text changed text (string)
         """
         self.__enableOkButton()
         
@@ -95,6 +95,6 @@ class NewDialogClassDialog(QDialog, Ui_NewDialogClassDialog):
         
         @return tuple giving the classname (string) and the file name (string)
         """
-        return unicode(self.classnameEdit.text()), \
-            os.path.join(unicode(self.pathnameEdit.text()), \
-                         unicode(self.filenameEdit.text()))
+        return self.classnameEdit.text(), \
+            os.path.join(self.pathnameEdit.text(),
+                         self.filenameEdit.text())
