@@ -8,38 +8,40 @@ Module implementing a dialog to add a new Python package.
 """
 
 from PyQt4.QtGui import QDialog, QDialogButtonBox
-from PyQt4.QtCore import pyqtSignature
+from PyQt4.QtCore import pyqtSlot
+
+from .Ui_NewPythonPackageDialog import Ui_NewPythonPackageDialog
 
-from Ui_NewPythonPackageDialog import Ui_NewPythonPackageDialog
 
 class NewPythonPackageDialog(QDialog, Ui_NewPythonPackageDialog):
     """
     Class implementing a dialog to add a new Python package.
     """
-    def __init__(self, relPath, parent = None):
+    def __init__(self, relPath, parent=None):
         """
         Constructor
         
         @param relPath initial package path relative to the project root
-            (string or QString)
+            (string)
+        @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         self.okButton.setEnabled(False)
         
-        rp = unicode(relPath).replace("/", ".").replace("\\", ".")
+        rp = relPath.replace("/", ".").replace("\\", ".")
         self.packageEdit.setText(rp)
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_packageEdit_textChanged(self, txt):
         """
         Private slot called, when the package name is changed.
         
-        @param txt new text of the package name edit (QString)
+        @param txt new text of the package name edit (string)
         """
-        self.okButton.setEnabled(not txt.isEmpty())
+        self.okButton.setEnabled(txt != "")
     
     def getData(self):
         """
@@ -47,4 +49,4 @@ class NewPythonPackageDialog(QDialog, Ui_NewPythonPackageDialog):
         
         @return package name (string)
         """
-        return unicode(self.packageEdit.text())
+        return self.packageEdit.text()
