@@ -8,32 +8,37 @@ Module implementing the baseclass for the various project browsers.
 """
 
 import os
-import sys
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QModelIndex, pyqtSignal, Qt
+from PyQt4.QtGui import QTreeView, QCursor, QItemSelection, \
+    QItemSelectionModel, QApplication, QMenu, QAbstractItemView, QDialog
 
-from KdeQt import KQMessageBox
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox
 
-from UI.Browser import *
+from UI.Browser import Browser
 
-from ProjectBrowserModel import *
-from ProjectBrowserSortFilterProxyModel import ProjectBrowserSortFilterProxyModel
+from .ProjectBrowserModel import ProjectBrowserSimpleDirectoryItem, \
+    ProjectBrowserDirectoryItem, ProjectBrowserFileItem
+from .ProjectBrowserSortFilterProxyModel import \
+    ProjectBrowserSortFilterProxyModel
 
-import UI.PixmapCache
-import Preferences
 
 class ProjectBaseBrowser(Browser):
     """
-    Baseclass implementing common functionality for the various project browsers.
+    Baseclass implementing common functionality for the various project
+    browsers.
+    
+    @signal closeSourceWindow(str) emitted to close a source file
     """
-    def __init__(self, project, type_, parent = None):
+    closeSourceWindow = pyqtSignal(str)
+    
+    def __init__(self, project, type_, parent=None):
         """
         Constructor
         
         @param project reference to the project object
-        @param type project browser type (string)
+        @param type_ project browser type (string)
         @param parent parent widget of this browser
         """
         QTreeView.__init__(self, parent)
@@ -53,17 +58,17 @@ class ProjectBaseBrowser(Browser):
         self.isTranslationsBrowser = False
         self.expandedNames = []
         
-        self.SelectFlags = QItemSelectionModel.SelectionFlags(\
+        self.SelectFlags = QItemSelectionModel.SelectionFlags(
             QItemSelectionModel.Select | QItemSelectionModel.Rows)
-        self.DeselectFlags = QItemSelectionModel.SelectionFlags(\
+        self.DeselectFlags = QItemSelectionModel.SelectionFlags(
             QItemSelectionModel.Deselect | QItemSelectionModel.Rows)
         
+        self._activating = False
+        
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"),
-                     self._contextMenuRequested)
-        self.connect(self, SIGNAL("activated(const QModelIndex &)"), self._openItem)
-        self.connect(self._model, SIGNAL("rowsInserted(const QModelIndex &, int, int)"),
-                     self.__modelRowsInserted)
+        self.customContextMenuRequested.connect(self._contextMenuRequested)
+        self.activated.connect(self._openItem)
+        self._model.rowsInserted.connect(self.__modelRowsInserted)
         self._connectExpandedCollapsed()
         
         self._createPopupMenus()
@@ -79,19 +84,15 @@ class ProjectBaseBrowser(Browser):
         """
         Protected method to connect the expanded and collapsed signals.
         """
-        self.connect(self, SIGNAL("expanded(const QModelIndex &)"), 
-            self._resizeColumns)
-        self.connect(self, SIGNAL("collapsed(const QModelIndex &)"), 
-            self._resizeColumns)
+        self.expanded.connect(self._resizeColumns)
+        self.collapsed.connect(self._resizeColumns)
         
     def _disconnectExpandedCollapsed(self):
         """
         Protected method to disconnect the expanded and collapsed signals.
         """
-        self.disconnect(self, SIGNAL("expanded(const QModelIndex &)"), 
-            self._resizeColumns)
-        self.disconnect(self, SIGNAL("collapsed(const QModelIndex &)"), 
-            self._resizeColumns)
+        self.expanded.disconnect(self._resizeColumns)
+        self.collapsed.disconnect(self._resizeColumns)
         
     def _createPopupMenus(self):
         """
@@ -100,18 +101,19 @@ class ProjectBaseBrowser(Browser):
         # create the popup menu for source files
         self.sourceMenu = QMenu(self)
         self.sourceMenu.addAction(
-            QApplication.translate('ProjectBaseBrowser', 'Open'), 
+            QApplication.translate('ProjectBaseBrowser', 'Open'),
             self._openItem)
         
         # create the popup menu for general use
         self.menu = QMenu(self)
         self.menu.addAction(
-            QApplication.translate('ProjectBaseBrowser', 'Open'), 
+            QApplication.translate('ProjectBaseBrowser', 'Open'),
             self._openItem)
 
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
-        self.multiMenu.addAction(QApplication.translate('ProjectBaseBrowser', 'Open'), 
+        self.multiMenu.addAction(
+            QApplication.translate('ProjectBaseBrowser', 'Open'),
             self._openItem)
         
         # create the background menu
@@ -158,7 +160,7 @@ class ProjectBaseBrowser(Browser):
         """
         if index.isValid():
             self.setCurrentIndex(index)
-            flags = QItemSelectionModel.SelectionFlags(\
+            flags = QItemSelectionModel.SelectionFlags(
                 QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
             self.selectionModel().select(index, flags)
         
@@ -170,8 +172,8 @@ class ProjectBaseBrowser(Browser):
         @param selected flag giving the new selection status (boolean)
         """
         if index.isValid():
-            self.selectionModel().select(index, 
-                selected and self.SelectFlags or self.DeselectFlags)
+            self.selectionModel().select(
+                index, selected and self.SelectFlags or self.DeselectFlags)
         
     def _setItemRangeSelected(self, startIndex, endIndex, selected):
         """
@@ -182,8 +184,8 @@ class ProjectBaseBrowser(Browser):
         @param selected flag giving the new selection status (boolean)
         """
         selection = QItemSelection(startIndex, endIndex)
-        self.selectionModel().select(selection, 
-            selected and self.SelectFlags or self.DeselectFlags)
+        self.selectionModel().select(
+            selection, selected and self.SelectFlags or self.DeselectFlags)
         
     def __modelRowsInserted(self, parent, start, end):
         """
@@ -224,10 +226,11 @@ class ProjectBaseBrowser(Browser):
             self.backMenu.setEnabled(True)
         
         if self.project.vcs is not None:
-            self.vcsHelper = self.project.vcs.vcsGetProjectBrowserHelper(self, 
-                self.project, self.isTranslationsBrowser)
-            self.vcsHelper.addVCSMenus(self.mainMenu, self.multiMenu,
-                self.backMenu, self.dirMenu, self.dirMultiMenu)
+            self.vcsHelper = self.project.vcs.vcsGetProjectBrowserHelper(
+                self, self.project, self.isTranslationsBrowser)
+            self.vcsHelper.addVCSMenus(
+                self.mainMenu, self.multiMenu, self.backMenu,
+                self.dirMenu, self.dirMultiMenu)
         
     def _newProject(self):
         """
@@ -243,10 +246,11 @@ class ProjectBaseBrowser(Browser):
             self.backMenu.setEnabled(True)
         
         if self.project.vcs is not None:
-            self.vcsHelper = self.project.vcs.vcsGetProjectBrowserHelper(self, 
-                self.project, self.isTranslationsBrowser)
-            self.vcsHelper.addVCSMenus(self.mainMenu, self.multiMenu,
-                self.backMenu, self.dirMenu, self.dirMultiMenu)
+            self.vcsHelper = self.project.vcs.vcsGetProjectBrowserHelper(
+                self, self.project, self.isTranslationsBrowser)
+            self.vcsHelper.addVCSMenus(
+                self.mainMenu, self.multiMenu, self.backMenu,
+                self.dirMenu, self.dirMultiMenu)
         
     def _removeFile(self):
         """
@@ -255,26 +259,54 @@ class ProjectBaseBrowser(Browser):
         itmList = self.getSelectedItems()
         
         for itm in itmList[:]:
-            fn = unicode(itm.fileName())
-            self.emit(SIGNAL('closeSourceWindow'), fn)
+            fn = itm.fileName()
+            self.closeSourceWindow.emit(fn)
             self.project.removeFile(fn)
         
     def _removeDir(self):
         """
         Protected method to remove a (single) directory from the project.
         """
-        itmList = self.getSelectedItems(\
+        itmList = self.getSelectedItems(
             [ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem])
         for itm in itmList[:]:
-            dn = unicode(itm.dirName())
+            dn = itm.dirName()
             self.project.removeDirectory(dn)
         
+    def _deleteDirectory(self):
+        """
+        Protected method to delete the selected directory from the project
+        data area.
+        """
+        itmList = self.getSelectedItems()
+        
+        dirs = []
+        fullNames = []
+        for itm in itmList:
+            dn = itm.dirName()
+            fullNames.append(dn)
+            dn = self.project.getRelativePath(dn)
+            dirs.append(dn)
+        
+        from UI.DeleteFilesConfirmationDialog import \
+            DeleteFilesConfirmationDialog
+        dlg = DeleteFilesConfirmationDialog(
+            self.parent(),
+            self.trUtf8("Delete directories"),
+            self.trUtf8("Do you really want to delete these directories from"
+                        " the project?"),
+            dirs)
+        
+        if dlg.exec_() == QDialog.Accepted:
+            for dn in fullNames:
+                self.project.deleteDirectory(dn)
+        
     def _renameFile(self):
         """
         Protected method to rename a file of the project.
         """
         itm = self.model().item(self.currentIndex())
-        fn = unicode(itm.fileName())
+        fn = itm.fileName()
         self.project.renameFile(fn)
         
     def _copyToClipboard(self):
@@ -283,10 +315,10 @@ class ProjectBaseBrowser(Browser):
         """
         itm = self.model().item(self.currentIndex())
         try:
-            fn = unicode(itm.fileName())
+            fn = itm.fileName()
         except AttributeError:
             try:
-                fn = unicode(itm.dirName())
+                fn = itm.dirName()
             except AttributeError:
                 fn = ""
         
@@ -297,9 +329,9 @@ class ProjectBaseBrowser(Browser):
         """
         Public method to highlight a node given its filename.
         
-        @param fn filename of file to be highlighted (string or QString)
+        @param fn filename of file to be highlighted (string)
         """
-        newfn = os.path.abspath(unicode(fn))
+        newfn = os.path.abspath(fn)
         newfn = self.project.getRelativePath(newfn)
         sindex = self._model.itemIndexByName(newfn)
         if sindex.isValid():
@@ -308,6 +340,22 @@ class ProjectBaseBrowser(Browser):
                 self._selectSingleItem(index)
                 self.scrollTo(index, QAbstractItemView.PositionAtTop)
         
+    def selectFileLine(self, fn, lineno):
+        """
+        Public method to highlight a node given its filename.
+        
+        @param fn filename of file to be highlighted (string)
+        @param lineno one based line number of the item (integer)
+        """
+        newfn = os.path.abspath(fn)
+        newfn = self.project.getRelativePath(newfn)
+        sindex = self._model.itemIndexByNameAndLine(newfn, lineno)
+        if sindex.isValid():
+            index = self.model().mapFromSource(sindex)
+            if index.isValid():
+                self._selectSingleItem(index)
+                self.scrollTo(index)
+        
     def _expandAllDirs(self):
         """
         Protected slot to handle the 'Expand all directories' menu action.
@@ -318,7 +366,7 @@ class ProjectBaseBrowser(Browser):
         index = self.model().index(0, 0)
         while index.isValid():
             itm = self.model().item(index)
-            if (isinstance(itm, ProjectBrowserSimpleDirectoryItem) or \
+            if (isinstance(itm, ProjectBrowserSimpleDirectoryItem) or
                 isinstance(itm, ProjectBrowserDirectoryItem)) and \
                not self.isExpanded(index):
                 self.expand(index)
@@ -345,7 +393,7 @@ class ProjectBaseBrowser(Browser):
         index = vindex
         while index.isValid():
             itm = self.model().item(index)
-            if (isinstance(itm, ProjectBrowserSimpleDirectoryItem) or \
+            if (isinstance(itm, ProjectBrowserSimpleDirectoryItem) or
                 isinstance(itm, ProjectBrowserDirectoryItem)) and \
                self.isExpanded(index):
                 self.collapse(index)
@@ -356,12 +404,12 @@ class ProjectBaseBrowser(Browser):
         
     def _showContextMenu(self, menu):
         """
-        Protected slot called before the context menu is shown. 
+        Protected slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
         
-        @param menu reference to the menu to be shown
+        @param menu reference to the menu to be shown (QMenu)
         """
         if self.project.vcs is None:
             for act in self.menuActions:
@@ -371,12 +419,13 @@ class ProjectBaseBrowser(Browser):
         
     def _showContextMenuMulti(self, menu):
         """
-        Protected slot called before the context menu (multiple selections) is shown. 
+        Protected slot called before the context menu (multiple selections) is
+        shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the files status.
         
-        @param menu reference to the menu to be shown
+        @param menu reference to the menu to be shown (QMenu)
         """
         if self.project.vcs is None:
             for act in self.multiMenuActions:
@@ -386,12 +435,12 @@ class ProjectBaseBrowser(Browser):
         
     def _showContextMenuDir(self, menu):
         """
-        Protected slot called before the context menu is shown. 
+        Protected slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
         
-        @param menu reference to the menu to be shown
+        @param menu reference to the menu to be shown (QMenu)
         """
         if self.project.vcs is None:
             for act in self.dirMenuActions:
@@ -401,43 +450,45 @@ class ProjectBaseBrowser(Browser):
         
     def _showContextMenuDirMulti(self, menu):
         """
-        Protected slot called before the context menu is shown. 
+        Protected slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
         
-        @param menu reference to the menu to be shown
+        @param menu reference to the menu to be shown (QMenu)
         """
         if self.project.vcs is None:
             for act in self.dirMultiMenuActions:
                 act.setEnabled(True)
         else:
-            self.vcsHelper.showContextMenuDirMulti(menu, self.dirMultiMenuActions)
+            self.vcsHelper.showContextMenuDirMulti(
+                menu, self.dirMultiMenuActions)
         
     def _showContextMenuBack(self, menu):
         """
-        Protected slot called before the context menu is shown. 
+        Protected slot called before the context menu is shown.
         
-        @param menu reference to the menu to be shown
+        @param menu reference to the menu to be shown (QMenu)
         """
         # nothing to do for now
         return
         
-    def _selectEntries(self, local = True, filter = None):
+    def _selectEntries(self, local=True, filter=None):
         """
         Protected method to select entries based on their VCS status.
         
-        @param local flag indicating local (i.e. non VCS controlled) file/directory
-            entries should be selected (boolean)
+        @param local flag indicating local (i.e. non VCS controlled)
+            file/directory entries should be selected (boolean)
         @param filter list of classes to check against
         """
         if self.project.vcs is None:
             return
         
         if local:
-            compareString = QApplication.translate('ProjectBaseBrowser', "local")
+            compareString = \
+                QApplication.translate('ProjectBaseBrowser', "local")
         else:
-            compareString = QString(self.project.vcs.vcsName())
+            compareString = self.project.vcs.vcsName()
         
         # expand all directories in order to iterate over all entries
         self._expandAllDirs()
@@ -455,7 +506,7 @@ class ProjectBaseBrowser(Browser):
         while index.isValid():
             itm = self.model().item(index)
             if self.wantedItem(itm, filter) and \
-               QString.compare(compareString, itm.data(1)) == 0:
+               compareString == itm.data(1):
                 if startIndex is not None and \
                    startIndex.parent() != index.parent():
                     self._setItemRangeSelected(startIndex, endIndex, True)
@@ -475,48 +526,55 @@ class ProjectBaseBrowser(Browser):
         QApplication.processEvents()
         
         if selectedEntries == 0:
-            KQMessageBox.information(None,
-            QApplication.translate('ProjectBaseBrowser', "Select entries"),
-            QApplication.translate('ProjectBaseBrowser', 
-                """There were no matching entries found."""))
+            E5MessageBox.information(
+                self,
+                QApplication.translate('ProjectBaseBrowser', "Select entries"),
+                QApplication.translate(
+                    'ProjectBaseBrowser',
+                    """There were no matching entries found."""))
         
     def selectLocalEntries(self):
         """
-        Public slot to handle the select local files context menu entries
+        Public slot to handle the select local files context menu entries.
         """
-        self._selectEntries(local = True, filter = [ProjectBrowserFileItem])
+        self._selectEntries(local=True, filter=[ProjectBrowserFileItem])
         
     def selectVCSEntries(self):
         """
-        Public slot to handle the select VCS files context menu entries
+        Public slot to handle the select VCS files context menu entries.
         """
-        self._selectEntries(local = False, filter = [ProjectBrowserFileItem])
+        self._selectEntries(local=False, filter=[ProjectBrowserFileItem])
         
     def selectLocalDirEntries(self):
         """
-        Public slot to handle the select local directories context menu entries
+        Public slot to handle the select local directories context menu
+        entries.
         """
-        self._selectEntries(local = True,
-            filter=[ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem])
+        self._selectEntries(
+            local=True,
+            filter=[ProjectBrowserSimpleDirectoryItem,
+                    ProjectBrowserDirectoryItem])
         
     def selectVCSDirEntries(self):
         """
-        Public slot to handle the select VCS directories context menu entries
+        Public slot to handle the select VCS directories context menu entries.
         """
-        self._selectEntries(local = False,
-            filter=[ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem])
+        self._selectEntries(
+            local=False,
+            filter=[ProjectBrowserSimpleDirectoryItem,
+                    ProjectBrowserDirectoryItem])
         
     def _prepareRepopulateItem(self, name):
         """
         Protected slot to handle the prepareRepopulateItem signal.
         
-        @param name relative name of file item to be repopulated
+        @param name relative name of file item to be repopulated (string)
         """
         QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
         QApplication.processEvents()
         itm = self.currentItem()
         if itm is not None:
-            self.currentItemName = QString(itm.data(0))
+            self.currentItemName = itm.data(0)
         self.expandedNames = []
         sindex = self._model.itemIndexByName(name)
         if not sindex.isValid():
@@ -531,31 +589,37 @@ class ProjectBaseBrowser(Browser):
             if childIndex.parent() == index.parent():
                 break
             if self.isExpanded(childIndex):
-                self.expandedNames.append(QString(self.model().item(childIndex).data(0)))
+                self.expandedNames.append(
+                    self.model().item(childIndex).data(0))
             childIndex = self.indexBelow(childIndex)
         
     def _completeRepopulateItem(self, name):
         """
         Protected slot to handle the completeRepopulateItem signal.
         
-        @param name relative name of file item to be repopulated
+        @param name relative name of file item to be repopulated (string)
         """
         sindex = self._model.itemIndexByName(name)
         if sindex.isValid():
             index = self.model().mapFromSource(sindex)
             if index.isValid():
-                childIndex = self.indexBelow(index)
-                while childIndex.isValid():
-                    if not childIndex.isValid() or childIndex.parent() == index.parent():
-                        break
-                    itm = self.model().item(childIndex)
-                    if itm is not None:
-                        itemData = QString(itm.data(0))
-                        if self.currentItemName and self.currentItemName == itemData:
-                            self._selectSingleItem(childIndex)
-                        if itemData in self.expandedNames:
-                            self.setExpanded(childIndex, True)
-                    childIndex = self.indexBelow(childIndex)
+                if self.isExpanded(index):
+                    childIndex = self.indexBelow(index)
+                    while childIndex.isValid():
+                        if not childIndex.isValid() or \
+                                childIndex.parent() == index.parent():
+                            break
+                        itm = self.model().item(childIndex)
+                        if itm is not None:
+                            itemData = itm.data(0)
+                            if self.currentItemName and \
+                                    self.currentItemName == itemData:
+                                self._selectSingleItem(childIndex)
+                            if itemData in self.expandedNames:
+                                self.setExpanded(childIndex, True)
+                        childIndex = self.indexBelow(childIndex)
+                else:
+                    self._selectSingleItem(index)
                 self.expandedNames = []
         self.currentItemName = None
         QApplication.restoreOverrideCursor()
@@ -571,9 +635,9 @@ class ProjectBaseBrowser(Browser):
         itm = self.model().item(self.currentIndex())
         return itm
     
-    ############################################################################
+    ###########################################################################
     ## Support for hooks below
-    ############################################################################
+    ###########################################################################
     
     def _initHookMethods(self):
         """
@@ -587,7 +651,10 @@ class ProjectBaseBrowser(Browser):
         
     def __checkHookKey(self, key):
         """
-        Private method to check a hook key
+        Private method to check a hook key.
+        
+        @param key key of the hook to check (string)
+        @exception KeyError raised to indicate an invalid hook
         """
         if len(self.hooks) == 0:
             raise KeyError("Hooks are not initialized.")
@@ -611,10 +678,10 @@ class ProjectBaseBrowser(Browser):
         
         @param key for the hook method (string)
         @param method reference to the hook method (method object)
-        @param menuEntry entry to be shown in the context menu (QString)
+        @param menuEntry entry to be shown in the context menu (string)
         """
         self.addHookMethod(key, method)
-        self.hooksMenuEntries[key] = QString(menuEntry)
+        self.hooksMenuEntries[key] = menuEntry
         
     def removeHookMethod(self, key):
         """
@@ -635,4 +702,5 @@ class ProjectBaseBrowser(Browser):
         """
         Protected method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("projectBrowserPage")
+        e5App().getObject("UserInterface")\
+            .showPreferences("projectBrowserPage")
