@@ -4,37 +4,28 @@
 #
 
 """
-Module implementing the project browser part of the eric4 UI.
+Module implementing the project browser part of the eric5 UI.
 """
 
-import os
-import sys
-
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt
+from PyQt4.QtGui import QColor, QApplication
 
 from UI.Browser import Browser
 
-from E4Gui.E4TabWidget import E4TabWidget
-from E4Gui.E4Led import E4Led
-
-from ProjectSourcesBrowser import ProjectSourcesBrowser
-from ProjectFormsBrowser import ProjectFormsBrowser
-from ProjectTranslationsBrowser import ProjectTranslationsBrowser
-from ProjectResourcesBrowser import ProjectResourcesBrowser
-from ProjectInterfacesBrowser import ProjectInterfacesBrowser
-from ProjectOthersBrowser import ProjectOthersBrowser
+from E5Gui.E5TabWidget import E5TabWidget
+from E5Gui.E5Led import E5Led
 
 import UI.PixmapCache
 import Preferences
 
-from ProjectBrowserFlags import SourcesBrowserFlag, FormsBrowserFlag, \
+from .ProjectBrowserFlags import SourcesBrowserFlag, FormsBrowserFlag, \
     ResourcesBrowserFlag, TranslationsBrowserFlag, InterfacesBrowserFlag, \
     OthersBrowserFlag, AllBrowsersFlag
 
-class ProjectBrowser(E4TabWidget):
+
+class ProjectBrowser(E5TabWidget):
     """
-    Class implementing the project browser part of the eric4 UI.
+    Class implementing the project browser part of the eric5 UI.
     
     It generates a widget with up to seven tabs. The individual tabs contain
     the project sources browser, the project forms browser,
@@ -43,8 +34,7 @@ class ProjectBrowser(E4TabWidget):
     that doesn't fit these categories. Optionally it contains an additional
     tab with the file system browser.
     """
-    
-    def __init__(self, project, parent = None, embeddedBrowser = True):
+    def __init__(self, project, parent=None, embeddedBrowser=True):
         """
         Constructor
         
@@ -55,35 +45,41 @@ class ProjectBrowser(E4TabWidget):
             have the file browser in a separate window or embedded
             in the debeug browser instead
         """
-        E4TabWidget.__init__(self, parent)
+        E5TabWidget.__init__(self, parent)
         self.project = project
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         
         self.setUsesScrollButtons(True)
         
-        self.vcsStatusIndicator = E4Led(self)
+        self.vcsStatusIndicator = E5Led(self)
         self.setCornerWidget(self.vcsStatusIndicator, Qt.TopLeftCorner)
         self.vcsStatusColorNames = {
-            "A" : "VcsAdded",
-            "M" : "VcsModified",
-            "O" : "VcsRemoved", 
-            "R" : "VcsReplaced", 
-            "U" : "VcsUpdate",
-            "Z" : "VcsConflict",
+            "A": "VcsAdded",
+            "M": "VcsModified",
+            "O": "VcsRemoved",
+            "R": "VcsReplaced",
+            "U": "VcsUpdate",
+            "Z": "VcsConflict",
         }
         self.vcsStatusText = {
-            " " : self.trUtf8("up to date"), 
-            "A" : self.trUtf8("files added"), 
-            "M" : self.trUtf8("local modifications"), 
-            "O" : self.trUtf8("files removed"), 
-            "R" : self.trUtf8("files replaced"), 
-            "U" : self.trUtf8("update required"), 
-            "Z" : self.trUtf8("conflict"), 
+            " ": self.trUtf8("up to date"),
+            "A": self.trUtf8("files added"),
+            "M": self.trUtf8("local modifications"),
+            "O": self.trUtf8("files removed"),
+            "R": self.trUtf8("files replaced"),
+            "U": self.trUtf8("update required"),
+            "Z": self.trUtf8("conflict"),
         }
         self.__vcsStateChanged(" ")
         
         # step 1: create all the individual browsers
+        from .ProjectSourcesBrowser import ProjectSourcesBrowser
+        from .ProjectFormsBrowser import ProjectFormsBrowser
+        from .ProjectTranslationsBrowser import ProjectTranslationsBrowser
+        from .ProjectResourcesBrowser import ProjectResourcesBrowser
+        from .ProjectInterfacesBrowser import ProjectInterfacesBrowser
+        from .ProjectOthersBrowser import ProjectOthersBrowser
         # sources browser
         self.psBrowser = ProjectSourcesBrowser(self.project)
         # forms browser
@@ -104,77 +100,49 @@ class ProjectBrowser(E4TabWidget):
         
         # step 2: connect all the browsers
         # connect the sources browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.psBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.psBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.psBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.psBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.psBrowser._projectClosed)
+        self.project.projectOpened.connect(self.psBrowser._projectOpened)
+        self.project.newProject.connect(self.psBrowser._newProject)
+        self.project.reinitVCS.connect(self.psBrowser._initMenusAndVcs)
         
         # connect the forms browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.pfBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.pfBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.pfBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.pfBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.pfBrowser._projectClosed)
+        self.project.projectOpened.connect(self.pfBrowser._projectOpened)
+        self.project.newProject.connect(self.pfBrowser._newProject)
+        self.project.reinitVCS.connect(self.pfBrowser._initMenusAndVcs)
         
         # connect the resources browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.prBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.prBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.prBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.prBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.prBrowser._projectClosed)
+        self.project.projectOpened.connect(self.prBrowser._projectOpened)
+        self.project.newProject.connect(self.prBrowser._newProject)
+        self.project.reinitVCS.connect(self.prBrowser._initMenusAndVcs)
         
         # connect the translations browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.ptBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.ptBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.ptBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.ptBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.ptBrowser._projectClosed)
+        self.project.projectOpened.connect(self.ptBrowser._projectOpened)
+        self.project.newProject.connect(self.ptBrowser._newProject)
+        self.project.reinitVCS.connect(self.ptBrowser._initMenusAndVcs)
         
         # connect the interfaces (IDL)  browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.piBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.piBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.piBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.piBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.piBrowser._projectClosed)
+        self.project.projectOpened.connect(self.piBrowser._projectOpened)
+        self.project.newProject.connect(self.piBrowser._newProject)
+        self.project.reinitVCS.connect(self.piBrowser._initMenusAndVcs)
         
         # connect the others browser
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.poBrowser._projectClosed)
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.poBrowser._projectOpened)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.poBrowser._newProject)
-        self.connect(self.project, SIGNAL('reinitVCS'),
-                self.poBrowser._initMenusAndVcs)
+        self.project.projectClosed.connect(self.poBrowser._projectClosed)
+        self.project.projectOpened.connect(self.poBrowser._projectOpened)
+        self.project.newProject.connect(self.poBrowser._newProject)
+        self.project.reinitVCS.connect(self.poBrowser._initMenusAndVcs)
         
         # add signal connection to ourself
-        self.connect(self.project, SIGNAL('projectOpened'),
-                self.__projectOpened)
-        self.connect(self.project, SIGNAL('projectClosed'),
-                self.__projectClosed)
-        self.connect(self.project, SIGNAL('newProject'),
-                self.__newProject)
-        self.connect(self.project, SIGNAL('projectPropertiesChanged'),
-                self.__projectPropertiesChanged)
-        self.connect(self, SIGNAL("currentChanged(int)"), self.__currentChanged)
-        self.connect(self.project.getModel(), SIGNAL("vcsStateChanged"), 
-                self.__vcsStateChanged)
+        self.project.projectOpened.connect(self.__projectOpened)
+        self.project.projectClosed.connect(self.__projectClosed)
+        self.project.newProject.connect(self.__newProject)
+        self.project.projectPropertiesChanged.connect(
+            self.__projectPropertiesChanged)
+        self.currentChanged.connect(self.__currentChanged)
+        self.project.getModel().vcsStateChanged.connect(self.__vcsStateChanged)
         
         self.__currentBrowsersFlags = 0
         self.__projectPropertiesChanged()
@@ -185,7 +153,7 @@ class ProjectBrowser(E4TabWidget):
         
     def __setBrowsersAvailable(self, browserFlags):
         """
-        Private method to add selected browsers to the project browser
+        Private method to add selected browsers to the project browser.
         
         @param browserFlags flags indicating the browsers to add (integer)
         """
@@ -195,37 +163,44 @@ class ProjectBrowser(E4TabWidget):
         
         # step 2: add browsers
         if browserFlags & SourcesBrowserFlag:
-            index = self.addTab(self.psBrowser,
+            index = self.addTab(
+                self.psBrowser,
                 UI.PixmapCache.getIcon("projectSources.png"), '')
             self.setTabToolTip(index, self.psBrowser.windowTitle())
         
         if browserFlags & FormsBrowserFlag:
-            index = self.addTab(self.pfBrowser, 
+            index = self.addTab(
+                self.pfBrowser,
                 UI.PixmapCache.getIcon("projectForms.png"), '')
             self.setTabToolTip(index, self.pfBrowser.windowTitle())
         
         if browserFlags & ResourcesBrowserFlag:
-            index = self.addTab(self.prBrowser, 
+            index = self.addTab(
+                self.prBrowser,
                 UI.PixmapCache.getIcon("projectResources.png"), '')
             self.setTabToolTip(index, self.prBrowser.windowTitle())
         
         if browserFlags & TranslationsBrowserFlag:
-            index = self.addTab(self.ptBrowser, 
+            index = self.addTab(
+                self.ptBrowser,
                 UI.PixmapCache.getIcon("projectTranslations.png"), '')
             self.setTabToolTip(index, self.ptBrowser.windowTitle())
         
         if browserFlags & InterfacesBrowserFlag:
-            index = self.addTab(self.piBrowser, 
+            index = self.addTab(
+                self.piBrowser,
                 UI.PixmapCache.getIcon("projectInterfaces.png"), '')
             self.setTabToolTip(index, self.piBrowser.windowTitle())
         
         if browserFlags & OthersBrowserFlag:
-            index = self.addTab(self.poBrowser, 
+            index = self.addTab(
+                self.poBrowser,
                 UI.PixmapCache.getIcon("projectOthers.png"), '')
             self.setTabToolTip(index, self.poBrowser.windowTitle())
         
         if self.embeddedBrowser:
-            index = self.addTab(self.fileBrowser, 
+            index = self.addTab(
+                self.fileBrowser,
                 UI.PixmapCache.getIcon("browser.png"), '')
             self.setTabToolTip(index, self.fileBrowser.windowTitle())
         
@@ -237,13 +212,15 @@ class ProjectBrowser(E4TabWidget):
         
         @param evt show event to handle (QShowEvent)
         """
-        E4TabWidget.showEvent(self, evt)
+        E5TabWidget.showEvent(self, evt)
         if self.embeddedBrowser:
             self.fileBrowser.layoutDisplay()
         
     def __currentChanged(self, index):
         """
         Private slot to handle the currentChanged(int) signal.
+        
+        @param index index of the tab (integer)
         """
         if index > -1:
             browser = self.widget(index)
@@ -282,7 +259,8 @@ class ProjectBrowser(E4TabWidget):
         Private slot to handle the projectPropertiesChanged signal.
         """
         if self.project.isOpen():
-            flags = Preferences.getProjectBrowserFlags(self.project.getProjectType())
+            flags = Preferences.getProjectBrowserFlags(
+                self.project.getProjectType())
         else:
             flags = AllBrowsersFlag
         
@@ -294,7 +272,7 @@ class ProjectBrowser(E4TabWidget):
             endIndex = self.count() - 1
         else:
             endIndex = self.count()
-        for index in range(endIndex) :
+        for index in range(endIndex):
             self.setTabEnabled(index, self.project.isOpen())
         
         self.__setSourcesIcon()
@@ -306,7 +284,8 @@ class ProjectBrowser(E4TabWidget):
         if not self.project.isOpen():
             icon = UI.PixmapCache.getIcon("projectSources.png")
         else:
-            if self.project.pdata["PROGLANGUAGE"][0] in ["Python", "Python3"]:
+            if self.project.pdata["PROGLANGUAGE"][0] in \
+                    ["Python", "Python2", "Python3"]:
                 if self.project.pdata["MIXEDLANGUAGE"][0]:
                     icon = UI.PixmapCache.getIcon("projectSourcesPyMixed.png")
                 else:
@@ -324,7 +303,7 @@ class ProjectBrowser(E4TabWidget):
         """
         Public slot to handle the editorChanged signal.
         
-        @param fn The filename of the saved files. (string or QString)
+        @param fn filename of the changed file (string)
         """
         if Preferences.getProject("FollowEditor"):
             if self.project.isProjectSource(fn):
@@ -334,6 +313,18 @@ class ProjectBrowser(E4TabWidget):
             elif self.project.isProjectInterface(fn):
                 self.piBrowser.selectFile(fn)
     
+    def handleEditorLineChanged(self, fn, lineno):
+        """
+        Public slot to handle the editorLineChanged signal.
+        
+        @param fn filename of the changed file (string)
+        @param lineno one based line number of the item (integer)
+        """
+        if Preferences.getProject("FollowEditor") and \
+           Preferences.getProject("FollowCursorLine"):
+            if self.project.isProjectSource(fn):
+                self.psBrowser.selectFileLine(fn, lineno)
+    
     def getProjectBrowsers(self):
         """
         Public method to get references to the individual project browsers.
@@ -384,8 +375,9 @@ class ProjectBrowser(E4TabWidget):
         if state == " " or state not in self.vcsStatusColorNames:
             self.vcsStatusIndicator.setColor(QColor(Qt.lightGray))
         else:
-            self.vcsStatusIndicator.setColor(\
-                Preferences.getProjectBrowserColour(self.vcsStatusColorNames[state]))
+            self.vcsStatusIndicator.setColor(
+                Preferences.getProjectBrowserColour(
+                    self.vcsStatusColorNames[state]))
         if state not in self.vcsStatusText:
             self.vcsStatusIndicator.setToolTip(self.trUtf8("unknown status"))
         else:
