@@ -7,13 +7,14 @@
 Module implementing the browser model.
 """
 
-import sys
 import os
+import re
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, QModelIndex, pyqtSignal, QFileSystemWatcher, Qt
+from PyQt4.QtGui import QColor
 
-from UI.BrowserModel import *
+from UI.BrowserModel import BrowserModel, BrowserItem, BrowserDirectoryItem, \
+    BrowserFileItem
 
 import UI.PixmapCache
 import Preferences
@@ -21,17 +22,18 @@ import Utilities
 
 import Utilities.ModuleParser
 
-ProjectBrowserItemSimpleDirectory  = 100
-ProjectBrowserItemDirectory        = 101
-ProjectBrowserItemFile             = 102
+ProjectBrowserItemSimpleDirectory = 100
+ProjectBrowserItemDirectory = 101
+ProjectBrowserItemFile = 102
 
-ProjectBrowserNoType          = 0
-ProjectBrowserSourceType      = 1
-ProjectBrowserFormType        = 2
-ProjectBrowserInterfaceType   = 3
+ProjectBrowserNoType = 0
+ProjectBrowserSourceType = 1
+ProjectBrowserFormType = 2
+ProjectBrowserInterfaceType = 3
 ProjectBrowserTranslationType = 4
-ProjectBrowserOthersType      = 5
-ProjectBrowserResourceType    = 6
+ProjectBrowserOthersType = 5
+ProjectBrowserResourceType = 6
+
 
 class ProjectBrowserItemMixin(object):
     """
@@ -39,7 +41,7 @@ class ProjectBrowserItemMixin(object):
     
     It is meant to be used as a mixin class.
     """
-    def __init__(self, type_, bold = False):
+    def __init__(self, type_, bold=False):
         """
         Constructor
         
@@ -54,12 +56,12 @@ class ProjectBrowserItemMixin(object):
         """
         Public method to get the items text color.
         
-        @return text color (QVariant(QColor))
+        @return text color (QColor)
         """
         if self.bold:
-            return QVariant(Preferences.getProjectBrowserColour("Highlighted"))
+            return Preferences.getProjectBrowserColour("Highlighted")
         else:
-            return QVariant()
+            return None
     
     def setVcsState(self, state):
         """
@@ -73,7 +75,7 @@ class ProjectBrowserItemMixin(object):
         """
         Public method to add the VCS status.
         
-        @param vcsStatus VCS status text (string or QString)
+        @param vcsStatus VCS status text (string)
         """
         self.itemData.append(vcsStatus)
     
@@ -81,7 +83,7 @@ class ProjectBrowserItemMixin(object):
         """
         Public method to set the VCS status.
         
-        @param vcsStatus VCS status text (string or QString)
+        @param vcsStatus VCS status text (string)
         """
         self.itemData[1] = vcsStatus
     
@@ -101,23 +103,25 @@ class ProjectBrowserItemMixin(object):
         """
         self._projectTypes.append(type_)
 
+
 class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
     """
-    Class implementing the data structure for project browser simple directory items.
+    Class implementing the data structure for project browser simple directory
+    items.
     """
-    def __init__(self, parent, projectType, text, path = ""):
+    def __init__(self, parent, projectType, text, path=""):
         """
         Constructor
         
         @param parent parent item
         @param projectType type of file/directory in the project
-        @param text text to be displayed (string or QString)
-        @param path path of the directory (string or QString)
+        @param text text to be displayed (string)
+        @param path path of the directory (string)
         """
         BrowserItem.__init__(self, parent, text)
         ProjectBrowserItemMixin.__init__(self, projectType)
         
-        self._dirName = unicode(path)
+        self._dirName = path
         if not os.path.isdir(self._dirName):
             self._dirName = os.path.dirname(self._dirName)
         
@@ -128,14 +132,14 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         else:
             self.icon = UI.PixmapCache.getIcon("dirClosed.png")
     
-    def setName(self, dinfo, full = True):
+    def setName(self, dinfo, full=True):
         """
         Public method to set the directory name.
         
-        @param dinfo dinfo is the string for the directory (string or QString)
+        @param dinfo dinfo is the string for the directory (string)
         @param full flag indicating full pathname should be displayed (boolean)
         """
-        self._dirName = os.path.abspath(unicode(dinfo))
+        self._dirName = os.path.abspath(dinfo)
         self.itemData[0] = os.path.basename(self._dirName)
     
     def dirName(self):
@@ -161,16 +165,18 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         
         return BrowserItem.lessThan(self, other, column, order)
 
-class ProjectBrowserDirectoryItem(BrowserDirectoryItem, ProjectBrowserItemMixin):
+
+class ProjectBrowserDirectoryItem(BrowserDirectoryItem,
+                                  ProjectBrowserItemMixin):
     """
     Class implementing the data structure for project browser directory items.
     """
-    def __init__(self, parent, dinfo, projectType, full = True, bold = False):
+    def __init__(self, parent, dinfo, projectType, full=True, bold=False):
         """
         Constructor
         
         @param parent parent item
-        @param dinfo dinfo is the string for the directory (string or QString)
+        @param dinfo dinfo is the string for the directory (string)
         @param projectType type of file/directory in the project
         @param full flag indicating full pathname should be displayed (boolean)
         @param bold flag indicating a highlighted font (boolean)
@@ -180,12 +186,13 @@ class ProjectBrowserDirectoryItem(BrowserDirectoryItem, ProjectBrowserItemMixin)
         
         self.type_ = ProjectBrowserItemDirectory
 
+
 class ProjectBrowserFileItem(BrowserFileItem, ProjectBrowserItemMixin):
     """
     Class implementing the data structure for project browser file items.
     """
-    def __init__(self, parent, finfo, projectType, full = True, bold = False,
-                 sourceLanguage = ""):
+    def __init__(self, parent, finfo, projectType, full=True, bold=False,
+                 sourceLanguage=""):
         """
         Constructor
         
@@ -201,62 +208,65 @@ class ProjectBrowserFileItem(BrowserFileItem, ProjectBrowserItemMixin):
         
         self.type_ = ProjectBrowserItemFile
 
+
 class ProjectBrowserModel(BrowserModel):
     """
     Class implementing the project browser model.
     
-    @signal vcsStateChanged(string) emitted after the VCS state has changed
+    @signal vcsStateChanged(str) emitted after the VCS state has changed
     """
+    vcsStateChanged = pyqtSignal(str)
+    
     def __init__(self, parent):
         """
         Constructor
         
         @param parent reference to parent object (Project.Project)
         """
-        QAbstractItemModel.__init__(self, parent)
+        super().__init__(parent, nopopulate=True)
         
-        rootData = QVariant(self.trUtf8("Name"))
+        rootData = self.trUtf8("Name")
         self.rootItem = BrowserItem(None, rootData)
-        self.rootItem.itemData.append(QVariant(self.trUtf8("VCS Status")))
+        self.rootItem.itemData.append(self.trUtf8("VCS Status"))
         
         self.progDir = None
         self.project = parent
         
         self.watchedItems = {}
         self.watcher = QFileSystemWatcher(self)
-        self.connect(self.watcher, SIGNAL("directoryChanged(const QString&)"), 
-                     self.directoryChanged)
+        self.watcher.directoryChanged.connect(self.directoryChanged)
         
         self.inRefresh = False
         
         self.projectBrowserTypes = {
-            "SOURCES"      : ProjectBrowserSourceType,
-            "FORMS"        : ProjectBrowserFormType,
-            "RESOURCES"    : ProjectBrowserResourceType,
-            "INTERFACES"   : ProjectBrowserInterfaceType,
-            "TRANSLATIONS" : ProjectBrowserTranslationType,
-            "OTHERS"       : ProjectBrowserOthersType,
+            "SOURCES": ProjectBrowserSourceType,
+            "FORMS": ProjectBrowserFormType,
+            "RESOURCES": ProjectBrowserResourceType,
+            "INTERFACES": ProjectBrowserInterfaceType,
+            "TRANSLATIONS": ProjectBrowserTranslationType,
+            "OTHERS": ProjectBrowserOthersType,
         }
         
         self.colorNames = {
-            "A" : "VcsAdded",
-            "M" : "VcsModified",
-            "O" : "VcsRemoved", 
-            "R" : "VcsReplaced", 
-            "U" : "VcsUpdate",
-            "Z" : "VcsConflict",
+            "A": "VcsAdded",
+            "M": "VcsModified",
+            "O": "VcsRemoved",
+            "R": "VcsReplaced",
+            "U": "VcsUpdate",
+            "Z": "VcsConflict",
         }
         self.itemBackgroundColors = {
-            " " : QColor(),
-            "A" : Preferences.getProjectBrowserColour(self.colorNames["A"]),
-            "M" : Preferences.getProjectBrowserColour(self.colorNames["M"]),
-            "O" : Preferences.getProjectBrowserColour(self.colorNames["O"]),
-            "R" : Preferences.getProjectBrowserColour(self.colorNames["R"]),
-            "U" : Preferences.getProjectBrowserColour(self.colorNames["U"]),
-            "Z" : Preferences.getProjectBrowserColour(self.colorNames["Z"]),
+            " ": QColor(),
+            "A": Preferences.getProjectBrowserColour(self.colorNames["A"]),
+            "M": Preferences.getProjectBrowserColour(self.colorNames["M"]),
+            "O": Preferences.getProjectBrowserColour(self.colorNames["O"]),
+            "R": Preferences.getProjectBrowserColour(self.colorNames["R"]),
+            "U": Preferences.getProjectBrowserColour(self.colorNames["U"]),
+            "Z": Preferences.getProjectBrowserColour(self.colorNames["Z"]),
         }
         
-        self.highLightColor = Preferences.getProjectBrowserColour("Highlighted")
+        self.highLightColor = \
+            Preferences.getProjectBrowserColour("Highlighted")
         # needed by preferencesChanged()
         
         self.vcsStatusReport = {}
@@ -267,32 +277,33 @@ class ProjectBrowserModel(BrowserModel):
         
         @param index index of the data to retrieve (QModelIndex)
         @param role role of data (Qt.ItemDataRole)
-        @return requested data (QVariant)
+        @return requested data
         """
         if not index.isValid():
-            return QVariant()
+            return None
         
         if role == Qt.TextColorRole:
             if index.column() == 0:
                 try:
                     return index.internalPointer().getTextColor()
                 except AttributeError:
-                    return QVariant()
+                    return None
         elif role == Qt.BackgroundColorRole:
             try:
-                col = self.itemBackgroundColors[index.internalPointer().vcsState]
+                col = self.itemBackgroundColors[
+                    index.internalPointer().vcsState]
                 if col.isValid():
-                    return QVariant(col)
+                    return col
                 else:
-                    return QVariant()
+                    return None
             except AttributeError:
-                return QVariant()
+                return None
             except KeyError:
-                return QVariant()
+                return None
         
         return BrowserModel.data(self, index, role)
     
-    def populateItem(self, parentItem, repopulate = False):
+    def populateItem(self, parentItem, repopulate=False):
         """
         Public method to populate an item's subtree.
         
@@ -308,7 +319,7 @@ class ProjectBrowserModel(BrowserModel):
         else:
             BrowserModel.populateItem(self, parentItem, repopulate)
 
-    def populateProjectDirectoryItem(self, parentItem, repopulate = False):
+    def populateProjectDirectoryItem(self, parentItem, repopulate=False):
         """
         Public method to populate a directory item's subtree.
         
@@ -319,17 +330,23 @@ class ProjectBrowserModel(BrowserModel):
         
         qdir = QDir(parentItem.dirName())
         
-        entryInfoList = \
-            qdir.entryInfoList(QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot))
+        if Preferences.getUI("BrowsersListHiddenFiles"):
+            filter = QDir.Filters(QDir.AllEntries |
+                                  QDir.Hidden |
+                                  QDir.NoDotAndDotDot)
+        else:
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+        entryInfoList = qdir.entryInfoList(filter)
         
         if len(entryInfoList) > 0:
             if repopulate:
-                self.beginInsertRows(self.createIndex(parentItem.row(), 0, parentItem),
+                self.beginInsertRows(self.createIndex(
+                    parentItem.row(), 0, parentItem),
                     0, len(entryInfoList) - 1)
             states = {}
             if self.project.vcs is not None:
                 for f in entryInfoList:
-                    fname = unicode(f.absoluteFilePath())
+                    fname = f.absoluteFilePath()
                     states[os.path.normcase(fname)] = 0
                 dname = parentItem.dirName()
                 self.project.vcs.clearStatusCache()
@@ -337,18 +354,22 @@ class ProjectBrowserModel(BrowserModel):
             
             for f in entryInfoList:
                 if f.isDir():
-                    node = ProjectBrowserDirectoryItem(parentItem,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())), 
+                    node = ProjectBrowserDirectoryItem(
+                        parentItem,
+                        Utilities.toNativeSeparators(f.absoluteFilePath()),
                         parentItem.getProjectTypes()[0], False)
                 else:
-                    node = ProjectBrowserFileItem(parentItem,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())),
+                    node = ProjectBrowserFileItem(
+                        parentItem,
+                        Utilities.toNativeSeparators(f.absoluteFilePath()),
                         parentItem.getProjectTypes()[0])
                 if self.project.vcs is not None:
-                    fname = unicode(f.absoluteFilePath())
-                    if states[os.path.normcase(fname)] == self.project.vcs.canBeCommitted:
+                    fname = f.absoluteFilePath()
+                    if states[os.path.normcase(fname)] == \
+                            self.project.vcs.canBeCommitted:
                         node.addVcsStatus(self.project.vcs.vcsName())
-                        self.project.clearStatusMonitorCachedState(f.absoluteFilePath())
+                        self.project.clearStatusMonitorCachedState(
+                            f.absoluteFilePath())
                     else:
                         node.addVcsStatus(self.trUtf8("local"))
                 self._addItem(node, parentItem)
@@ -363,7 +384,7 @@ class ProjectBrowserModel(BrowserModel):
         
         self.watchedItems = {}
         watchedDirs = self.watcher.directories()
-        if len(watchedDirs) != 0:
+        if watchedDirs:
             self.watcher.removePaths(watchedDirs)
         
         self.rootItem.removeChildren()
@@ -374,23 +395,27 @@ class ProjectBrowserModel(BrowserModel):
         
     def projectOpened(self):
         """
-        Public method used to populate the model after a project has been opened.
+        Public method used to populate the model after a project has been
+        opened.
         """
         self.__vcsStatus = {}
         states = {}
-        keys = self.projectBrowserTypes.keys()[:]
+        keys = list(self.projectBrowserTypes.keys())[:]
         
         if self.project.vcs is not None:
             for key in keys:
                 for fn in self.project.pdata[key]:
-                    states[os.path.normcase(os.path.join(self.project.ppath, fn))] = 0
+                    states[os.path.normcase(
+                        os.path.join(self.project.ppath, fn))] = 0
             
             self.project.vcs.clearStatusCache()
-            states = self.project.vcs.vcsAllRegisteredStates(states, self.project.ppath)
+            states = self.project.vcs.vcsAllRegisteredStates(
+                states, self.project.ppath)
         
         self.inRefresh = True
         for key in keys:
-            # Show the entry in bold in the others browser to make it more distinguishable
+            # Show the entry in bold in the others browser to make it more
+            # distinguishable
             if key == "OTHERS":
                 bold = True
             else:
@@ -403,18 +428,20 @@ class ProjectBrowserModel(BrowserModel):
             
             for fn in self.project.pdata[key]:
                 fname = os.path.join(self.project.ppath, fn)
-                parentItem, dt = \
-                    self.findParentItemByName(self.projectBrowserTypes[key], fn)
+                parentItem, dt = self.findParentItemByName(
+                    self.projectBrowserTypes[key], fn)
                 if os.path.isdir(fname):
-                    itm = ProjectBrowserDirectoryItem(parentItem, fname,
-                        self.projectBrowserTypes[key], False, bold)
+                    itm = ProjectBrowserDirectoryItem(
+                        parentItem, fname, self.projectBrowserTypes[key],
+                        False, bold)
                 else:
-                    itm = ProjectBrowserFileItem(parentItem, fname,
-                        self.projectBrowserTypes[key], False, bold,
-                        sourceLanguage = sourceLanguage)
+                    itm = ProjectBrowserFileItem(
+                        parentItem, fname, self.projectBrowserTypes[key],
+                        False, bold, sourceLanguage=sourceLanguage)
                 self._addItem(itm, parentItem)
                 if self.project.vcs is not None:
-                    if states[os.path.normcase(fname)] == self.project.vcs.canBeCommitted:
+                    if states[os.path.normcase(fname)] == \
+                            self.project.vcs.canBeCommitted:
                         itm.addVcsStatus(self.project.vcs.vcsName())
                     else:
                         itm.addVcsStatus(self.trUtf8("local"))
@@ -423,7 +450,7 @@ class ProjectBrowserModel(BrowserModel):
         self.inRefresh = False
         self.reset()
 
-    def findParentItemByName(self, type_, name, dontSplit = False):
+    def findParentItemByName(self, type_, name, dontSplit=False):
         """
         Public method to find an item given its name.
         
@@ -431,25 +458,26 @@ class ProjectBrowserModel(BrowserModel):
         don't exist.
         
         @param type_ type of the item
-        @param name name of the item (string or QString)
+        @param name name of the item (string)
         @param dontSplit flag indicating the name should not be split (boolean)
-        @return reference to the item found and the new display name (QString)
+        @return reference to the item found and the new display name (string)
         """
         if dontSplit:
-            pathlist = QStringList()
+            pathlist = []
             pathlist.append(name)
             pathlist.append("ignore_me")
         else:
-            pathlist = QString(name).split(QRegExp(r'/|\\'))
+            pathlist = re.split(r'/|\\', name)
         
         if len(pathlist) > 1:
             olditem = self.rootItem
             path = self.project.ppath
             for p in pathlist[:-1]:
                 itm = self.findChildItem(p, 0, olditem)
-                path = os.path.join(path, unicode(p))
+                path = os.path.join(path, p)
                 if itm is None:
-                    itm = ProjectBrowserSimpleDirectoryItem(olditem, type_, p, path)
+                    itm = ProjectBrowserSimpleDirectoryItem(
+                        olditem, type_, p, path)
                     self.__addVCSStatus(itm, path)
                     if self.inRefresh:
                         self._addItem(itm, olditem)
@@ -457,25 +485,24 @@ class ProjectBrowserModel(BrowserModel):
                         if olditem == self.rootItem:
                             oldindex = QModelIndex()
                         else:
-                            oldindex = self.createIndex(olditem.row(), 0, olditem)
+                            oldindex = self.createIndex(
+                                olditem.row(), 0, olditem)
                         self.addItem(itm, oldindex)
                 else:
                     if type_ and type_ not in itm.getProjectTypes():
                         itm.addProjectType(type_)
                         index = self.createIndex(itm.row(), 0, itm)
-                        self.emit(SIGNAL(\
-                            "dataChanged(const QModelIndex &, const QModelIndex &)"),
-                            index, index)
+                        self.dataChanged.emit(index, index)
                 olditem = itm
-            return (itm, QString(pathlist[-1]))
+            return (itm, pathlist[-1])
         else:
             return (self.rootItem, name)
     
-    def findChildItem(self, text, column, parentItem = None):
+    def findChildItem(self, text, column, parentItem=None):
         """
         Public method to find a child item given some text.
         
-        @param text text to search for (string or QString)
+        @param text text to search for (string)
         @param column column to search in (integer)
         @param parentItem reference to parent item
         @return reference to the item found
@@ -484,12 +511,12 @@ class ProjectBrowserModel(BrowserModel):
             parentItem = self.rootItem
         
         for itm in parentItem.children():
-            if QString(itm.data(column)) == QString(text):
+            if itm.data(column) == text:
                 return itm
         
         return None
         
-    def addNewItem(self, typeString, name, additionalTypeStrings = []):
+    def addNewItem(self, typeString, name, additionalTypeStrings=[]):
         """
         Public method to add a new item to the model.
         
@@ -497,30 +524,32 @@ class ProjectBrowserModel(BrowserModel):
         @param name name of the new item (string)
         @param additionalTypeStrings names of additional types (list of string)
         """
-        # Show the entry in bold in the others browser to make it more distinguishable
+        # Show the entry in bold in the others browser to make it more
+        # distinguishable
         if typeString == "OTHERS":
             bold = True
         else:
             bold = False
         
         fname = os.path.join(self.project.ppath, name)
-        parentItem, dt = \
-            self.findParentItemByName(self.projectBrowserTypes[typeString], name)
+        parentItem, dt = self.findParentItemByName(
+            self.projectBrowserTypes[typeString], name)
         if parentItem == self.rootItem:
             parentIndex = QModelIndex()
         else:
             parentIndex = self.createIndex(parentItem.row(), 0, parentItem)
         if os.path.isdir(fname):
-            itm = ProjectBrowserDirectoryItem(parentItem, fname,
-                self.projectBrowserTypes[typeString], False, bold)
+            itm = ProjectBrowserDirectoryItem(
+                parentItem, fname, self.projectBrowserTypes[typeString],
+                False, bold)
         else:
             if typeString == "SOURCES":
                 sourceLanguage = self.project.pdata["PROGLANGUAGE"][0]
             else:
                 sourceLanguage = ""
-            itm = ProjectBrowserFileItem(parentItem, fname,
-                self.projectBrowserTypes[typeString], False, bold,
-                sourceLanguage = sourceLanguage)
+            itm = ProjectBrowserFileItem(
+                parentItem, fname, self.projectBrowserTypes[typeString],
+                False, bold, sourceLanguage=sourceLanguage)
         self.__addVCSStatus(itm, fname)
         if additionalTypeStrings:
             for additionalTypeString in additionalTypeStrings:
@@ -532,7 +561,7 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to rename an item.
         
-        @param name the old display name (string or QString)
+        @param name the old display name (string)
         @param newFilename new filename of the item (string)
         """
         itm = self.findItem(name)
@@ -541,21 +570,19 @@ class ProjectBrowserModel(BrowserModel):
         
         index = self.createIndex(itm.row(), 0, itm)
         itm.setName(newFilename)
-        self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                  index, index)
+        self.dataChanged.emit(index, index)
         self.repopulateItem(newFilename)
     
     def findItem(self, name):
         """
         Public method to find an item given its name.
         
-        @param name name of the item (string or QString)
+        @param name name of the item (string)
         @return reference to the item found
         """
-        name = QString(name)
         if QDir.isAbsolutePath(name):
             name = self.project.getRelativePath(name)
-        pathlist = name.split(QRegExp(r'/|\\'))
+        pathlist = re.split(r'/|\\', name)
         if len(pathlist) > 0:
             olditem = self.rootItem
             for p in pathlist:
@@ -571,14 +598,52 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to find an item's index given its name.
         
-        @param name name of the item (string or QString)
+        @param name name of the item (string)
         @return index of the item found (QModelIndex)
         """
         itm = self.findItem(name)
         if itm is None:
-            index =  QModelIndex()
+            index = QModelIndex()
         else:
-            index =  self.createIndex(itm.row(), 0, itm)
+            index = self.createIndex(itm.row(), 0, itm)
+        return index
+    
+    def itemIndexByNameAndLine(self, name, lineno):
+        """
+        Public method to find an item's index given its name.
+        
+        @param name name of the item (string)
+        @param lineno one based line number of the item (integer)
+        @return index of the item found (QModelIndex)
+        """
+        index = QModelIndex()
+        itm = self.findItem(name)
+        if itm is not None and \
+           isinstance(itm, ProjectBrowserFileItem):
+            olditem = itm
+            autoPopulate = Preferences.getProject("AutoPopulateItems")
+            while itm is not None:
+                if not itm.isPopulated():
+                    if itm.isLazyPopulated() and autoPopulate:
+                        self.populateItem(itm)
+                    else:
+                        break
+                for child in itm.children():
+                    try:
+                        start, end = child.boundaries()
+                        if end == -1:
+                            end = 1000000   # assume end of file
+                        if start <= lineno <= end:
+                            itm = child
+                            break
+                    except AttributeError:
+                        pass
+                else:
+                    itm = None
+                if itm:
+                    olditem = itm
+            index = self.createIndex(olditem.row(), 0, olditem)
+        
         return index
     
     def directoryChanged(self, path):
@@ -587,23 +652,28 @@ class ProjectBrowserModel(BrowserModel):
         
         @param path path of the directory (string)
         """
-        path = unicode(path)
         if path not in self.watchedItems:
             # just ignore the situation we don't have a reference to the item
             return
         
+        if Preferences.getUI("BrowsersListHiddenFiles"):
+            filter = QDir.Filters(QDir.AllEntries |
+                                  QDir.Hidden |
+                                  QDir.NoDotAndDotDot)
+        else:
+            filter = QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot)
+        
         for itm in self.watchedItems[path]:
             oldCnt = itm.childCount()
             
             qdir = QDir(itm.dirName())
             
-            entryInfoList = qdir.entryInfoList(
-                QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot))
+            entryInfoList = qdir.entryInfoList(filter)
             
             # step 1: check for new entries
             children = itm.children()
             for f in entryInfoList:
-                fpath = unicode(Utilities.toNativeSeparators(f.absoluteFilePath()))
+                fpath = Utilities.toNativeSeparators(f.absoluteFilePath())
                 childFound = False
                 for child in children:
                     if child.name() == fpath:
@@ -614,16 +684,18 @@ class ProjectBrowserModel(BrowserModel):
                     continue
                 
                 cnt = itm.childCount()
-                self.beginInsertRows(self.createIndex(itm.row(), 0, itm),
-                    cnt, cnt)
+                self.beginInsertRows(
+                    self.createIndex(itm.row(), 0, itm), cnt, cnt)
                 if f.isDir():
-                    node = ProjectBrowserDirectoryItem(itm,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())), 
-                        itm.getProjectTypes()[0], 
+                    node = ProjectBrowserDirectoryItem(
+                        itm,
+                        Utilities.toNativeSeparators(f.absoluteFilePath()),
+                        itm.getProjectTypes()[0],
                         False)
                 else:
-                    node = ProjectBrowserFileItem(itm,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())), 
+                    node = ProjectBrowserFileItem(
+                        itm,
+                        Utilities.toNativeSeparators(f.absoluteFilePath()),
                         itm.getProjectTypes()[0])
                 self._addItem(node, itm)
                 if self.project.vcs is not None:
@@ -642,7 +714,7 @@ class ProjectBrowserModel(BrowserModel):
                     childname = Utilities.fromNativeSeparators(child.name())
                     entryFound = False
                     for f in entryInfoList:
-                        if unicode(f.absoluteFilePath()) == childname:
+                        if f.absoluteFilePath() == childname:
                             entryFound = True
                             entryInfoList.remove(f)
                             break
@@ -650,8 +722,8 @@ class ProjectBrowserModel(BrowserModel):
                         continue
                     
                     self._removeWatchedItem(child)
-                    self.beginRemoveRows(self.createIndex(itm.row(), 0, itm),
-                        row, row)
+                    self.beginRemoveRows(
+                        self.createIndex(itm.row(), 0, itm), row, row)
                     itm.removeChild(child)
                     self.endRemoveRows()
     
@@ -671,7 +743,7 @@ class ProjectBrowserModel(BrowserModel):
         else:
             item.addVcsStatus("")
     
-    def __updateVCSStatus(self, item, name, recursive = True):
+    def __updateVCSStatus(self, item, name, recursive=True):
         """
         Private method used to update the vcs status of a node.
         
@@ -695,10 +767,9 @@ class ProjectBrowserModel(BrowserModel):
             item.setVcsStatus("")
         
         index = self.createIndex(item.row(), 0, item)
-        self.emit(SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                  index, index)
+        self.dataChanged.emit(index, index)
     
-    def updateVCSStatus(self, name, recursive = True):
+    def updateVCSStatus(self, name, recursive=True):
         """
         Public method used to update the vcs status of a node.
         
@@ -713,9 +784,9 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method to remove a named item.
         
-        @param name file or directory name of the item (string or QString).
+        @param name file or directory name of the item (string).
         """
-        fname = os.path.basename(unicode(name))
+        fname = os.path.basename(name)
         parentItem = self.findParentItemByName(0, name)[0]
         if parentItem == self.rootItem:
             parentIndex = QModelIndex()
@@ -747,7 +818,7 @@ class ProjectBrowserModel(BrowserModel):
                 self.beginRemoveRows(index, 0, itm.childCount() - 1)
                 itm.removeChildren()
                 self.endRemoveRows()
-                Utilities.ModuleParser.resetParsedModule(\
+                Utilities.ModuleParser.resetParsedModule(
                     os.path.join(self.project.ppath, name))
                 
                 self.populateItem(itm, True)
@@ -763,13 +834,14 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public slot to record the (non normal) VCS states.
         
-        @param statesList list of VCS state entries (QStringList) giving the 
-            states in the first column and the path relative to the project 
-            directory starting with the third column. The allowed status flags 
+        @param statesList list of VCS state entries (list of strings) giving
+            the states in the first column and the path relative to the project
+            directory starting with the third column. The allowed status flags
             are:
             <ul>
                 <li>"A" path was added but not yet comitted</li>
                 <li>"M" path has local changes</li>
+                <li>"O" path was removed</li>
                 <li>"R" path was deleted and then re-added</li>
                 <li>"U" path needs an update</li>
                 <li>"Z" path contains a conflict</li>
@@ -780,13 +852,13 @@ class ProjectBrowserModel(BrowserModel):
         lastHead = ""
         itemCache = {}
         if len(statesList) == 1 and statesList[0] == '--RESET--':
-            statesList = QStringList()
-            for name in self.__vcsStatus.keys():
-                statesList.append(" %s" % name)
+            statesList = []
+            for name in list(self.__vcsStatus.keys()):
+                statesList.append(" {0}".format(name))
         
         for name in statesList:
-            state = unicode(name)[0]
-            name = unicode(name)[1:].strip()
+            state = name[0]
+            name = name[1:].strip()
             if state == ' ':
                 if name in self.__vcsStatus:
                     del self.__vcsStatus[name]
@@ -802,11 +874,9 @@ class ProjectBrowserModel(BrowserModel):
             if itm:
                 itm.setVcsState(state)
                 index1 = self.createIndex(itm.row(), 0, itm)
-                index2 = self.createIndex(itm.row(), 
-                    self.rootItem.columnCount(), itm)
-                self.emit(\
-                    SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                    index1, index2)
+                index2 = self.createIndex(
+                    itm.row(), self.rootItem.columnCount(), itm)
+                self.dataChanged.emit(index1, index2)
             
             head, tail = os.path.split(name)
             if head != lastHead:
@@ -819,7 +889,7 @@ class ProjectBrowserModel(BrowserModel):
             globalVcsStatus = sorted(self.__vcsStatus.values())[-1]
         except IndexError:
             globalVcsStatus = ' '
-        self.emit(SIGNAL("vcsStateChanged"), globalVcsStatus)
+        self.vcsStateChanged.emit(globalVcsStatus)
 
     def __changeParentsVCSState(self, path, itemCache):
         """
@@ -844,18 +914,16 @@ class ProjectBrowserModel(BrowserModel):
                 if state != itm.vcsState:
                     itm.setVcsState(state)
                     index1 = self.createIndex(itm.row(), 0, itm)
-                    index2 = self.createIndex(itm.row(), 
-                        self.rootItem.columnCount(), itm)
-                    self.emit(\
-                        SIGNAL("dataChanged(const QModelIndex &, const QModelIndex &)"),
-                        index1, index2)
+                    index2 = self.createIndex(
+                        itm.row(), self.rootItem.columnCount(), itm)
+                    self.dataChanged.emit(index1, index2)
             path, tail = os.path.split(path)
     
     def preferencesChanged(self):
         """
         Public method used to handle a change in preferences.
         """
-        for code in self.colorNames.keys():
+        for code in list(self.colorNames.keys()):
             color = Preferences.getProjectBrowserColour(self.colorNames[code])
             if color.name() == self.itemBackgroundColors[code].name():
                 continue
