@@ -7,19 +7,17 @@
 Module implementing the browser sort filter proxy model.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-
 from UI.BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
-from ProjectBrowserModel import ProjectBrowserSourceType
+from .ProjectBrowserModel import ProjectBrowserSourceType
 
 import Preferences
 
+
 class ProjectBrowserSortFilterProxyModel(BrowserSortFilterProxyModel):
     """
     Class implementing the browser sort filter proxy model.
     """
-    def __init__(self, filterType, parent = None):
+    def __init__(self, filterType, parent=None):
         """
         Constructor
         
@@ -52,7 +50,7 @@ class ProjectBrowserSortFilterProxyModel(BrowserSortFilterProxyModel):
                 return False
             if self.hideGeneratedForms and \
                self.__filterType == ProjectBrowserSourceType and \
-               QString(sitem.data(0)).startsWith("Ui_"):
+               sitem.data(0).startswith("Ui_"):
                 return False
         except AttributeError:
             pass
