@@ -4,60 +4,67 @@
 #
 
 """
-Module implementing the a class used to display the interfaces (IDL) part of the project.
+Module implementing the a class used to display the interfaces (IDL) part
+of the project.
 """
 
 import os
-import sys
 import glob
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QThread, pyqtSignal, QProcess
+from PyQt4.QtGui import QDialog, QApplication, QMenu
 
-from KdeQt import KQMessageBox
-from KdeQt.KQProgressDialog import KQProgressDialog
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox
+from E5Gui.E5ProgressDialog import E5ProgressDialog
 
-from ProjectBrowserModel import ProjectBrowserFileItem, \
+from .ProjectBrowserModel import ProjectBrowserFileItem, \
     ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem, \
     ProjectBrowserInterfaceType
-from ProjectBaseBrowser import ProjectBaseBrowser
+from .ProjectBaseBrowser import ProjectBaseBrowser
 
-from UI.BrowserModel import BrowserFileItem, BrowserClassItem, BrowserMethodItem, \
-    BrowserClassAttributeItem
-from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
+from UI.BrowserModel import BrowserFileItem, BrowserClassItem, \
+    BrowserMethodItem, BrowserClassAttributeItem
 import UI.PixmapCache
 
 import Preferences
 import Utilities
 
+
 class ProjectInterfacesBrowser(ProjectBaseBrowser):
     """
-    A class used to display the interfaces (IDL) part of the project. 
+    A class used to display the interfaces (IDL) part of the project.
     
-    @signal closeSourceWindow(string) emitted after a file has been removed/deleted 
-            from the project
-    @signal appendStdout(string) emitted after something was received from
-            a QProcess on stdout
-    @signal appendStderr(string) emitted after something was received from
-            a QProcess on stderr
-    @signal showMenu(string, QMenu) emitted when a menu is about to be shown. The name
-            of the menu and a reference to the menu are given.
+    @signal sourceFile(str, int = 0) emitted to open a file
+    @signal closeSourceWindow(str) emitted after a file has been
+        removed/deleted from the project
+    @signal appendStdout(str) emitted after something was received from
+        a QProcess on stdout
+    @signal appendStderr(str) emitted after something was received from
+        a QProcess on stderr
+    @signal showMenu(str, QMenu) emitted when a menu is about to be shown.
+        The name of the menu and a reference to the menu are given.
     """
-    def __init__(self, project, parent = None):
+    appendStdout = pyqtSignal(str)
+    appendStderr = pyqtSignal(str)
+    showMenu = pyqtSignal(str, QMenu)
+    
+    def __init__(self, project, parent=None):
         """
         Constructor
         
         @param project reference to the project object
         @param parent parent widget of this browser (QWidget)
         """
-        self.omniidl = unicode(Preferences.getCorba("omniidl"))
+        self.omniidl = Preferences.getCorba("omniidl")
         if self.omniidl == "":
-            self.omniidl = Utilities.isWindowsPlatform() and "omniidl.exe" or "omniidl"
+            self.omniidl = Utilities.isWindowsPlatform() and \
+                "omniidl.exe" or "omniidl"
         if not Utilities.isinpath(self.omniidl):
             self.omniidl = None
         
-        ProjectBaseBrowser.__init__(self, project, ProjectBrowserInterfaceType, parent)
+        ProjectBaseBrowser.__init__(self, project,
+                                    ProjectBrowserInterfaceType, parent)
         
         self.selectedItemsFilter = \
             [ProjectBrowserFileItem, ProjectBrowserSimpleDirectoryItem]
@@ -67,14 +74,12 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         self.setWhatsThis(self.trUtf8(
             """<b>Project Interfaces Browser</b>"""
             """<p>This allows to easily see all interfaces (CORBA IDL files)"""
-            """ contained in the current project. Several actions can be executed"""
-            """ via the context menu.</p>"""
+            """ contained in the current project. Several actions can be"""
+            """ executed via the context menu.</p>"""
         ))
         
-        self.connect(project, SIGNAL("prepareRepopulateItem"), 
-            self._prepareRepopulateItem)
-        self.connect(project, SIGNAL("completeRepopulateItem"),
-            self._completeRepopulateItem)
+        project.prepareRepopulateItem.connect(self._prepareRepopulateItem)
+        project.completeRepopulateItem.connect(self._completeRepopulateItem)
         
     def _createPopupMenus(self):
         """
@@ -87,147 +92,167 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         
         self.sourceMenu = QMenu(self)
         if self.omniidl is not None:
-            self.sourceMenu.addAction(self.trUtf8('Compile interface'), 
-                self.__compileInterface)
-            self.sourceMenu.addAction(self.trUtf8('Compile all interfaces'), 
+            self.sourceMenu.addAction(
+                self.trUtf8('Compile interface'), self.__compileInterface)
+            self.sourceMenu.addAction(
+                self.trUtf8('Compile all interfaces'),
                 self.__compileAllInterfaces)
         self.sourceMenu.addAction(self.trUtf8('Open'), self._openItem)
         self.sourceMenu.addSeparator()
-        act = self.sourceMenu.addAction(self.trUtf8('Rename file'), self._renameFile)
+        act = self.sourceMenu.addAction(
+            self.trUtf8('Rename file'), self._renameFile)
         self.menuActions.append(act)
-        act = self.sourceMenu.addAction(self.trUtf8('Remove from project'), 
-            self._removeFile)
+        act = self.sourceMenu.addAction(
+            self.trUtf8('Remove from project'), self._removeFile)
         self.menuActions.append(act)
-        act = self.sourceMenu.addAction(self.trUtf8('Delete'), self.__deleteFile)
+        act = self.sourceMenu.addAction(
+            self.trUtf8('Delete'), self.__deleteFile)
         self.menuActions.append(act)
         self.sourceMenu.addSeparator()
-        self.sourceMenu.addAction(self.trUtf8('Add interfaces...'), 
-            self.__addInterfaceFiles)
-        self.sourceMenu.addAction(self.trUtf8('Add interfaces directory...'), 
+        self.sourceMenu.addAction(
+            self.trUtf8('Add interfaces...'), self.__addInterfaceFiles)
+        self.sourceMenu.addAction(
+            self.trUtf8('Add interfaces directory...'),
             self.__addInterfacesDirectory)
         self.sourceMenu.addSeparator()
-        self.sourceMenu.addAction(self.trUtf8('Copy Path to Clipboard'), 
-            self._copyToClipboard)
+        self.sourceMenu.addAction(
+            self.trUtf8('Copy Path to Clipboard'), self._copyToClipboard)
         self.sourceMenu.addSeparator()
-        self.sourceMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.sourceMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.sourceMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.sourceMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.sourceMenu.addSeparator()
         self.sourceMenu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.sourceMenu.addAction(self.trUtf8('Configure CORBA...'), self.__configureCorba)
+        self.sourceMenu.addAction(
+            self.trUtf8('Configure CORBA...'), self.__configureCorba)
 
         self.menu = QMenu(self)
         if self.omniidl is not None:
-            self.menu.addAction(self.trUtf8('Compile interface'), self.__compileInterface)
-            self.menu.addAction(self.trUtf8('Compile all interfaces'), 
+            self.menu.addAction(
+                self.trUtf8('Compile interface'), self.__compileInterface)
+            self.menu.addAction(
+                self.trUtf8('Compile all interfaces'),
                 self.__compileAllInterfaces)
         self.menu.addAction(self.trUtf8('Open'), self._openItem)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Add interfaces...'), self.__addInterfaceFiles)
-        self.menu.addAction(self.trUtf8('Add interfaces directory...'), 
+        self.menu.addAction(
+            self.trUtf8('Add interfaces...'), self.__addInterfaceFiles)
+        self.menu.addAction(
+            self.trUtf8('Add interfaces directory...'),
             self.__addInterfacesDirectory)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.menu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.menu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.menu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.menu.addAction(self.trUtf8('Configure CORBA...'), self.__configureCorba)
+        self.menu.addAction(
+            self.trUtf8('Configure CORBA...'), self.__configureCorba)
 
         self.backMenu = QMenu(self)
         if self.omniidl is not None:
-            self.backMenu.addAction(self.trUtf8('Compile all interfaces'), 
+            self.backMenu.addAction(
+                self.trUtf8('Compile all interfaces'),
                 self.__compileAllInterfaces)
             self.backMenu.addSeparator()
-        self.backMenu.addAction(self.trUtf8('Add interfaces...'), 
-            self.project.addIdlFiles)
-        self.backMenu.addAction(self.trUtf8('Add interfaces directory...'), 
-            self.project.addIdlDir)
+        self.backMenu.addAction(
+            self.trUtf8('Add interfaces...'), self.project.addIdlFiles)
+        self.backMenu.addAction(
+            self.trUtf8('Add interfaces directory...'), self.project.addIdlDir)
         self.backMenu.addSeparator()
-        self.backMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.backMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.backMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.backMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.backMenu.addAction(self.trUtf8('Configure CORBA...'), self.__configureCorba)
+        self.backMenu.addAction(
+            self.trUtf8('Configure CORBA...'), self.__configureCorba)
         self.backMenu.setEnabled(False)
 
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.omniidl is not None:
-            self.multiMenu.addAction(self.trUtf8('Compile interfaces'),
+            self.multiMenu.addAction(
+                self.trUtf8('Compile interfaces'),
                 self.__compileSelectedInterfaces)
         self.multiMenu.addAction(self.trUtf8('Open'), self._openItem)
         self.multiMenu.addSeparator()
-        act = self.multiMenu.addAction(self.trUtf8('Remove from project'), 
-            self._removeFile)
+        act = self.multiMenu.addAction(
+            self.trUtf8('Remove from project'), self._removeFile)
         self.multiMenuActions.append(act)
-        act = self.multiMenu.addAction(self.trUtf8('Delete'), self.__deleteFile)
+        act = self.multiMenu.addAction(
+            self.trUtf8('Delete'), self.__deleteFile)
         self.multiMenuActions.append(act)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.multiMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.multiMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.multiMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.multiMenu.addSeparator()
         self.multiMenu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.multiMenu.addAction(self.trUtf8('Configure CORBA...'), self.__configureCorba)
+        self.multiMenu.addAction(
+            self.trUtf8('Configure CORBA...'), self.__configureCorba)
 
         self.dirMenu = QMenu(self)
         if self.omniidl is not None:
-            self.dirMenu.addAction(self.trUtf8('Compile all interfaces'), 
+            self.dirMenu.addAction(
+                self.trUtf8('Compile all interfaces'),
                 self.__compileAllInterfaces)
             self.dirMenu.addSeparator()
-        act = self.dirMenu.addAction(self.trUtf8('Remove from project'), self._removeFile)
+        act = self.dirMenu.addAction(
+            self.trUtf8('Remove from project'), self._removeFile)
+        self.dirMenuActions.append(act)
+        act = self.dirMenu.addAction(
+            self.trUtf8('Delete'), self._deleteDirectory)
         self.dirMenuActions.append(act)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(self.trUtf8('Add interfaces...'), self.__addInterfaceFiles)
-        self.dirMenu.addAction(self.trUtf8('Add interfaces directory...'), 
+        self.dirMenu.addAction(
+            self.trUtf8('Add interfaces...'), self.__addInterfaceFiles)
+        self.dirMenu.addAction(
+            self.trUtf8('Add interfaces directory...'),
             self.__addInterfacesDirectory)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(self.trUtf8('Copy Path to Clipboard'), 
-            self._copyToClipboard)
+        self.dirMenu.addAction(
+            self.trUtf8('Copy Path to Clipboard'), self._copyToClipboard)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.dirMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.dirMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.dirMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.dirMenu.addSeparator()
         self.dirMenu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.dirMenu.addAction(self.trUtf8('Configure CORBA...'), self.__configureCorba)
+        self.dirMenu.addAction(
+            self.trUtf8('Configure CORBA...'), self.__configureCorba)
         
         self.dirMultiMenu = QMenu(self)
         if self.omniidl is not None:
-            self.dirMultiMenu.addAction(self.trUtf8('Compile all interfaces'), 
+            self.dirMultiMenu.addAction(
+                self.trUtf8('Compile all interfaces'),
                 self.__compileAllInterfaces)
             self.dirMultiMenu.addSeparator()
-        self.dirMultiMenu.addAction(self.trUtf8('Add interfaces...'), 
-            self.project.addIdlFiles)
-        self.dirMultiMenu.addAction(self.trUtf8('Add interfaces directory...'), 
-            self.project.addIdlDir)
+        self.dirMultiMenu.addAction(
+            self.trUtf8('Add interfaces...'), self.project.addIdlFiles)
+        self.dirMultiMenu.addAction(
+            self.trUtf8('Add interfaces directory...'), self.project.addIdlDir)
         self.dirMultiMenu.addSeparator()
-        self.dirMultiMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.dirMultiMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.dirMultiMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.dirMultiMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.dirMultiMenu.addSeparator()
-        self.dirMultiMenu.addAction(self.trUtf8('Configure...'), self._configure)
-        self.dirMultiMenu.addAction(self.trUtf8('Configure CORBA...'), 
+        self.dirMultiMenu.addAction(
+            self.trUtf8('Configure...'), self._configure)
+        self.dirMultiMenu.addAction(self.trUtf8('Configure CORBA...'),
                                     self.__configureCorba)
         
-        self.connect(self.sourceMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenu)
-        self.connect(self.multiMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuMulti)
-        self.connect(self.dirMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuDir)
-        self.connect(self.dirMultiMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuDirMulti)
-        self.connect(self.backMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuBack)
+        self.sourceMenu.aboutToShow.connect(self.__showContextMenu)
+        self.multiMenu.aboutToShow.connect(self.__showContextMenuMulti)
+        self.dirMenu.aboutToShow.connect(self.__showContextMenuDir)
+        self.dirMultiMenu.aboutToShow.connect(self.__showContextMenuDirMulti)
+        self.backMenu.aboutToShow.connect(self.__showContextMenuBack)
         self.mainMenu = self.sourceMenu
         
     def _contextMenuRequested(self, coord):
@@ -240,23 +265,23 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
             return
         
         try:
-            categories = self.getSelectedItemsCountCategorized(\
-                [ProjectBrowserFileItem, BrowserClassItem, 
+            categories = self.getSelectedItemsCountCategorized(
+                [ProjectBrowserFileItem, BrowserClassItem,
                  BrowserMethodItem, ProjectBrowserSimpleDirectoryItem])
             cnt = categories["sum"]
             if cnt <= 1:
                 index = self.indexAt(coord)
                 if index.isValid():
                     self._selectSingleItem(index)
-                    categories = self.getSelectedItemsCountCategorized(\
-                        [ProjectBrowserFileItem, BrowserClassItem, 
+                    categories = self.getSelectedItemsCountCategorized(
+                        [ProjectBrowserFileItem, BrowserClassItem,
                          BrowserMethodItem, ProjectBrowserSimpleDirectoryItem])
                     cnt = categories["sum"]
             
-            bfcnt = categories[unicode(ProjectBrowserFileItem)]
-            cmcnt = categories[unicode(BrowserClassItem)] + \
-                    categories[unicode(BrowserMethodItem)]
-            sdcnt = categories[unicode(ProjectBrowserSimpleDirectoryItem)]
+            bfcnt = categories[str(ProjectBrowserFileItem)]
+            cmcnt = categories[str(BrowserClassItem)] + \
+                categories[str(BrowserMethodItem)]
+            sdcnt = categories[str(ProjectBrowserSimpleDirectoryItem)]
             if cnt > 1 and cnt == bfcnt:
                 self.multiMenu.popup(self.mapToGlobal(coord))
             elif cnt > 1 and cnt == sdcnt:
@@ -288,7 +313,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenu(self, self.menu)
         
-        self.emit(SIGNAL("showMenu"), "Main", self.menu)
+        self.showMenu.emit("Main", self.menu)
         
     def __showContextMenuMulti(self):
         """
@@ -296,7 +321,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuMulti(self, self.multiMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainMulti", self.multiMenu)
+        self.showMenu.emit("MainMulti", self.multiMenu)
         
     def __showContextMenuDir(self):
         """
@@ -304,7 +329,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuDir(self, self.dirMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainDir", self.dirMenu)
+        self.showMenu.emit("MainDir", self.dirMenu)
         
     def __showContextMenuDirMulti(self):
         """
@@ -312,7 +337,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuDirMulti(self, self.dirMultiMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainDirMulti", self.dirMultiMenu)
+        self.showMenu.emit("MainDirMulti", self.dirMultiMenu)
         
     def __showContextMenuBack(self):
         """
@@ -320,28 +345,28 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuBack(self, self.backMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainBack", self.backMenu)
+        self.showMenu.emit("MainBack", self.backMenu)
         
     def _openItem(self):
         """
         Protected slot to handle the open popup menu entry.
         """
-        itmList = self.getSelectedItems(\
-            [BrowserFileItem, BrowserClassItem, BrowserMethodItem, 
+        itmList = self.getSelectedItems(
+            [BrowserFileItem, BrowserClassItem, BrowserMethodItem,
              BrowserClassAttributeItem])
         
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName())
+                self.sourceFile[str].emit(itm.fileName())
             elif isinstance(itm, BrowserClassItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.classObject().lineno)
-            elif isinstance(itm,BrowserMethodItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.functionObject().lineno)
+                self.sourceFile[str, int].emit(
+                    itm.fileName(), itm.classObject().lineno)
+            elif isinstance(itm, BrowserMethodItem):
+                self.sourceFile[str, int].emit(
+                    itm.fileName(), itm.functionObject().lineno)
             elif isinstance(itm, BrowserClassAttributeItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.attributeObject().lineno)
+                self.sourceFile[str, int].emit(
+                    itm.fileName(), itm.attributeObject().lineno)
         
     def __addInterfaceFiles(self):
         """
@@ -351,10 +376,10 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         if isinstance(itm, ProjectBrowserFileItem) or \
            isinstance(itm, BrowserClassItem) or \
            isinstance(itm, BrowserMethodItem):
-            dn = os.path.dirname(unicode(itm.fileName()))
+            dn = os.path.dirname(itm.fileName())
         elif isinstance(itm, ProjectBrowserSimpleDirectoryItem) or \
-             isinstance(itm, ProjectBrowserDirectoryItem):
-            dn = unicode(itm.dirName())
+                isinstance(itm, ProjectBrowserDirectoryItem):
+            dn = itm.dirName()
         else:
             dn = None
         self.project.addFiles('interface', dn)
@@ -367,10 +392,10 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         if isinstance(itm, ProjectBrowserFileItem) or \
            isinstance(itm, BrowserClassItem) or \
            isinstance(itm, BrowserMethodItem):
-            dn = os.path.dirname(unicode(itm.fileName()))
+            dn = os.path.dirname(itm.fileName())
         elif isinstance(itm, ProjectBrowserSimpleDirectoryItem) or \
-             isinstance(itm, ProjectBrowserDirectoryItem):
-            dn = unicode(itm.dirName())
+                isinstance(itm, ProjectBrowserDirectoryItem):
+            dn = itm.dirName()
         else:
             dn = None
         self.project.addDirectory('interface', dn)
@@ -384,59 +409,62 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         files = []
         fullNames = []
         for itm in itmList:
-            fn2 = unicode(itm.fileName())
+            fn2 = itm.fileName()
             fullNames.append(fn2)
             fn = self.project.getRelativePath(fn2)
             files.append(fn)
         
-        dlg = DeleteFilesConfirmationDialog(self.parent(),
+        from UI.DeleteFilesConfirmationDialog import \
+            DeleteFilesConfirmationDialog
+        dlg = DeleteFilesConfirmationDialog(
+            self.parent(),
             self.trUtf8("Delete interfaces"),
             self.trUtf8("Do you really want to delete these interfaces from"
-                " the project?"),
+                        " the project?"),
             files)
         
         if dlg.exec_() == QDialog.Accepted:
             for fn2, fn in zip(fullNames, files):
-                self.emit(SIGNAL('closeSourceWindow'), fn2)
+                self.closeSourceWindow.emit(fn2)
                 self.project.deleteFile(fn)
     
-    ############################################################################
+    ###########################################################################
     ##  Methods to handle the various compile commands
-    ############################################################################
+    ###########################################################################
     
     def __readStdout(self):
         """
-        Private slot to handle the readyReadStandardOutput signal of the omniidl process.
+        Private slot to handle the readyReadStandardOutput signal of the
+        omniidl process.
         """
         if self.compileProc is None:
             return
         
-        ioEncoding = str(Preferences.getSystem("IOEncoding"))
+        ioEncoding = Preferences.getSystem("IOEncoding")
         
         self.compileProc.setReadChannel(QProcess.StandardOutput)
         while self.compileProc and self.compileProc.canReadLine():
-            s = QString('omniidl: ')
-            output = unicode(self.compileProc.readLine(), 
-                             ioEncoding, 'replace')
-            s.append(output)
-            self.emit(SIGNAL('appendStdout'), s)
+            s = 'omniidl: '
+            output = str(self.compileProc.readLine(), ioEncoding, 'replace')
+            s += output
+            self.appendStdout.emit(s)
         
     def __readStderr(self):
         """
-        Private slot to handle the readyReadStandardError signal of the omniidl process.
+        Private slot to handle the readyReadStandardError signal of the
+        omniidl process.
         """
         if self.compileProc is None:
             return
         
-        ioEncoding = str(Preferences.getSystem("IOEncoding"))
+        ioEncoding = Preferences.getSystem("IOEncoding")
         
         self.compileProc.setReadChannel(QProcess.StandardError)
         while self.compileProc and self.compileProc.canReadLine():
-            s = QString('omniidl: ')
-            error = unicode(self.compileProc.readLine(), 
-                            ioEncoding, 'replace')
-            s.append(error)
-            self.emit(SIGNAL('appendStderr'), s)
+            s = 'omniidl: '
+            error = str(self.compileProc.readLine(), ioEncoding, 'replace')
+            s += error
+            self.appendStderr.emit(s)
         
     def __compileIDLDone(self, exitCode, exitStatus):
         """
@@ -446,6 +474,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         @param exitStatus exit status of the process (QProcess.ExitStatus)
         """
         self.compileRunning = False
+        ui = e5App().getObject("UserInterface")
         if exitStatus == QProcess.NormalExit and exitCode == 0:
             path = os.path.dirname(self.idlFile)
             poaList = glob.glob(os.path.join(path, "*__POA"))
@@ -455,47 +484,62 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
                 fileList += Utilities.direntries(dir, True, "*.py")
             for file in fileList:
                 self.project.appendFile(file)
-            if not self.noDialog:
-                KQMessageBox.information(None,
+            if not self.noDialog and not ui.notificationsEnabled():
+                E5MessageBox.information(
+                    self,
                     self.trUtf8("Interface Compilation"),
-                    self.trUtf8("The compilation of the interface file was successful."))
+                    self.trUtf8(
+                        "The compilation of the interface file was"
+                        " successful."))
+            else:
+                ui.showNotification(
+                    UI.PixmapCache.getPixmap("corba48.png"),
+                    self.trUtf8("Interface Compilation"),
+                    self.trUtf8(
+                        "The compilation of the interface file was"
+                        " successful."))
         else:
             if not self.noDialog:
-                KQMessageBox.information(None,
+                E5MessageBox.information(
+                    self,
                     self.trUtf8("Interface Compilation"),
-                    self.trUtf8("The compilation of the interface file failed."))
+                    self.trUtf8(
+                        "The compilation of the interface file failed."))
+            else:
+                ui.showNotification(
+                    UI.PixmapCache.getPixmap("corba48.png"),
+                    self.trUtf8("Interface Compilation"),
+                    self.trUtf8(
+                        "The compilation of the interface file failed."))
         self.compileProc = None
         
-    def __compileIDL(self, fn, noDialog = False, progress = None):
+    def __compileIDL(self, fn, noDialog=False, progress=None):
         """
         Privat method to compile a .idl file to python.
 
-        @param fn filename of the .idl file to be compiled
-        @param noDialog flag indicating silent operations
-        @param progress reference to the progress dialog
+        @param fn filename of the .idl file to be compiled (string)
+        @param noDialog flag indicating silent operations (boolean)
+        @param progress reference to the progress dialog (E5ProgressDialog)
         @return reference to the compile process (QProcess)
         """
         self.compileProc = QProcess()
-        args = QStringList()
+        args = []
         
         args.append("-bpython")
         args.append("-I.")
         
         fn = os.path.join(self.project.ppath, fn)
         self.idlFile = fn
-        args.append("-C%s" % os.path.dirname(fn))
+        args.append("-C{0}".format(os.path.dirname(fn)))
         args.append(fn)
         
-        self.connect(self.compileProc, SIGNAL('finished(int, QProcess::ExitStatus)'), 
-            self.__compileIDLDone)
-        self.connect(self.compileProc, SIGNAL('readyReadStandardOutput()'), 
-            self.__readStdout)
-        self.connect(self.compileProc, SIGNAL('readyReadStandardError()'), 
-            self.__readStderr)
+        self.compileProc.finished.connect(self.__compileIDLDone)
+        self.compileProc.readyReadStandardOutput.connect(self.__readStdout)
+        self.compileProc.readyReadStandardError.connect(self.__readStderr)
         
         self.noDialog = noDialog
         self.compileProc.start(self.omniidl, args)
-        procStarted = self.compileProc.waitForStarted()
+        procStarted = self.compileProc.waitForStarted(5000)
         if procStarted:
             self.compileRunning = True
             return self.compileProc
@@ -503,12 +547,13 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
             self.compileRunning = False
             if progress is not None:
                 progress.cancel()
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    '<p>Could not start %1.<br>'
+                    '<p>Could not start {0}.<br>'
                     'Ensure that it is in the search path.</p>'
-                ).arg(self.omniidl))
+                ).format(self.omniidl))
             return None
         
     def __compileInterface(self):
@@ -517,7 +562,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         if self.omniidl is not None:
             itm = self.model().item(self.currentIndex())
-            fn2 = unicode(itm.fileName())
+            fn2 = itm.fileName()
             fn = self.project.getRelativePath(fn2)
             self.__compileIDL(fn)
         
@@ -527,8 +572,10 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         if self.omniidl is not None:
             numIDLs = len(self.project.pdata["INTERFACES"])
-            progress = KQProgressDialog(self.trUtf8("Compiling interfaces..."), 
-                self.trUtf8("Abort"), 0, numIDLs, self)
+            progress = E5ProgressDialog(
+                self.trUtf8("Compiling interfaces..."),
+                self.trUtf8("Abort"), 0, numIDLs,
+                self.trUtf8("%v/%m Interfaces"), self)
             progress.setModal(True)
             progress.setMinimumDuration(0)
             i = 0
@@ -556,11 +603,13 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         if self.omniidl is not None:
             items = self.getSelectedItems()
             
-            files = [self.project.getRelativePath(unicode(itm.fileName())) \
+            files = [self.project.getRelativePath(itm.fileName())
                      for itm in items]
             numIDLs = len(files)
-            progress = KQProgressDialog(self.trUtf8("Compiling interfaces..."), 
-                self.trUtf8("Abort"), 0, numIDLs, self)
+            progress = E5ProgressDialog(
+                self.trUtf8("Compiling interfaces..."),
+                self.trUtf8("Abort"), 0, numIDLs,
+                self.trUtf8("%v/%m Interfaces"), self)
             progress.setModal(True)
             progress.setMinimumDuration(0)
             i = 0
@@ -585,4 +634,4 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         """
         Private method to open the configuration dialog.
         """
-        e4App().getObject("UserInterface").showPreferences("corbaPage")
+        e5App().getObject("UserInterface").showPreferences("corbaPage")
