@@ -4,42 +4,37 @@
 #
 
 """
-Module implementing a class used to display the parts of the project, that don't fit 
-the other categories.
+Module implementing a class used to display the parts of the project, that
+don't fit the other categories.
 """
 
-import os
-import sys
-import mimetypes
+from PyQt4.QtCore import QModelIndex, pyqtSignal, QUrl
+from PyQt4.QtGui import QDesktopServices, QDialog, QMenu
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-
-from ProjectBrowserModel import ProjectBrowserFileItem, \
+from .ProjectBrowserModel import ProjectBrowserFileItem, \
     ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem, \
     ProjectBrowserOthersType
-from ProjectBaseBrowser import ProjectBaseBrowser
+from .ProjectBaseBrowser import ProjectBaseBrowser
 
-from UI.BrowserModel import BrowserClassItem, BrowserMethodItem, \
-    BrowserDirectoryItem, BrowserFileItem
-from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
-import UI.PixmapCache
+import Utilities.mimetypes
 
-import Preferences
 
 class ProjectOthersBrowser(ProjectBaseBrowser):
     """
-    A class used to display the parts of the project, that don't fit the other categories.
+    A class used to display the parts of the project, that don't fit the
+    other categories.
     
-    @signal sourceFile(string) emitted to open a file
-    @signal pixmapFile(string) emitted to open a pixmap file
-    @signal pixmapEditFile(string) emitted to edit a pixmap file
-    @signal svgFile(string) emitted to open a SVG file
-    @signal closeSourceWindow(string) emitted after a file has been removed/deleted
-            from the project
-    @signal showMenu(string, QMenu) emitted when a menu is about to be shown. The name
-            of the menu and a reference to the menu are given.
+    @signal sourceFile(str) emitted to open a file
+    @signal pixmapFile(str) emitted to open a pixmap file
+    @signal pixmapEditFile(str) emitted to edit a pixmap file
+    @signal svgFile(str) emitted to open a SVG file
+    @signal closeSourceWindow(str) emitted after a file has been
+        removed/deleted from the project
+    @signal showMenu(str, QMenu) emitted when a menu is about to be shown.
+        The name of the menu and a reference to the menu are given.
     """
+    showMenu = pyqtSignal(str, QMenu)
+    
     def __init__(self, project, parent=None):
         """
         Constructor
@@ -47,9 +42,11 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         @param project reference to the project object
         @param parent parent widget of this browser (QWidget)
         """
-        ProjectBaseBrowser.__init__(self, project, ProjectBrowserOthersType, parent)
+        ProjectBaseBrowser.__init__(self, project, ProjectBrowserOthersType,
+                                    parent)
     
-        self.selectedItemsFilter = [ProjectBrowserFileItem, ProjectBrowserDirectoryItem]
+        self.selectedItemsFilter = [ProjectBrowserFileItem,
+                                    ProjectBrowserDirectoryItem]
         self.specialMenuEntries = [1]
 
         self.setWindowTitle(self.trUtf8('Others'))
@@ -62,10 +59,8 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
             """ in the project is shown in a different colour.</p>"""
         ))
         
-        self.connect(project, SIGNAL("prepareRepopulateItem"), 
-            self._prepareRepopulateItem)
-        self.connect(project, SIGNAL("completeRepopulateItem"),
-            self._completeRepopulateItem)
+        project.prepareRepopulateItem.connect(self._prepareRepopulateItem)
+        project.completeRepopulateItem.connect(self._completeRepopulateItem)
         
     def _createPopupMenus(self):
         """
@@ -73,67 +68,67 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._createPopupMenus(self)
         
-        self.editPixmapAct = \
-            self.menu.addAction(self.trUtf8('Open in Icon Editor'), 
-            self._editPixmap)
+        self.editPixmapAct = self.menu.addAction(
+            self.trUtf8('Open in Icon Editor'), self._editPixmap)
         self.menu.addSeparator()
-        self.renameFileAct = self.menu.addAction(self.trUtf8('Rename file'), 
-            self._renameFile)
+        self.renameFileAct = self.menu.addAction(
+            self.trUtf8('Rename file'), self._renameFile)
         self.menuActions.append(self.renameFileAct)
-        act = self.menu.addAction(self.trUtf8('Remove from project'), self.__removeItem)
+        act = self.menu.addAction(
+            self.trUtf8('Remove from project'), self.__removeItem)
         self.menuActions.append(act)
         act = self.menu.addAction(self.trUtf8('Delete'), self.__deleteItem)
         self.menuActions.append(act)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Add files...'), self.project.addOthersFiles)
-        self.menu.addAction(self.trUtf8('Add directory...'), self.project.addOthersDir)
+        self.menu.addAction(
+            self.trUtf8('Add files...'), self.project.addOthersFiles)
+        self.menu.addAction(
+            self.trUtf8('Add directory...'), self.project.addOthersDir)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8('Refresh'), self.__refreshItem)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Copy Path to Clipboard'), 
-            self._copyToClipboard)
+        self.menu.addAction(
+            self.trUtf8('Copy Path to Clipboard'), self._copyToClipboard)
         self.menu.addSeparator()
-        self.menu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.menu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.menu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.menu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.menu.addSeparator()
         self.menu.addAction(self.trUtf8('Configure...'), self._configure)
 
         self.backMenu = QMenu(self)
-        self.backMenu.addAction(self.trUtf8('Add files...'), 
-            self.project.addOthersFiles)
-        self.backMenu.addAction(self.trUtf8('Add directory...'), 
-            self.project.addOthersDir)
+        self.backMenu.addAction(
+            self.trUtf8('Add files...'), self.project.addOthersFiles)
+        self.backMenu.addAction(
+            self.trUtf8('Add directory...'), self.project.addOthersDir)
         self.backMenu.addSeparator()
-        self.backMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.backMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.backMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.backMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.backMenu.addSeparator()
         self.backMenu.addAction(self.trUtf8('Configure...'), self._configure)
         self.backMenu.setEnabled(False)
 
         self.multiMenu.addSeparator()
-        act = self.multiMenu.addAction(self.trUtf8('Remove from project'), 
-            self.__removeItem)
+        act = self.multiMenu.addAction(
+            self.trUtf8('Remove from project'), self.__removeItem)
         self.multiMenuActions.append(act)
-        act = self.multiMenu.addAction(self.trUtf8('Delete'), self.__deleteItem)
+        act = self.multiMenu.addAction(
+            self.trUtf8('Delete'), self.__deleteItem)
         self.multiMenuActions.append(act)
         self.multiMenu.addSeparator()
-        self.multiMenu.addAction(self.trUtf8('Expand all directories'), 
-            self._expandAllDirs)
-        self.multiMenu.addAction(self.trUtf8('Collapse all directories'), 
-            self._collapseAllDirs)
+        self.multiMenu.addAction(
+            self.trUtf8('Expand all directories'), self._expandAllDirs)
+        self.multiMenu.addAction(
+            self.trUtf8('Collapse all directories'), self._collapseAllDirs)
         self.multiMenu.addSeparator()
         self.multiMenu.addAction(self.trUtf8('Configure...'), self._configure)
         
-        self.connect(self.menu, SIGNAL('aboutToShow()'),
-            self.__showContextMenu)
-        self.connect(self.multiMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuMulti)
-        self.connect(self.backMenu, SIGNAL('aboutToShow()'),
-            self.__showContextMenuBack)
+        self.menu.aboutToShow.connect(self.__showContextMenu)
+        self.multiMenu.aboutToShow.connect(self.__showContextMenuMulti)
+        self.backMenu.aboutToShow.connect(self.__showContextMenuBack)
         self.mainMenu = self.menu
         
     def _contextMenuRequested(self, coord):
@@ -178,7 +173,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         self._showContextMenu(self.menu)
         
-        self.emit(SIGNAL("showMenu"), "Main", self.menu)
+        self.showMenu.emit("Main", self.menu)
         
     def __showContextMenuMulti(self):
         """
@@ -186,7 +181,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuMulti(self, self.multiMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainMulti", self.multiMenu)
+        self.showMenu.emit("MainMulti", self.multiMenu)
         
     def __showContextMenuBack(self):
         """
@@ -194,13 +189,13 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         """
         ProjectBaseBrowser._showContextMenuBack(self, self.backMenu)
         
-        self.emit(SIGNAL("showMenu"), "MainBack", self.backMenu)
+        self.showMenu.emit("MainBack", self.backMenu)
         
     def _showContextMenu(self, menu):
         """
-        Protected slot called before the context menu is shown. 
+        Protected slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
         
         @param menu Reference to the popup menu (QPopupMenu)
@@ -224,7 +219,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
                 if itm.isPixmapFile():
-                    self.emit(SIGNAL('pixmapEditFile'), itm.fileName())
+                    self.pixmapEditFile.emit(itm.fileName())
         
     def _openItem(self):
         """
@@ -235,34 +230,35 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
                 if itm.isPixmapFile():
-                    self.emit(SIGNAL('pixmapFile'), itm.fileName())
+                    self.pixmapFile.emit(itm.fileName())
                 elif itm.isSvgFile():
-                    self.emit(SIGNAL('svgFile'), itm.fileName())
+                    self.svgFile.emit(itm.fileName())
                 else:
-                    type_ = mimetypes.guess_type(itm.fileName())[0]
-                    if type_ is None or type_.split("/")[0] == "text":
-                        self.emit(SIGNAL('sourceFile'), itm.fileName())
+                    if Utilities.mimetypes.isTextFile(itm.fileName()):
+                        self.sourceFile.emit(itm.fileName())
                     else:
                         QDesktopServices.openUrl(QUrl(itm.fileName()))
         
     def __removeItem(self):
         """
-        Private slot to remove the selected entry from the OTHERS project data area.
+        Private slot to remove the selected entry from the OTHERS project
+        data area.
         """
         itmList = self.getSelectedItems()
         
         for itm in itmList[:]:
             if isinstance(itm, ProjectBrowserFileItem):
-                fn = unicode(itm.fileName())
-                self.emit(SIGNAL('closeSourceWindow'), fn)
+                fn = itm.fileName()
+                self.closeSourceWindow.emit(fn)
                 self.project.removeFile(fn)
             else:
-                dn = unicode(itm.dirName())
+                dn = itm.dirName()
                 self.project.removeDirectory(dn)
         
     def __deleteItem(self):
         """
-        Private method to delete the selected entry from the OTHERS project data area.
+        Private method to delete the selected entry from the OTHERS project
+        data area.
         """
         itmList = self.getSelectedItems()
         
@@ -274,13 +270,13 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         dirFullNames = []
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
-                fn2 = unicode(itm.fileName())
+                fn2 = itm.fileName()
                 fn = self.project.getRelativePath(fn2)
                 items.append(itm)
                 fullNames.append(fn2)
                 names.append(fn)
             else:
-                dn2 = unicode(itm.dirName())
+                dn2 = itm.dirName()
                 dn = self.project.getRelativePath(dn2)
                 dirItems.append(itm)
                 dirFullNames.append(dn2)
@@ -292,15 +288,20 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         del dirFullNames
         del dirNames
         
-        dlg = DeleteFilesConfirmationDialog(self.parent(),
+        from UI.DeleteFilesConfirmationDialog import \
+            DeleteFilesConfirmationDialog
+        dlg = DeleteFilesConfirmationDialog(
+            self.parent(),
             self.trUtf8("Delete files/directories"),
-            self.trUtf8("Do you really want to delete these entries from the project?"),
+            self.trUtf8(
+                "Do you really want to delete these entries from the"
+                " project?"),
             names)
         
         if dlg.exec_() == QDialog.Accepted:
             for itm, fn2, fn in zip(items[:], fullNames, names):
                 if isinstance(itm, ProjectBrowserFileItem):
-                    self.emit(SIGNAL('closeSourceWindow'), fn2)
+                    self.closeSourceWindow.emit(fn2)
                     self.project.deleteFile(fn)
                 elif isinstance(itm, ProjectBrowserDirectoryItem):
                     self.project.deleteDirectory(fn2)
