@@ -9,20 +9,18 @@ Module implementing the Spelling Properties dialog.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QDialog
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from QScintilla.SpellChecker import SpellChecker
-
-from Ui_SpellingPropertiesDialog import Ui_SpellingPropertiesDialog
+from .Ui_SpellingPropertiesDialog import Ui_SpellingPropertiesDialog
 
 import Utilities
 import Preferences
 
+
 class SpellingPropertiesDialog(QDialog, Ui_SpellingPropertiesDialog):
     """
     Class implementing the Spelling Properties dialog.
@@ -35,19 +33,19 @@ class SpellingPropertiesDialog(QDialog, Ui_SpellingPropertiesDialog):
         @param new flag indicating the generation of a new project
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.project = project
         self.parent = parent
         
-        self.pwlCompleter = E4FileCompleter(self.pwlEdit)
-        self.pelCompleter = E4FileCompleter(self.pelEdit)
+        self.pwlCompleter = E5FileCompleter(self.pwlEdit)
+        self.pelCompleter = E5FileCompleter(self.pelEdit)
         
-        projectSpellings = QStringList(self.trUtf8("<default>"))
-        for language in sorted(SpellChecker.getAvailableLanguages()):
-            projectSpellings.append(language)
-        self.spellingComboBox.addItems(projectSpellings)
+        from QScintilla.SpellChecker import SpellChecker
+        self.spellingComboBox.addItem(self.trUtf8("<default>"))
+        self.spellingComboBox.addItems(
+            sorted(SpellChecker.getAvailableLanguages()))
         
         if not new:
             self.initDialog()
@@ -56,50 +54,59 @@ class SpellingPropertiesDialog(QDialog, Ui_SpellingPropertiesDialog):
         """
         Public method to initialize the dialogs data.
         """
-        index = self.spellingComboBox.findText(self.project.pdata["SPELLLANGUAGE"][0])
+        index = self.spellingComboBox.findText(
+            self.project.pdata["SPELLLANGUAGE"][0])
         if index == -1:
             index = 0
         self.spellingComboBox.setCurrentIndex(index)
         if self.project.pdata["SPELLWORDS"][0]:
-            self.pwlEdit.setText(
-                os.path.join(self.project.ppath, self.project.pdata["SPELLWORDS"][0]))
+            self.pwlEdit.setText(Utilities.toNativeSeparators(
+                self.project.pdata["SPELLWORDS"][0]))
         if self.project.pdata["SPELLEXCLUDES"][0]:
-            self.pelEdit.setText(
-                os.path.join(self.project.ppath, self.project.pdata["SPELLEXCLUDES"][0]))
+            self.pelEdit.setText(Utilities.toNativeSeparators(
+                self.project.pdata["SPELLEXCLUDES"][0]))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pwlButton_clicked(self):
         """
         Private slot to select the project word list file.
         """
-        pwl = self.pwlEdit.text()
-        if pwl.isEmpty():
+        pwl = Utilities.fromNativeSeparators(self.pwlEdit.text())
+        if not pwl:
             pwl = self.project.ppath
-        file = KQFileDialog.getOpenFileName(\
+        elif not os.path.isabs(pwl):
+            pwl = Utilities.fromNativeSeparators(
+                os.path.join(self.project.ppath, pwl))
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select project word list"),
             pwl,
             self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
-            
-        if not file.isEmpty():
-            self.pwlEdit.setText(Utilities.toNativeSeparators(file))
+        
+        if file:
+            self.pwlEdit.setText(self.project.getRelativePath(
+                Utilities.toNativeSeparators(file)))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_pelButton_clicked(self):
         """
         Private slot to select the project exclude list file.
         """
-        pel = self.pelEdit.text()
-        if pel.isEmpty():
+        pel = Utilities.fromNativeSeparators(self.pelEdit.text())
+        if not pel:
             pel = self.project.ppath
-        file = KQFileDialog.getOpenFileName(\
+        elif not os.path.isabs(pel):
+            pel = Utilities.fromNativeSeparators(
+                os.path.join(self.project.ppath, pel))
+        file = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select project exclude list"),
             pel,
             self.trUtf8("Dictionary File (*.dic);;All Files (*)"))
             
-        if not file.isEmpty():
-            self.pelEdit.setText(Utilities.toNativeSeparators(file))
+        if file:
+            self.pelEdit.setText(self.project.getRelativePath(
+                Utilities.toNativeSeparators(file)))
     
     def storeData(self):
         """
@@ -110,8 +117,8 @@ class SpellingPropertiesDialog(QDialog, Ui_SpellingPropertiesDialog):
                 [Preferences.getEditor("SpellCheckingDefaultLanguage")]
         else:
             self.project.pdata["SPELLLANGUAGE"] = \
-                [unicode(self.spellingComboBox.currentText())]
+                [self.spellingComboBox.currentText()]
         self.project.pdata["SPELLWORDS"] = \
-            [self.project.getRelativePath(unicode(self.pwlEdit.text()))]
+            [self.project.getRelativePath(self.pwlEdit.text())]
         self.project.pdata["SPELLEXCLUDES"] = \
-            [self.project.getRelativePath(unicode(self.pelEdit.text()))]
+            [self.project.getRelativePath(self.pelEdit.text())]
