@@ -9,17 +9,17 @@ Module implementing the Translations Properties dialog.
 
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSlot
+from PyQt4.QtGui import QListWidgetItem, QDialog, QDialogButtonBox
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter, E5DirCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter, E4DirCompleter
-
-from Ui_TranslationPropertiesDialog import Ui_TranslationPropertiesDialog
+from .Ui_TranslationPropertiesDialog import Ui_TranslationPropertiesDialog
 
 import Utilities
 
+
 class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
     """
     Class implementing the Translations Properties dialog.
@@ -32,15 +32,15 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         @param new flag indicating the generation of a new project
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.project = project
         self.parent = parent
         
-        self.transPatternCompleter = E4FileCompleter(self.transPatternEdit)
-        self.transBinPathCompleter = E4DirCompleter(self.transBinPathEdit)
-        self.exceptionCompleter = E4FileCompleter(self.exceptionEdit)
+        self.transPatternCompleter = E5FileCompleter(self.transPatternEdit)
+        self.transBinPathCompleter = E5DirCompleter(self.transBinPathEdit)
+        self.exceptionCompleter = E5FileCompleter(self.exceptionEdit)
         
         self.initFilters()
         if not new:
@@ -51,18 +51,17 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         Public method to initialize the filters.
         """
         patterns = {
-            "SOURCES"    : QStringList(), 
-            "FORMS"      : QStringList(), 
+            "SOURCES": [],
+            "FORMS": [],
         }
-        for pattern, filetype in self.project.pdata["FILETYPES"].items():
-            if patterns.has_key(filetype):
-                patterns[filetype].append(QString(pattern))
-        self.filters = self.trUtf8("Source Files (%1);;")\
-            .arg(patterns["SOURCES"].join(" "))
-        if self.parent.getProjectType() in ["Qt4", "E4Plugin", "Kde4", "PySide"]:
-            self.filters.append(self.trUtf8("Forms Files (%1);;")\
-                .arg(patterns["FORMS"].join(" ")))
-        self.filters.append(self.trUtf8("All Files (*)"))
+        for pattern, filetype in list(self.project.pdata["FILETYPES"].items()):
+            if filetype in patterns:
+                patterns[filetype].append(pattern)
+        self.filters = self.trUtf8("Source Files ({0});;")\
+            .format(" ".join(patterns["SOURCES"]))
+        self.filters += self.trUtf8("Forms Files ({0});;")\
+            .format(" ".join(patterns["FORMS"]))
+        self.filters += self.trUtf8("All Files (*)")
         
     def initDialog(self):
         """
@@ -70,13 +69,13 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
         try:
-            self.transPatternEdit.setText(os.path.join(\
-                self.project.ppath, self.project.pdata["TRANSLATIONPATTERN"][0]))
+            self.transPatternEdit.setText(Utilities.toNativeSeparators(
+                self.project.pdata["TRANSLATIONPATTERN"][0]))
         except IndexError:
             pass
         try:
-            self.transBinPathEdit.setText(os.path.join(\
-                self.project.ppath, self.project.pdata["TRANSLATIONSBINPATH"][0]))
+            self.transBinPathEdit.setText(Utilities.toNativeSeparators(
+                self.project.pdata["TRANSLATIONSBINPATH"][0]))
         except IndexError:
             pass
         self.exceptionsList.clear()
@@ -84,49 +83,56 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
             if texcept:
                 self.exceptionsList.addItem(texcept)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_transPatternButton_clicked(self):
         """
         Private slot to display a file selection dialog.
         """
-        tp = self.transPatternEdit.text()
-        if tp.contains("%language%"):
-            tp = tp.section("%language%", 0, 0)
-        tsfile = KQFileDialog.getOpenFileName(\
+        tp = Utilities.fromNativeSeparators(self.transPatternEdit.text())
+        if "%language%" in tp:
+            tp = tp.split("%language%")[0]
+        if not os.path.isabs(tp):
+            tp = Utilities.fromNativeSeparators(
+                os.path.join(self.project.ppath, tp))
+        tsfile = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select translation file"),
             tp,
-            QString(),
-            None)
+            "")
         
-        if not tsfile.isEmpty():
-            self.transPatternEdit.setText(Utilities.toNativeSeparators(tsfile))
+        if tsfile:
+            self.transPatternEdit.setText(self.project.getRelativePath(
+                Utilities.toNativeSeparators(tsfile)))
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_transPatternEdit_textChanged(self, txt):
         """
         Private slot to check the translation pattern for correctness.
         
-        @param txt text of the transPatternEdit lineedit (QString)
+        @param txt text of the transPatternEdit lineedit (string)
         """
         self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
-            txt.contains("%language%"))
+            "%language%" in txt)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_transBinPathButton_clicked(self):
         """
         Private slot to display a directory selection dialog.
         """
-        directory = KQFileDialog.getExistingDirectory(\
+        tbp = Utilities.fromNativeSeparators(self.transBinPathEdit.text())
+        if not os.path.isabs(tbp):
+            tbp = Utilities.fromNativeSeparators(
+                os.path.join(self.project.ppath, tbp))
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select directory for binary translations"),
-            self.transBinPathEdit.text(),
-            QFileDialog.Options(QFileDialog.Option(0)))
+            tbp)
         
-        if not directory.isEmpty():
-            self.transBinPathEdit.setText(Utilities.toNativeSeparators(directory))
+        if directory:
+            self.transBinPathEdit.setText(self.project.getRelativePath(
+                Utilities.toNativeSeparators(directory)))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteExceptionButton_clicked(self):
         """
         Private slot to delete the currently selected entry of the listwidget.
@@ -137,12 +143,12 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         row = self.exceptionsList.currentRow()
         self.on_exceptionsList_currentRowChanged(row)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addExceptionButton_clicked(self):
         """
         Private slot to add the shown exception to the listwidget.
         """
-        texcept = unicode(self.exceptionEdit.text())
+        texcept = self.exceptionEdit.text()
         if self.project.ppath == '':
             texcept = texcept.replace(self.parent.getPPath() + os.sep, "")
         else:
@@ -155,36 +161,36 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         row = self.exceptionsList.currentRow()
         self.on_exceptionsList_currentRowChanged(row)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_exceptFileButton_clicked(self):
         """
         Private slot to select a file to exempt from translation.
         """
-        texcept = KQFileDialog.getOpenFileName(\
+        texcept = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Exempt file from translation"),
             self.project.ppath,
-            self.filters,
-            None)
-        if not texcept.isEmpty():
+            self.filters)
+        if texcept:
             self.exceptionEdit.setText(Utilities.toNativeSeparators(texcept))
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_exceptDirButton_clicked(self):
         """
         Private slot to select a file to exempt from translation.
         """
-        texcept = KQFileDialog.getExistingDirectory(\
+        texcept = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Exempt directory from translation"),
             self.project.ppath,
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
-        if not texcept.isEmpty():
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
+        if texcept:
             self.exceptionEdit.setText(Utilities.toNativeSeparators(texcept))
         
     def on_exceptionsList_currentRowChanged(self, row):
         """
-        Private slot to handle the currentRowChanged signal of the exceptions list.
+        Private slot to handle the currentRowChanged signal of the exceptions
+        list.
         
         @param row the current row (integer)
         """
@@ -197,28 +203,28 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         Private slot to handle the textChanged signal of the exception edit.
         
-        @param txt the text of the exception edit (QString)
+        @param txt the text of the exception edit (string)
         """
-        self.addExceptionButton.setEnabled(not txt.isEmpty())
+        self.addExceptionButton.setEnabled(txt != "")
         
     def storeData(self):
         """
         Public method to store the entered/modified data.
         """
         tp = Utilities.toNativeSeparators(self.transPatternEdit.text())
-        if not tp.isEmpty():
-            tp = self.project.getRelativePath(unicode(tp))
+        if tp:
+            tp = self.project.getRelativePath(tp)
             self.project.pdata["TRANSLATIONPATTERN"] = [tp]
             self.project.translationsRoot = tp.split("%language%")[0]
         else:
             self.project.pdata["TRANSLATIONPATTERN"] = []
         tp = Utilities.toNativeSeparators(self.transBinPathEdit.text())
-        if not tp.isEmpty():
-            tp = self.project.getRelativePath(unicode(tp))
+        if tp:
+            tp = self.project.getRelativePath(tp)
             self.project.pdata["TRANSLATIONSBINPATH"] = [tp]
         else:
             self.project.pdata["TRANSLATIONSBINPATH"] = []
         exceptList = []
         for i in range(self.exceptionsList.count()):
-            exceptList.append(unicode(self.exceptionsList.item(i).text()))
+            exceptList.append(self.exceptionsList.item(i).text())
         self.project.pdata["TRANSLATIONEXCEPTIONS"] = exceptList[:]
