@@ -4,12 +4,12 @@
 #
 
 """
-Package implementing the project management module of eric4.
+Package implementing the project management module of eric5.
 
 The project management module consists of the main part, which is
-used for reading and writing of eric4 project files (*.e4p *.e4pz) and
-for performing all operations on the project. It is accompanied by 
-various UI related modules implementing different dialogs and a tabbed 
+used for reading and writing of eric4 and eric5 project files (*.e4p)
+and for performing all operations on the project. It is accompanied by
+various UI related modules implementing different dialogs and a tabbed
 tree browser for the display of files belonging to the current project
 as well as the project model related modules.
 """
