@@ -9,74 +9,88 @@ Module implementing the UI to the pyunit package.
 
 import unittest
 import sys
-import traceback
 import time
 import re
 import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, QEvent, Qt, pyqtSlot
+from PyQt4.QtGui import QWidget, QColor, QDialog, QApplication, \
+    QDialogButtonBox, QListWidgetItem
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from Ui_UnittestDialog import Ui_UnittestDialog
-from Ui_UnittestStacktraceDialog import Ui_UnittestStacktraceDialog
-
-from DebugClients.Python.coverage import coverage
+from .Ui_UnittestDialog import Ui_UnittestDialog
 
 import UI.PixmapCache
 
 import Utilities
+import Preferences
+
 
 class UnittestDialog(QWidget, Ui_UnittestDialog):
     """
     Class implementing the UI to the pyunit package.
     
-    @signal unittestFile(string,int,int) emitted to show the source of a unittest file
+    @signal unittestFile(str, int, int) emitted to show the source of a
+        unittest file
+    @signal unittestStopped() emitted after a unit test was run
     """
-    def __init__(self, prog = None, dbs = None, ui = None, fromEric=False, parent = None,
-                 name = None):
+    unittestFile = pyqtSignal(str, int, int)
+    unittestStopped = pyqtSignal()
+    
+    def __init__(self, prog=None, dbs=None, ui=None, fromEric=False,
+                 parent=None, name=None):
         """
         Constructor
         
         @param prog filename of the program to open
         @param dbs reference to the debug server object. It is an indication
-            whether we were called from within the eric4 IDE
+            whether we were called from within the eric5 IDE
         @param ui reference to the UI object
         @param fromEric flag indicating an instantiation from within the
             eric IDE (boolean)
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
         """
-        QWidget.__init__(self,parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
         
-        self.startButton = self.buttonBox.addButton(\
+        self.startButton = self.buttonBox.addButton(
             self.trUtf8("Start"), QDialogButtonBox.ActionRole)
-        self.startButton.setToolTip(self.trUtf8("Start the selected testsuite"))
-        self.startButton.setWhatsThis(self.trUtf8(\
+        self.startButton.setToolTip(self.trUtf8(
+            "Start the selected testsuite"))
+        self.startButton.setWhatsThis(self.trUtf8(
             """<b>Start Test</b>"""
             """<p>This button starts the selected testsuite.</p>"""))
-        self.stopButton = self.buttonBox.addButton(\
+        self.startFailedButton = self.buttonBox.addButton(
+            self.trUtf8("Rerun Failed"), QDialogButtonBox.ActionRole)
+        self.startFailedButton.setToolTip(
+            self.trUtf8("Reruns failed tests of the selected testsuite"))
+        self.startFailedButton.setWhatsThis(self.trUtf8(
+            """<b>Rerun Failed</b>"""
+            """<p>This button reruns all failed tests of the selected"""
+            """ testsuite.</p>"""))
+        self.stopButton = self.buttonBox.addButton(
             self.trUtf8("Stop"), QDialogButtonBox.ActionRole)
         self.stopButton.setToolTip(self.trUtf8("Stop the running unittest"))
-        self.stopButton.setWhatsThis(self.trUtf8(\
+        self.stopButton.setWhatsThis(self.trUtf8(
             """<b>Stop Test</b>"""
             """<p>This button stops a running unittest.</p>"""))
         self.stopButton.setEnabled(False)
         self.startButton.setDefault(True)
+        self.startFailedButton.setEnabled(False)
         
         self.dbs = dbs
         self.__fromEric = fromEric
         
-        self.setWindowFlags(\
-            self.windowFlags() | Qt.WindowFlags(Qt.WindowContextHelpButtonHint))
+        self.setWindowFlags(
+            self.windowFlags() | Qt.WindowFlags(
+                Qt.WindowContextHelpButtonHint))
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         self.setWindowTitle(self.trUtf8("Unittest"))
         if dbs:
@@ -87,33 +101,35 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.progressLed.setDarkFactor(150)
         self.progressLed.off()
         
-        self.testSuiteCompleter = E4FileCompleter(self.testsuiteComboBox)
+        self.testSuiteCompleter = E5FileCompleter(self.testsuiteComboBox)
         
-        self.fileHistory = QStringList()
-        self.testNameHistory = QStringList()
+        self.fileHistory = []
+        self.testNameHistory = []
         self.running = False
         self.savedModulelist = None
         self.savedSysPath = sys.path
         if prog:
             self.insertProg(prog)
         
-        self.rx1 = QRegExp(self.trUtf8("^Failure: "))
-        self.rx2 = QRegExp(self.trUtf8("^Error: "))
+        self.rxPatterns = [
+            self.trUtf8("^Failure: "),
+            self.trUtf8("^Error: "),
+        ]
         
-        # now connect the debug server signals if called from the eric4 IDE
+        self.__failedTests = []
+        
+        # now connect the debug server signals if called from the eric5 IDE
         if self.dbs:
-            self.connect(self.dbs, SIGNAL('utPrepared'),
-                self.__UTPrepared)
-            self.connect(self.dbs, SIGNAL('utFinished'),
-                self.__setStoppedMode)
-            self.connect(self.dbs, SIGNAL('utStartTest'),
-                self.testStarted)
-            self.connect(self.dbs, SIGNAL('utStopTest'),
-                self.testFinished)
-            self.connect(self.dbs, SIGNAL('utTestFailed'),
-                self.testFailed)
-            self.connect(self.dbs, SIGNAL('utTestErrored'),
-                self.testErrored)
+            self.dbs.utPrepared.connect(self.__UTPrepared)
+            self.dbs.utFinished.connect(self.__setStoppedMode)
+            self.dbs.utStartTest.connect(self.testStarted)
+            self.dbs.utStopTest.connect(self.testFinished)
+            self.dbs.utTestFailed.connect(self.testFailed)
+            self.dbs.utTestErrored.connect(self.testErrored)
+            self.dbs.utTestSkipped.connect(self.testSkipped)
+            self.dbs.utTestFailedExpected.connect(self.testFailedExpected)
+            self.dbs.utTestSucceededUnexpected.connect(
+                self.testSucceededUnexpected)
     
     def keyPressEvent(self, evt):
         """
@@ -128,21 +144,23 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         Private methode to set the color of the progress color label.
         
-        @param color colour to be shown
+        @param color colour to be shown (string)
         """
         self.progressLed.setColor(QColor(color))
         
     def insertProg(self, prog):
         """
-        Public slot to insert the filename prog into the testsuiteComboBox object.
+        Public slot to insert the filename prog into the testsuiteComboBox
+        object.
         
-        @param prog filename to be inserted (string or QString)
+        @param prog filename to be inserted (string)
         """
         # prepend the selected file to the testsuite combobox
         if prog is None:
-            prog = QString()
-        self.fileHistory.removeAll(prog)
-        self.fileHistory.prepend(prog)
+            prog = ""
+        if prog in self.fileHistory:
+            self.fileHistory.remove(prog)
+        self.fileHistory.insert(0, prog)
         self.testsuiteComboBox.clear()
         self.testsuiteComboBox.addItems(self.fileHistory)
         
@@ -150,42 +168,46 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         Public slot to insert a test name into the testComboBox object.
         
-        @param testName name of the test to be inserted (string or QString)
+        @param testName name of the test to be inserted (string)
         """
         # prepend the selected file to the testsuite combobox
         if testName is None:
-            testName = QString()
-        self.testNameHistory.removeAll(testName)
-        self.testNameHistory.prepend(testName)
+            testName = ""
+        if testName in self.testNameHistory:
+            self.testNameHistory.remove(testName)
+        self.testNameHistory.insert(0, testName)
         self.testComboBox.clear()
         self.testComboBox.addItems(self.testNameHistory)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fileDialogButton_clicked(self):
         """
         Private slot to open a file dialog.
         """
         if self.dbs:
-            pyExtensions = \
-                ' '.join(["*%s" % ext for ext in self.dbs.getExtensions('Python')])
+            py2Extensions = \
+                ' '.join(["*{0}".format(ext)
+                          for ext in self.dbs.getExtensions('Python2')])
             py3Extensions = \
-                ' '.join(["*%s" % ext for ext in self.dbs.getExtensions('Python3')])
-            filter = self.trUtf8("Python Files (%1);;Python3 Files (%2);;All Files (*)")\
-                .arg(pyExtensions).arg(py3Extensions)
+                ' '.join(["*{0}".format(ext)
+                          for ext in self.dbs.getExtensions('Python3')])
+            filter = self.trUtf8(
+                "Python3 Files ({1});;Python2 Files ({0});;All Files (*)")\
+                .format(py2Extensions, py3Extensions)
         else:
             filter = self.trUtf8("Python Files (*.py);;All Files (*)")
-        prog = KQFileDialog.getOpenFileName(\
+        prog = E5FileDialog.getOpenFileName(
             self,
-            QString(),
+            "",
             self.testsuiteComboBox.currentText(),
             filter)
         
-        if prog.isNull():
+        if not prog:
             return
         
         self.insertProg(Utilities.toNativeSeparators(prog))
         
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_testsuiteComboBox_editTextChanged(self, txt):
         """
         Private slot to handle changes of the test file name.
@@ -193,8 +215,11 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         @param txt name of the test file (string)
         """
         if self.dbs:
-            exts = self.dbs.getExtensions("Python3")
-            if unicode(txt).endswith(exts):
+            exts = self.dbs.getExtensions("Python2")
+            flags = Utilities.extractFlagsFromFile(txt)
+            if txt.endswith(exts) or \
+               ("FileType" in flags and
+                    flags["FileType"] in ["Python", "Python2"]):
                 self.coverageCheckBox.setChecked(False)
                 self.coverageCheckBox.setEnabled(False)
                 self.localCheckBox.setChecked(False)
@@ -214,20 +239,25 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             self.on_startButton_clicked()
         elif button == self.stopButton:
             self.on_stopButton_clicked()
+        elif button == self.startFailedButton:
+            self.on_startButton_clicked(failedOnly=True)
         
-    @pyqtSignature("")
-    def on_startButton_clicked(self):
+    @pyqtSlot()
+    def on_startButton_clicked(self, failedOnly=False):
         """
         Public slot to start the test.
+        
+        @keyparam failedOnly flag indicating to run only failed tests (boolean)
         """
         if self.running:
             return
         
-        prog = unicode(self.testsuiteComboBox.currentText())
+        prog = self.testsuiteComboBox.currentText()
         if not prog:
-            KQMessageBox.critical(self, 
-                    self.trUtf8("Unittest"), 
-                    self.trUtf8("You must enter a test suite file."))
+            E5MessageBox.critical(
+                self,
+                self.trUtf8("Unittest"),
+                self.trUtf8("You must enter a test suite file."))
             return
         
         # prepend the selected file to the testsuite combobox
@@ -235,8 +265,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.sbLabel.setText(self.trUtf8("Preparing Testsuite"))
         QApplication.processEvents()
         
-        
-        testFunctionName = unicode(self.testComboBox.currentText())
+        testFunctionName = self.testComboBox.currentText()
         if testFunctionName:
             self.insertTestName(testFunctionName)
         else:
@@ -246,23 +275,40 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.testName = os.path.splitext(os.path.basename(prog))[0]
         
         if self.dbs and not self.localCheckBox.isChecked():
-            # we are cooperating with the eric4 IDE
-            project = e4App().getObject("Project")
+            # we are cooperating with the eric5 IDE
+            project = e5App().getObject("Project")
             if project.isOpen() and project.isProjectSource(prog):
                 mainScript = project.getMainScript(True)
+                clientType = project.getProjectLanguage()
             else:
                 mainScript = os.path.abspath(prog)
-            self.dbs.remoteUTPrepare(prog, self.testName, testFunctionName,
+                flags = Utilities.extractFlagsFromFile(mainScript)
+                if mainScript.endswith(
+                    tuple(Preferences.getPython("PythonExtensions"))) or \
+                   ("FileType" in flags and
+                        flags["FileType"] in ["Python", "Python2"]):
+                    clientType = "Python2"
+                else:
+                    clientType = ""
+            if failedOnly and self.__failedTests:
+                failed = [t.split(".", 1)[1] for t in self.__failedTests]
+            else:
+                failed = []
+            self.__failedTests = []
+            self.dbs.remoteUTPrepare(
+                prog, self.testName, testFunctionName, failed,
                 self.coverageCheckBox.isChecked(), mainScript,
-                self.coverageEraseCheckBox.isChecked())
+                self.coverageEraseCheckBox.isChecked(), clientType=clientType)
         else:
             # we are running as an application or in local mode
-            sys.path = [os.path.dirname(os.path.abspath(prog))] + self.savedSysPath
+            sys.path = [os.path.dirname(os.path.abspath(prog))] + \
+                self.savedSysPath
             
-            # clean up list of imported modules to force a reimport upon running the test
+            # clean up list of imported modules to force a reimport upon
+            # running the test
             if self.savedModulelist:
-                for modname in sys.modules.keys():
-                    if not self.savedModulelist.has_key(modname):
+                for modname in list(sys.modules.keys()):
+                    if modname not in self.savedModulelist:
                         # delete it
                         del(sys.modules[modname])
             self.savedModulelist = sys.modules.copy()
@@ -271,25 +317,33 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             try:
                 module = __import__(self.testName)
                 try:
-                    test = unittest.defaultTestLoader.loadTestsFromName(\
-                        testFunctionName, module)
+                    if failedOnly and self.__failedTests:
+                        test = unittest.defaultTestLoader.loadTestsFromNames(
+                            [t.split(".", 1)[1] for t in self.__failedTests],
+                            module)
+                    else:
+                        test = unittest.defaultTestLoader.loadTestsFromName(
+                            testFunctionName, module)
                 except AttributeError:
-                    test = unittest.defaultTestLoader.loadTestsFromModule(module)
+                    test = unittest.defaultTestLoader.loadTestsFromModule(
+                        module)
             except:
                 exc_type, exc_value, exc_tb = sys.exc_info()
-                KQMessageBox.critical(self, 
-                        self.trUtf8("Unittest"),
-                        self.trUtf8("<p>Unable to run test <b>%1</b>.<br>%2<br>%3</p>")
-                            .arg(self.testName)
-                            .arg(unicode(exc_type))
-                            .arg(unicode(exc_value)))
+                E5MessageBox.critical(
+                    self,
+                    self.trUtf8("Unittest"),
+                    self.trUtf8(
+                        "<p>Unable to run test <b>{0}</b>.<br>"
+                        "{1}<br>{2}</p>")
+                    .format(self.testName, str(exc_type),
+                            str(exc_value)))
                 return
                 
             # now set up the coverage stuff
             if self.coverageCheckBox.isChecked():
                 if self.dbs:
-                    # we are cooperating with the eric4 IDE
-                    project = e4App().getObject("Project")
+                    # we are cooperating with the eric5 IDE
+                    project = e5App().getObject("Project")
                     if project.isOpen() and project.isProjectSource(prog):
                         mainScript = project.getMainScript(True)
                         if not mainScript:
@@ -298,8 +352,11 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                         mainScript = os.path.abspath(prog)
                 else:
                     mainScript = os.path.abspath(prog)
+                
+                from DebugClients.Python3.coverage import coverage
                 cover = coverage(
-                    data_file = "%s.coverage" % os.path.splitext(mainScript)[0])
+                    data_file="{0}.coverage".format(
+                        os.path.splitext(mainScript)[0]))
                 cover.use_cache(True)
                 if self.coverageEraseCheckBox.isChecked():
                     cover.erase()
@@ -308,6 +365,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             
             self.testResult = QtTestResult(self)
             self.totalTests = test.countTestCases()
+            self.__failedTests = []
             self.__setRunningMode()
             if cover:
                 cover.start()
@@ -330,19 +388,19 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         @param exc_value value of exception occured during preparation (string)
         """
         if nrTests == 0:
-            KQMessageBox.critical(self, 
-                    self.trUtf8("Unittest"),
-                    self.trUtf8("<p>Unable to run test <b>%1</b>.<br>%2<br>%3</p>")
-                        .arg(self.testName)
-                        .arg(exc_type)
-                        .arg(exc_value))
+            E5MessageBox.critical(
+                self,
+                self.trUtf8("Unittest"),
+                self.trUtf8(
+                    "<p>Unable to run test <b>{0}</b>.<br>{1}<br>{2}</p>")
+                .format(self.testName, exc_type, exc_value))
             return
             
         self.totalTests = nrTests
         self.__setRunningMode()
         self.dbs.remoteUTRun()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_stopButton_clicked(self):
         """
         Private slot to stop the test.
@@ -354,11 +412,15 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
             
     def on_errorsListWidget_currentTextChanged(self, text):
         """
-        Private slot to handle the highlighted(const QString&) signal.
+        Private slot to handle the highlighted signal.
+        
+        @param text current text (string)
         """
-        if not text.isEmpty():
-            text.remove(self.rx1).remove(self.rx2)
-            itm = self.testsListWidget.findItems(text, Qt.MatchFlags(Qt.MatchExactly))[0]
+        if text:
+            for pattern in self.rxPatterns:
+                text = re.sub(pattern, "", text)
+            itm = self.testsListWidget.findItems(
+                text, Qt.MatchFlags(Qt.MatchExactly))[0]
             self.testsListWidget.setCurrentItem(itm)
             self.testsListWidget.scrollToItem(itm)
         
@@ -372,14 +434,21 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.runCount = 0
         self.failCount = 0
         self.errorCount = 0
+        self.skippedCount = 0
+        self.expectedFailureCount = 0
+        self.unexpectedSuccessCount = 0
         self.remainingCount = self.totalTests
-        self.errorInfo = []
 
         # reset the GUI
         self.progressCounterRunCount.setText(str(self.runCount))
+        self.progressCounterRemCount.setText(str(self.remainingCount))
         self.progressCounterFailureCount.setText(str(self.failCount))
         self.progressCounterErrorCount.setText(str(self.errorCount))
-        self.progressCounterRemCount.setText(str(self.remainingCount))
+        self.progressCounterSkippedCount.setText(str(self.skippedCount))
+        self.progressCounterExpectedFailureCount.setText(
+            str(self.expectedFailureCount))
+        self.progressCounterUnexpectedSuccessCount.setText(
+            str(self.unexpectedSuccessCount))
         self.errorsListWidget.clear()
         self.testsListWidget.clear()
         self.progressProgressBar.setRange(0, self.totalTests)
@@ -403,41 +472,96 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.running = False
         
         self.startButton.setEnabled(True)
+        self.startFailedButton.setEnabled(bool(self.__failedTests))
         self.stopButton.setEnabled(False)
-        self.startButton.setDefault(True)
-        if self.runCount == 1:
-            self.sbLabel.setText(self.trUtf8("Ran %1 test in %2s")
-                .arg(self.runCount)
-                .arg("%.3f" % self.timeTaken))
+        if self.__failedTests:
+            self.startFailedButton.setDefault(True)
+            self.startButton.setDefault(False)
         else:
-            self.sbLabel.setText(self.trUtf8("Ran %1 tests in %2s")
-                .arg(self.runCount)
-                .arg("%.3f" % self.timeTaken))
+            self.startFailedButton.setDefault(False)
+            self.startButton.setDefault(True)
+        if self.runCount == 1:
+            self.sbLabel.setText(self.trUtf8("Ran {0} test in {1:.3f}s")
+                .format(self.runCount, self.timeTaken))
+        else:
+            self.sbLabel.setText(self.trUtf8("Ran {0} tests in {1:.3f}s")
+                .format(self.runCount, self.timeTaken))
         self.progressLed.off()
+        
+        self.unittestStopped.emit()
 
-    def testFailed(self, test, exc):
+    def testFailed(self, test, exc, id):
         """
         Public method called if a test fails.
         
-        @param test name of the failed test (string)
-        @param exc string representation of the exception (list of strings)
+        @param test name of the test (string)
+        @param exc string representation of the exception (string)
+        @param id id of the test (string)
         """
         self.failCount += 1
         self.progressCounterFailureCount.setText(str(self.failCount))
-        self.errorsListWidget.insertItem(0, self.trUtf8("Failure: %1").arg(test))
-        self.errorInfo.insert(0, (test, exc))
+        itm = QListWidgetItem(self.trUtf8("Failure: {0}").format(test))
+        itm.setData(Qt.UserRole, (test, exc))
+        self.errorsListWidget.insertItem(0, itm)
+        self.__failedTests.append(id)
         
-    def testErrored(self, test, exc):
+    def testErrored(self, test, exc, id):
         """
         Public method called if a test errors.
         
-        @param test name of the failed test (string)
-        @param exc string representation of the exception (list of strings)
+        @param test name of the test (string)
+        @param exc string representation of the exception (string)
+        @param id id of the test (string)
         """
         self.errorCount += 1
         self.progressCounterErrorCount.setText(str(self.errorCount))
-        self.errorsListWidget.insertItem(0, self.trUtf8("Error: %1").arg(test))
-        self.errorInfo.insert(0, (test, exc))
+        itm = QListWidgetItem(self.trUtf8("Error: {0}").format(test))
+        itm.setData(Qt.UserRole, (test, exc))
+        self.errorsListWidget.insertItem(0, itm)
+        self.__failedTests.append(id)
+        
+    def testSkipped(self, test, reason, id):
+        """
+        Public method called if a test was skipped.
+        
+        @param test name of the test (string)
+        @param reason reason for skipping the test (string)
+        @param id id of the test (string)
+        """
+        self.skippedCount += 1
+        self.progressCounterSkippedCount.setText(str(self.skippedCount))
+        itm = QListWidgetItem(self.trUtf8("    Skipped: {0}").format(reason))
+        itm.setForeground(Qt.blue)
+        self.testsListWidget.insertItem(1, itm)
+        
+    def testFailedExpected(self, test, exc, id):
+        """
+        Public method called if a test fails expectedly.
+        
+        @param test name of the test (string)
+        @param exc string representation of the exception (string)
+        @param id id of the test (string)
+        """
+        self.expectedFailureCount += 1
+        self.progressCounterExpectedFailureCount.setText(
+            str(self.expectedFailureCount))
+        itm = QListWidgetItem(self.trUtf8("    Expected Failure"))
+        itm.setForeground(Qt.blue)
+        self.testsListWidget.insertItem(1, itm)
+        
+    def testSucceededUnexpected(self, test, id):
+        """
+        Public method called if a test succeeds unexpectedly.
+        
+        @param test name of the test (string)
+        @param id id of the test (string)
+        """
+        self.unexpectedSuccessCount += 1
+        self.progressCounterUnexpectedSuccessCount.setText(
+            str(self.unexpectedSuccessCount))
+        itm = QListWidgetItem(self.trUtf8("    Unexpected Success"))
+        itm.setForeground(Qt.red)
+        self.testsListWidget.insertItem(1, itm)
         
     def testStarted(self, test, doc):
         """
@@ -447,8 +571,8 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         @param doc documentation of the started test (string)
         """
         if doc:
-            self.testsListWidget.insertItem(0, "    %s" % doc)
-        self.testsListWidget.insertItem(0, unicode(test))
+            self.testsListWidget.insertItem(0, "    {0}".format(doc))
+        self.testsListWidget.insertItem(0, test)
         if self.dbs is None or self.localCheckBox.isChecked():
             QApplication.processEvents()
         
@@ -484,17 +608,19 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         """
         self.errListIndex = self.errorsListWidget.row(lbitem)
         text = lbitem.text()
+        self.on_errorsListWidget_currentTextChanged(text)
 
         # get the error info
-        test, tracebackLines = self.errorInfo[self.errListIndex]
-        tracebackText = "".join(tracebackLines)
+        test, tracebackText = lbitem.data(Qt.UserRole)
 
         # now build the dialog
+        from .Ui_UnittestStacktraceDialog import Ui_UnittestStacktraceDialog
         self.dlg = QDialog()
         ui = Ui_UnittestStacktraceDialog()
         ui.setupUi(self.dlg)
+        self.dlg.traceback = ui.traceback
         
-        ui.showButton = ui.buttonBox.addButton(\
+        ui.showButton = ui.buttonBox.addButton(
             self.trUtf8("Show Source"), QDialogButtonBox.ActionRole)
         ui.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
@@ -504,8 +630,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
         # one more button if called from eric
         if self.dbs:
-            self.dlg.connect(ui.showButton, SIGNAL("clicked()"),
-                            self.__showSource)
+            ui.showButton.clicked[()].connect(self.__showSource)
         else:
             ui.showButton.hide()
 
@@ -515,21 +640,31 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
     def __showSource(self):
         """
-        Private slot to show the source of a traceback in an eric4 editor.
+        Private slot to show the source of a traceback in an eric5 editor.
         """
         if not self.dbs:
             return
             
         # get the error info
-        test, tracebackLines = self.errorInfo[self.errListIndex]
+        tracebackLines = self.dlg.traceback.toPlainText().splitlines()
         # find the last entry matching the pattern
         for index in range(len(tracebackLines) - 1, -1, -1):
-            fmatch = re.search(r'File "(.*?)", line (\d*?),.*', tracebackLines[index])
+            fmatch = re.search(r'File "(.*?)", line (\d*?),.*',
+                               tracebackLines[index])
             if fmatch:
                 break
         if fmatch:
             fn, ln = fmatch.group(1, 2)
-            self.emit(SIGNAL('unittestFile'), fn, int(ln), 1)
+            self.unittestFile.emit(fn, int(ln), 1)
+    
+    def hasFailedTests(self):
+        """
+        Public method to check, if there are failed tests from the last run.
+        
+        @return flag indicating the presence of failed tests (boolean)
+        """
+        return bool(self.__failedTests)
+
 
 class QtTestResult(unittest.TestResult):
     """
@@ -543,30 +678,60 @@ class QtTestResult(unittest.TestResult):
         
         @param parent The parent widget.
         """
-        unittest.TestResult.__init__(self)
+        super().__init__()
         self.parent = parent
         
     def addFailure(self, test, err):
         """
         Method called if a test failed.
         
-        @param test Reference to the test object
-        @param err The error traceback
+        @param test reference to the test object
+        @param err error traceback
         """
-        unittest.TestResult.addFailure(self, test, err)
-        tracebackLines = apply(traceback.format_exception, err + (10,))
-        self.parent.testFailed(unicode(test), tracebackLines)
+        super().addFailure(test, err)
+        tracebackLines = self._exc_info_to_string(err, test)
+        self.parent.testFailed(str(test), tracebackLines, test.id())
         
     def addError(self, test, err):
         """
         Method called if a test errored.
         
-        @param test Reference to the test object
-        @param err The error traceback
+        @param test reference to the test object
+        @param err error traceback
         """
-        unittest.TestResult.addError(self, test, err)
-        tracebackLines = apply(traceback.format_exception, err + (10,))
-        self.parent.testErrored(unicode(test), tracebackLines)
+        super().addError(test, err)
+        tracebackLines = self._exc_info_to_string(err, test)
+        self.parent.testErrored(str(test), tracebackLines, test.id())
+        
+    def addSkip(self, test, reason):
+        """
+        Method called if a test was skipped.
+        
+        @param test reference to the test object
+        @param reason reason for skipping the test (string)
+        """
+        super().addSkip(test, reason)
+        self.parent.testSkipped(str(test), reason, test.id())
+        
+    def addExpectedFailure(self, test, err):
+        """
+        Method called if a test failed expected.
+        
+        @param test reference to the test object
+        @param err error traceback
+        """
+        super().addExpectedFailure(test, err)
+        tracebackLines = self._exc_info_to_string(err, test)
+        self.parent.testFailedExpected(str(test), tracebackLines, test.id())
+        
+    def addUnexpectedSuccess(self, test):
+        """
+        Method called if a test succeeded expectedly.
+        
+        @param test reference to the test object
+        """
+        super().addUnexpectedSuccess(test)
+        self.parent.testSucceededUnexpected(str(test), test.id())
         
     def startTest(self, test):
         """
@@ -574,8 +739,8 @@ class QtTestResult(unittest.TestResult):
         
         @param test Reference to the test object
         """
-        unittest.TestResult.startTest(self, test)
-        self.parent.testStarted(unicode(test), test.shortDescription())
+        super().startTest(test)
+        self.parent.testStarted(str(test), test.shortDescription())
 
     def stopTest(self, test):
         """
@@ -583,26 +748,30 @@ class QtTestResult(unittest.TestResult):
         
         @param test Reference to the test object
         """
-        unittest.TestResult.stopTest(self, test)
+        super().stopTest(test)
         self.parent.testFinished()
 
-class UnittestWindow(KQMainWindow):
+
+class UnittestWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, prog = None, parent = None):
+    def __init__(self, prog=None, parent=None):
         """
         Constructor
         
         @param prog filename of the program to open
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
-        self.cw = UnittestDialog(prog = prog, parent = self)
+        super().__init__(parent)
+        self.cw = UnittestDialog(prog=prog, parent=self)
         self.cw.installEventFilter(self)
         size = self.cw.size()
         self.setCentralWidget(self.cw)
         self.resize(size)
+        
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
     
     def eventFilter(self, obj, event):
         """
