@@ -7,62 +7,62 @@
 Module implementing the exporter base class.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QFileInfo, QObject
+from PyQt4.QtGui import QApplication
 
-from KdeQt import KQFileDialog, KQMessageBox
+from E5Gui import E5MessageBox, E5FileDialog
 
 import Utilities
 
+
 class ExporterBase(QObject):
     """
     Class implementing the exporter base class.
     """
-    def __init__(self, editor, parent = None):
+    def __init__(self, editor, parent=None):
         """
         Constructor
         
         @param editor reference to the editor object (QScintilla.Editor.Editor)
         @param parent parent object of the exporter (QObject)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         self.editor = editor
     
     def _getFileName(self, filter):
         """
         Protected method to get the file name of the export file from the user.
         
-        @param filter the filter string to be used (QString). The filter for
+        @param filter the filter string to be used (string). The filter for
             "All Files (*)" is appended by this method.
+        @return file name entered by the user (string)
         """
-        filter_ = QString()
-        filter_.append(QApplication.translate('Exporter', "All Files (*)"))
-        selectedFilter = QString(filter)
-        fn = KQFileDialog.getSaveFileName(\
+        filter_ = filter
+        filter_ += ";;"
+        filter_ += QApplication.translate('Exporter', "All Files (*)")
+        fn, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self.editor,
             self.trUtf8("Export source"),
-            QString(),
+            "",
             filter_,
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+            "",
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if not fn.isEmpty():
+        if fn:
             ext = QFileInfo(fn).suffix()
-            if ext.isEmpty():
-                ex = selectedFilter.section('(*', 1, 1).section(')', 0, 0)
-                if not ex.isEmpty():
-                    fn.append(ex)
+            if not ext:
+                ex = selectedFilter.split("(*")[1].split(")")[0]
+                if ex:
+                    fn += ex
             if QFileInfo(fn).exists():
-                res = KQMessageBox.warning(self.editor,
+                res = E5MessageBox.yesNo(
+                    self.editor,
                     self.trUtf8("Export source"),
-                    self.trUtf8("<p>The file <b>%1</b> already exists.</p>")
-                        .arg(fn),
-                    QMessageBox.StandardButtons(\
-                        QMessageBox.Abort | \
-                        QMessageBox.Save),
-                    QMessageBox.Abort)
-                if res == QMessageBox.Abort or res == QMessageBox.Cancel:
-                    return QString()
+                    self.trUtf8("<p>The file <b>{0}</b> already exists."
+                                " Overwrite it?</p>").format(fn),
+                    icon=E5MessageBox.Warning)
+                if not res:
+                    return ""
             
             fn = Utilities.toNativeSeparators(fn)
         
@@ -73,5 +73,8 @@ class ExporterBase(QObject):
         Public method performing the export.
         
         This method must be overridden by the real exporters.
+        
+        @exception NotImplementedError raised to indicate that this method
+            must be implemented by a subclass
         """
         raise NotImplementedError
