@@ -9,23 +9,24 @@ Module implementing the Goto dialog.
 
 from PyQt4.QtGui import QDialog
 
-from Ui_GotoDialog import Ui_GotoDialog
+from .Ui_GotoDialog import Ui_GotoDialog
+
 
 class GotoDialog(QDialog, Ui_GotoDialog):
     """
     Class implementing the Goto dialog.
     """
-    def __init__(self, maximum, curLine, parent, name = None, modal = False):
+    def __init__(self, maximum, curLine, parent, name=None, modal=False):
         """
         Constructor
         
         @param maximum maximum allowed for the spinbox (integer)
         @param curLine current line number (integer)
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
         @param modal flag indicating a modal dialog (boolean)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
