@@ -4,30 +4,29 @@
 #
 
 """
-Module implementing the lexer base class.
+Module implementing the lexer mixin class.
 """
 
-from PyQt4.QtCore import QString, QStringList
-
 import Preferences
 
+
 class Lexer(object):
-    """ 
+    """
     Class to implement the lexer mixin class.
     """
     def __init__(self):
         """
         Constructor
         """
-        self.commentString = QString('')
+        self.commentString = ''
         self.streamCommentString = {
-            'start' : QString(''),
-            'end' : QString('')
+            'start': '',
+            'end': ''
         }
         self.boxCommentString = {
-            'start' : QString(''),
-            'middle' : QString(''),
-            'end' : QString('')
+            'start': '',
+            'middle': '',
+            'end': ''
         }
         
         # last indented line wrapper
@@ -48,35 +47,37 @@ class Lexer(object):
         """
         Public method to return the comment string.
         
-        @return comment string (QString)
+        @return comment string (string)
         """
         return self.commentString
         
     def canBlockComment(self):
         """
-        Public method to determine, whether the lexer language supports a block comment.
+        Public method to determine, whether the lexer language supports a
+        block comment.
         
         @return flag (boolean)
         """
-        return not self.commentString.isEmpty()
+        return self.commentString != ""
         
     def streamCommentStr(self):
         """
         Public method to return the stream comment strings.
         
-        @return stream comment strings (dictionary with two QStrings)
+        @return stream comment strings (dictionary with two strings)
         """
         return self.streamCommentString
         
     def canStreamComment(self):
         """
-        Public method to determine, whether the lexer language supports a stream comment.
+        Public method to determine, whether the lexer language supports a
+        stream comment.
         
         @return flag (boolean)
         """
         return \
-            (not self.streamCommentString['start'].isEmpty()) and \
-            (not self.streamCommentString['end'].isEmpty())
+            (self.streamCommentString['start'] != "") and \
+            (self.streamCommentString['end'] != "")
         
     def boxCommentStr(self):
         """
@@ -88,14 +89,15 @@ class Lexer(object):
         
     def canBoxComment(self):
         """
-        Public method to determine, whether the lexer language supports a box comment.
+        Public method to determine, whether the lexer language supports a
+        box comment.
         
         @return flag (boolean)
         """
         return \
-            (not self.boxCommentString['start'].isEmpty()) and \
-            (not self.boxCommentString['middle'].isEmpty()) and \
-            (not self.boxCommentString['end'].isEmpty())
+            (self.boxCommentString['start'] != "") and \
+            (self.boxCommentString['middle'] != "") and \
+            (self.boxCommentString['end'] != "")
         
     def alwaysKeepTabs(self):
         """
@@ -161,9 +163,9 @@ class Lexer(object):
         
         editor.beginUndoAction()
         # iterate over the lines
-        for line in range(lineFrom, endLine+1):
-            editor.setIndentation(line, 
-                editor.indentation(line) + indentDifference)
+        for line in range(lineFrom, endLine + 1):
+            editor.setIndentation(
+                line, editor.indentation(line) + indentDifference)
         editor.endUndoAction()
         
         if self.lastIndentedIndex != 0:
@@ -183,14 +185,15 @@ class Lexer(object):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList()
+        return []
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return True
@@ -199,6 +202,7 @@ class Lexer(object):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return True
@@ -211,11 +215,19 @@ class Lexer(object):
         @return string giving the keywords (string) or None
         """
         keywords_ = Preferences.getEditorKeywords(self.language())
-        if not keywords_.isEmpty():
-            kw = unicode(keywords_[kwSet])
+        if keywords_ and len(keywords_) > kwSet:
+            kw = keywords_[kwSet]
             if kw == "":
                 return None
             else:
                 return kw
         else:
             return self.defaultKeywords(kwSet)
+    
+    def lexerName(self):
+        """
+        Public method to return the lexer name.
+        
+        @return lexer name (string)
+        """
+        return self.lexer()
