@@ -8,16 +8,16 @@ Module implementing a Bash lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerBash
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerBash(QsciLexerBash, Lexer):
-    """ 
+
+class LexerBash(Lexer, QsciLexerBash):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
@@ -26,7 +26,7 @@ class LexerBash(QsciLexerBash, Lexer):
         QsciLexerBash.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
     
     def initProperties(self):
         """
@@ -39,6 +39,7 @@ class LexerBash(QsciLexerBash, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerBash.Comment]
@@ -47,10 +48,11 @@ class LexerBash(QsciLexerBash, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerBash.DoubleQuotedString, 
-                         QsciLexerBash.SingleQuotedString, 
+        return style in [QsciLexerBash.DoubleQuotedString,
+                         QsciLexerBash.SingleQuotedString,
                          QsciLexerBash.SingleQuotedHereDocument]
     
     def defaultKeywords(self, kwSet):
