@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2014 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,12 +8,12 @@ Module implementing a Batch file lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerBatch
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 
-class LexerBatch(QsciLexerBatch, Lexer):
-    """ 
+
+class LexerBatch(Lexer, QsciLexerBatch):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -25,12 +25,13 @@ class LexerBatch(QsciLexerBatch, Lexer):
         QsciLexerBatch.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("REM ")
+        self.commentString = "REM "
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerBatch.Comment]
@@ -39,6 +40,7 @@ class LexerBatch(QsciLexerBatch, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return False
