@@ -8,33 +8,35 @@ Module implementing a CPP lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerCPP,  QsciScintilla
-from PyQt4.QtCore import QString, QStringList
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerCPP(QsciLexerCPP, Lexer):
-    """ 
+
+class LexerCPP(Lexer, QsciLexerCPP):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent=None, caseInsensitiveKeywords = False):
+    def __init__(self, parent=None, caseInsensitiveKeywords=False):
         """
         Constructor
         
         @param parent parent widget of this lexer
+        @param caseInsensitiveKeywords flag indicating keywords are case
+            insensitive (boolean)
         """
         QsciLexerCPP.__init__(self, parent, caseInsensitiveKeywords)
         Lexer.__init__(self)
         
-        self.commentString = QString("//")
+        self.commentString = "//"
         self.streamCommentString = {
-            'start' : QString('/* '),
-            'end'   : QString(' */')
+            'start': '/* ',
+            'end': ' */'
         }
         self.boxCommentString = {
-            'start'  : QString('/* '),
-            'middle' : QString(' * '),
-            'end'    : QString(' */')
+            'start': '/* ',
+            'middle': ' * ',
+            'end': ' */'
         }
 
     def initProperties(self):
@@ -56,7 +58,8 @@ class LexerCPP(QsciLexerCPP, Lexer):
         except AttributeError:
             pass
         try:
-            self.setStylePreprocessor(Preferences.getEditor("CppStylePreprocessor"))
+            self.setStylePreprocessor(
+                Preferences.getEditor("CppStylePreprocessor"))
         except AttributeError:
             pass
         try:
@@ -64,35 +67,42 @@ class LexerCPP(QsciLexerCPP, Lexer):
                 Preferences.getEditor("CppHighlightTripleQuotedStrings"))
         except AttributeError:
             pass
+        try:
+            self.setHighlightHashQuotedStrings(
+                Preferences.getEditor("CppHighlightHashQuotedStrings"))
+        except AttributeError:
+            pass
     
     def autoCompletionWordSeparators(self):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '::' << '->' << '.'
+        return ['::', '->', '.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerCPP.Comment, 
-                         QsciLexerCPP.CommentDoc, 
-                         QsciLexerCPP.CommentLine, 
+        return style in [QsciLexerCPP.Comment,
+                         QsciLexerCPP.CommentDoc,
+                         QsciLexerCPP.CommentLine,
                          QsciLexerCPP.CommentLineDoc]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerCPP.DoubleQuotedString, 
-                         QsciLexerCPP.SingleQuotedString, 
-                         QsciLexerCPP.UnclosedString, 
+        return style in [QsciLexerCPP.DoubleQuotedString,
+                         QsciLexerCPP.SingleQuotedString,
+                         QsciLexerCPP.UnclosedString,
                          QsciLexerCPP.VerbatimString]
     
     def defaultKeywords(self, kwSet):
