@@ -8,13 +8,13 @@ Module implementing a CSS lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerCSS
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerCSS(QsciLexerCSS, Lexer):
-    """ 
+
+class LexerCSS(Lexer, QsciLexerCSS):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,10 +26,10 @@ class LexerCSS(QsciLexerCSS, Lexer):
         QsciLexerCSS.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
         self.streamCommentString = {
-            'start' : QString('/* '),
-            'end'   : QString(' */')
+            'start': '/* ',
+            'end': ' */'
         }
     
     def initProperties(self):
@@ -38,11 +38,21 @@ class LexerCSS(QsciLexerCSS, Lexer):
         """
         self.setFoldComments(Preferences.getEditor("CssFoldComment"))
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
+        try:
+            self.setHSSLanguage(
+                Preferences.getEditor("CssHssSupport"))
+            self.setLessLanguage(
+                Preferences.getEditor("CssLessSupport"))
+            self.setSCSSLanguage(
+                Preferences.getEditor("CssSassySupport"))
+        except AttributeError:
+            pass
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerCSS.Comment]
@@ -51,9 +61,10 @@ class LexerCSS(QsciLexerCSS, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerCSS.DoubleQuotedString, 
+        return style in [QsciLexerCSS.DoubleQuotedString,
                          QsciLexerCSS.SingleQuotedString]
     
     def defaultKeywords(self, kwSet):
