@@ -8,15 +8,15 @@ Module implementing a base class for custom lexers.
 """
 
 from PyQt4.Qsci import QsciLexer
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 
-class LexerContainer(QsciLexer, Lexer):
-    """ 
+
+class LexerContainer(Lexer, QsciLexer):
+    """
     Subclass as a base for the implementation of custom lexers.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
@@ -54,8 +54,9 @@ class LexerContainer(QsciLexer, Lexer):
         <b>Note</b>: This methods needs to be overridden by the lexer class.
         
         @param style style number (integer)
+        @return description for the given style (string)
         """
-        return QString()
+        return ""
     
     def styleBitsNeeded(self):
         """
@@ -77,10 +78,9 @@ class LexerContainer(QsciLexer, Lexer):
     
     def keywords(self, kwSet):
         """
-        Public method to get the list of keywords.
+        Public method to get the keywords.
         
-        @param kwSet number of keyword set (integer, one based)
-        @return list of supported keywords (string) or None
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
         """
-        
         return Lexer.keywords(self, kwSet)
