@@ -8,13 +8,13 @@ Module implementing a D lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerD, QsciScintilla
-from PyQt4.QtCore import QString, QStringList
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerD(QsciLexerD, Lexer):
-    """ 
+
+class LexerD(Lexer, QsciLexerD):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,15 +26,15 @@ class LexerD(QsciLexerD, Lexer):
         QsciLexerD.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("//")
+        self.commentString = "//"
         self.streamCommentString = {
-            'start' : QString('/+ '),
-            'end'   : QString(' +/')
+            'start': '/+ ',
+            'end': ' +/'
         }
         self.boxCommentString = {
-            'start'  : QString('/* '),
-            'middle' : QString(' * '),
-            'end'    : QString(' */')
+            'start': '/* ',
+            'middle': ' * ',
+            'end': ' */'
         }
     
     def initProperties(self):
@@ -55,29 +55,31 @@ class LexerD(QsciLexerD, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '.'
+        return ['.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerD.Comment, 
-                         QsciLexerD.CommentDoc, 
-                         QsciLexerD.CommentLine, 
-                         QsciLexerD.CommentLineDoc, 
+        return style in [QsciLexerD.Comment,
+                         QsciLexerD.CommentDoc,
+                         QsciLexerD.CommentLine,
+                         QsciLexerD.CommentLineDoc,
                          QsciLexerD.CommentNested]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerD.String, 
+        return style in [QsciLexerD.String,
                          QsciLexerD.UnclosedString]
     
     def defaultKeywords(self, kwSet):
