@@ -8,12 +8,12 @@ Module implementing a Diff lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerDiff
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 
-class LexerDiff(QsciLexerDiff, Lexer):
-    """ 
+
+class LexerDiff(Lexer, QsciLexerDiff):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -29,6 +29,7 @@ class LexerDiff(QsciLexerDiff, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [LexerDiff.Comment]
@@ -37,6 +38,7 @@ class LexerDiff(QsciLexerDiff, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return False
