@@ -7,17 +7,17 @@
 Module implementing a Fortran lexer with some additional methods.
 """
 
-from PyQt4.Qsci import QsciLexerFortran, QsciScintilla
-from PyQt4.QtCore import QString, QStringList
+from PyQt4.Qsci import QsciLexerFortran
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerFortran(QsciLexerFortran, Lexer):
-    """ 
+
+class LexerFortran(Lexer, QsciLexerFortran):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
@@ -26,7 +26,7 @@ class LexerFortran(QsciLexerFortran, Lexer):
         QsciLexerFortran.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("!")
+        self.commentString = "!"
     
     def initProperties(self):
         """
@@ -38,14 +38,15 @@ class LexerFortran(QsciLexerFortran, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '.'
+        return ['.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerFortran.Comment]
@@ -54,10 +55,11 @@ class LexerFortran(QsciLexerFortran, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerFortran.DoubleQuotedString, 
-                         QsciLexerFortran.SingleQuotedString, 
+        return style in [QsciLexerFortran.DoubleQuotedString,
+                         QsciLexerFortran.SingleQuotedString,
                          QsciLexerFortran.UnclosedString]
     
     def defaultKeywords(self, kwSet):
