@@ -8,13 +8,13 @@ Module implementing an IDL lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerIDL,  QsciScintilla
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerIDL(QsciLexerIDL, Lexer):
-    """ 
+
+class LexerIDL(Lexer, QsciLexerIDL):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,15 +26,15 @@ class LexerIDL(QsciLexerIDL, Lexer):
         QsciLexerIDL.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("//")
+        self.commentString = "//"
         self.streamCommentString = {
-            'start' : QString('/* '),
-            'end'   : QString(' */')
+            'start': '/* ',
+            'end': ' */'
         }
         self.boxCommentString = {
-            'start'  : QString('/* '),
-            'middle' : QString(' * '),
-            'end'    : QString(' */')
+            'start': '/* ',
+            'middle': ' * ',
+            'end': ' */'
         }
 
     def initProperties(self):
@@ -56,22 +56,24 @@ class LexerIDL(QsciLexerIDL, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerIDL.Comment, 
-                         QsciLexerIDL.CommentDoc, 
-                         QsciLexerIDL.CommentLine, 
+        return style in [QsciLexerIDL.Comment,
+                         QsciLexerIDL.CommentDoc,
+                         QsciLexerIDL.CommentLine,
                          QsciLexerIDL.CommentLineDoc]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerIDL.DoubleQuotedString, 
-                         QsciLexerIDL.SingleQuotedString, 
-                         QsciLexerIDL.UnclosedString, 
+        return style in [QsciLexerIDL.DoubleQuotedString,
+                         QsciLexerIDL.SingleQuotedString,
+                         QsciLexerIDL.UnclosedString,
                          QsciLexerIDL.VerbatimString]
     
     def defaultKeywords(self, kwSet):
