@@ -8,12 +8,12 @@ Module implementing a Makefile lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerMakefile
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 
-class LexerMakefile(QsciLexerMakefile, Lexer):
-    """ 
+
+class LexerMakefile(Lexer, QsciLexerMakefile):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -25,13 +25,14 @@ class LexerMakefile(QsciLexerMakefile, Lexer):
         QsciLexerMakefile.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
         self._alwaysKeepTabs = True
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerMakefile.Comment]
@@ -40,6 +41,7 @@ class LexerMakefile(QsciLexerMakefile, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return False
