@@ -8,13 +8,13 @@ Module implementing a Povray lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerPOV
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerPOV(QsciLexerPOV, Lexer):
-    """ 
+
+class LexerPOV(Lexer, QsciLexerPOV):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,15 +26,15 @@ class LexerPOV(QsciLexerPOV, Lexer):
         QsciLexerPOV.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("//")
+        self.commentString = "//"
         self.streamCommentString = {
-            'start' : QString('/* '),
-            'end'   : QString(' */')
+            'start': '/* ',
+            'end': ' */'
         }
         self.boxCommentString = {
-            'start'  : QString('/* '),
-            'middle' : QString(' * '),
-            'end'    : QString(' */')
+            'start': '/* ',
+            'middle': ' * ',
+            'end': ' */'
         }
     
     def initProperties(self):
@@ -49,18 +49,20 @@ class LexerPOV(QsciLexerPOV, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerPOV.Comment, 
+        return style in [QsciLexerPOV.Comment,
                          QsciLexerPOV.CommentLine]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerPOV.String, 
+        return style in [QsciLexerPOV.String,
                          QsciLexerPOV.UnclosedString]
     
     def defaultKeywords(self, kwSet):
