@@ -7,17 +7,17 @@
 Module implementing a Pascal lexer with some additional methods.
 """
 
-from PyQt4.Qsci import QsciLexerPascal, QsciScintilla
-from PyQt4.QtCore import QString, QStringList
+from PyQt4.Qsci import QsciLexerPascal
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerPascal(QsciLexerPascal, Lexer):
-    """ 
+
+class LexerPascal(Lexer, QsciLexerPascal):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
@@ -26,10 +26,10 @@ class LexerPascal(QsciLexerPascal, Lexer):
         QsciLexerPascal.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("//")
+        self.commentString = "//"
         self.streamCommentString = {
-            'start' : QString('{ '),
-            'end'   : QString(' }')
+            'start': '{ ',
+            'end': ' }'
         }
     
     def initProperties(self):
@@ -37,10 +37,12 @@ class LexerPascal(QsciLexerPascal, Lexer):
         Public slot to initialize the properties.
         """
         self.setFoldComments(Preferences.getEditor("PascalFoldComment"))
-        self.setFoldPreprocessor(Preferences.getEditor("PascalFoldPreprocessor"))
+        self.setFoldPreprocessor(
+            Preferences.getEditor("PascalFoldPreprocessor"))
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
         try:
-            self.setSmartHighlighting(Preferences.getEditor("PascalSmartHighlighting"))
+            self.setSmartHighlighting(
+                Preferences.getEditor("PascalSmartHighlighting"))
         except AttributeError:
             pass
     
@@ -48,29 +50,31 @@ class LexerPascal(QsciLexerPascal, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '.'
+        return ['.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         try:
-            return style in [QsciLexerPascal.Comment, 
-                             QsciLexerPascal.CommentDoc, 
+            return style in [QsciLexerPascal.Comment,
+                             QsciLexerPascal.CommentDoc,
                              QsciLexerPascal.CommentLine]
         except AttributeError:
-            return style in [QsciLexerPascal.Comment, 
-                             QsciLexerPascal.CommentParenthesis, 
+            return style in [QsciLexerPascal.Comment,
+                             QsciLexerPascal.CommentParenthesis,
                              QsciLexerPascal.CommentLine]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerPascal.SingleQuotedString]
