@@ -8,13 +8,13 @@ Module implementing a Perl lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerPerl
-from PyQt4.QtCore import QString, QStringList
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerPerl(QsciLexerPerl, Lexer):
-    """ 
+
+class LexerPerl(Lexer, QsciLexerPerl):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,7 +26,7 @@ class LexerPerl(QsciLexerPerl, Lexer):
         QsciLexerPerl.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
     
     def initProperties(self):
         """
@@ -48,14 +48,15 @@ class LexerPerl(QsciLexerPerl, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '::' << '->'
+        return ['::', '->']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerPerl.Comment]
@@ -64,16 +65,17 @@ class LexerPerl(QsciLexerPerl, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerPerl.DoubleQuotedHereDocument, 
-                         QsciLexerPerl.DoubleQuotedString, 
-                         QsciLexerPerl.QuotedStringQ, 
-                         QsciLexerPerl.QuotedStringQQ, 
-                         QsciLexerPerl.QuotedStringQR, 
-                         QsciLexerPerl.QuotedStringQW, 
-                         QsciLexerPerl.QuotedStringQX, 
-                         QsciLexerPerl.SingleQuotedHereDocument, 
+        return style in [QsciLexerPerl.DoubleQuotedHereDocument,
+                         QsciLexerPerl.DoubleQuotedString,
+                         QsciLexerPerl.QuotedStringQ,
+                         QsciLexerPerl.QuotedStringQQ,
+                         QsciLexerPerl.QuotedStringQR,
+                         QsciLexerPerl.QuotedStringQW,
+                         QsciLexerPerl.QuotedStringQX,
+                         QsciLexerPerl.SingleQuotedHereDocument,
                          QsciLexerPerl.SingleQuotedString]
     
     def defaultKeywords(self, kwSet):
