@@ -8,16 +8,16 @@ Module implementing a PostScript lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerPostScript
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerPostScript(QsciLexerPostScript, Lexer):
-    """ 
+
+class LexerPostScript(Lexer, QsciLexerPostScript):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
@@ -26,7 +26,7 @@ class LexerPostScript(QsciLexerPostScript, Lexer):
         QsciLexerPostScript.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("%")
+        self.commentString = "%"
     
     def initProperties(self):
         """
@@ -41,6 +41,7 @@ class LexerPostScript(QsciLexerPostScript, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerPostScript.Comment]
@@ -49,6 +50,7 @@ class LexerPostScript(QsciLexerPostScript, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return False
