@@ -10,26 +10,39 @@ Module implementing a Python lexer with some additional methods.
 import re
 
 from PyQt4.Qsci import QsciLexerPython,  QsciScintilla
-from PyQt4.QtCore import QString, QStringList
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerPython(QsciLexerPython, Lexer):
-    """ 
+
+class LexerPython(Lexer, QsciLexerPython):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
-    def __init__(self, parent=None):
+    def __init__(self, variant="", parent=None):
         """
         Constructor
         
+        @param variant name of the language variant (string)
         @param parent parent widget of this lexer
         """
         QsciLexerPython.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
-
+        self.variant = variant
+        self.commentString = "#"
+    
+    def language(self):
+        """
+        Public method to get the lexer language.
+        
+        @return lexer language (string)
+        """
+        if not self.variant:
+            return QsciLexerPython.language(self)
+        else:
+            return self.variant
+    
     def initProperties(self):
         """
         Public slot to initialize the properties.
@@ -41,10 +54,12 @@ class LexerPython(QsciLexerPython, Lexer):
         self.setFoldComments(Preferences.getEditor("PythonFoldComment"))
         self.setFoldQuotes(Preferences.getEditor("PythonFoldString"))
         if not Preferences.getEditor("PythonAutoIndent"):
-           self.setAutoIndentStyle(QsciScintilla.AiMaintain)
+            self.setAutoIndentStyle(QsciScintilla.AiMaintain)
         try:
-            self.setV2UnicodeAllowed(Preferences.getEditor("PythonAllowV2Unicode"))
-            self.setV3BinaryOctalAllowed(Preferences.getEditor("PythonAllowV3Binary"))
+            self.setV2UnicodeAllowed(
+                Preferences.getEditor("PythonAllowV2Unicode"))
+            self.setV3BinaryOctalAllowed(
+                Preferences.getEditor("PythonAllowV3Binary"))
             self.setV3BytesAllowed(Preferences.getEditor("PythonAllowV3Bytes"))
         except AttributeError:
             pass
@@ -73,7 +88,7 @@ class LexerPython(QsciLexerPython, Lexer):
         lead_spaces = editor.indentation(line)
         
         pline = line - 1
-        while pline >= 0 and re.match('^\s*(#.*)?$', unicode(editor.text(pline))):
+        while pline >= 0 and re.match('^\s*(#.*)?$', editor.text(pline)):
             pline -= 1
         
         if pline < 0:
@@ -81,14 +96,14 @@ class LexerPython(QsciLexerPython, Lexer):
         else:
             previous_lead_spaces = editor.indentation(pline)
             # trailing spaces
-            m = re.search(':\s*(#.*)?$', unicode(editor.text(pline)))
+            m = re.search(':\s*(#.*)?$', editor.text(pline))
             last = previous_lead_spaces
             if m:
                 last += indent_width
             else:
                 # special cases, like pass (unindent) or return (also unindent)
-                m = re.search('(pass\s*(#.*)?$)|(^[^#]return)', 
-                              unicode(editor.text(pline)))
+                m = re.search('(pass\s*(#.*)?$)|(^[^#]return)',
+                              editor.text(pline))
                 if m:
                     last -= indent_width
         
@@ -104,29 +119,31 @@ class LexerPython(QsciLexerPython, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '.'
+        return ['.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerPython.Comment, 
+        return style in [QsciLexerPython.Comment,
                          QsciLexerPython.CommentBlock]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerPython.DoubleQuotedString, 
-                         QsciLexerPython.SingleQuotedString, 
-                         QsciLexerPython.TripleDoubleQuotedString, 
-                         QsciLexerPython.TripleSingleQuotedString, 
+        return style in [QsciLexerPython.DoubleQuotedString,
+                         QsciLexerPython.SingleQuotedString,
+                         QsciLexerPython.TripleDoubleQuotedString,
+                         QsciLexerPython.TripleSingleQuotedString,
                          QsciLexerPython.UnclosedString]
     
     def defaultKeywords(self, kwSet):
