@@ -8,14 +8,14 @@ Module implementing a Ruby lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerRuby
-from PyQt4.QtCore import QString, QStringList
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerRuby(QsciLexerRuby, Lexer):
-    """ 
-    Subclass to implement some additional lexer dependent methods.
+
+class LexerRuby(Lexer, QsciLexerRuby):
+    """
+    Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
         """
@@ -26,7 +26,7 @@ class LexerRuby(QsciLexerRuby, Lexer):
         QsciLexerRuby.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
     
     def initProperties(self):
         """
@@ -42,14 +42,15 @@ class LexerRuby(QsciLexerRuby, Lexer):
         """
         Public method to return the list of separators for autocompletion.
         
-        @return list of separators (QStringList)
+        @return list of separators (list of strings)
         """
-        return QStringList() << '.'
+        return ['.']
     
     def isCommentStyle(self, style):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return style in [QsciLexerRuby.Comment]
@@ -58,15 +59,16 @@ class LexerRuby(QsciLexerRuby, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerRuby.DoubleQuotedString, 
-                         QsciLexerRuby.HereDocument, 
-                         QsciLexerRuby.PercentStringQ, 
-                         QsciLexerRuby.PercentStringq, 
-                         QsciLexerRuby.PercentStringr, 
-                         QsciLexerRuby.PercentStringw, 
-                         QsciLexerRuby.PercentStringx, 
+        return style in [QsciLexerRuby.DoubleQuotedString,
+                         QsciLexerRuby.HereDocument,
+                         QsciLexerRuby.PercentStringQ,
+                         QsciLexerRuby.PercentStringq,
+                         QsciLexerRuby.PercentStringr,
+                         QsciLexerRuby.PercentStringw,
+                         QsciLexerRuby.PercentStringx,
                          QsciLexerRuby.SingleQuotedString]
     
     def defaultKeywords(self, kwSet):
