@@ -8,13 +8,13 @@ Module implementing a SQL lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerSQL
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerSQL(QsciLexerSQL, Lexer):
-    """ 
+
+class LexerSQL(Lexer, QsciLexerSQL):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -25,6 +25,8 @@ class LexerSQL(QsciLexerSQL, Lexer):
         """
         QsciLexerSQL.__init__(self, parent)
         Lexer.__init__(self)
+        
+        self.commentString = "--"
     
     def initProperties(self):
         """
@@ -38,7 +40,8 @@ class LexerSQL(QsciLexerSQL, Lexer):
             self.setFoldAtElse(Preferences.getEditor("SqlFoldAtElse"))
             self.setFoldOnlyBegin(Preferences.getEditor("SqlFoldOnlyBegin"))
             self.setHashComments(Preferences.getEditor("SqlHashComments"))
-            self.setQuotedIdentifiers(Preferences.getEditor("SqlQuotedIdentifiers"))
+            self.setQuotedIdentifiers(
+                Preferences.getEditor("SqlQuotedIdentifiers"))
         except AttributeError:
             pass
     
@@ -46,20 +49,22 @@ class LexerSQL(QsciLexerSQL, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerSQL.Comment, 
-                         QsciLexerSQL.CommentDoc, 
-                         QsciLexerSQL.CommentLine, 
+        return style in [QsciLexerSQL.Comment,
+                         QsciLexerSQL.CommentDoc,
+                         QsciLexerSQL.CommentLine,
                          QsciLexerSQL.CommentLineHash]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerSQL.DoubleQuotedString, 
+        return style in [QsciLexerSQL.DoubleQuotedString,
                          QsciLexerSQL.SingleQuotedString]
     
     def defaultKeywords(self, kwSet):
