@@ -8,14 +8,14 @@ Module implementing a TCL/Tk lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerTCL
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 
 import Preferences
 
-class LexerTCL(QsciLexerTCL, Lexer):
-    """ 
+
+class LexerTCL(Lexer, QsciLexerTCL):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -27,7 +27,7 @@ class LexerTCL(QsciLexerTCL, Lexer):
         QsciLexerTCL.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("#")
+        self.commentString = "#"
     
     def initProperties(self):
         """
@@ -46,17 +46,19 @@ class LexerTCL(QsciLexerTCL, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerTCL.Comment, 
-                         QsciLexerTCL.CommentBlock, 
-                         QsciLexerTCL.CommentBox, 
+        return style in [QsciLexerTCL.Comment,
+                         QsciLexerTCL.CommentBlock,
+                         QsciLexerTCL.CommentBox,
                          QsciLexerTCL.CommentLine]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerTCL.QuotedString]
