@@ -8,13 +8,13 @@ Module implementing a Tex lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerTeX
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerTeX(QsciLexerTeX, Lexer):
-    """ 
+
+class LexerTeX(Lexer, QsciLexerTeX):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,7 +26,7 @@ class LexerTeX(QsciLexerTeX, Lexer):
         QsciLexerTeX.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("%")
+        self.commentString = "%"
     
     def initProperties(self):
         """
@@ -35,7 +35,8 @@ class LexerTeX(QsciLexerTeX, Lexer):
         try:
             self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
             self.setFoldComments(Preferences.getEditor("TexFoldComment"))
-            self.setProcessComments(Preferences.getEditor("TexProcessComments"))
+            self.setProcessComments(
+                Preferences.getEditor("TexProcessComments"))
             self.setProcessIf(Preferences.getEditor("TexProcessIf"))
         except AttributeError:
             pass
@@ -44,6 +45,7 @@ class LexerTeX(QsciLexerTeX, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
         return False
@@ -52,6 +54,7 @@ class LexerTeX(QsciLexerTeX, Lexer):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerTeX.Text]
