@@ -8,13 +8,13 @@ Module implementing a VHDL lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerVHDL
-from PyQt4.QtCore import QString
 
-from Lexer import Lexer
+from .Lexer import Lexer
 import Preferences
 
-class LexerVHDL(QsciLexerVHDL, Lexer):
-    """ 
+
+class LexerVHDL(Lexer, QsciLexerVHDL):
+    """
     Subclass to implement some additional lexer dependant methods.
     """
     def __init__(self, parent=None):
@@ -26,7 +26,7 @@ class LexerVHDL(QsciLexerVHDL, Lexer):
         QsciLexerVHDL.__init__(self, parent)
         Lexer.__init__(self)
         
-        self.commentString = QString("--")
+        self.commentString = "--"
     
     def initProperties(self):
         """
@@ -35,7 +35,7 @@ class LexerVHDL(QsciLexerVHDL, Lexer):
         self.setFoldComments(Preferences.getEditor("VHDLFoldComment"))
         self.setFoldAtElse(Preferences.getEditor("VHDLFoldAtElse"))
         self.setFoldAtBegin(Preferences.getEditor("VHDLFoldAtBegin"))
-        self.setFoldAtParenthesis(\
+        self.setFoldAtParenthesis(
             Preferences.getEditor("VHDLFoldAtParenthesis"))
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
     
@@ -43,18 +43,20 @@ class LexerVHDL(QsciLexerVHDL, Lexer):
         """
         Public method to check, if a style is a comment style.
         
+        @param style style to check (integer)
         @return flag indicating a comment style (boolean)
         """
-        return style in [QsciLexerVHDL.Comment, 
+        return style in [QsciLexerVHDL.Comment,
                          QsciLexerVHDL.CommentLine]
     
     def isStringStyle(self, style):
         """
         Public method to check, if a style is a string style.
         
+        @param style style to check (integer)
         @return flag indicating a string style (boolean)
         """
-        return style in [QsciLexerVHDL.String, 
+        return style in [QsciLexerVHDL.String,
                          QsciLexerVHDL.UnclosedString]
     
     def defaultKeywords(self, kwSet):
