@@ -7,23 +7,24 @@
 Module implementing the printer functionality.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4.Qsci import QsciScintilla, QsciPrinter
+from PyQt4.QtCore import QTime, QDate, Qt
+from PyQt4.QtGui import QColor, QPrinter, QApplication
+from PyQt4.Qsci import QsciPrinter
 
 import Preferences
 
+
 class Printer(QsciPrinter):
-    """ 
+    """
     Class implementing the QextScintillaPrinter with a header.
     """
-    def __init__(self, mode = QPrinter.ScreenResolution):
+    def __init__(self, mode=QPrinter.ScreenResolution):
         """
         Constructor
         
         @param mode mode of the printer (QPrinter.PrinterMode)
         """
-        QsciPrinter.__init__(self, mode)
+        super().__init__(mode)
         
         self.setMagnification(Preferences.getPrinter("Magnification"))
         if Preferences.getPrinter("ColorMode"):
@@ -39,9 +40,11 @@ class Printer(QsciPrinter):
             Preferences.getPrinter("TopMargin") * 10,
             Preferences.getPrinter("RightMargin") * 10,
             Preferences.getPrinter("BottomMargin") * 10,
-            QsciPrinter.Millimeter
+            QPrinter.Millimeter
         )
-        self.setPrinterName(Preferences.getPrinter("PrinterName"))
+        printerName = Preferences.getPrinter("PrinterName")
+        if printerName:
+            self.setPrinterName(printerName)
         self.time = QTime.currentTime().toString(Qt.LocalDate)
         self.date = QDate.currentDate().toString(Qt.LocalDate)
         self.headerFont = Preferences.getPrinter("HeaderFont")
@@ -57,17 +60,16 @@ class Printer(QsciPrinter):
         """
         fn = self.docName()
         
-        header = QApplication.translate('Printer', '%1 - Printed on %2, %3 - Page %4')\
-            .arg(fn)\
-            .arg(self.date)\
-            .arg(self.time)\
-            .arg(pagenr)
+        header = QApplication.translate(
+            'Printer', '{0} - Printed on {1}, {2} - Page {3}')\
+            .format(fn, self.date, self.time, pagenr)
         
         painter.save()
         painter.setFont(self.headerFont)    # set our header font
         painter.setPen(QColor(Qt.black))            # set color
         if drawing:
-            painter.drawText(area.right() - painter.fontMetrics().width(header),
+            painter.drawText(
+                area.right() - painter.fontMetrics().width(header),
                 area.top() + painter.fontMetrics().ascent(), header)
         area.setTop(area.top() + painter.fontMetrics().height() + 5)
         painter.restore()
