@@ -9,17 +9,18 @@ Module implementing the spell checker for the editor component.
 The spell checker is based on pyenchant.
 """
 
+import os
+
+from PyQt4.QtCore import QTimer, QObject
+
+import Preferences
+import Utilities
+
 try:
     import enchant
 except (ImportError, AttributeError, OSError):
     pass
 
-import os
-
-from PyQt4.QtCore import *
-
-import Preferences
-import Utilities
 
 class SpellChecker(QObject):
     """
@@ -29,17 +30,20 @@ class SpellChecker(QObject):
     _spelling_lang = None
     _spelling_dict = None
     
-    def __init__(self, editor, indicator, defaultLanguage = None, checkRegion = None):
+    def __init__(self, editor, indicator, defaultLanguage=None,
+                 checkRegion=None):
         """
         Constructor
         
         @param editor reference to the editor object (QScintilla.Editor)
         @param indicator spell checking indicator
-        @keyparam defaultLanguage the language to be used as the default (string).
-            The string should be in language locale format (e.g. en_US, de).
-        @keyparam checkRegion reference to a function to check for a valid region
+        @keyparam defaultLanguage the language to be used as the default
+            (string). The string should be in language locale format
+            (e.g. en_US, de).
+        @keyparam checkRegion reference to a function to check for a valid
+            region
         """
-        QObject.__init__(self, editor)
+        super().__init__(editor)
         
         self.editor = editor
         self.indicator = indicator
@@ -83,7 +87,44 @@ class SpellChecker(QObject):
         return False
     
     @classmethod
-    def _getDict(cls, lang, pwl = "", pel = ""):
+    def getDefaultPath(cls, isException=False):
+        """
+        Class method to get the default path names of the user dictionaries.
+        
+        @param isException flag indicating to return the name of the default
+            exception dictionary (boolean)
+        @return file name of the default user dictionary or the default user
+            exception dictionary (string)
+        """
+        if isException:
+            return os.path.join(
+                Utilities.getConfigDir(), "spelling", "pel.dic")
+        else:
+            return os.path.join(
+                Utilities.getConfigDir(), "spelling", "pwl.dic")
+    
+    @classmethod
+    def getUserDictionaryPath(cls, isException=False):
+        """
+        Class method to get the path name of a user dictionary file.
+        
+        @param isException flag indicating to return the name of the user
+            exception dictionary (boolean)
+        @return file name of the user dictionary or the user exception
+            dictionary (string)
+        """
+        if isException:
+            dicFile = Preferences.getEditor("SpellCheckingPersonalExcludeList")
+            if not dicFile:
+                dicFile = SpellChecker.getDefaultPath(False)
+        else:
+            dicFile = Preferences.getEditor("SpellCheckingPersonalWordList")
+            if not dicFile:
+                dicFile = SpellChecker.getDefaultPath()
+        return dicFile
+    
+    @classmethod
+    def _getDict(cls, lang, pwl="", pel=""):
         """
         Protected classmethod to get a new dictionary.
         
@@ -94,17 +135,13 @@ class SpellChecker(QObject):
         @return reference to the dictionary (enchant.Dict)
         """
         if not pwl:
-            pwl = unicode(Preferences.getEditor("SpellCheckingPersonalWordList"))
-            if not pwl:
-                pwl = os.path.join(Utilities.getConfigDir(), "spelling", "pwl.dic")
+            pwl = SpellChecker.getUserDictionaryPath()
             d = os.path.dirname(pwl)
             if not os.path.exists(d):
                 os.makedirs(d)
         
         if not pel:
-            pel = unicode(Preferences.getEditor("SpellCheckingPersonalExcludeList"))
-            if not pel:
-                pel = os.path.join(Utilities.getConfigDir(), "spelling", "pel.dic")
+            pel = SpellChecker.getUserDictionaryPath(False)
             d = os.path.dirname(pel)
             if not os.path.exists(d):
                 os.makedirs(d)
@@ -128,7 +165,7 @@ class SpellChecker(QObject):
         cls._spelling_lang = language
         cls._spelling_dict = cls._getDict(language)
     
-    def setLanguage(self, language, pwl = "", pel = ""):
+    def setLanguage(self, language, pwl="", pel=""):
         """
         Public method to set the current language.
         
@@ -138,8 +175,8 @@ class SpellChecker(QObject):
         @keyparam pel name of the personal/project exclude list (string)
         """
         self._spelling_lang = language
-        self._spelling_dict = self._getDict(language, pwl = unicode(pwl), 
-                                            pel = unicode(pel))
+        self._spelling_dict = self._getDict(language, pwl=pwl,
+                                            pel=pel)
     
     def getLanguage(self):
         """
@@ -159,11 +196,12 @@ class SpellChecker(QObject):
     
     def __getNextWord(self, pos, endPosition):
         """
-        Private method to get the next word in the text after the given position.
+        Private method to get the next word in the text after the given
+        position.
         
         @param pos position to start word extraction (integer)
         @param endPosition position to stop word extraction (integer)
-        @return tuple of three values (the extracted word (string), 
+        @return tuple of three values (the extracted word (string),
             start position (integer), end position (integer))
         """
         if pos < 0 or pos >= endPosition:
@@ -175,7 +213,7 @@ class SpellChecker(QObject):
             pos = self.editor.positionAfter(pos)
             ch = self.editor.charAt(pos)
         if pos == endPosition:
-            return "",  -1, -1
+            return "", -1, -1
         startPos = pos
         
         # 2. extract the word
@@ -196,21 +234,22 @@ class SpellChecker(QObject):
         
         @param wordStart the starting position of the word (integer)
         @param wordEnd the ending position of the word (integer)
-        @return tuple of the leading and trailing context (QString, QString)
+        @return tuple of the leading and trailing context (string, string)
         """
         sline, sindex = self.editor.lineIndexFromPosition(wordStart)
         eline, eindex = self.editor.lineIndexFromPosition(wordEnd)
         text = self.editor.text(sline)
-        return (text.left(sindex), text.mid(eindex))
+        return (text[:sindex], text[eindex:])
     
     def getError(self):
         """
         Public method to get information about the last error found.
         
-        @return tuple of last faulty word (QString), starting position of the
-            faulty word (integer) and ending position of the faulty word (integer)
+        @return tuple of last faulty word (string), starting position of the
+            faulty word (integer) and ending position of the faulty word
+            (integer)
         """
-        return (QString(self.word), self.wordStart, self.wordEnd)
+        return (self.word, self.wordStart, self.wordEnd)
     
     def initCheck(self, startPos, endPos):
         """
@@ -227,7 +266,8 @@ class SpellChecker(QObject):
         if spell is None:
             return False
         
-        self.editor.clearIndicatorRange(self.indicator, startPos, endPos - startPos)
+        self.editor.clearIndicatorRange(
+            self.indicator, startPos, endPos - startPos)
         
         self.pos = startPos
         self.endPos = endPos
@@ -248,8 +288,8 @@ class SpellChecker(QObject):
         
         while True:
             try:
-                self.next()
-                self.editor.setIndicatorRange(self.indicator, self.wordStart, 
+                next(self)
+                self.editor.setIndicatorRange(self.indicator, self.wordStart,
                                               self.wordEnd - self.wordStart)
             except StopIteration:
                 break
@@ -262,14 +302,15 @@ class SpellChecker(QObject):
             return
         
         linesChunk = Preferences.getEditor("AutoSpellCheckChunkSize")
-        self.checkLines(self.lastCheckedLine, self.lastCheckedLine + linesChunk)
+        self.checkLines(self.lastCheckedLine,
+                        self.lastCheckedLine + linesChunk)
         self.lastCheckedLine = self.lastCheckedLine + linesChunk + 1
         if self.lastCheckedLine >= self.editor.lines():
             self.lastCheckedLine = -1
         else:
             QTimer.singleShot(0, self.__incrementalCheck)
     
-    def checkWord(self, pos, atEnd = False):
+    def checkWord(self, pos, atEnd=False):
         """
         Public method to check the word at position pos.
         
@@ -289,25 +330,28 @@ class SpellChecker(QObject):
             pos1 = -1
             if not self.editor.charAt(pos).isalnum():
                 line, index = self.editor.lineIndexFromPosition(pos)
-                self.editor.clearIndicator(self.indicator, line, index, line, index + 1)
+                self.editor.clearIndicator(
+                    self.indicator, line, index, line, index + 1)
                 pos1 = self.editor.positionAfter(pos)
                 pos0 = self.editor.positionBefore(pos)
             
             for pos in [pos0, pos1]:
                 if self.editor.charAt(pos).isalnum():
                     line, index = self.editor.lineIndexFromPosition(pos)
-                    word = self.editor.getWord(line, index, useWordChars = False)
-                    if word.length() >= self.minimumWordSize:
-                        ok = spell.check(unicode(word))
+                    word = self.editor.getWord(line, index, useWordChars=False)
+                    if len(word) >= self.minimumWordSize:
+                        ok = spell.check(word)
                     else:
                         ok = True
-                    start, end = \
-                        self.editor.getWordBoundaries(line, index, useWordChars = False)
+                    start, end = self.editor.getWordBoundaries(
+                        line, index, useWordChars=False)
                     if ok:
-                        self.editor.clearIndicator(self.indicator, line, start, line, end)
+                        self.editor.clearIndicator(
+                            self.indicator, line, start, line, end)
                     else:
                         # spell check indicated an error
-                        self.editor.setIndicator(self.indicator, line, start, line, end)
+                        self.editor.setIndicator(
+                            self.indicator, line, start, line, end)
     
     def checkLines(self, firstLine, lastLine):
         """
@@ -326,7 +370,7 @@ class SpellChecker(QObject):
     
     def checkDocument(self):
         """
-        Public method to check the complete document
+        Public method to check the complete document.
         """
         self.__checkDocumentPart(0, self.editor.length())
     
@@ -355,7 +399,7 @@ class SpellChecker(QObject):
         selStartLine, selStartIndex, selEndLine, selEndIndex = \
             self.editor.getSelection()
         self.__checkDocumentPart(
-            self.editor.positionFromLineIndex(selStartLine, selStartIndex), 
+            self.editor.positionFromLineIndex(selStartLine, selStartIndex),
             self.editor.positionFromLineIndex(selEndLine, selEndIndex)
         )
     
@@ -371,18 +415,18 @@ class SpellChecker(QObject):
         """
         Public method to clear all spelling markers.
         """
-        self.editor.clearIndicatorRange(self.indicator, 0, self.editor.length())
+        self.editor.clearIndicatorRange(
+            self.indicator, 0, self.editor.length())
     
     def getSuggestions(self, word):
         """
         Public method to get suggestions for the given word.
         
-        @param word word to get suggestions for (string or QString)
+        @param word word to get suggestions for (string)
         @return list of suggestions (list of strings)
         """
         suggestions = []
         spell = self._spelling_dict
-        word = unicode(word)
         if spell and len(word) >= self.minimumWordSize:
             try:
                 suggestions = spell.suggest(word)
@@ -391,49 +435,47 @@ class SpellChecker(QObject):
                 pass
         return suggestions
     
-    def add(self, word = None):
+    def add(self, word=None):
         """
         Public method to add a word to the personal word list.
         
-        @param word word to add (string or QString)
+        @param word word to add (string)
         """
         spell = self._spelling_dict
         if spell:
             if word is None:
                 word = self.word
-            spell.add(unicode(word))
+            spell.add(word)
     
     def remove(self, word):
         """
         Public method to add a word to the personal exclude list.
         
-        @param word word to add (string or QString)
+        @param word word to add (string)
         """
         spell = self._spelling_dict
         if spell:
-            spell.remove(unicode(word))
+            spell.remove(word)
     
-    def ignoreAlways(self, word = None):
+    def ignoreAlways(self, word=None):
         """
         Public method to tell the checker, to always ignore the given word
         or the current word.
         
-        @param word word to be ignored (string or QString)
+        @param word word to be ignored (string)
         """
         if word is None:
             word = self.word
-        word = unicode(word)
         if word not in self.__ignoreWords:
             self.__ignoreWords.append(word)
     
     def replace(self, replacement):
         """
-        Public method to tell the checker to replace the current word with 
+        Public method to tell the checker to replace the current word with
         the replacement string.
         
-        @param replacement replacement string (string or QString)
+        @param replacement replacement string (string)
         """
-        replacement = unicode(replacement)
         sline, sindex = self.editor.lineIndexFromPosition(self.wordStart)
         eline, eindex = self.editor.lineIndexFromPosition(self.wordEnd)
         self.editor.setSelection(sline, sindex, eline, eindex)
@@ -448,9 +490,8 @@ class SpellChecker(QObject):
         Public method to tell the checker to always replace the current word
         with the replacement string.
         
-        @param replacement replacement string (string or QString)
+        @param replacement replacement string (string)
         """
-        replacement = unicode(replacement)
         self.__replaceWords[self.word] = replacement
         self.replace(replacement)
     
@@ -461,24 +502,23 @@ class SpellChecker(QObject):
     def __iter__(self):
         """
         Private method to create an iterator.
+        
+        @return self
         """
         return self
     
     def __next__(self):
-        """
-        Private method to advance to the next error.
-        """
-    
-    def next(self):
         """
         Public method to advance to the next error.
         
         @return self
+        @exception StopIteration raised to indicate the end of the iteration
         """
         spell = self._spelling_dict
         if spell:
             while self.pos < self.endPos and self.pos >= 0:
-                word, wordStart, wordEnd = self.__getNextWord(self.pos, self.endPos)
+                word, wordStart, wordEnd = \
+                    self.__getNextWord(self.pos, self.endPos)
                 self.pos = wordEnd
                 if (wordEnd - wordStart) >= self.minimumWordSize and \
                    self.__checkRegion(wordStart):
