@@ -7,26 +7,33 @@
 Module implementing the spell checking dialog.
 """
 
+from PyQt4.QtCore import pyqtSlot
 from PyQt4.QtGui import QDialog
-from PyQt4.QtCore import *
 
-from Ui_SpellCheckingDialog import Ui_SpellCheckingDialog
+from .Ui_SpellCheckingDialog import Ui_SpellCheckingDialog
 
 import Utilities
 
+
 class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
     """
     Class implementing the spell checking dialog.
     """
-    def __init__(self, spellChecker, startPos, endPos, parent = None):
+    def __init__(self, spellChecker, startPos, endPos, parent=None):
         """
         Constructor
+        
+        @param spellChecker reference to the spell checker (SpellChecker)
+        @param startPos position to start spell checking (integer)
+        @param endPos end position for spell checking (integer)
+        @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.__spell = spellChecker
-        self.languageLabel.setText("<b>%s</b>" % self.__spell.getLanguage())
+        self.languageLabel.setText(
+            "<b>{0}</b>".format(self.__spell.getLanguage()))
         if not self.__spell.initCheck(startPos, endPos):
             self.__enableButtons(False)
         else:
@@ -35,6 +42,8 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
     def __enableButtons(self, enable):
         """
         Private method to set the buttons enabled state.
+        
+        @param enable enable state (boolean)
         """
         self.addButton.setEnabled(enable)
         self.ignoreButton.setEnabled(enable)
@@ -47,7 +56,7 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
         Private method to advance to the next error.
         """
         try:
-            self.__spell.next()
+            next(self.__spell)
         except StopIteration:
             self.__enableButtons(False)
             self.contextLabel.setText("")
@@ -57,44 +66,46 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
         
         self.__enableButtons(True)
         self.word, self.wordStart, self.wordEnd = self.__spell.getError()
-        lcontext, rcontext = self.__spell.getContext(self.wordStart, self.wordEnd)
+        lcontext, rcontext = self.__spell.getContext(
+            self.wordStart, self.wordEnd)
         self.changeEdit.setText(self.word)
-        self.contextLabel.setText(QString('%1<font color="#FF0000">%2</font>%3')\
-                                  .arg(Utilities.html_encode(unicode(lcontext)))\
-                                  .arg(self.word)\
-                                  .arg(Utilities.html_encode(unicode(rcontext))))
+        self.contextLabel.setText(
+            '{0}<font color="#FF0000">{1}</font>{2}'.format(
+                Utilities.html_encode(lcontext),
+                self.word,
+                Utilities.html_encode(rcontext)))
         suggestions = self.__spell.getSuggestions(self.word)
         self.suggestionsList.clear()
         self.suggestionsList.addItems(suggestions)
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_changeEdit_textChanged(self, text):
         """
         Private method to handle a change of the replacement text.
         
-        @param text contents of the line edit (QString)
+        @param text contents of the line edit (string)
         """
-        self.replaceButton.setEnabled(not text.isEmpty())
-        self.replaceAllButton.setEnabled(not text.isEmpty())
+        self.replaceButton.setEnabled(text != "")
+        self.replaceAllButton.setEnabled(text != "")
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_suggestionsList_currentTextChanged(self, currentText):
         """
         Private method to handle the selection of a suggestion.
         
-        @param currentText the currently selected text (QString)
+        @param currentText the currently selected text (string)
         """
-        if not currentText.isEmpty():
+        if currentText:
             self.changeEdit.setText(currentText)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_ignoreButton_clicked(self):
         """
         Private slot to ignore the found error.
         """
         self.__advance()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_ignoreAllButton_clicked(self):
         """
         Private slot to always ignore the found error.
@@ -102,7 +113,7 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
         self.__spell.ignoreAlways()
         self.__advance()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add the current word to the personal word list.
@@ -110,7 +121,7 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
         self.__spell.add()
         self.__advance()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_replaceButton_clicked(self):
         """
         Private slot to replace the current word with the given replacement.
@@ -118,7 +129,7 @@ class SpellCheckingDialog(QDialog, Ui_SpellCheckingDialog):
         self.__spell.replace(self.changeEdit.text())
         self.__advance()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_replaceAllButton_clicked(self):
         """
         Private slot to replace the current word with the given replacement.
