@@ -11,13 +11,14 @@ that are performed while the user is typing (e.g. insert ')' when the
 user types '(').
 """
 
-from PyQt4.QtCore import QObject, SIGNAL
+from PyQt4.QtCore import QObject
+
 
 class CompleterBase(QObject):
     """
     Class implementing the base class for all completers.
     """
-    def __init__(self, editor, parent = None):
+    def __init__(self, editor, parent=None):
         """
         Constructor
         
@@ -28,7 +29,7 @@ class CompleterBase(QObject):
         if parent is None:
             parent = editor
         
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.editor = editor
         self.enabled = False
@@ -37,19 +38,21 @@ class CompleterBase(QObject):
         """
         Public slot to set the enabled state.
         
-        @param enabled flag indicating the new state (boolean)
+        @param enable flag indicating the new enabled state (boolean)
         """
         if enable:
             if not self.enabled:
-                self.connect(self.editor, SIGNAL("SCN_CHARADDED(int)"), self.charAdded)
+                self.editor.SCN_CHARADDED.connect(self.charAdded)
         else:
             if self.enabled:
-                self.disconnect(self.editor, SIGNAL("SCN_CHARADDED(int)"), self.charAdded)
+                self.editor.SCN_CHARADDED.disconnect(self.charAdded)
         self.enabled = enable
     
     def isEnabled(self):
         """
         Public method to get the enabled state.
+        
+        @return enabled state (boolean)
         """
         return self.enabled
     
