@@ -7,18 +7,21 @@
 Module implementing a typing completer for Python.
 """
 
-from PyQt4.QtCore import QObject, SIGNAL, QRegExp
+import re
+
+from PyQt4.QtCore import QRegExp
 from PyQt4.Qsci import QsciLexerPython
 
-from CompleterBase import CompleterBase
+from .CompleterBase import CompleterBase
 
 import Preferences
 
+
 class CompleterPython(CompleterBase):
     """
     Class implementing typing completer for Python.
     """
-    def __init__(self, editor, parent = None):
+    def __init__(self, editor, parent=None):
         """
         Constructor
         
@@ -33,6 +36,7 @@ class CompleterPython(CompleterBase):
         self.__classRX = QRegExp(r"""^[ \t]*class \w+\(""")
         self.__importRX = QRegExp(r"""^[ \t]*from [\w.]+ """)
         self.__classmethodRX = QRegExp(r"""^[ \t]*@classmethod""")
+        self.__staticmethodRX = QRegExp(r"""^[ \t]*@staticmethod""")
         
         self.__defOnlyRX = QRegExp(r"""^[ \t]*def """)
         
@@ -54,7 +58,8 @@ class CompleterPython(CompleterBase):
         """
         Public slot called to reread the configuration parameters.
         """
-        self.setEnabled(Preferences.getEditorTyping("Python/EnabledTypingAids"))
+        self.setEnabled(
+            Preferences.getEditorTyping("Python/EnabledTypingAids"))
         self.__insertClosingBrace = \
             Preferences.getEditorTyping("Python/InsertClosingBrace")
         self.__indentBrace = \
@@ -75,9 +80,9 @@ class CompleterPython(CompleterBase):
             Preferences.getEditorTyping("Python/InsertSelf")
         self.__insertBlank = \
             Preferences.getEditorTyping("Python/InsertBlank")
-        self.__colonDetection= \
+        self.__colonDetection = \
             Preferences.getEditorTyping("Python/ColonDetection")
-        self.__dedentDef= \
+        self.__dedentDef = \
             Preferences.getEditorTyping("Python/DedentDef")
 
     def charAdded(self, charNumber):
@@ -86,8 +91,9 @@ class CompleterPython(CompleterBase):
         
         @param charNumber value of the character entered (integer)
         """
-        char = unichr(charNumber)
-        if char not in ['(', ')', '{', '}', '[', ']', ' ', ',', "'", '"', '\n', ':']:
+        char = chr(charNumber)
+        if char not in ['(', ')', '{', '}', '[', ']', ' ', ',', "'", '"',
+                        '\n', ':']:
             return  # take the short route
         
         line, col = self.editor.getCursorPosition()
@@ -102,12 +108,15 @@ class CompleterPython(CompleterBase):
         # open parenthesis
         # insert closing parenthesis and self
         if char == '(':
-            txt = self.editor.text(line).left(col)
+            txt = self.editor.text(line)[:col]
             if self.__insertSelf and \
                self.__defRX.exactMatch(txt):
-                if self.__isClassmethodDef():
+                if self.__isClassMethodDef():
                     self.editor.insert('cls')
                     self.editor.setCursorPosition(line, col + 3)
+                elif self.__isStaticMethodDef():
+                    # nothing to insert
+                    pass
                 elif self.__isClassMethod():
                     self.editor.insert('self')
                     self.editor.setCursorPosition(line, col + 4)
@@ -121,15 +130,17 @@ class CompleterPython(CompleterBase):
         # closing parenthesis
         # skip matching closing parenthesis
         elif char in [')', '}', ']']:
-            if char == self.editor.text(line).mid(col, 1):
+            txt = self.editor.text(line)
+            if col < len(txt) and char == txt[col]:
                 if self.__skipBrace:
                     self.editor.setSelection(line, col, line, col + 1)
                     self.editor.removeSelectedText()
         
         # space
-        # insert import, dedent to if for elif, dedent to try for except, dedent def
+        # insert import, dedent to if for elif, dedent to try for except,
+        # dedent def
         elif char == ' ':
-            txt = self.editor.text(line).left(col)
+            txt = self.editor.text(line)[:col]
             if self.__insertImport and self.__importRX.exactMatch(txt):
                 self.editor.insert('import ')
                 self.editor.setCursorPosition(line, col + 7)
@@ -174,12 +185,13 @@ class CompleterPython(CompleterBase):
         # colon
         # skip colon, dedent to if for else:
         elif char == ':':
-            if char == self.editor.text(line).mid(col, 1):
+            text = self.editor.text(line)
+            if col < len(text) and char == text[col]:
                 if self.__colonDetection:
                     self.editor.setSelection(line, col, line, col + 1)
                     self.editor.removeSelectedText()
             else:
-                txt = self.editor.text(line).left(col)
+                txt = text[:col]
                 if self.__dedentElse and self.__elseRX.exactMatch(txt):
                     self.__dedentElseToIfWhileForTry()
                 elif self.__dedentExcept and self.__exceptcRX.exactMatch(txt):
@@ -192,22 +204,24 @@ class CompleterPython(CompleterBase):
         elif char == '\n':
             if self.__indentBrace:
                 txt = self.editor.text(line - 1)
-                if txt.lastIndexOf(QRegExp(":\r?\n")) == -1:
-                    openCount = txt.count(QRegExp("[({[]"))
-                    closeCount = txt.count(QRegExp("[)}\]]"))
+                if re.search(":\r?\n", txt) is None:
+                    openCount = len(re.findall("[({[]", txt))
+                    closeCount = len(re.findall("[)}\]]", txt))
                     if openCount > closeCount:
-                        lastOpenIndex = 0
                         openCount = 0
                         closeCount = 0
-                        while lastOpenIndex > -1 and openCount == closeCount:
-                            lastOpenIndex = \
-                                txt.lastIndexOf(QRegExp("[({[]"), lastOpenIndex - 1)
-                            txt2 = txt.mid(lastOpenIndex)
-                            openCount = txt2.count(QRegExp("[({[]"))
-                            closeCount = txt2.count(QRegExp("[)}\]]"))
-                        if lastOpenIndex > -1 and lastOpenIndex > col:
+                        openList = list(re.finditer("[({[]", txt))
+                        index = len(openList) - 1
+                        while index > -1 and openCount == closeCount:
+                            lastOpenIndex = openList[index].start()
+                            txt2 = txt[lastOpenIndex:]
+                            openCount = len(re.findall("[({[]", txt2))
+                            closeCount = len(re.findall("[)}\]]", txt2))
+                            index -= 1
+                        if openCount > closeCount and lastOpenIndex > col:
                             self.editor.insert(' ' * (lastOpenIndex - col + 1))
-                            self.editor.setCursorPosition(line, lastOpenIndex + 1)
+                            self.editor.setCursorPosition(
+                                line, lastOpenIndex + 1)
     
     def __dedentToIf(self):
         """
@@ -220,10 +234,10 @@ class CompleterPython(CompleterBase):
         while ifLine >= 0:
             txt = self.editor.text(ifLine)
             edInd = self.editor.indentation(ifLine)
-            if txt.indexOf(self.__elseRX) == 0 and edInd <= indentation:
+            if self.__elseRX.indexIn(txt) == 0 and edInd <= indentation:
                 indentation = edInd - 1
-            elif (txt.indexOf(self.__ifRX) == 0 or \
-                  txt.indexOf(self.__elifRX) == 0) and edInd <= indentation:
+            elif (self.__ifRX.indexIn(txt) == 0 or
+                  self.__elifRX.indexIn(txt) == 0) and edInd <= indentation:
                 self.editor.cancelList()
                 self.editor.setIndentation(line, edInd)
                 break
@@ -242,17 +256,17 @@ class CompleterPython(CompleterBase):
         while ifLine >= 0:
             txt = self.editor.text(ifLine)
             edInd = self.editor.indentation(ifLine)
-            if txt.indexOf(self.__elseRX) == 0 and edInd <= indentation:
+            if self.__elseRX.indexIn(txt) == 0 and edInd <= indentation:
                 indentation = edInd - 1
-            elif txt.indexOf(self.__elifRX) == 0 and \
-                 edInd == indentation and \
-                 edInd == prevInd:
-                    indentation = edInd - 1
-            elif (txt.indexOf(self.__ifRX) == 0 or \
-                  txt.indexOf(self.__whileRX) == 0 or \
-                  txt.indexOf(self.__forRX) == 0 or \
-                  txt.indexOf(self.__tryRX) == 0) and \
-                 edInd <= indentation:
+            elif self.__elifRX.indexIn(txt) == 0 and \
+                edInd == indentation and \
+                    edInd == prevInd:
+                indentation = edInd - 1
+            elif (self.__ifRX.indexIn(txt) == 0 or
+                  self.__whileRX.indexIn(txt) == 0 or
+                  self.__forRX.indexIn(txt) == 0 or
+                  self.__tryRX.indexIn(txt) == 0) and \
+                    edInd <= indentation:
                 self.editor.cancelList()
                 self.editor.setIndentation(line, edInd)
                 break
@@ -260,7 +274,7 @@ class CompleterPython(CompleterBase):
     
     def __dedentExceptToTry(self, hasColon):
         """
-        Private method to dedent the line of the except statement to the last 
+        Private method to dedent the line of the except statement to the last
         try statement with less (or equal) indentation.
         
         @param hasColon flag indicating the except type (boolean)
@@ -271,11 +285,12 @@ class CompleterPython(CompleterBase):
         while tryLine >= 0:
             txt = self.editor.text(tryLine)
             edInd = self.editor.indentation(tryLine)
-            if (txt.indexOf(self.__exceptcRX) == 0 or \
-                txt.indexOf(self.__finallyRX) == 0) and edInd <= indentation:
+            if (self.__exceptcRX.indexIn(txt) == 0 or
+                self.__finallyRX.indexIn(txt) == 0) and \
+                    edInd <= indentation:
                 indentation = edInd - 1
-            elif (txt.indexOf(self.__exceptRX) == 0 or \
-                  txt.indexOf(self.__tryRX) == 0) and edInd <= indentation:
+            elif (self.__exceptRX.indexIn(txt) == 0 or
+                  self.__tryRX.indexIn(txt) == 0) and edInd <= indentation:
                 self.editor.cancelList()
                 self.editor.setIndentation(line, edInd)
                 break
@@ -283,7 +298,7 @@ class CompleterPython(CompleterBase):
     
     def __dedentFinallyToTry(self):
         """
-        Private method to dedent the line of the except statement to the last 
+        Private method to dedent the line of the except statement to the last
         try statement with less (or equal) indentation.
         """
         line, col = self.editor.getCursorPosition()
@@ -293,20 +308,22 @@ class CompleterPython(CompleterBase):
             txt = self.editor.text(tryLine)
             edInd = self.editor.indentation(tryLine)
             if self.__py24StyleTry:
-                if (txt.indexOf(self.__exceptcRX) == 0 or \
-                    txt.indexOf(self.__exceptRX) == 0 or \
-                    txt.indexOf(self.__finallyRX) == 0) and edInd <= indentation:
+                if (self.__exceptcRX.indexIn(txt) == 0 or
+                    self.__exceptRX.indexIn(txt) == 0 or
+                    self.__finallyRX.indexIn(txt) == 0) and \
+                        edInd <= indentation:
                     indentation = edInd - 1
-                elif txt.indexOf(self.__tryRX) == 0 and edInd <= indentation:
+                elif self.__tryRX.indexIn(txt) == 0 and edInd <= indentation:
                     self.editor.cancelList()
                     self.editor.setIndentation(line, edInd)
                     break
             else:
-                if txt.indexOf(self.__finallyRX) == 0 and edInd <= indentation:
+                if self.__finallyRX.indexIn(txt) == 0 and edInd <= indentation:
                     indentation = edInd - 1
-                elif (txt.indexOf(self.__tryRX) == 0 or \
-                      txt.indexOf(self.__exceptcRX) == 0 or \
-                      txt.indexOf(self.__exceptRX) == 0) and edInd <= indentation:
+                elif (self.__tryRX.indexIn(txt) == 0 or
+                      self.__exceptcRX.indexIn(txt) == 0 or
+                      self.__exceptRX.indexIn(txt) == 0) and \
+                        edInd <= indentation:
                     self.editor.cancelList()
                     self.editor.setIndentation(line, edInd)
                     break
@@ -314,8 +331,8 @@ class CompleterPython(CompleterBase):
     
     def __dedentDefStatement(self):
         """
-        Private method to dedent the line of the def statement to a previous def
-        statement or class statement.
+        Private method to dedent the line of the def statement to a previous
+        def statement or class statement.
         """
         line, col = self.editor.getCursorPosition()
         indentation = self.editor.indentation(line)
@@ -324,9 +341,9 @@ class CompleterPython(CompleterBase):
             txt = self.editor.text(tryLine)
             edInd = self.editor.indentation(tryLine)
             newInd = -1
-            if txt.indexOf(self.__defRX) == 0 and edInd < indentation:
+            if self.__defRX.indexIn(txt) == 0 and edInd < indentation:
                 newInd = edInd
-            elif txt.indexOf(self.__classRX) == 0 and edInd < indentation:
+            elif self.__classRX.indexIn(txt) == 0 and edInd < indentation:
                 newInd = edInd + \
                     (self.editor.indentationWidth() or self.editor.tabWidth())
             if newInd >= 0:
@@ -345,81 +362,105 @@ class CompleterPython(CompleterBase):
         indentation = self.editor.indentation(line)
         curLine = line - 1
         while curLine >= 0:
-            if (self.editor.text(curLine).indexOf(self.__defSelfRX) == 0 or \
-                self.editor.text(curLine).indexOf(self.__defClsRX) == 0) and \
+            txt = self.editor.text(curLine)
+            if (self.__defSelfRX.indexIn(txt) == 0 or
+                self.__defClsRX.indexIn(txt) == 0) and \
                self.editor.indentation(curLine) == indentation:
                 return True
-            elif self.editor.text(curLine).indexOf(self.__classRX) == 0 and \
-               self.editor.indentation(curLine) < indentation:
+            elif self.__classRX.indexIn(txt) == 0 and \
+                    self.editor.indentation(curLine) < indentation:
                 return True
-            elif self.editor.text(curLine).indexOf(self.__defRX) == 0 and \
-               self.editor.indentation(curLine) <= indentation:
+            elif self.__defRX.indexIn(txt) == 0 and \
+                    self.editor.indentation(curLine) <= indentation:
                 return False
             curLine -= 1
         return False
     
-    def __isClassmethodDef(self):
+    def __isClassMethodDef(self):
         """
-        Private method to check, if the user is defing a classmethod 
-        (@classmethod) method.
+        Private method to check, if the user is defing a class method
+        (@classmethod).
         
-        @return flag indicating the definition of a classmethod method (boolean)
+        @return flag indicating the definition of a class method (boolean)
         """
         line, col = self.editor.getCursorPosition()
         indentation = self.editor.indentation(line)
         curLine = line - 1
-        if self.editor.text(curLine).indexOf(self.__classmethodRX) == 0 and \
+        if self.__classmethodRX.indexIn(self.editor.text(curLine)) == 0 and \
+           self.editor.indentation(curLine) == indentation:
+            return True
+        return False
+    
+    def __isStaticMethodDef(self):
+        """
+        Private method to check, if the user is defing a static method
+        (@staticmethod) method.
+        
+        @return flag indicating the definition of a static method (boolean)
+        """
+        line, col = self.editor.getCursorPosition()
+        indentation = self.editor.indentation(line)
+        curLine = line - 1
+        if self.__staticmethodRX.indexIn(self.editor.text(curLine)) == 0 and \
            self.editor.indentation(curLine) == indentation:
             return True
         return False
     
     def __inComment(self, line, col):
         """
-        Private method to check, if the cursor is inside a comment
+        Private method to check, if the cursor is inside a comment.
         
         @param line current line (integer)
         @param col current position within line (integer)
         @return flag indicating, if the cursor is inside a comment (boolean)
         """
         txt = self.editor.text(line)
+        if col == len(txt):
+            col -= 1
         while col >= 0:
-            if txt.mid(col, 1) == "#":
+            if txt[col] == "#":
                 return True
             col -= 1
         return False
     
     def __inDoubleQuotedString(self):
         """
-        Private method to check, if the cursor is within a double quoted string.
+        Private method to check, if the cursor is within a double quoted
+        string.
         
-        @return flag indicating, if the cursor is inside a double 
+        @return flag indicating, if the cursor is inside a double
             quoted string (boolean)
         """
         return self.editor.currentStyle() == QsciLexerPython.DoubleQuotedString
     
     def __inTripleDoubleQuotedString(self):
         """
-        Private method to check, if the cursor is within a triple double quoted string.
+        Private method to check, if the cursor is within a triple double
+        quoted string.
         
-        @return flag indicating, if the cursor is inside a triple double 
+        @return flag indicating, if the cursor is inside a triple double
             quoted string (boolean)
         """
-        return self.editor.currentStyle() == QsciLexerPython.TripleDoubleQuotedString
+        return self.editor.currentStyle() == \
+            QsciLexerPython.TripleDoubleQuotedString
     
     def __inSingleQuotedString(self):
         """
-        Private method to check, if the cursor is within a single quoted string.
+        Private method to check, if the cursor is within a single quoted
+        string.
         
-        @return flag indicating, if the cursor is inside a single 
+        @return flag indicating, if the cursor is inside a single
             quoted string (boolean)
         """
         return self.editor.currentStyle() == QsciLexerPython.SingleQuotedString
     
     def __inTripleSingleQuotedString(self):
         """
-        Private method to check, if the cursor is within a triple single quoted string.
+        Private method to check, if the cursor is within a triple single
+        quoted string.
         
-        @return flag indicating, if the cursor is inside a triple single 
+        @return flag indicating, if the cursor is inside a triple single
             quoted string (boolean)
         """
-        return self.editor.currentStyle() == QsciLexerPython.TripleSingleQuotedString
+        return self.editor.currentStyle() == \
+            QsciLexerPython.TripleSingleQuotedString
