@@ -7,18 +7,21 @@
 Module implementing a typing completer for Ruby.
 """
 
-from PyQt4.QtCore import QObject, SIGNAL, QRegExp
+import re
+
+from PyQt4.QtCore import QRegExp
 from PyQt4.Qsci import QsciLexerRuby
 
-from CompleterBase import CompleterBase
+from .CompleterBase import CompleterBase
 
 import Preferences
 
+
 class CompleterRuby(CompleterBase):
     """
     Class implementing typing completer for Ruby.
     """
-    def __init__(self, editor, parent = None):
+    def __init__(self, editor, parent=None):
         """
         Constructor
         
@@ -59,8 +62,9 @@ class CompleterRuby(CompleterBase):
         
         @param charNumber value of the character entered (integer)
         """
-        char = unichr(charNumber)
-        if char not in ['(', ')', '{', '}', '[', ']', ',', "'", '"', '\n', ' ']:
+        char = chr(charNumber)
+        if char not in ['(', ')', '{', '}', '[', ']', ',', "'", '"',
+                        '\n', ' ']:
             return  # take the short route
         
         line, col = self.editor.getCursorPosition()
@@ -75,14 +79,15 @@ class CompleterRuby(CompleterBase):
         # open parenthesis
         # insert closing parenthesis and self
         if char == '(':
-            txt = self.editor.text(line).left(col)
+            txt = self.editor.text(line)[:col]
             if self.__insertClosingBrace:
                 self.editor.insert(')')
         
         # closing parenthesis
         # skip matching closing parenthesis
         elif char in [')', '}', ']']:
-            if char == self.editor.text(line).mid(col, 1):
+            txt = self.editor.text(line)
+            if col < len(txt) and char == txt[col]:
                 if self.__skipBrace:
                     self.editor.setSelection(line, col, line, col + 1)
                     self.editor.removeSelectedText()
@@ -90,7 +95,7 @@ class CompleterRuby(CompleterBase):
         # space
         # complete inline documentation
         elif char == ' ':
-            txt = self.editor.text(line).left(col)
+            txt = self.editor.text(line)[:col]
             if self.__insertInlineDoc and self.__beginRX.exactMatch(txt):
                 self.editor.insert('=end')
         
@@ -133,52 +138,57 @@ class CompleterRuby(CompleterBase):
                 self.editor.insert('=end')
             elif self.__insertHereDoc and self.__hereRX.exactMatch(txt):
                 self.editor.insert(self.__hereRX.cap(1))
-            elif self.__indentBrace and txt.lastIndexOf(QRegExp(":\r?\n")) == -1:
-                    openCount = txt.count(QRegExp("[({[]"))
-                    closeCount = txt.count(QRegExp("[)}\]]"))
-                    if openCount > closeCount:
-                        lastOpenIndex = 0
-                        openCount = 0
-                        closeCount = 0
-                        while lastOpenIndex > -1 and openCount == closeCount:
-                            lastOpenIndex = \
-                                txt.lastIndexOf(QRegExp("[({[]"), lastOpenIndex - 1)
-                            txt2 = txt.mid(lastOpenIndex)
-                            openCount = txt2.count(QRegExp("[({[]"))
-                            closeCount = txt2.count(QRegExp("[)}\]]"))
-                        if lastOpenIndex > -1 and lastOpenIndex > col:
-                            self.editor.insert(' ' * (lastOpenIndex - col + 1))
-                            self.editor.setCursorPosition(line, lastOpenIndex + 1)
+            elif self.__indentBrace and re.search(":\r?\n", txt) is None:
+                openCount = len(re.findall("[({[]", txt))
+                closeCount = len(re.findall("[)}\]]", txt))
+                if openCount > closeCount:
+                    openCount = 0
+                    closeCount = 0
+                    openList = list(re.finditer("[({[]", txt))
+                    index = len(openList) - 1
+                    while index > -1 and openCount == closeCount:
+                        lastOpenIndex = openList[index].start()
+                        txt2 = txt[lastOpenIndex:]
+                        openCount = len(re.findall("[({[]", txt2))
+                        closeCount = len(re.findall("[)}\]]", txt2))
+                        index -= 1
+                    if openCount > closeCount and lastOpenIndex > col:
+                        self.editor.insert(' ' * (lastOpenIndex - col + 1))
+                        self.editor.setCursorPosition(line, lastOpenIndex + 1)
     
     def __inComment(self, line, col):
         """
-        Private method to check, if the cursor is inside a comment
+        Private method to check, if the cursor is inside a comment.
         
         @param line current line (integer)
         @param col current position within line (integer)
         @return flag indicating, if the cursor is inside a comment (boolean)
         """
         txt = self.editor.text(line)
+        if col == len(txt):
+            col -= 1
         while col >= 0:
-            if txt.mid(col, 1) == "#":
+            if txt[col] == "#":
                 return True
             col -= 1
         return False
     
     def __inDoubleQuotedString(self):
         """
-        Private method to check, if the cursor is within a double quoted string.
+        Private method to check, if the cursor is within a double quoted
+        string.
         
-        @return flag indicating, if the cursor is inside a double 
+        @return flag indicating, if the cursor is inside a double
             quoted string (boolean)
         """
         return self.editor.currentStyle() == QsciLexerRuby.DoubleQuotedString
     
     def __inSingleQuotedString(self):
         """
-        Private method to check, if the cursor is within a single quoted string.
+        Private method to check, if the cursor is within a single quoted
+        string.
         
-        @return flag indicating, if the cursor is inside a single 
+        @return flag indicating, if the cursor is inside a single
             quoted string (boolean)
         """
         return self.editor.currentStyle() == QsciLexerRuby.SingleQuotedString
@@ -187,7 +197,8 @@ class CompleterRuby(CompleterBase):
         """
         Private method to check, if the cursor is within a here document.
         
-        @return flag indicating, if the cursor is inside a here document (boolean)
+        @return flag indicating, if the cursor is inside a here document
+            (boolean)
         """
         return self.editor.currentStyle() == QsciLexerRuby.HereDocument
     
@@ -195,6 +206,7 @@ class CompleterRuby(CompleterBase):
         """
         Private method to check, if the cursor is within an inline document.
         
-        @return flag indicating, if the cursor is inside an inline document (boolean)
+        @return flag indicating, if the cursor is inside an inline document
+            (boolean)
         """
         return self.editor.currentStyle() == QsciLexerRuby.POD
