@@ -7,7 +7,8 @@
 Package implementing lexers for the various supported programming languages.
 """
 
-def getCompleter(language, editor, parent = None):
+
+def getCompleter(language, editor, parent=None):
     """
     Module function to instantiate a lexer object for a given language.
     
@@ -17,11 +18,11 @@ def getCompleter(language, editor, parent = None):
     @return reference to the instanciated lexer object (QsciLexer)
     """
     try:
-        if language == "Python":
-            from CompleterPython import CompleterPython
+        if language in ["Python", "Python2", "Python3"]:
+            from .CompleterPython import CompleterPython
             return CompleterPython(editor, parent)
         elif language == "Ruby":
-            from CompleterRuby import CompleterRuby
+            from .CompleterRuby import CompleterRuby
             return CompleterRuby(editor, parent)
         else:
             return None
