@@ -9,21 +9,23 @@ Module implementing a dialog to select the zoom scale.
 
 from PyQt4.QtGui import QDialog
 
-from Ui_ZoomDialog import Ui_ZoomDialog
+from .Ui_ZoomDialog import Ui_ZoomDialog
+
 
 class ZoomDialog(QDialog, Ui_ZoomDialog):
     """
     Class implementing a dialog to select the zoom scale.
     """
-    def __init__(self, zoom, parent, name = None, modal = False):
+    def __init__(self, zoom, parent, name=None, modal=False):
         """
         Constructor
         
         @param zoom zoom factor to show in the spinbox
         @param parent parent widget of this dialog (QWidget)
-        @param name name of this dialog (string or QString)
+        @param name name of this dialog (string)
+        @param modal modal dialog state (boolean)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.setupUi(self)
