@@ -7,53 +7,56 @@
 Module implementing the SQL Browser widget.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4.QtSql import QSqlDatabase, QSqlError, QSqlTableModel, QSqlQueryModel, QSqlQuery
+from PyQt4.QtCore import pyqtSignal, QVariant, Qt, pyqtSlot
+from PyQt4.QtGui import QWidget, QStandardItemModel, QDialog, QAbstractItemView
+from PyQt4.QtSql import QSqlDatabase, QSqlError, QSqlTableModel, \
+    QSqlQueryModel, QSqlQuery
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
-from SqlConnectionDialog import SqlConnectionDialog
+from .Ui_SqlBrowserWidget import Ui_SqlBrowserWidget
 
-from Ui_SqlBrowserWidget import Ui_SqlBrowserWidget
 
 class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
     """
     Class implementing the SQL Browser widget.
     
-    @signal statusMessage(QString) emitted to show a status message
+    @signal statusMessage(str) emitted to show a status message
     """
+    statusMessage = pyqtSignal(str)
+    
     cCount = 0
     
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.table.addAction(self.insertRowAction)
         self.table.addAction(self.deleteRowAction)
         
-        if QSqlDatabase.drivers().isEmpty():
-            KQMessageBox.information(None,
+        if len(QSqlDatabase.drivers()) == 0:
+            E5MessageBox.information(
+                self,
                 self.trUtf8("No database drivers found"),
-                self.trUtf8("""This tool requires at least one Qt database driver. """
-                """Please check the Qt documentation how to build the """
-                """Qt SQL plugins."""))
+                self.trUtf8(
+                    """This tool requires at least one Qt database driver. """
+                    """Please check the Qt documentation how to build the """
+                    """Qt SQL plugins."""))
         
-        self.connect(self.connections, SIGNAL("tableActivated(QString)"), 
-                     self.on_connections_tableActivated)
-        self.connect(self.connections, SIGNAL("schemaRequested(QString)"), 
-                     self.on_connections_schemaRequested)
-        self.connect(self.connections, SIGNAL("cleared()"), 
-                     self.on_connections_cleared)
+        self.connections.tableActivated.connect(
+            self.on_connections_tableActivated)
+        self.connections.schemaRequested.connect(
+            self.on_connections_schemaRequested)
+        self.connections.cleared.connect(self.on_connections_cleared)
         
-        self.emit(SIGNAL("statusMessage(QString)"), self.trUtf8("Ready"))
+        self.statusMessage.emit(self.trUtf8("Ready"))
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_clearButton_clicked(self):
         """
         Private slot to clear the SQL entry widget.
@@ -61,7 +64,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         self.sqlEdit.clear()
         self.sqlEdit.setFocus()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_executeButton_clicked(self):
         """
         Private slot to execute the entered SQL query.
@@ -69,39 +72,39 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         self.executeQuery()
         self.sqlEdit.setFocus()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_insertRowAction_triggered(self):
         """
         Private slot handling the action to insert a new row.
         """
         self.__insertRow()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteRowAction_triggered(self):
         """
         Private slot handling the action to delete a row.
         """
         self.__deleteRow()
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_connections_tableActivated(self, table):
         """
         Private slot to show the contents of a table.
         
-        @param table name of the table for which to show the contents (QString)
+        @param table name of the table for which to show the contents (string)
         """
         self.showTable(table)
     
-    @pyqtSignature("QString")
+    @pyqtSlot(str)
     def on_connections_schemaRequested(self, table):
         """
         Private slot to show the schema of a table.
         
-        @param table name of the table for which to show the schema (QString)
+        @param table name of the table for which to show the schema (string)
         """
         self.showSchema(table)
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_connections_cleared(self):
         """
         Private slot to clear the table.
@@ -116,25 +119,27 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         """
         Public method to add a database connection.
         
-        @param driver name of the Qt database driver (QString)
-        @param dbName name of the database (QString)
-        @param user user name (QString)
-        @param password password (QString)
-        @param host host name (QString)
+        @param driver name of the Qt database driver (string)
+        @param dbName name of the database (string)
+        @param user user name (string)
+        @param password password (string)
+        @param host host name (string)
         @param port port number (integer)
+        @return SQL error object (QSqlError)
         """
         err = QSqlError()
         
         self.__class__.cCount += 1
-        db = QSqlDatabase.addDatabase(driver.toUpper(), 
-                                      QString("Browser%1").arg(self.__class__.cCount))
+        db = QSqlDatabase.addDatabase(
+            driver.upper(), "Browser{0:d}".format(self.__class__.cCount))
         db.setDatabaseName(dbName)
         db.setHostName(host)
         db.setPort(port)
         if not db.open(user, password):
             err = db.lastError()
             db = QSqlDatabase()
-            QSqlDatabase.removeDatabase(QString("Browser%1").arg(self.__class__.cCount))
+            QSqlDatabase.removeDatabase(
+                "Browser{0:d}".format(self.__class__.cCount))
         
         self.connections.refresh()
         
@@ -144,37 +149,40 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         """
         Public slot to add a database connection via an input dialog.
         """
+        from .SqlConnectionDialog import SqlConnectionDialog
         dlg = SqlConnectionDialog(self)
         if dlg.exec_() == QDialog.Accepted:
             driver, dbName, user, password, host, port = dlg.getData()
-            err = self.addConnection(driver, dbName, user, password, host, port)
+            err = self.addConnection(
+                driver, dbName, user, password, host, port)
             
             if err.type() != QSqlError.NoError:
-                KQMessageBox.warning(self,
+                E5MessageBox.warning(
+                    self,
                     self.trUtf8("Unable to open database"),
-                    self.trUtf8("""An error occurred while opening the connection."""))
+                    self.trUtf8(
+                        """An error occurred while opening the connection."""))
     
     def showTable(self, table):
         """
         Public slot to show the contents of a table.
         
-        @param table name of the table to be shown (string or QString)
+        @param table name of the table to be shown (string)
         """
         model = QSqlTableModel(self.table, self.connections.currentDatabase())
         model.setEditStrategy(QSqlTableModel.OnRowChange)
         model.setTable(table)
         model.select()
         if model.lastError().type() != QSqlError.NoError:
-            self.emit(SIGNAL("statusMessage(QString)"), model.lastError().text())
+            self.statusMessage.emit(model.lastError().text())
         self.table.setModel(model)
         self.table.setEditTriggers(
             QAbstractItemView.DoubleClicked | QAbstractItemView.EditKeyPressed)
         
         self.table.resizeColumnsToContents()
         
-        self.connect(self.table.selectionModel(), 
-                     SIGNAL("currentRowChanged(QModelIndex, QModelIndex)"), 
-                     self.updateActions)
+        self.table.selectionModel().currentRowChanged.connect(
+            self.updateActions)
         
         self.updateActions()
     
@@ -182,7 +190,7 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         """
         Public slot to show the schema of a table.
         
-        @param table name of the table to be shown (string or QString)
+        @param table name of the table to be shown (string)
         """
         rec = self.connections.currentDatabase().record(table)
         model = QStandardItemModel(self.table)
@@ -190,38 +198,38 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         model.insertRows(0, rec.count())
         model.insertColumns(0, 7)
         
-        model.setHeaderData(0, Qt.Horizontal, QVariant("Fieldname"))
-        model.setHeaderData(1, Qt.Horizontal, QVariant("Type"))
-        model.setHeaderData(2, Qt.Horizontal, QVariant("Length"))
-        model.setHeaderData(3, Qt.Horizontal, QVariant("Precision"))
-        model.setHeaderData(4, Qt.Horizontal, QVariant("Required"))
-        model.setHeaderData(5, Qt.Horizontal, QVariant("Auto Value"))
-        model.setHeaderData(6, Qt.Horizontal, QVariant("Default Value"))
+        model.setHeaderData(0, Qt.Horizontal, "Fieldname")
+        model.setHeaderData(1, Qt.Horizontal, "Type")
+        model.setHeaderData(2, Qt.Horizontal, "Length")
+        model.setHeaderData(3, Qt.Horizontal, "Precision")
+        model.setHeaderData(4, Qt.Horizontal, "Required")
+        model.setHeaderData(5, Qt.Horizontal, "Auto Value")
+        model.setHeaderData(6, Qt.Horizontal, "Default Value")
         
         for i in range(rec.count()):
             fld = rec.field(i)
-            model.setData(model.index(i, 0), QVariant(fld.name()))
+            model.setData(model.index(i, 0), fld.name())
             if fld.typeID() == -1:
-                model.setData(model.index(i, 1), 
-                              QVariant(QString(QVariant.typeToName(fld.type()))))
+                model.setData(model.index(i, 1),
+                              QVariant.typeToName(fld.type()))
             else:
-                model.setData(model.index(i, 1), QVariant(QString("%1 (%2)")\
-                                                 .arg(QVariant.typeToName(fld.type()))\
-                                                 .arg(fld.typeID())))
+                model.setData(
+                    model.index(i, 1), "{0} ({1})".format(
+                        QVariant.typeToName(fld.type()), fld.typeID()))
             if fld.length() < 0:
-                model.setData(model.index(i, 2), QVariant("?"))
+                model.setData(model.index(i, 2), "?")
             else:
-                model.setData(model.index(i, 2), QVariant(fld.length()))
+                model.setData(model.index(i, 2), fld.length())
             if fld.precision() < 0:
-                model.setData(model.index(i, 3), QVariant("?"))
+                model.setData(model.index(i, 3), "?")
             else:
-                model.setData(model.index(i, 3), QVariant(fld.precision()))
+                model.setData(model.index(i, 3), fld.precision())
             if fld.requiredStatus() == -1:
-                model.setData(model.index(i, 4), QVariant("?"))
+                model.setData(model.index(i, 4), "?")
             else:
-                model.setData(model.index(i, 4), QVariant(bool(fld.requiredStatus())))
-            model.setData(model.index(i, 5), QVariant(fld.isAutoValue()))
-            model.setData(model.index(i, 6), QVariant(fld.defaultValue()))
+                model.setData(model.index(i, 4), bool(fld.requiredStatus()))
+            model.setData(model.index(i, 5), fld.isAutoValue())
+            model.setData(model.index(i, 6), fld.defaultValue())
         
         self.table.setModel(model)
         self.table.setEditTriggers(QAbstractItemView.NoEditTriggers)
@@ -284,18 +292,18 @@ class SqlBrowserWidget(QWidget, Ui_SqlBrowserWidget):
         Public slot to execute the entered query.
         """
         model = QSqlQueryModel(self.table)
-        model.setQuery(
-            QSqlQuery(self.sqlEdit.toPlainText(), self.connections.currentDatabase()))
+        model.setQuery(QSqlQuery(
+            self.sqlEdit.toPlainText(), self.connections.currentDatabase()))
         self.table.setModel(model)
         
         if model.lastError().type() != QSqlError.NoError:
-            self.emit(SIGNAL("statusMessage(QString)"), model.lastError().text())
+            self.statusMessage.emit(model.lastError().text())
         elif model.query().isSelect():
-            self.emit(SIGNAL("statusMessage(QString)"), self.trUtf8("Query OK."))
+            self.statusMessage.emit(self.trUtf8("Query OK."))
         else:
-            self.emit(SIGNAL("statusMessage(QString)"), 
-                self.trUtf8("Query OK, number of affected rows: %1")\
-                    .arg(model.query().numRowsAffected()))
+            self.statusMessage.emit(
+                self.trUtf8("Query OK, number of affected rows: {0}")
+                    .format(model.query().numRowsAffected()))
         
         self.table.resizeColumnsToContents()
         
