@@ -9,19 +9,18 @@ Module implementing the task properties dialog.
 
 import time
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtGui import QDialog
 
-from E4Gui.E4Completers import E4FileCompleter
+from E5Gui.E5Completers import E5FileCompleter
 
-from Ui_TaskPropertiesDialog import Ui_TaskPropertiesDialog
+from .Ui_TaskPropertiesDialog import Ui_TaskPropertiesDialog
 
 
 class TaskPropertiesDialog(QDialog, Ui_TaskPropertiesDialog):
     """
     Class implementing the task properties dialog.
     """
-    def __init__(self, task = None, parent = None, projectOpen = False):
+    def __init__(self, task=None, parent=None, projectOpen=False):
         """
         Constructor
         
@@ -29,18 +28,19 @@ class TaskPropertiesDialog(QDialog, Ui_TaskPropertiesDialog):
         @param parent the parent widget (QWidget)
         @param projectOpen flag indicating status of the project (boolean)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.filenameCompleter = E4FileCompleter(self.filenameEdit)
+        self.filenameCompleter = E5FileCompleter(self.filenameEdit)
         
         if not projectOpen:
             self.projectCheckBox.setEnabled(False)
         if task is not None:
+            self.summaryEdit.setText(task.summary)
             self.descriptionEdit.setText(task.description)
-            self.longtextEdit.setText(task.longtext)
-            self.creationLabel.setText(time.strftime("%Y-%m-%d, %H:%M:%S", 
-                                                     time.localtime(task.created)))
+            self.creationLabel.setText(
+                time.strftime("%Y-%m-%d, %H:%M:%S",
+                              time.localtime(task.created)))
             self.priorityCombo.setCurrentIndex(task.priority)
             self.projectCheckBox.setChecked(task._isProjectTask)
             self.completedCheckBox.setChecked(task.completed)
@@ -54,17 +54,21 @@ class TaskPropertiesDialog(QDialog, Ui_TaskPropertiesDialog):
         """
         Public slot to set the dialog to read only mode.
         """
-        self.descriptionEdit.setReadOnly(True)
+        self.summaryEdit.setReadOnly(True)
         self.completedCheckBox.setEnabled(False)
         self.priorityCombo.setEnabled(False)
+        self.projectCheckBox.setEnabled(False)
         
     def getData(self):
         """
         Public method to retrieve the dialogs data.
         
-        @return tuple of description, priority, completion flag
-                and project flag
+        @return tuple of description, priority, completion flag,
+                project flag and long text (string, string, boolean,
+                boolean, string)
         """
-        return (self.descriptionEdit.text(), self.priorityCombo.currentIndex(),
-                self.completedCheckBox.isChecked(), self.projectCheckBox.isChecked(), 
-                self.longtextEdit.toPlainText())
+        return (self.summaryEdit.text(),
+                self.priorityCombo.currentIndex(),
+                self.completedCheckBox.isChecked(),
+                self.projectCheckBox.isChecked(),
+                self.descriptionEdit.toPlainText())
