@@ -7,21 +7,19 @@
 Module implementing the templates properties dialog.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QRegExp, Qt, pyqtSlot
+from PyQt4.QtGui import QDialog, QRegExpValidator
 
-from KdeQt import KQMessageBox
+from .Ui_TemplatePropertiesDialog import Ui_TemplatePropertiesDialog
 
-import QScintilla.Lexers
-
-from Ui_TemplatePropertiesDialog import Ui_TemplatePropertiesDialog
+from E5Gui import E5MessageBox
 
 
 class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
     """
     Class implementing the templates properties dialog.
     """
-    def __init__(self, parent, groupMode = False, itm = None):
+    def __init__(self, parent, groupMode=False, itm=None):
         """
         Constructor
         
@@ -30,7 +28,7 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
         @param itm item (TemplateEntry or TemplateGroup) to
             read the data from
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         if not groupMode:
@@ -41,20 +39,20 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
                 """ must only consist of letters (a-z and A-Z),"""
                 """ digits (0-9) and underscores (_).</p>"""
             ))
-            self.__nameValidator = QRegExpValidator(QRegExp("[a-zA-Z0-9_]+"), 
+            self.__nameValidator = QRegExpValidator(QRegExp("[a-zA-Z0-9_]+"),
                                                     self.nameEdit)
             self.nameEdit.setValidator(self.__nameValidator)
         
+        import QScintilla.Lexers
         self.languages = [("All", self.trUtf8("All"))]
         supportedLanguages = QScintilla.Lexers.getSupportedLanguages()
-        languages = supportedLanguages.keys()
-        languages.sort()
+        languages = sorted(supportedLanguages.keys())
         for language in languages:
             self.languages.append((language, supportedLanguages[language][0]))
         
         self.groupMode = groupMode
         if groupMode:
-            langList = QStringList()
+            langList = []
             for lang, langDisp in self.languages:
                 langList.append(langDisp)
             
@@ -67,7 +65,7 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
             self.descriptionLabel.hide()
             self.descriptionEdit.hide()
         else:
-            groups = QStringList()
+            groups = []
             for group in parent.getGroupNames():
                 groups.append(group)
             self.groupCombo.addItems(groups)
@@ -94,51 +92,54 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
         @param ev key event (QKeyEvent)
         """
         if ev.key() == Qt.Key_Escape:
-            res = KQMessageBox.question(self,
+            res = E5MessageBox.yesNo(
+                self,
                 self.trUtf8("Close dialog"),
-                self.trUtf8("""Do you really want to close the dialog?"""),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.No | \
-                    QMessageBox.Yes),
-                QMessageBox.No)
-            if res == QMessageBox.Yes:
+                self.trUtf8("""Do you really want to close the dialog?"""))
+            if not res:
                 self.reject()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_helpButton_clicked(self):
         """
         Public slot to show some help.
         """
-        KQMessageBox.information(self,
+        E5MessageBox.information(
+            self,
             self.trUtf8("Template Help"),
-            self.trUtf8(\
-                """<p>To use variables in a template, you just have to enclose"""
-                """ the variablename with $-characters. When you use the template,"""
-                """ you will then be asked for a value for this variable.</p>"""
+            self.trUtf8(
+                """<p>To use variables in a template, you just have to"""
+                """ enclose the variablename with $-characters. When you"""
+                """ use the template, you will then be asked for a value"""
+                """ for this variable.</p>"""
                 """<p>Example template: This is a $VAR$</p>"""
-                """<p>When you use this template you will be prompted for a value"""
-                """ for the variable $VAR$. Any occurrences of $VAR$ will then be"""
-                """ replaced with whatever you've entered.</p>"""
-                """<p>If you need a single $-character in a template, which is not"""
-                """ used to enclose a variable, type $$(two dollar characters)"""
-                """ instead. They will automatically be replaced with a single"""
-                """ $-character when you use the template.</p>"""
-                """<p>If you want a variables contents to be treated specially,"""
-                """ the variablename must be followed by a ':' and one formatting"""
-                """ specifier (e.g. $VAR:ml$). The supported specifiers are:"""
+                """<p>When you use this template you will be prompted for"""
+                """ a value for the variable $VAR$. Any occurrences of $VAR$"""
+                """ will then be replaced with whatever you've entered.</p>"""
+                """<p>If you need a single $-character in a template, which"""
+                """ is not used to enclose a variable, type $$(two dollar"""
+                """ characters) instead. They will automatically be replaced"""
+                """ with a single $-character when you use the template.</p>"""
+                """<p>If you want a variables contents to be treated"""
+                """ specially, the variablename must be followed by a ':'"""
+                """ and one formatting specifier (e.g. $VAR:ml$). The"""
+                """ supported specifiers are:"""
                 """<table>"""
                 """<tr><td>ml</td><td>Specifies a multiline formatting."""
-                """ The first line of the variable contents is prefixed with the string"""
-                """ occuring before the variable on the same line of the template."""
-                """ All other lines are prefixed by the same amount of whitespace"""
-                """ as the line containing the variable."""
+                """ The first line of the variable contents is prefixed with"""
+                """ the string occurring before the variable on the same"""
+                """ line of the template. All other lines are prefixed by"""
+                """ the same amount of whitespace as the line containing"""
+                """ the variable."""
                 """</td></tr>"""
                 """<tr><td>rl</td><td>Specifies a repeated line formatting."""
-                """ Each line of the variable contents is prefixed with the string"""
-                """ occuring before the variable on the same line of the template."""
+                """ Each line of the variable contents is prefixed with the"""
+                """ string occuring before the variable on the same line of"""
+                """ the template."""
                 """</td></tr>"""
                 """</table></p>"""
-                """<p>The following predefined variables may be used in a template:"""
+                """<p>The following predefined variables may be used in a"""
+                """ template:"""
                 """<table>"""
                 """<tr><td>date</td>"""
                 """<td>today's date in ISO format (YYYY-MM-DD)</td></tr>"""
@@ -146,6 +147,8 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
                 """<td>the current year</td></tr>"""
                 """<tr><td>project_name</td>"""
                 """<td>the name of the project (if any)</td></tr>"""
+                """<tr><td>project_path</td>"""
+                """<td>the path of the project (if any)</td></tr>"""
                 """<tr><td>path_name</td>"""
                 """<td>full path of the current file</td></tr>"""
                 """<tr><td>dir_name</td>"""
@@ -153,18 +156,35 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
                 """<tr><td>file_name</td>"""
                 """<td>the current file name (without directory)</td></tr>"""
                 """<tr><td>base_name</td>"""
-                """<td>like <i>file_name</i>, but without extension</td></tr>"""
+                """<td>like <i>file_name</i>, but without extension"""
+                """</td></tr>"""
                 """<tr><td>ext</td>"""
                 """<td>the extension of the current file</td></tr>"""
+                """<tr><td>cur_select</td>"""
+                """<td>the currently selected text</td></tr>"""
+                """<tr><td>insertion</td>"""
+                """<td>Sets insertion point for cursor after template is"""
+                """ inserted.</td>"""
+                """</tr>"""
+                """<tr><td>select_start</td>"""
+                """<td>Sets span of selected text in template after template"""
+                """ is inserted (used together with 'select_end').</td></tr>"""
+                """<tr><td>select_end</td>"""
+                """<td>Sets span of selected text in template after template"""
+                """ is inserted (used together with 'select_start')."""
+                """</td></tr>"""
+                """<tr><td>clipboard</td>"""
+                """<td>the text of the clipboard</td></tr>"""
                 """</table></p>"""
-                """<p>If you want to change the default delimiter to anything"""
-                """ different, please use the configuration dialog to do so.</p>"""))
+                """<p>If you want to change the default delimiter to"""
+                """ anything different, please use the configuration"""
+                """ dialog to do so.</p>"""))
         
     def setSelectedGroup(self, name):
         """
         Public method to select a group.
         
-        @param name name of the group to be selected (string or QString)
+        @param name name of the group to be selected (string)
         """
         index = self.groupCombo.findText(name)
         self.groupCombo.setCurrentIndex(index)
@@ -173,17 +193,17 @@ class TemplatePropertiesDialog(QDialog, Ui_TemplatePropertiesDialog):
         """
         Public method to get the data entered into the dialog.
         
-        @return a tuple of two strings (name, language), if the dialog is in group mode,
-            and a tuple of four strings (name, description,group name, template) 
-            otherwise.
+        @return a tuple of two strings (name, language), if the dialog is in
+            group mode, and a tuple of four strings (name, description, group
+            name, template) otherwise.
         """
         if self.groupMode:
-            return (unicode(self.nameEdit.text()),
+            return (self.nameEdit.text(),
                     self.languages[self.groupCombo.currentIndex()][0]
-                   )
+                    )
         else:
-            return (unicode(self.nameEdit.text()),
-                    unicode(self.descriptionEdit.text()), 
-                    unicode(self.groupCombo.currentText()),
-                    unicode(self.templateEdit.toPlainText())
-                   )
+            return (self.nameEdit.text(),
+                    self.descriptionEdit.text(),
+                    self.groupCombo.currentText(),
+                    self.templateEdit.toPlainText()
+                    )
