@@ -9,21 +9,21 @@ Module implementing a dialog for entering a single template variable.
 
 from PyQt4.QtGui import QDialog
 
-from Ui_TemplateSingleVariableDialog import Ui_TemplateSingleVariableDialog
+from .Ui_TemplateSingleVariableDialog import Ui_TemplateSingleVariableDialog
 
 
 class TemplateSingleVariableDialog(QDialog, Ui_TemplateSingleVariableDialog):
     """
     Class implementing a dialog for entering a single template variable.
     """
-    def __init__(self, variable, parent = None):
+    def __init__(self, variable, parent=None):
         """
         Constructor
         
         @param variable template variable name (string)
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.variableLabel.setText(variable)
@@ -34,4 +34,4 @@ class TemplateSingleVariableDialog(QDialog, Ui_TemplateSingleVariableDialog):
         
         @return value for the template variable (string)
         """
-        return unicode(self.variableEdit.toPlainText())
+        return self.variableEdit.toPlainText()
