@@ -5,7 +5,7 @@
 
     Basic style object.
 
-    :copyright: Copyright 2006-2012 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2013 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -26,7 +26,7 @@ class StyleMeta(type):
                 if len(col) == 6:
                     return col
                 elif len(col) == 3:
-                    return col[0]+'0'+col[1]+'0'+col[2]+'0'
+                    return col[0]*2 + col[1]*2 + col[2]*2
             elif text == '':
                 return ''
             assert False, "wrong color format %r" % text
@@ -104,10 +104,7 @@ class StyleMeta(type):
         return len(cls._styles)
 
 
-class Style(object):
-    __metaclass__ = StyleMeta
-
-    #: overall background color (``None`` means transparent)
+class Style(object, metaclass=StyleMeta):
     background_color = '#ffffff'
 
     #: highlight background color
