@@ -7,45 +7,51 @@
 Module implementing the TR Previewer main window.
 """
 
-import sys
+import os
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, QTimer, QFileInfo, pyqtSignal, QEvent, QSize, \
+    QTranslator, QObject, Qt
+from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
+    QKeySequence, QWhatsThis, QMdiArea, qApp, QApplication, QComboBox, \
+    QVBoxLayout, QAction, QLabel
 from PyQt4 import uic
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
-import KdeQt
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
-from TRSingleApplication import TRSingleApplicationServer
-
-import Preferences
 import UI.PixmapCache
 import UI.Config
 
+import Preferences
+
 
 noTranslationName = QApplication.translate("TRPreviewer", "<No translation>")
 
-class TRPreviewer(KQMainWindow):
+
+class TRPreviewer(E5MainWindow):
     """
     Class implementing the UI Previewer main window.
     """
-    def __init__(self, filenames = [], parent = None, name = None):
+    def __init__(self, filenames=[], parent=None, name=None):
         """
         Constructor
         
         @param filenames filenames of form and/or translation files to load
         @param parent parent widget of this window (QWidget)
-        @param name name of this window (string or QString)
+        @param name name of this window (string)
         """
         self.mainWidget = None
         self.currentFile = QDir.currentPath()
         
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
         if not name:
             self.setObjectName("TRPreviewer")
         else:
             self.setObjectName(name)
+        
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
         self.resize(QSize(800, 600).expandedTo(self.minimumSizeHint()))
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.statusBar()
@@ -57,16 +63,17 @@ class TRPreviewer(KQMainWindow):
         self.cw.setObjectName("qt_central_widget")
         
         self.TRPreviewerLayout = QVBoxLayout(self.cw)
-        self.TRPreviewerLayout.setMargin(6)
+        self.TRPreviewerLayout.setContentsMargins(6, 6, 6, 6)
         self.TRPreviewerLayout.setSpacing(6)
         self.TRPreviewerLayout.setObjectName("TRPreviewerLayout")
 
         self.languageLayout = QHBoxLayout()
-        self.languageLayout.setMargin(0)
+        self.languageLayout.setContentsMargins(0, 0, 0, 0)
         self.languageLayout.setSpacing(6)
         self.languageLayout.setObjectName("languageLayout")
 
-        self.languageLabel = QLabel(self.trUtf8("Select language file"), self.cw)
+        self.languageLabel = QLabel(
+            self.trUtf8("Select language file"), self.cw)
         self.languageLabel.setObjectName("languageLabel")
         self.languageLayout.addWidget(self.languageLabel)
 
@@ -74,25 +81,27 @@ class TRPreviewer(KQMainWindow):
         self.languageCombo.setObjectName("languageCombo")
         self.languageCombo.setEditable(False)
         self.languageCombo.setToolTip(self.trUtf8("Select language file"))
+        self.languageCombo.setSizePolicy(
+            QSizePolicy.Expanding, QSizePolicy.Preferred)
         self.languageLayout.addWidget(self.languageCombo)
         
-        languageSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
+        languageSpacer = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         self.languageLayout.addItem(languageSpacer)
         self.TRPreviewerLayout.addLayout(self.languageLayout)
 
-        self.preview = WidgetWorkspace(self.cw)
+        self.preview = WidgetArea(self.cw)
         self.preview.setObjectName("preview")
         self.TRPreviewerLayout.addWidget(self.preview)
-        self.connect(self.preview, SIGNAL('lastWidgetClosed'), self.__updateActions)
+        self.preview.lastWidgetClosed.connect(self.__updateActions)
 
         self.setCentralWidget(self.cw)
         
-        self.connect(self.languageCombo,SIGNAL("activated(const QString&)"),
-                     self.setTranslation)
+        self.languageCombo.activated[str].connect(self.setTranslation)
         
         self.translations = TranslationsDict(self.languageCombo, self)
-        self.connect(self.translations, SIGNAL('translationChanged'),
-                     self.preview, SIGNAL('rebuildWidgets'))
+        self.translations.translationChanged.connect(
+            self.preview.rebuildWidgets)
         
         self.__initActions()
         self.__initMenus()
@@ -101,9 +110,10 @@ class TRPreviewer(KQMainWindow):
         self.__updateActions()
         
         # fire up the single application server
+        from .TRSingleApplication import TRSingleApplicationServer
         self.SAServer = TRSingleApplicationServer(self)
-        self.connect(self.SAServer, SIGNAL('loadForm'), self.preview.loadWidget)
-        self.connect(self.SAServer, SIGNAL('loadTranslation'), self.translations.add)
+        self.SAServer.loadForm.connect(self.preview.loadWidget)
+        self.SAServer.loadTranslation.connect(self.translations.add)
         
         # defere loading of a UI file until we are shown
         self.filesToLoad = filenames[:]
@@ -116,15 +126,15 @@ class TRPreviewer(KQMainWindow):
         the main window has been shown. This way, previewing a dialog
         doesn't interfere with showing the main window.
         """
-        QMainWindow.show(self)
+        super().show()
         if self.filesToLoad:
             filenames, self.filesToLoad = (self.filesToLoad[:], [])
             first = True
             for fn in filenames:
                 fi = QFileInfo(fn)
-                if fi.suffix().toLower().compare('ui') == 0:
+                if fi.suffix().lower() == 'ui':
                     self.preview.loadWidget(fn)
-                elif fi.suffix().toLower().compare('qm') == 0:
+                elif fi.suffix().lower() == 'qm':
                     self.translations.add(fn, first)
                     first = False
             
@@ -145,109 +155,119 @@ class TRPreviewer(KQMainWindow):
         """
         Private method to define the user interface actions.
         """
-        self.openUIAct = QAction(UI.PixmapCache.getIcon("openUI.png"), 
-                        self.trUtf8('&Open UI Files...'), self)
+        self.openUIAct = QAction(
+            UI.PixmapCache.getIcon("openUI.png"),
+            self.trUtf8('&Open UI Files...'), self)
         self.openUIAct.setStatusTip(self.trUtf8('Open UI files for display'))
         self.openUIAct.setWhatsThis(self.trUtf8(
-                """<b>Open UI Files</b>"""
-                """<p>This opens some UI files for display.</p>"""
+            """<b>Open UI Files</b>"""
+            """<p>This opens some UI files for display.</p>"""
         ))
-        self.connect(self.openUIAct, SIGNAL('triggered()'), self.__openWidget)
+        self.openUIAct.triggered[()].connect(self.__openWidget)
         
-        self.openQMAct = QAction(UI.PixmapCache.getIcon("openQM.png"), 
-                        self.trUtf8('Open &Translation Files...'), self)
-        self.openQMAct.setStatusTip(self.trUtf8('Open Translation files for display'))
+        self.openQMAct = QAction(
+            UI.PixmapCache.getIcon("openQM.png"),
+            self.trUtf8('Open &Translation Files...'), self)
+        self.openQMAct.setStatusTip(self.trUtf8(
+            'Open Translation files for display'))
         self.openQMAct.setWhatsThis(self.trUtf8(
-                """<b>Open Translation Files</b>"""
-                """<p>This opens some translation files for display.</p>"""
+            """<b>Open Translation Files</b>"""
+            """<p>This opens some translation files for display.</p>"""
         ))
-        self.connect(self.openQMAct, SIGNAL('triggered()'), self.__openTranslation)
+        self.openQMAct.triggered[()].connect(self.__openTranslation)
         
-        self.reloadAct = QAction(UI.PixmapCache.getIcon("reload.png"), 
-                        self.trUtf8('&Reload Translations'), self)
-        self.reloadAct.setStatusTip(self.trUtf8('Reload the loaded translations'))
+        self.reloadAct = QAction(
+            UI.PixmapCache.getIcon("reload.png"),
+            self.trUtf8('&Reload Translations'), self)
+        self.reloadAct.setStatusTip(self.trUtf8(
+            'Reload the loaded translations'))
         self.reloadAct.setWhatsThis(self.trUtf8(
-                """<b>Reload Translations</b>"""
-                """<p>This reloads the translations for the loaded languages.</p>"""
+            """<b>Reload Translations</b>"""
+            """<p>This reloads the translations for the loaded"""
+            """ languages.</p>"""
         ))
-        self.connect(self.reloadAct, SIGNAL('triggered()'), self.translations.reload)
+        self.reloadAct.triggered[()].connect(self.translations.reload)
         
-        self.exitAct = QAction(UI.PixmapCache.getIcon("exit.png"), 
-                        self.trUtf8('&Quit'), self)
-        self.exitAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+Q","File|Quit")))
+        self.exitAct = QAction(
+            UI.PixmapCache.getIcon("exit.png"), self.trUtf8('&Quit'), self)
+        self.exitAct.setShortcut(QKeySequence(
+            self.trUtf8("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.trUtf8('Quit the application'))
         self.exitAct.setWhatsThis(self.trUtf8(
-                """<b>Quit</b>"""
-                """<p>Quit the application.</p>"""
+            """<b>Quit</b>"""
+            """<p>Quit the application.</p>"""
         ))
-        self.connect(self.exitAct, SIGNAL('triggered()'), 
-                     qApp, SLOT('closeAllWindows()'))
+        self.exitAct.triggered[()].connect(qApp.closeAllWindows)
         
-        self.whatsThisAct = QAction(UI.PixmapCache.getIcon("whatsThis.png"),
-                                self.trUtf8('&What\'s This?'), self)
+        self.whatsThisAct = QAction(
+            UI.PixmapCache.getIcon("whatsThis.png"),
+            self.trUtf8('&What\'s This?'), self)
         self.whatsThisAct.setShortcut(QKeySequence(self.trUtf8("Shift+F1")))
         self.whatsThisAct.setStatusTip(self.trUtf8('Context sensitive help'))
         self.whatsThisAct.setWhatsThis(self.trUtf8(
-                """<b>Display context sensitive help</b>"""
-                """<p>In What's This? mode, the mouse cursor shows an arrow with a"""
-                """ question mark, and you can click on the interface elements to get"""
-                """ a short description of what they do and how to use them. In"""
-                """ dialogs, this feature can be accessed using the context help"""
-                """ button in the titlebar.</p>"""
+            """<b>Display context sensitive help</b>"""
+            """<p>In What's This? mode, the mouse cursor shows an arrow"""
+            """ with a question mark, and you can click on the interface"""
+            """ elements to get a short description of what they do and"""
+            """ how to use them. In dialogs, this feature can be accessed"""
+            """ using the context help button in the titlebar.</p>"""
         ))
-        self.connect(self.whatsThisAct,SIGNAL('triggered()'),self.__whatsThis)
+        self.whatsThisAct.triggered[()].connect(self.__whatsThis)
 
         self.aboutAct = QAction(self.trUtf8('&About'), self)
-        self.aboutAct.setStatusTip(self.trUtf8('Display information about this software'))
+        self.aboutAct.setStatusTip(self.trUtf8(
+            'Display information about this software'))
         self.aboutAct.setWhatsThis(self.trUtf8(
-                """<b>About</b>"""
-                """<p>Display some information about this software.</p>"""
+            """<b>About</b>"""
+            """<p>Display some information about this software.</p>"""
         ))
-        self.connect(self.aboutAct,SIGNAL('triggered()'),self.__about)
+        self.aboutAct.triggered[()].connect(self.__about)
         
         self.aboutQtAct = QAction(self.trUtf8('About &Qt'), self)
-        self.aboutQtAct.setStatusTip(\
+        self.aboutQtAct.setStatusTip(
             self.trUtf8('Display information about the Qt toolkit'))
         self.aboutQtAct.setWhatsThis(self.trUtf8(
-                """<b>About Qt</b>"""
-                """<p>Display some information about the Qt toolkit.</p>"""
+            """<b>About Qt</b>"""
+            """<p>Display some information about the Qt toolkit.</p>"""
         ))
-        self.connect(self.aboutQtAct,SIGNAL('triggered()'),self.__aboutQt)
+        self.aboutQtAct.triggered[()].connect(self.__aboutQt)
         
         self.tileAct = QAction(self.trUtf8('&Tile'), self)
         self.tileAct.setStatusTip(self.trUtf8('Tile the windows'))
         self.tileAct.setWhatsThis(self.trUtf8(
-                """<b>Tile the windows</b>"""
-                """<p>Rearrange and resize the windows so that they are tiled.</p>"""
+            """<b>Tile the windows</b>"""
+            """<p>Rearrange and resize the windows so that they are"""
+            """ tiled.</p>"""
         ))
-        self.connect(self.tileAct, SIGNAL('triggered()'),self.preview.tile)
+        self.tileAct.triggered[()].connect(self.preview.tileSubWindows)
         
         self.cascadeAct = QAction(self.trUtf8('&Cascade'), self)
         self.cascadeAct.setStatusTip(self.trUtf8('Cascade the windows'))
         self.cascadeAct.setWhatsThis(self.trUtf8(
-                """<b>Cascade the windows</b>"""
-                """<p>Rearrange and resize the windows so that they are cascaded.</p>"""
+            """<b>Cascade the windows</b>"""
+            """<p>Rearrange and resize the windows so that they are"""
+            """ cascaded.</p>"""
         ))
-        self.connect(self.cascadeAct, SIGNAL('triggered()'),self.preview.cascade)
+        self.cascadeAct.triggered[()].connect(self.preview.cascadeSubWindows)
         
-        self.closeAct = QAction(UI.PixmapCache.getIcon("close.png"),
-                            self.trUtf8('&Close'), self)
-        self.closeAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+W","File|Close")))
+        self.closeAct = QAction(
+            UI.PixmapCache.getIcon("close.png"), self.trUtf8('&Close'), self)
+        self.closeAct.setShortcut(QKeySequence(self.trUtf8(
+            "Ctrl+W", "File|Close")))
         self.closeAct.setStatusTip(self.trUtf8('Close the current window'))
         self.closeAct.setWhatsThis(self.trUtf8(
-                """<b>Close Window</b>"""
-                """<p>Close the current window.</p>"""
+            """<b>Close Window</b>"""
+            """<p>Close the current window.</p>"""
         ))
-        self.connect(self.closeAct, SIGNAL('triggered()'),self.preview.closeWidget)
+        self.closeAct.triggered[()].connect(self.preview.closeWidget)
         
         self.closeAllAct = QAction(self.trUtf8('Clos&e All'), self)
         self.closeAllAct.setStatusTip(self.trUtf8('Close all windows'))
         self.closeAllAct.setWhatsThis(self.trUtf8(
-                """<b>Close All Windows</b>"""
-                """<p>Close all windows.</p>"""
+            """<b>Close All Windows</b>"""
+            """<p>Close all windows.</p>"""
         ))
-        self.connect(self.closeAllAct, SIGNAL('triggered()'),
-                     self.preview.closeAllWidgets)
+        self.closeAllAct.triggered[()].connect(self.preview.closeAllWidgets)
 
     def __initMenus(self):
         """
@@ -268,9 +288,8 @@ class TRPreviewer(KQMainWindow):
         
         self.windowMenu = mb.addMenu(self.trUtf8('&Window'))
         self.windowMenu.setTearOffEnabled(True)
-        self.connect(self.windowMenu, SIGNAL('aboutToShow()'), self.__showWindowMenu)
-        self.connect(self.windowMenu, SIGNAL('triggered(QAction *)'),
-                     self.preview.toggleSelectedWidget)
+        self.windowMenu.aboutToShow.connect(self.__showWindowMenu)
+        self.windowMenu.triggered.connect(self.preview.toggleSelectedWidget)
         
         mb.addSeparator()
         
@@ -329,26 +348,31 @@ class TRPreviewer(KQMainWindow):
         """
         Private slot to show the about information.
         """
-        KQMessageBox.about(self, self.trUtf8("TR Previewer"), self.trUtf8(
-            """<h3> About TR Previewer </h3>"""
-            """<p>The TR Previewer loads and displays Qt User-Interface files"""
-            """ and translation files and shows dialogs for a selected language.</p>"""
-        ))
+        E5MessageBox.about(
+            self,
+            self.trUtf8("TR Previewer"),
+            self.trUtf8(
+                """<h3> About TR Previewer </h3>"""
+                """<p>The TR Previewer loads and displays Qt User-Interface"""
+                """ files and translation files and shows dialogs for a"""
+                """ selected language.</p>"""
+            )
+        )
     
     def __aboutQt(self):
         """
         Private slot to show info about Qt.
         """
-        QMessageBox.aboutQt(self, self.trUtf8("TR Previewer"))
+        E5MessageBox.aboutQt(self, self.trUtf8("TR Previewer"))
     
     def __openWidget(self):
         """
         Private slot to handle the Open Dialog action.
         """
-        fileNameList = KQFileDialog.getOpenFileNames(\
+        fileNameList = E5FileDialog.getOpenFileNames(
             None,
             self.trUtf8("Select UI files"),
-            QString(),
+            "",
             self.trUtf8("Qt User-Interface Files (*.ui)"))
         
         for fileName in fileNameList:
@@ -360,10 +384,10 @@ class TRPreviewer(KQMainWindow):
         """
         Private slot to handle the Open Translation action.
         """
-        fileNameList = KQFileDialog.getOpenFileNames(\
+        fileNameList = E5FileDialog.getOpenFileNames(
             None,
             self.trUtf8("Select translation files"),
-            QString(),
+            "",
             self.trUtf8("Qt Translation Files (*.qm)"))
         
         first = True
@@ -377,7 +401,7 @@ class TRPreviewer(KQMainWindow):
         """
         Public slot to activate a translation.
         
-        @param name name (language) of the translation (string or QString)
+        @param name name (language) of the translation (string)
         """
         self.translations.set(name)
     
@@ -398,9 +422,10 @@ class TRPreviewer(KQMainWindow):
         """
         self.translations.reload()
 
+
 class Translation(object):
     """
-    Class to store the properties of a translation
+    Class to store the properties of a translation.
     """
     def __init__(self):
         """
@@ -410,12 +435,15 @@ class Translation(object):
         self.name = None
         self.translator = None
 
+
 class TranslationsDict(QObject):
     """
     Class to store all loaded translations.
     
     @signal translationChanged() emit after a translator was set
     """
+    translationChanged = pyqtSignal()
+    
     def __init__(self, selector, parent):
         """
         Constructor
@@ -424,34 +452,35 @@ class TranslationsDict(QObject):
             available languages (QComboBox)
         @param parent parent widget (QWidget)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         
         self.selector = selector
         self.currentTranslator = None
         self.selector.addItem(noTranslationName)
-        self.translations = [] # list of Translation objects
+        self.translations = []  # list of Translation objects
     
-    def add(self, transFileName, setTranslation = True):
+    def add(self, fileName, setTranslation=True):
         """
         Public method to add a translation to the list.
         
         If the translation file (*.qm) has not been loaded yet, it will
         be loaded automatically.
         
-        @param transFileName name of the translation file to be added (string or QString)
-        @param setTranslation flag indicating, if this should be set as the active
-            translation (boolean)
+        @param fileName name of the translation file to be added (string)
+        @param setTranslation flag indicating, if this should be set as
+            the active translation (boolean)
         """
-        fileName = QString(transFileName)
         if not self.__haveFileName(fileName):
             ntr = Translation()
             ntr.fileName = fileName
             ntr.name = self.__uniqueName(fileName)
-            if ntr.name.isNull():
-                KQMessageBox.warning(None,
+            if ntr.name is None:
+                E5MessageBox.warning(
+                    self.parent(),
                     self.trUtf8("Set Translator"),
-                    self.trUtf8("""<p>The translation filename <b>%1</b>"""
-                        """ is invalid.</p>""").arg(fileName))
+                    self.trUtf8(
+                        """<p>The translation filename <b>{0}</b>"""
+                        """ is invalid.</p>""").format(fileName))
                 return
             
             ntr.translator = self.loadTransFile(fileName)
@@ -469,18 +498,19 @@ class TranslationsDict(QObject):
         """
         Public slot to set a translator by name.
         
-        @param name name (language) of the translator to set (string or QString)
+        @param name name (language) of the translator to set (string)
         """
-        name = QString(name)
         nTranslator = None
         
-        if name.compare(noTranslationName) != 0:
+        if name != noTranslationName:
             trans = self.__findName(name)
             if trans is None:
-                KQMessageBox.warning(None,
+                E5MessageBox.warning(
+                    self.parent(),
                     self.trUtf8("Set Translator"),
-                    self.trUtf8("""<p>The translator <b>%1</b> is not known.</p>""")\
-                        .arg(name))
+                    self.trUtf8(
+                        """<p>The translator <b>{0}</b> is not known.</p>""")
+                    .format(name))
                 return
                 
             nTranslator = trans.translator
@@ -498,7 +528,7 @@ class TranslationsDict(QObject):
         self.selector.setCurrentIndex(self.selector.findText(name))
         self.selector.blockSignals(False)
         
-        self.emit(SIGNAL('translationChanged'))
+        self.translationChanged.emit()
     
     def reload(self):
         """
@@ -509,7 +539,7 @@ class TranslationsDict(QObject):
             QApplication.removeTranslator(self.currentTranslator)
             self.currentTranslator = None
         
-        fileNames = QStringList()
+        fileNames = []
         for trans in self.translations:
             trans.translator = None
             fileNames.append(trans.fileName)
@@ -530,11 +560,11 @@ class TranslationsDict(QObject):
         """
         Private method to find a translation by file name.
         
-        @param transFileName file name of the translation file (string or QString)
+        @param transFileName file name of the translation file (string)
         @return reference to a translation object or None
         """
         for trans in self.translations:
-            if trans.fileName.compare(transFileName) == 0:
+            if trans.fileName == transFileName:
                 return trans
         return None
     
@@ -542,11 +572,11 @@ class TranslationsDict(QObject):
         """
         Private method to find a translation by name.
         
-        @param name name (language) of the translation (string or QString)
+        @param name name (language) of the translation (string)
         @return reference to a translation object or None
         """
         for trans in self.translations:
-            if trans.name.compare(name) == 0:
+            if trans.name == name:
                 return trans
         return None
     
@@ -554,7 +584,7 @@ class TranslationsDict(QObject):
         """
         Private method to check for the presence of a translation.
         
-        @param transFileName file name of the translation file (string or QString)
+        @param transFileName file name of the translation file (string)
         @return flag indicating the presence of the translation (boolean)
         """
         return self.__findFileName(transFileName) is not None
@@ -563,7 +593,7 @@ class TranslationsDict(QObject):
         """
         Private method to check for the presence of a named translation.
         
-        @param name name (language) of the translation (string or QString)
+        @param name name (language) of the translation (string)
         @return flag indicating the presence of the translation (boolean)
         """
         return self.__findName(name) is not None
@@ -572,36 +602,36 @@ class TranslationsDict(QObject):
         """
         Private method to generate a unique name.
         
-        @param transFileName file name of the translation file (string or QString)
-        @return unique name (QString)
+        @param transFileName file name of the translation file (string)
+        @return unique name (string or None)
         """
-        name = _filename(transFileName)
-        if name.isNull():
-            return QString()
+        name = os.path.basename(transFileName)
+        if not name:
+            return None
         
-        uname = QString(name)
+        uname = name
         cnt = 1
         while self.__haveName(uname):
             cnt += 1
-            uname = QString("%1 <%2>").arg(name).arg(cnt)
+            uname = "{0} <{1}>".format(name, cnt)
         
         return uname
     
     def __del(self, name):
         """
-        Private method to delete a translator from the list of available translators.
+        Private method to delete a translator from the list of available
+        translators.
         
-        @param name name of the translator to delete (string or QString)
+        @param name name of the translator to delete (string)
         """
-        name = QString(name)
-        if name.compare(noTranslationName) == 0:
+        if name == noTranslationName:
             return
         
         trans = self.__findName(name)
         if trans is None:
             return
         
-        if self.selector().currentText().compare(name) == 0:
+        if self.selector().currentText() == name:
             self.set(noTranslationName)
         
         self.translations.remove(trans)
@@ -611,17 +641,18 @@ class TranslationsDict(QObject):
         """
         Public slot to load a translation file.
         
-        @param transFileName file name of the translation file (string or QString)
+        @param transFileName file name of the translation file (string)
         @return reference to the new translator object (QTranslator)
         """
         tr = QTranslator()
         if tr.load(transFileName):
             return tr
         
-        KQMessageBox.warning(None,
+        E5MessageBox.warning(
+            self.parent(),
             self.trUtf8("Load Translator"),
-            self.trUtf8("""<p>The translation file <b>%1</b> could not be loaded.</p>""")\
-                .arg(transFileName))
+            self.trUtf8("""<p>The translation file <b>{0}</b> could"""
+                        """ not be loaded.</p>""").format(transFileName))
         return None
 
     def hasTranslations(self):
@@ -632,19 +663,20 @@ class TranslationsDict(QObject):
         """
         return len(self.translations) > 0
 
+
 class WidgetView(QWidget):
     """
     Class to show a dynamically loaded widget (or dialog).
     """
-    def __init__(self, uiFileName, parent = None, name = None):
+    def __init__(self, uiFileName, parent=None, name=None):
         """
         Constructor
         
-        @param uiFileName name of the UI file to load (string or QString)
+        @param uiFileName name of the UI file to load (string)
         @param parent parent widget (QWidget)
         @param name name of this widget (string)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
             self.setWindowTitle(name)
@@ -656,7 +688,7 @@ class WidgetView(QWidget):
         self.__valid = False
         self.__timer = QTimer(self)
         self.__timer.setSingleShot(True)
-        self.connect(self.__timer, SIGNAL('timeout()'), self.buildWidget)
+        self.__timer.timeout.connect(self.buildWidget)
     
     def isValid(self):
         """
@@ -670,9 +702,9 @@ class WidgetView(QWidget):
         """
         Public method to retrieve the name of the UI file.
         
-        @return filename of the loaded UI file (QString)
+        @return filename of the loaded UI file (string)
         """
-        return QString(self.__uiFileName)
+        return self.__uiFileName
     
     def buildWidget(self):
         """
@@ -690,10 +722,12 @@ class WidgetView(QWidget):
             pass
         
         if not self.__widget:
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                self,
                 self.trUtf8("Load UI File"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be loaded.</p>""")\
-                    .arg(self.__uiFileName))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be loaded.</p>""")
+                .format(self.__uiFileName))
             self.__valid = False
             return
         
@@ -711,21 +745,26 @@ class WidgetView(QWidget):
         """
         self.__timer.start(0)
 
-class WidgetWorkspace(QWorkspace):
+
+class WidgetArea(QMdiArea):
     """
-    Specialized workspace to show the loaded widgets.
+    Specialized MDI area to show the loaded widgets.
     
     @signal lastWidgetClosed() emitted after last widget was closed
     """
-    def __init__(self, parent = None):
+    lastWidgetClosed = pyqtSignal()
+    rebuildWidgets = pyqtSignal()
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QWorkspace.__init__(self, parent)
+        super().__init__(parent)
         
-        self.setScrollBarsEnabled(True)
+        self.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
+        self.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
         
         self.widgets = []
     
@@ -733,24 +772,26 @@ class WidgetWorkspace(QWorkspace):
         """
         Public slot to load a UI file.
         
-        @param uiFileName name of the UI file to load (string or QString)
+        @param uiFileName name of the UI file to load (string)
         """
         wview = self.__findWidget(uiFileName)
         if wview is None:
-            name = _filename(uiFileName)
-            if name.isEmpty():
-                KQMessageBox.warning(None,
+            name = os.path.basename(uiFileName)
+            if not name:
+                E5MessageBox.warning(
+                    self,
                     self.trUtf8("Load UI File"),
-                    self.trUtf8("""<p>The file <b>%1</b> could not be loaded.</p>""")\
-                        .arg(uiFileName))
+                    self.trUtf8(
+                        """<p>The file <b>{0}</b> could not be loaded.</p>""")
+                    .format(uiFileName))
                 return
             
-            uname = QString(name)
+            uname = name
             cnt = 1
             while self.findChild(WidgetView, uname) is not None:
                 cnt += 1
-                uname = QString("%1 <%2>").arg(name).arg(cnt)
-            name = QString(uname)
+                uname = "{0} <{1}>".format(name, cnt)
+            name = uname
             
             wview = WidgetView(uiFileName, self, name)
             wview.buildWidget()
@@ -758,43 +799,37 @@ class WidgetWorkspace(QWorkspace):
                 del wview
                 return
             
-            self.connect(self, SIGNAL("rebuildWidgets"), wview.buildWidget)
-            wview.installEventFilter(self)
+            self.rebuildWidgets.connect(wview.buildWidget)  # __IGNORE_WARNING__
+            wview.installEventFilter(self)  # __IGNORE_WARNING__
             
-            self.addWindow(wview)
-            self.widgets.append(wview)
+            win = self.addSubWindow(wview)  # __IGNORE_WARNING__
+            self.widgets.append(win)
         
-        wview.showNormal()
+        wview.showNormal()  # __IGNORE_WARNING__
     
     def eventFilter(self, obj, ev):
         """
         Protected method called to filter an event.
         
-        @param object object, that generated the event (QObject)
-        @param event the event, that was generated by object (QEvent)
+        @param obj object, that generated the event (QObject)
+        @param ev the event, that was generated by object (QEvent)
         @return flag indicating if event was filtered out
         """
-        if not isinstance(obj, QWidget):
-            return False
-        
-        if not obj in self.widgets:
-            return False
-            
-        if ev.type() == QEvent.Close:
+        if obj in self.widgets and ev.type() == QEvent.Close:
             try:
                 self.widgets.remove(obj)
                 if len(self.widgets) == 0:
-                    self.emit(SIGNAL('lastWidgetClosed'))
+                    self.lastWidgetClosed.emit()
             except ValueError:
                 pass
         
-        return False
+        return QMdiArea.eventFilter(self, obj, ev)
     
     def __findWidget(self, uiFileName):
         """
         Private method to find a specific widget view.
         
-        @param uiFileName filename of the loaded UI file (string or QString)
+        @param uiFileName filename of the loaded UI file (string)
         @return reference to the widget (WidgetView) or None
         """
         wviewList = self.findChildren(WidgetView)
@@ -802,7 +837,7 @@ class WidgetWorkspace(QWorkspace):
             return None
         
         for wview in wviewList:
-            if wview.uiFileName().compare(uiFileName) == 0:
+            if wview.uiFileName() == uiFileName:
                 return wview
         
         return None
@@ -811,7 +846,7 @@ class WidgetWorkspace(QWorkspace):
         """
         Public slot to close the active window.
         """
-        aw = self.activeWindow()
+        aw = self.activeSubWindow()
         if aw is not None:
             aw.close()
     
@@ -831,7 +866,7 @@ class WidgetWorkspace(QWorkspace):
         idx = 0
         for wid in self.widgets:
             act = windowMenu.addAction(wid.windowTitle())
-            act.setData(QVariant(idx))
+            act.setData(idx)
             act.setCheckable(True)
             act.setChecked(not wid.isHidden())
             idx = idx + 1
@@ -842,8 +877,8 @@ class WidgetWorkspace(QWorkspace):
         
         @param act reference to the action that triggered (QAction)
         """
-        idx, ok = act.data().toInt()
-        if ok:
+        idx = act.data()
+        if idx is not None:
             self.__toggleWidget(self.widgets[idx])
     
     def __toggleWidget(self, w):
@@ -864,19 +899,3 @@ class WidgetWorkspace(QWorkspace):
         @return flag signaling if any widget was loaded (boolean)
         """
         return len(self.widgets) > 0
-
-def _filename(path):
-    """
-    Protected module function to chop off the path.
-    
-    @param path path to extract the filename from (string or QString)
-    @return extracted filename (QString)
-    """
-    path = QString(path)
-    idx = path.lastIndexOf("/")
-    if idx == -1:
-        idx = path.lastIndexOf(QDir.separator())
-    if idx == -1:
-        return path
-    else:
-        return path.mid(idx + 1)
