@@ -9,28 +9,33 @@ Module implementing the single application server and client.
 
 import os
 
-from PyQt4.QtCore import SIGNAL
+from PyQt4.QtCore import pyqtSignal
 
-from Utilities.SingleApplication import SingleApplicationClient, SingleApplicationServer
+from Toolbox.SingleApplication import SingleApplicationClient, \
+    SingleApplicationServer
 
 ###########################################################################
 # define some module global stuff
 ###########################################################################
 
-SAFile = "eric4_trpreviewer.lck"
+SAFile = "eric5_trpreviewer"
 
 # define the protocol tokens
-SALoadForm =        '>LoadForm<'
+SALoadForm = '>LoadForm<'
 SALoadTranslation = '>LoadTranslation<'
 
+
 class TRSingleApplicationServer(SingleApplicationServer):
     """
-    Class implementing the single application server embedded within the 
+    Class implementing the single application server embedded within the
     Translations Previewer.
     
-    @signal loadForm(fname) emitted to load a form file
-    @signal loadTranslation(fname, first) emitted to load a translation file
+    @signal loadForm(str) emitted to load a form file
+    @signal loadTranslation(str, bool) emitted to load a translation file
     """
+    loadForm = pyqtSignal(str)
+    loadTranslation = pyqtSignal(str, bool)
+    
     def __init__(self, parent):
         """
         Constructor
@@ -63,22 +68,25 @@ class TRSingleApplicationServer(SingleApplicationServer):
         @param fnames filenames of the forms to be loaded (list of strings)
         """
         for fname in fnames:
-            self.emit(SIGNAL('loadForm'), fname)
+            self.loadForm.emit(fname)
         
     def __saLoadTranslation(self, fnames):
         """
         Private method used to handle the "Load Translation" command.
         
-        @param fnames filenames of the translations to be loaded (list of strings)
+        @param fnames filenames of the translations to be loaded
+            (list of strings)
         """
         first = True
         for fname in fnames:
-            self.emit(SIGNAL('loadTranslation'), fname, first)
+            self.loadTranslation.emit(fname, first)
             first = False
 
+
 class TRSingleApplicationClient(SingleApplicationClient):
     """
-    Class implementing the single application client of the Translations Previewer.
+    Class implementing the single application client of the Translations
+    Previewer.
     """
     def __init__(self):
         """
@@ -108,9 +116,9 @@ class TRSingleApplicationClient(SingleApplicationClient):
             elif ext == '.qm':
                 qmFiles.append(arg)
         
-        cmd = "%s%s\n" % (SALoadForm, unicode(uiFiles))
+        cmd = "{0}{1}\n".format(SALoadForm, str(uiFiles))
         self.sendCommand(cmd)
-        cmd = "%s%s\n" % (SALoadTranslation, unicode(qmFiles))
+        cmd = "{0}{1}\n".format(SALoadTranslation, str(qmFiles))
         self.sendCommand(cmd)
         
         self.disconnect()
