@@ -7,43 +7,46 @@
 Module implementing the UI Previewer main window.
 """
 
-import sys
-
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import qVersion, QDir, QFileInfo, QEvent, QSize, Qt
+from PyQt4.QtGui import QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, \
+    QCursor, QPrinter, QKeySequence, QPrintDialog, QWhatsThis, QPixmap, \
+    QImageWriter, QPainter, QDialog, QScrollArea, qApp, QApplication, \
+    QStyleFactory, QFrame, QMainWindow, QComboBox, QVBoxLayout, QAction, \
+    QLabel
 from PyQt4 import uic
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
-import KdeQt.KQPrinter
-from KdeQt.KQPrintDialog import KQPrintDialog
-import KdeQt
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
 import Preferences
 import UI.PixmapCache
 import UI.Config
 
 
-class UIPreviewer(KQMainWindow):
+class UIPreviewer(E5MainWindow):
     """
     Class implementing the UI Previewer main window.
     """
-    def __init__(self, filename = None, parent = None, name = None):
+    def __init__(self, filename=None, parent=None, name=None):
         """
         Constructor
         
         @param filename name of a UI file to load
         @param parent parent widget of this window (QWidget)
-        @param name name of this window (string or QString)
+        @param name name of this window (string)
         """
         self.mainWidget = None
         self.currentFile = QDir.currentPath()
         
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
         if not name:
             self.setObjectName("UIPreviewer")
         else:
             self.setObjectName(name)
+        
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
         self.resize(QSize(600, 480).expandedTo(self.minimumSizeHint()))
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.statusBar()
@@ -55,12 +58,12 @@ class UIPreviewer(KQMainWindow):
         self.cw.setObjectName("centralWidget")
         
         self.UIPreviewerLayout = QVBoxLayout(self.cw)
-        self.UIPreviewerLayout.setMargin(6)
+        self.UIPreviewerLayout.setContentsMargins(6, 6, 6, 6)
         self.UIPreviewerLayout.setSpacing(6)
         self.UIPreviewerLayout.setObjectName("UIPreviewerLayout")
 
         self.styleLayout = QHBoxLayout()
-        self.styleLayout.setMargin(0)
+        self.styleLayout.setContentsMargins(0, 0, 0, 0)
         self.styleLayout.setSpacing(6)
         self.styleLayout.setObjectName("styleLayout")
 
@@ -73,11 +76,13 @@ class UIPreviewer(KQMainWindow):
         self.styleCombo.setEditable(False)
         self.styleCombo.setToolTip(self.trUtf8("Select the GUI Theme"))
         self.styleLayout.addWidget(self.styleCombo)
-        self.styleCombo.addItems(QStyleFactory().keys())
-        self.styleCombo.setCurrentIndex(\
-            Preferences.Prefs.settings.value('UIPreviewer/style').toInt()[0])
+        self.styleCombo.addItems(list(QStyleFactory().keys()))
+        currentStyle = Preferences.Prefs.settings.value('UIPreviewer/style')
+        if currentStyle is not None:
+            self.styleCombo.setCurrentIndex(int(currentStyle))
         
-        styleSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
+        styleSpacer = QSpacerItem(
+            40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
         self.styleLayout.addItem(styleSpacer)
         self.UIPreviewerLayout.addLayout(self.styleLayout)
 
@@ -85,13 +90,13 @@ class UIPreviewer(KQMainWindow):
         self.previewSV.setObjectName("preview")
         self.previewSV.setFrameShape(QFrame.NoFrame)
         self.previewSV.setFrameShadow(QFrame.Plain)
-        self.previewSV.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        self.previewSV.setSizePolicy(
+            QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.UIPreviewerLayout.addWidget(self.previewSV)
 
         self.setCentralWidget(self.cw)
         
-        self.connect(self.styleCombo, SIGNAL("activated(const QString&)"),
-                     self.__guiStyleSelected)
+        self.styleCombo.activated[str].connect(self.__guiStyleSelected)
         
         self.__initActions()
         self.__initMenus()
@@ -110,7 +115,7 @@ class UIPreviewer(KQMainWindow):
         the main window has been shown. This way, previewing a dialog
         doesn't interfere with showing the main window.
         """
-        QMainWindow.show(self)
+        super().show()
         if self.fileToLoad is not None:
             fn, self.fileToLoad = (self.fileToLoad, None)
             self.__loadFile(fn)
@@ -119,99 +124,109 @@ class UIPreviewer(KQMainWindow):
         """
         Private method to define the user interface actions.
         """
-        self.openAct = QAction(UI.PixmapCache.getIcon("openUI.png"), 
-                        self.trUtf8('&Open File'), self)
-        self.openAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+O","File|Open")))
+        self.openAct = QAction(
+            UI.PixmapCache.getIcon("openUI.png"),
+            self.trUtf8('&Open File'), self)
+        self.openAct.setShortcut(
+            QKeySequence(self.trUtf8("Ctrl+O", "File|Open")))
         self.openAct.setStatusTip(self.trUtf8('Open a UI file for display'))
         self.openAct.setWhatsThis(self.trUtf8(
-                """<b>Open File</b>"""
-                """<p>This opens a new UI file for display.</p>"""
+            """<b>Open File</b>"""
+            """<p>This opens a new UI file for display.</p>"""
         ))
-        self.connect(self.openAct, SIGNAL('triggered()'), self.__openFile)
+        self.openAct.triggered[()].connect(self.__openFile)
         
-        self.printAct = QAction(UI.PixmapCache.getIcon("print.png"), 
-                        self.trUtf8('&Print'), self)
-        self.printAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+P","File|Print")))
+        self.printAct = QAction(
+            UI.PixmapCache.getIcon("print.png"),
+            self.trUtf8('&Print'), self)
+        self.printAct.setShortcut(
+            QKeySequence(self.trUtf8("Ctrl+P", "File|Print")))
         self.printAct.setStatusTip(self.trUtf8('Print a screen capture'))
         self.printAct.setWhatsThis(self.trUtf8(
-                """<b>Print</b>"""
-                """<p>Print a screen capture.</p>"""
+            """<b>Print</b>"""
+            """<p>Print a screen capture.</p>"""
         ))
-        self.connect(self.printAct, SIGNAL('triggered()'), self.__printImage)
+        self.printAct.triggered[()].connect(self.__printImage)
         
-        self.printPreviewAct = QAction(UI.PixmapCache.getIcon("printPreview.png"), 
-                        self.trUtf8('Print Preview'), self)
+        self.printPreviewAct = QAction(
+            UI.PixmapCache.getIcon("printPreview.png"),
+            self.trUtf8('Print Preview'), self)
         self.printPreviewAct.setStatusTip(self.trUtf8(
-                'Print preview a screen capture'))
+            'Print preview a screen capture'))
         self.printPreviewAct.setWhatsThis(self.trUtf8(
-                """<b>Print Preview</b>"""
-                """<p>Print preview a screen capture.</p>"""
+            """<b>Print Preview</b>"""
+            """<p>Print preview a screen capture.</p>"""
         ))
-        self.connect(self.printPreviewAct, SIGNAL('triggered()'), 
-            self.__printPreviewImage)
+        self.printPreviewAct.triggered[()].connect(self.__printPreviewImage)
         
-        self.imageAct = QAction(UI.PixmapCache.getIcon("screenCapture.png"), 
-                        self.trUtf8('&Screen Capture'), self)
-        self.imageAct.setShortcut(\
-            QKeySequence(self.trUtf8("Ctrl+S","File|Screen Capture")))
-        self.imageAct.setStatusTip(self.trUtf8('Save a screen capture to an image file'))
+        self.imageAct = QAction(
+            UI.PixmapCache.getIcon("screenCapture.png"),
+            self.trUtf8('&Screen Capture'), self)
+        self.imageAct.setShortcut(
+            QKeySequence(self.trUtf8("Ctrl+S", "File|Screen Capture")))
+        self.imageAct.setStatusTip(self.trUtf8(
+            'Save a screen capture to an image file'))
         self.imageAct.setWhatsThis(self.trUtf8(
-                """<b>Screen Capture</b>"""
-                """<p>Save a screen capture to an image file.</p>"""
+            """<b>Screen Capture</b>"""
+            """<p>Save a screen capture to an image file.</p>"""
         ))
-        self.connect(self.imageAct, SIGNAL('triggered()'), self.__saveImage)
+        self.imageAct.triggered[()].connect(self.__saveImage)
         
-        self.exitAct = QAction(UI.PixmapCache.getIcon("exit.png"), 
-                        self.trUtf8('&Quit'), self)
-        self.exitAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+Q","File|Quit")))
+        self.exitAct = QAction(
+            UI.PixmapCache.getIcon("exit.png"), self.trUtf8('&Quit'), self)
+        self.exitAct.setShortcut(
+            QKeySequence(self.trUtf8("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.trUtf8('Quit the application'))
         self.exitAct.setWhatsThis(self.trUtf8(
-                """<b>Quit</b>"""
-                """<p>Quit the application.</p>"""
+            """<b>Quit</b>"""
+            """<p>Quit the application.</p>"""
         ))
-        self.connect(self.exitAct, SIGNAL('triggered()'), 
-                     qApp, SLOT('closeAllWindows()'))
+        self.exitAct.triggered[()].connect(qApp.closeAllWindows)
         
-        self.copyAct = QAction(UI.PixmapCache.getIcon("editCopy.png"),
-                            self.trUtf8('&Copy'), self)
-        self.copyAct.setShortcut(QKeySequence(self.trUtf8("Ctrl+C","Edit|Copy")))
-        self.copyAct.setStatusTip(self.trUtf8('Copy screen capture to clipboard'))
+        self.copyAct = QAction(
+            UI.PixmapCache.getIcon("editCopy.png"), self.trUtf8('&Copy'), self)
+        self.copyAct.setShortcut(
+            QKeySequence(self.trUtf8("Ctrl+C", "Edit|Copy")))
+        self.copyAct.setStatusTip(
+            self.trUtf8('Copy screen capture to clipboard'))
         self.copyAct.setWhatsThis(self.trUtf8(
-                """<b>Copy</b>"""
-                """<p>Copy screen capture to clipboard.</p>"""
+            """<b>Copy</b>"""
+            """<p>Copy screen capture to clipboard.</p>"""
         ))
-        self.connect(self.copyAct,SIGNAL('triggered()'),self.__copyImageToClipboard)
+        self.copyAct.triggered[()].connect(self.__copyImageToClipboard)
         
-        self.whatsThisAct = QAction(UI.PixmapCache.getIcon("whatsThis.png"),
-                                self.trUtf8('&What\'s This?'), self)
+        self.whatsThisAct = QAction(
+            UI.PixmapCache.getIcon("whatsThis.png"),
+            self.trUtf8('&What\'s This?'), self)
         self.whatsThisAct.setShortcut(QKeySequence(self.trUtf8("Shift+F1")))
         self.whatsThisAct.setStatusTip(self.trUtf8('Context sensitive help'))
         self.whatsThisAct.setWhatsThis(self.trUtf8(
-                """<b>Display context sensitive help</b>"""
-                """<p>In What's This? mode, the mouse cursor shows an arrow with a"""
-                """ question mark, and you can click on the interface elements to get"""
-                """ a short description of what they do and how to use them. In"""
-                """ dialogs, this feature can be accessed using the context help"""
-                """ button in the titlebar.</p>"""
+            """<b>Display context sensitive help</b>"""
+            """<p>In What's This? mode, the mouse cursor shows an arrow"""
+            """ with a question mark, and you can click on the interface"""
+            """ elements to get a short description of what they do and"""
+            """ how to use them. In dialogs, this feature can be accessed"""
+            """ using the context help button in the titlebar.</p>"""
         ))
-        self.connect(self.whatsThisAct,SIGNAL('triggered()'),self.__whatsThis)
+        self.whatsThisAct.triggered[()].connect(self.__whatsThis)
 
         self.aboutAct = QAction(self.trUtf8('&About'), self)
-        self.aboutAct.setStatusTip(self.trUtf8('Display information about this software'))
+        self.aboutAct.setStatusTip(self.trUtf8(
+            'Display information about this software'))
         self.aboutAct.setWhatsThis(self.trUtf8(
-                """<b>About</b>"""
-                """<p>Display some information about this software.</p>"""
+            """<b>About</b>"""
+            """<p>Display some information about this software.</p>"""
         ))
-        self.connect(self.aboutAct,SIGNAL('triggered()'),self.__about)
+        self.aboutAct.triggered[()].connect(self.__about)
                      
         self.aboutQtAct = QAction(self.trUtf8('About &Qt'), self)
-        self.aboutQtAct.setStatusTip(\
+        self.aboutQtAct.setStatusTip(
             self.trUtf8('Display information about the Qt toolkit'))
         self.aboutQtAct.setWhatsThis(self.trUtf8(
-                """<b>About Qt</b>"""
-                """<p>Display some information about the Qt toolkit.</p>"""
+            """<b>About Qt</b>"""
+            """<p>Display some information about the Qt toolkit.</p>"""
         ))
-        self.connect(self.aboutQtAct,SIGNAL('triggered()'),self.__aboutQt)
+        self.aboutQtAct.triggered[()].connect(self.__aboutQt)
 
     def __initMenus(self):
         """
@@ -274,7 +289,7 @@ class UIPreviewer(KQMainWindow):
         """
         Private slot to handle the selection of a GUI style.
         
-        @param selectedStyle name of the selected style (QString)
+        @param selectedStyle name of the selected style (string)
         """
         if self.mainWidget:
             self.__updateChildren(selectedStyle)
@@ -283,35 +298,40 @@ class UIPreviewer(KQMainWindow):
         """
         Private slot to show the about information.
         """
-        KQMessageBox.about(self, self.trUtf8("UI Previewer"), self.trUtf8(
-            """<h3> About UI Previewer </h3>"""
-            """<p>The UI Previewer loads and displays Qt User-Interface files"""
-            """ with various styles, which are selectable via a selection list.</p>"""
-        ))
+        E5MessageBox.about(
+            self,
+            self.trUtf8("UI Previewer"),
+            self.trUtf8(
+                """<h3> About UI Previewer </h3>"""
+                """<p>The UI Previewer loads and displays Qt User-Interface"""
+                """ files with various styles, which are selectable via a"""
+                """ selection list.</p>"""
+            )
+        )
     
     def __aboutQt(self):
         """
         Private slot to show info about Qt.
         """
-        QMessageBox.aboutQt(self, self.trUtf8("UI Previewer"))
+        E5MessageBox.aboutQt(self, self.trUtf8("UI Previewer"))
 
     def __openFile(self):
         """
         Private slot to load a new file.
         """
-        fn = KQFileDialog.getOpenFileName(\
-            self, 
+        fn = E5FileDialog.getOpenFileName(
+            self,
             self.trUtf8("Select UI file"),
             self.currentFile,
             self.trUtf8("Qt User-Interface Files (*.ui)"))
-        if not fn.isEmpty():
+        if fn:
             self.__loadFile(fn)
         
     def __loadFile(self, fn):
         """
         Private slot to load a ui file.
         
-        @param fn name of the ui file to be laoded (string or QString)
+        @param fn name of the ui file to be laoded (string)
         """
         if self.mainWidget:
             self.mainWidget.close()
@@ -336,17 +356,19 @@ class UIPreviewer(KQMainWindow):
                 self.previewSV.setWidget(self.mainWidget)
                 self.mainWidget.show()
         else:
-            KQMessageBox.warning(None,
+            E5MessageBox.warning(
+                self,
                 self.trUtf8("Load UI File"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be loaded.</p>""")\
-                    .arg(fn))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be loaded.</p>""")
+                .format(fn))
         self.__updateActions()
     
     def __updateChildren(self, sstyle):
         """
         Private slot to change the style of the show UI.
         
-        @param sstyle name of the selected style (QString)
+        @param sstyle name of the selected style (string)
         """
         QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
         qstyle = QStyleFactory.create(sstyle)
@@ -364,9 +386,9 @@ class UIPreviewer(KQMainWindow):
         self.mainWidget.show()
         
         self.lastQStyle = qstyle
-        self.lastStyle = QString(sstyle)
-        Preferences.Prefs.settings.setValue('UIPreviewer/style', 
-            QVariant(self.styleCombo.currentIndex()))
+        self.lastStyle = sstyle
+        Preferences.Prefs.settings.setValue(
+            'UIPreviewer/style', self.styleCombo.currentIndex())
         QApplication.restoreOverrideCursor()
     
     def __updateActions(self):
@@ -402,8 +424,8 @@ class UIPreviewer(KQMainWindow):
         """
         Protected method called to filter an event.
         
-        @param object object, that generated the event (QObject)
-        @param event the event, that was generated by object (QEvent)
+        @param obj object, that generated the event (QObject)
+        @param ev the event, that was generated by object (QEvent)
         @return flag indicating if event was filtered out
         """
         if obj == self.mainWidget:
@@ -423,7 +445,8 @@ class UIPreviewer(KQMainWindow):
         Private slot to handle the Save Image menu action.
         """
         if self.mainWidget is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Save Image"),
                 self.trUtf8("""There is no UI file loaded."""))
             return
@@ -432,42 +455,52 @@ class UIPreviewer(KQMainWindow):
         filters = ""
         formats = QImageWriter.supportedImageFormats()
         for format in formats:
-            filters = "%s*.%s " % (filters, unicode(QString(format)).lower())
-        filter = self.trUtf8("Images (%1)").arg(QString(filters[:-1]))
+            filters = "{0}*.{1} ".format(
+                filters, bytes(format).decode().lower())
+        filter = self.trUtf8("Images ({0})").format(filters[:-1])
         
-        fname = KQFileDialog.getSaveFileName(\
+        fname = E5FileDialog.getSaveFileName(
             self,
             self.trUtf8("Save Image"),
-            QString(),
+            "",
             filter)
-        if fname.isEmpty():
+        if not fname:
             return
             
-        ext = QFileInfo(fname).suffix().toUpper()
-        if ext.isEmpty():
+        ext = QFileInfo(fname).suffix().upper()
+        if not ext:
             ext = defaultExt
-            fname.append(".%s" % defaultExt.lower())
+            fname.append(".{0}".format(defaultExt.lower()))
         
-        pix = QPixmap.grabWidget(self.mainWidget)
+        if qVersion() >= "5.0.0":
+            pix = self.mainWidget.grab()
+        else:
+            pix = QPixmap.grabWidget(self.mainWidget)
         self.__updateChildren(self.lastStyle)
         if not pix.save(fname, str(ext)):
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Save Image"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be saved.</p>""")
-                    .arg(fname))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be saved.</p>""")
+                .format(fname))
 
     def __copyImageToClipboard(self):
         """
         Private slot to handle the Copy Image menu action.
         """
         if self.mainWidget is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Save Image"),
                 self.trUtf8("""There is no UI file loaded."""))
             return
         
         cb = QApplication.clipboard()
-        cb.setPixmap(QPixmap.grabWidget(self.mainWidget))
+        if qVersion() >= "5.0.0":
+            cb.setPixmap(self.mainWidget.grab())
+        else:
+            cb.setPixmap(QPixmap.grabWidget(self.mainWidget))
         self.__updateChildren(self.lastStyle)
     
     def __printImage(self):
@@ -475,41 +508,41 @@ class UIPreviewer(KQMainWindow):
         Private slot to handle the Print Image menu action.
         """
         if self.mainWidget is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Print Image"),
                 self.trUtf8("""There is no UI file loaded."""))
             return
         
         settings = Preferences.Prefs.settings
-        printer = KdeQt.KQPrinter.KQPrinter(mode = QPrinter.HighResolution)
+        printer = QPrinter(QPrinter.HighResolution)
         printer.setFullPage(True)
         
-        if not KdeQt.isKDE():
-            printer.setPrinterName(settings.value("UIPreviewer/printername").toString())
-            printer.setPageSize(
-                QPrinter.PageSize(settings.value("UIPreviewer/pagesize").toInt()[0]))
-            printer.setPageOrder(
-                QPrinter.PageOrder(settings.value("UIPreviewer/pageorder").toInt()[0]))
-            printer.setOrientation(
-                QPrinter.Orientation(settings.value("UIPreviewer/orientation").toInt()[0]))
-            printer.setColorMode(
-                QPrinter.ColorMode(settings.value("UIPreviewer/colormode").toInt()[0]))
+        printerName = Preferences.getPrinter("UIPreviewer/printername")
+        if printerName:
+            printer.setPrinterName(printerName)
+        printer.setPageSize(
+            QPrinter.PageSize(int(settings.value("UIPreviewer/pagesize"))))
+        printer.setPageOrder(
+            QPrinter.PageOrder(int(settings.value("UIPreviewer/pageorder"))))
+        printer.setOrientation(QPrinter.Orientation(
+            int(settings.value("UIPreviewer/orientation"))))
+        printer.setColorMode(
+            QPrinter.ColorMode(int(settings.value("UIPreviewer/colormode"))))
         
-        printDialog = KQPrintDialog(printer, self)
+        printDialog = QPrintDialog(printer, self)
         if printDialog.exec_() == QDialog.Accepted:
             self.statusBar().showMessage(self.trUtf8("Printing the image..."))
             self.__print(printer)
             
-            if not KdeQt.isKDE():
-                settings.setValue("UIPreviewer/printername", 
-                    QVariant(printer.printerName()))
-                settings.setValue("UIPreviewer/pagesize", QVariant(printer.pageSize()))
-                settings.setValue("UIPreviewer/pageorder", QVariant(printer.pageOrder()))
-                settings.setValue("UIPreviewer/orientation", 
-                    QVariant(printer.orientation()))
-                settings.setValue("UIPreviewer/colormode", QVariant(printer.colorMode()))
+            settings.setValue("UIPreviewer/printername", printer.printerName())
+            settings.setValue("UIPreviewer/pagesize", printer.pageSize())
+            settings.setValue("UIPreviewer/pageorder", printer.pageOrder())
+            settings.setValue("UIPreviewer/orientation", printer.orientation())
+            settings.setValue("UIPreviewer/colormode", printer.colorMode())
         
-        self.statusBar().showMessage(self.trUtf8("Image sent to printer..."), 2000)
+        self.statusBar().showMessage(
+            self.trUtf8("Image sent to printer..."), 2000)
 
     def __printPreviewImage(self):
         """
@@ -518,28 +551,30 @@ class UIPreviewer(KQMainWindow):
         from PyQt4.QtGui import QPrintPreviewDialog
         
         if self.mainWidget is None:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Print Preview"),
                 self.trUtf8("""There is no UI file loaded."""))
             return
         
         settings = Preferences.Prefs.settings
-        printer = KdeQt.KQPrinter.KQPrinter(mode = QPrinter.HighResolution)
+        printer = QPrinter(QPrinter.HighResolution)
         printer.setFullPage(True)
         
-        if not KdeQt.isKDE():
-            printer.setPrinterName(settings.value("UIPreviewer/printername").toString())
-            printer.setPageSize(
-                QPrinter.PageSize(settings.value("UIPreviewer/pagesize").toInt()[0]))
-            printer.setPageOrder(
-                QPrinter.PageOrder(settings.value("UIPreviewer/pageorder").toInt()[0]))
-            printer.setOrientation(
-                QPrinter.Orientation(settings.value("UIPreviewer/orientation").toInt()[0]))
-            printer.setColorMode(
-                QPrinter.ColorMode(settings.value("UIPreviewer/colormode").toInt()[0]))
+        printerName = Preferences.getPrinter("UIPreviewer/printername")
+        if printerName:
+            printer.setPrinterName(printerName)
+        printer.setPageSize(
+            QPrinter.PageSize(int(settings.value("UIPreviewer/pagesize"))))
+        printer.setPageOrder(
+            QPrinter.PageOrder(int(settings.value("UIPreviewer/pageorder"))))
+        printer.setOrientation(QPrinter.Orientation(
+            int(settings.value("UIPreviewer/orientation"))))
+        printer.setColorMode(
+            QPrinter.ColorMode(int(settings.value("UIPreviewer/colormode"))))
         
         preview = QPrintPreviewDialog(printer, self)
-        self.connect(preview, SIGNAL("paintRequested(QPrinter*)"), self.__print)
+        preview.paintRequested.connect(self.__print)
         preview.exec_()
         
     def __print(self, printer):
@@ -549,20 +584,23 @@ class UIPreviewer(KQMainWindow):
         @param printer reference to the printer object (QPrinter)
         """
         p = QPainter(printer)
-        marginX = (printer.pageRect().x() - printer.paperRect().x()) / 2
-        marginY = (printer.pageRect().y() - printer.paperRect().y()) / 2
+        marginX = (printer.pageRect().x() - printer.paperRect().x()) // 2
+        marginY = (printer.pageRect().y() - printer.paperRect().y()) // 2
 
         # double the margin on bottom of page
-        if printer.orientation() == KdeQt.KQPrinter.Portrait:
+        if printer.orientation() == QPrinter.Portrait:
             width = printer.width() - marginX * 2
             height = printer.height() - marginY * 3
         else:
             marginX *= 2
             width = printer.width() - marginX * 2
             height = printer.height() - marginY * 2
-        img = QPixmap.grabWidget(self.mainWidget).toImage()
+        if qVersion() >= "5.0.0":
+            img = self.mainWidget.grab().toImage()
+        else:
+            img = QPixmap.grabWidget(self.mainWidget).toImage()
         self.__updateChildren(self.lastStyle)
-        p.drawImage(marginX, marginY, 
-                    img.scaled(width, height, 
+        p.drawImage(marginX, marginY,
+                    img.scaled(width, height,
                                Qt.KeepAspectRatio, Qt.SmoothTransformation))
         p.end()
