@@ -9,22 +9,25 @@ Module implementing the authentication dialog for the help browser.
 
 from PyQt4.QtGui import QDialog, QStyle
 
-from Ui_AuthenticationDialog import Ui_AuthenticationDialog
+from .Ui_AuthenticationDialog import Ui_AuthenticationDialog
+
 
 class AuthenticationDialog(QDialog, Ui_AuthenticationDialog):
     """
     Class implementing the authentication dialog for the help browser.
     """
-    def __init__(self, info, username, showSave = False, saveIt = False, parent = None):
+    def __init__(self, info, username, showSave=False, saveIt=False,
+                 parent=None):
         """
         Constructor
         
-        @param info information to be shown (string or QString)
-        @param username username as supplied by subversion (string or QString)
+        @param info information to be shown (string)
+        @param username username as supplied by subversion (string)
         @param showSave flag to indicate to show the save checkbox (boolean)
         @param saveIt flag indicating the value for the save checkbox (boolean)
+        @param parent reference to the parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         self.infoLabel.setText(info)
@@ -34,14 +37,15 @@ class AuthenticationDialog(QDialog, Ui_AuthenticationDialog):
         
         self.iconLabel.setText("")
         self.iconLabel.setPixmap(
-            self.style().standardIcon(QStyle.SP_MessageBoxQuestion).pixmap(32, 32))
+            self.style().standardIcon(QStyle.SP_MessageBoxQuestion).pixmap(
+                32, 32))
     
     def setData(self, username, password):
         """
         Public method to set the login data.
         
-        @param username username (string or QString)
-        @param password password (string or QString)
+        @param username username (string)
+        @param password password (string)
         """
         self.usernameEdit.setText(username)
         self.passwordEdit.setText(password)
@@ -50,7 +54,7 @@ class AuthenticationDialog(QDialog, Ui_AuthenticationDialog):
         """
         Public method to retrieve the login data.
         
-        @return tuple of two QString values (username, password)
+        @return tuple of two string values (username, password)
         """
         return (self.usernameEdit.text(), self.passwordEdit.text())
     
