@@ -7,51 +7,65 @@
 Module implementing a browser with class browsing capabilities.
 """
 
-import sys
 import os
-import mimetypes
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QModelIndex, pyqtSignal, QUrl, Qt, qVersion
+from PyQt4.QtGui import QTreeView, QDesktopServices, QItemSelectionModel, \
+    QApplication, QMenu, QAbstractItemView
 
-from KdeQt import KQFileDialog
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
+from E5Gui import E5FileDialog
 
-from BrowserModel import BrowserModel, \
-    BrowserDirectoryItem, BrowserFileItem, BrowserClassItem, BrowserMethodItem, \
+from .BrowserModel import BrowserModel, BrowserDirectoryItem, \
+    BrowserFileItem, BrowserClassItem, BrowserMethodItem, \
     BrowserClassAttributeItem
-from BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
+from .BrowserSortFilterProxyModel import BrowserSortFilterProxyModel
 
 import UI.PixmapCache
 import Preferences
 import Utilities
+import Utilities.mimetypes
+
 
 class Browser(QTreeView):
     """
-    Class used to display a file system tree. 
+    Class used to display a file system tree.
     
     Via the context menu that
     is displayed by a right click the user can select various actions on
     the selected file.
     
-    @signal sourceFile(string, int, string) emitted to open a Python file at a line 
-    @signal designerFile(string) emitted to open a Qt-Designer file
-    @signal linguistFile(string) emitted to open a Qt-Linguist (*.ts) file
-    @signal trpreview(string list) emitted to preview a Qt-Linguist (*.qm) file
-    @signal projectFile(string) emitted to open an eric4 project file
-    @signal multiProjectFile(string) emitted to open an eric4 multi project file
-    @signal pixmapFile(string) emitted to open a pixmap file
-    @signal pixmapEditFile(string) emitted to edit a pixmap file
-    @signal svgFile(string) emitted to open a SVG file
-    @signal unittestOpen(string) emitted to open a Python file for a unittest
+    @signal sourceFile(str, int = 0, str = "") emitted to open a Python file
+        at a line
+    @signal designerFile(str) emitted to open a Qt-Designer file
+    @signal linguistFile(str) emitted to open a Qt-Linguist (*.ts) file
+    @signal trpreview(list of str, bool = False) emitted to preview a
+        Qt-Linguist (*.qm) file
+    @signal projectFile(str) emitted to open an eric4/5 project file
+    @signal multiProjectFile(str) emitted to open an eric4/5 multi project file
+    @signal pixmapFile(str) emitted to open a pixmap file
+    @signal pixmapEditFile(str) emitted to edit a pixmap file
+    @signal svgFile(str) emitted to open a SVG file
+    @signal unittestOpen(str) emitted to open a Python file for a unittest
     """
-    def __init__(self, parent = None):
+    sourceFile = pyqtSignal((str, ), (str, int), (str, int, str))
+    designerFile = pyqtSignal(str)
+    linguistFile = pyqtSignal(str)
+    trpreview = pyqtSignal((list, ), (list, bool))
+    projectFile = pyqtSignal(str)
+    multiProjectFile = pyqtSignal(str)
+    pixmapFile = pyqtSignal(str)
+    pixmapEditFile = pyqtSignal(str)
+    svgFile = pyqtSignal(str)
+    unittestOpen = pyqtSignal(str)
+    
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent parent widget (QWidget)
         """
-        QTreeView.__init__(self, parent)
+        super().__init__(parent)
         
         self.setWindowTitle(QApplication.translate('Browser', 'File-Browser'))
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
@@ -65,45 +79,52 @@ class Browser(QTreeView):
         
         self.selectedItemsFilter = [BrowserFileItem]
         
-        self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"),
-                     self._contextMenuRequested)
-        self.connect(self, SIGNAL("activated(const QModelIndex &)"), self._openItem)
-        self.connect(self, SIGNAL("expanded(const QModelIndex &)"), self._resizeColumns)
-        self.connect(self, SIGNAL("collapsed(const QModelIndex &)"), self._resizeColumns)
+        self._activating = False
         
-        self.setWhatsThis(QApplication.translate('Browser', 
+        self.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.customContextMenuRequested.connect(self._contextMenuRequested)
+        self.activated.connect(self._openItem)
+        self.expanded.connect(self._resizeColumns)
+        self.collapsed.connect(self._resizeColumns)
+        
+        self.setWhatsThis(QApplication.translate(
+            'Browser',
             """<b>The Browser Window</b>"""
-            """<p>This allows you to easily navigate the hierachy of directories and"""
-            """ files on your system, identify the Python programs and open them up in"""
-            """ a Source Viewer window. The window displays several separate"""
-            """ hierachies.</p>"""
-            """<p>The first hierachy is only shown if you have opened a program for"""
-            """ debugging and its root is the directory containing that program."""
-            """ Usually all of the separate files that make up a Python application are"""
-            """ held in the same directory, so this hierachy gives you easy access to"""
-            """ most of what you will need.</p>"""
-            """<p>The next hierachy is used to easily navigate the directories that are"""
-            """ specified in the Python <tt>sys.path</tt> variable.</p>"""
-            """<p>The remaining hierachies allow you navigate your system as a whole."""
-            """ On a UNIX system there will be a hierachy with <tt>/</tt> at its"""
-            """ root and another with the user home directory."""
-            """ On a Windows system there will be a hierachy for each drive on the"""
+            """<p>This allows you to easily navigate the hierarchy of"""
+            """ directories and files on your system, identify the Python"""
+            """ programs and open them up in a Source Viewer window. The"""
+            """ window displays several separate hierarchies.</p>"""
+            """<p>The first hierarchy is only shown if you have opened a"""
+            """ program for debugging and its root is the directory"""
+            """ containing that program. Usually all of the separate files"""
+            """ that make up a Python application are held in the same"""
+            """ directory, so this hierarchy gives you easy access to most"""
+            """ of what you will need.</p>"""
+            """<p>The next hierarchy is used to easily navigate the"""
+            """ directories that are specified in the Python"""
+            """ <tt>sys.path</tt> variable.</p>"""
+            """<p>The remaining hierarchies allow you navigate your system"""
+            """ as a whole. On a UNIX system there will be a hierarchy with"""
+            """ <tt>/</tt> at its root and another with the user home"""
+            """ directory. On a Windows system there will be a hierarchy for"""
+            """ each drive on the"""
             """ system.</p>"""
-            """<p>Python programs (i.e. those with a <tt>.py</tt> file name suffix)"""
-            """ are identified in the hierachies with a Python icon."""
-            """ The right mouse button will popup a menu which lets you"""
-            """ open the file in a Source Viewer window,"""
-            """ open the file for debugging or use it for a unittest run.</p>"""
-            """<p>The context menu of a class, function or method allows you to open"""
-            """ the file defining this class, function or method and will ensure, that"""
-            """ the correct source line is visible.</p>"""
-            """<p>Qt-Designer files (i.e. those with a <tt>.ui</tt> file name suffix)"""
-            """ are shown with a Designer icon. The context menu of these files"""
-            """ allows you to start Qt-Designer with that file.</p>"""
-            """<p>Qt-Linguist files (i.e. those with a <tt>.ts</tt> file name suffix)"""
-            """ are shown with a Linguist icon. The context menu of these files"""
-            """ allows you to start Qt-Linguist with that file.</p>"""
+            """<p>Python programs (i.e. those with a <tt>.py</tt> file name"""
+            """ suffix) are identified in the hierarchies with a Python"""
+            """ icon. The right mouse button will popup a menu which lets"""
+            """ you open the file in a Source Viewer window, open the file"""
+            """ for debugging or use it for a unittest run.</p>"""
+            """<p>The context menu of a class, function or method allows you"""
+            """ to open the file defining this class, function or method and"""
+            """ will ensure, that the correct source line is visible.</p>"""
+            """<p>Qt-Designer files (i.e. those with a <tt>.ui</tt> file"""
+            """ name suffix) are shown with a Designer icon. The context"""
+            """ menu of these files allows you to start Qt-Designer with"""
+            """ that file.</p>"""
+            """<p>Qt-Linguist files (i.e. those with a <tt>.ts</tt> file"""
+            """ name suffix) are shown with a Linguist icon. The context"""
+            """ menu of these files allows you to start Qt-Linguist with"""
+            """ that file.</p>"""
         ))
         
         self.__createPopupMenus()
@@ -121,7 +142,10 @@ class Browser(QTreeView):
         header = self.header()
         header.setSortIndicator(0, Qt.AscendingOrder)
         header.setSortIndicatorShown(True)
-        header.setClickable(True)
+        if qVersion() >= "5.0.0":
+            header.setSectionsClickable(True)
+        else:
+            header.setClickable(True)
         
         self.setSortingEnabled(True)
         
@@ -154,7 +178,7 @@ class Browser(QTreeView):
         """
         Protected slot to resort the tree.
         """
-        self.model().sort(self.header().sortIndicatorSection(), 
+        self.model().sort(self.header().sortIndicatorSection(),
                           self.header().sortIndicatorOrder())
         
     def __createPopupMenus(self):
@@ -163,83 +187,107 @@ class Browser(QTreeView):
         """
         # create the popup menu for source files
         self.sourceMenu = QMenu(self)
-        self.sourceMenu.addAction(QApplication.translate('Browser', 'Open'), 
-            self._openItem)
-        self.unittestAct = self.sourceMenu.addAction(\
-            QApplication.translate('Browser', 'Run unittest...'), self.handleUnittest)
         self.sourceMenu.addAction(
-            QApplication.translate('Browser', 'Copy Path to Clipboard'), 
+            QApplication.translate('Browser', 'Open'), self._openItem)
+        self.unittestAct = self.sourceMenu.addAction(
+            QApplication.translate('Browser', 'Run unittest...'),
+            self.handleUnittest)
+        self.sourceMenu.addAction(
+            QApplication.translate('Browser', 'Copy Path to Clipboard'),
             self._copyToClipboard)
         
         # create the popup menu for general use
         self.menu = QMenu(self)
-        self.menu.addAction(QApplication.translate('Browser', 'Open'), self._openItem)
-        self.editPixmapAct = \
-            self.menu.addAction(QApplication.translate('Browser', 'Open in Icon Editor'), 
+        self.menu.addAction(
+            QApplication.translate('Browser', 'Open'), self._openItem)
+        self.editPixmapAct = self.menu.addAction(
+            QApplication.translate('Browser', 'Open in Icon Editor'),
             self._editPixmap)
         self.menu.addAction(
-            QApplication.translate('Browser', 'Copy Path to Clipboard'), 
+            QApplication.translate('Browser', 'Copy Path to Clipboard'),
             self._copyToClipboard)
         if self.__embeddedBrowser in [1, 2]:
             self.menu.addSeparator()
-            self.menu.addAction(QApplication.translate('Browser', 'Configure...'), 
-                                self.__configure)
+            self.menu.addAction(
+                QApplication.translate('Browser', 'Configure...'),
+                self.__configure)
 
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
-        self.multiMenu.addAction(QApplication.translate('Browser', 'Open'), 
-            self._openItem)
+        self.multiMenu.addAction(
+            QApplication.translate('Browser', 'Open'), self._openItem)
         if self.__embeddedBrowser in [1, 2]:
             self.multiMenu.addSeparator()
-            self.multiMenu.addAction(QApplication.translate('Browser', 'Configure...'), 
-                                     self.__configure)
+            self.multiMenu.addAction(
+                QApplication.translate('Browser', 'Configure...'),
+                self.__configure)
         
         # create the directory menu
         self.dirMenu = QMenu(self)
-        self.dirMenu.addAction(QApplication.translate('Browser', 
-            'New toplevel directory...'), 
+        self.dirMenu.addAction(
+            QApplication.translate('Browser', 'New toplevel directory...'),
             self.__newToplevelDir)
-        self.addAsTopLevelAct = self.dirMenu.addAction(\
+        self.addAsTopLevelAct = self.dirMenu.addAction(
             QApplication.translate('Browser', 'Add as toplevel directory'),
             self.__addAsToplevelDir)
-        self.removeFromToplevelAct = self.dirMenu.addAction(\
+        self.removeFromToplevelAct = self.dirMenu.addAction(
             QApplication.translate('Browser', 'Remove from toplevel'),
             self.__removeToplevel)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(QApplication.translate('Browser', 
-            'Refresh directory'),
+        self.dirMenu.addAction(
+            QApplication.translate('Browser', 'Refresh directory'),
             self.__refreshDirectory)
         self.dirMenu.addSeparator()
-        self.dirMenu.addAction(QApplication.translate('Browser', 
-            'Find in this directory'),
+        self.dirMenu.addAction(
+            QApplication.translate('Browser', 'Find in this directory'),
             self.__findInDirectory)
-        self.dirMenu.addAction(QApplication.translate('Browser', 
-            'Find&&Replace in this directory'),
+        self.dirMenu.addAction(
+            QApplication.translate(
+                'Browser', 'Find&&Replace in this directory'),
             self.__replaceInDirectory)
         self.dirMenu.addAction(
-            QApplication.translate('Browser', 'Copy Path to Clipboard'), 
+            QApplication.translate('Browser', 'Copy Path to Clipboard'),
             self._copyToClipboard)
         if self.__embeddedBrowser in [1, 2]:
             self.dirMenu.addSeparator()
-            self.dirMenu.addAction(QApplication.translate('Browser', 'Configure...'), 
-                                   self.__configure)
+            self.dirMenu.addAction(
+                QApplication.translate('Browser', 'Configure...'),
+                self.__configure)
+        
+        # create the attribute menu
+        self.gotoMenu = QMenu(self.trUtf8("Goto"), self)
+        self.gotoMenu.aboutToShow.connect(self._showGotoMenu)
+        self.gotoMenu.triggered.connect(self._gotoAttribute)
+        
+        self.attributeMenu = QMenu(self)
+        self.attributeMenu.addAction(
+            QApplication.translate('Browser', 'New toplevel directory...'),
+            self.__newToplevelDir)
+        self.attributeMenu.addSeparator()
+        self.attributeMenu.addMenu(self.gotoMenu)
+        if self.__embeddedBrowser in [1, 2]:
+            self.attributeMenu.addSeparator()
+            self.attributeMenu.addAction(
+                QApplication.translate('Browser', 'Configure...'),
+                self.__configure)
         
         # create the background menu
         self.backMenu = QMenu(self)
-        self.backMenu.addAction(QApplication.translate('Browser', 
-            'New toplevel directory...'), 
+        self.backMenu.addAction(
+            QApplication.translate('Browser', 'New toplevel directory...'),
             self.__newToplevelDir)
         if self.__embeddedBrowser in [1, 2]:
             self.backMenu.addSeparator()
-            self.backMenu.addAction(QApplication.translate('Browser', 'Configure...'), 
-                                    self.__configure)
+            self.backMenu.addAction(
+                QApplication.translate('Browser', 'Configure...'),
+                self.__configure)
 
     def mouseDoubleClickEvent(self, mouseEvent):
         """
-        Protected method of QAbstractItemView. 
+        Protected method of QAbstractItemView.
         
-        Reimplemented to disable expanding/collapsing
-        of items when double-clicking. Instead the double-clicked entry is opened.
+        Reimplemented to disable expanding/collapsing of items when
+        double-clicking. Instead the double-clicked entry is opened.
         
         @param mouseEvent the mouse event (QMouseEvent)
         """
@@ -253,11 +301,11 @@ class Browser(QTreeView):
         
         @param coord the position of the mouse pointer (QPoint)
         """
-        categories = self.getSelectedItemsCountCategorized(\
-            [BrowserDirectoryItem, BrowserFileItem, 
+        categories = self.getSelectedItemsCountCategorized(
+            [BrowserDirectoryItem, BrowserFileItem,
              BrowserClassItem, BrowserMethodItem])
         cnt = categories["sum"]
-        bfcnt = categories[unicode(BrowserFileItem)]
+        bfcnt = categories[str(BrowserFileItem)]
         if cnt > 1 and cnt == bfcnt:
             self.multiMenu.popup(self.mapToGlobal(coord))
         else:
@@ -265,14 +313,15 @@ class Browser(QTreeView):
             
             if index.isValid():
                 self.setCurrentIndex(index)
-                flags = QItemSelectionModel.SelectionFlags(\
-                    QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
+                flags = QItemSelectionModel.SelectionFlags(
+                    QItemSelectionModel.ClearAndSelect |
+                    QItemSelectionModel.Rows)
                 self.selectionModel().select(index, flags)
                 
                 itm = self.model().item(index)
                 coord = self.mapToGlobal(coord)
                 if isinstance(itm, BrowserFileItem):
-                    if itm.isPythonFile():
+                    if itm.isPython3File():
                         if itm.fileName().endswith('.py'):
                             self.unittestAct.setEnabled(True)
                         else:
@@ -284,6 +333,8 @@ class Browser(QTreeView):
                 elif isinstance(itm, BrowserClassItem) or \
                         isinstance(itm, BrowserMethodItem):
                     self.menu.popup(coord)
+                elif isinstance(itm, BrowserClassAttributeItem):
+                    self.attributeMenu.popup(coord)
                 elif isinstance(itm, BrowserDirectoryItem):
                     if not index.parent().isValid():
                         self.removeFromToplevelAct.setEnabled(True)
@@ -297,6 +348,30 @@ class Browser(QTreeView):
             else:
                 self.backMenu.popup(self.mapToGlobal(coord))
         
+    def _showGotoMenu(self):
+        """
+        Protected slot to prepare the goto submenu of the attribute menu.
+        """
+        self.gotoMenu.clear()
+        
+        itm = self.model().item(self.currentIndex())
+        linenos = itm.linenos()
+        fileName = itm.fileName()
+        
+        for lineno in sorted(linenos):
+            act = self.gotoMenu.addAction(
+                self.trUtf8("Line {0}".format(lineno)))
+            act.setData([fileName, lineno])
+        
+    def _gotoAttribute(self, act):
+        """
+        Protected slot to handle the selection of the goto menu.
+        
+        @param act reference to the action (E5Action)
+        """
+        fileName, lineno = act.data()
+        self.sourceFile[str, int].emit(fileName, lineno)
+        
     def handlePreferencesChanged(self):
         """
         Public slot used to handle the preferencesChanged signal.
@@ -308,56 +383,58 @@ class Browser(QTreeView):
         """
         Protected slot to handle the open popup menu entry.
         """
-        itmList = self.getSelectedItems(\
-            [BrowserFileItem, BrowserClassItem, 
+        itmList = self.getSelectedItems(
+            [BrowserFileItem, BrowserClassItem,
              BrowserMethodItem, BrowserClassAttributeItem])
         
-        for itm in itmList:
-            if isinstance(itm, BrowserFileItem):
-                if itm.isPythonFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python")
-                elif itm.isPython3File():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python3")
-                elif itm.isRubyFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Ruby")
-                elif itm.isDFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "D")
-                elif itm.isDesignerFile():
-                    self.emit(SIGNAL('designerFile'), itm.fileName())
-                elif itm.isDesignerHeaderFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName())
-                elif itm.isLinguistFile():
-                    if itm.fileExt() == '.ts':
-                        self.emit(SIGNAL('linguistFile'), itm.fileName())
+        if not self._activating:
+            self._activating = True
+            for itm in itmList:
+                if isinstance(itm, BrowserFileItem):
+                    if itm.isPython2File():
+                        self.sourceFile[str].emit(itm.fileName())
+                    elif itm.isPython3File():
+                        self.sourceFile[str].emit(itm.fileName())
+                    elif itm.isRubyFile():
+                        self.sourceFile[str, int, str].emit(
+                            itm.fileName(), -1, "Ruby")
+                    elif itm.isDFile():
+                        self.sourceFile[str, int, str].emit(
+                            itm.fileName(), -1, "D")
+                    elif itm.isDesignerFile():
+                        self.designerFile.emit(itm.fileName())
+                    elif itm.isLinguistFile():
+                        if itm.fileExt() == '.ts':
+                            self.linguistFile.emit(itm.fileName())
+                        else:
+                            self.trpreview.emit([itm.fileName()])
+                    elif itm.isProjectFile():
+                        self.projectFile.emit(itm.fileName())
+                    elif itm.isMultiProjectFile():
+                        self.multiProjectFile.emit(itm.fileName())
+                    elif itm.isIdlFile():
+                        self.sourceFile[str].emit(itm.fileName())
+                    elif itm.isResourcesFile():
+                        self.sourceFile[str].emit(itm.fileName())
+                    elif itm.isSvgFile():
+                        self.svgFile.emit(itm.fileName())
+                    elif itm.isPixmapFile():
+                        self.pixmapFile.emit(itm.fileName())
                     else:
-                        self.emit(SIGNAL('trpreview'), [itm.fileName()])
-                elif itm.isProjectFile():
-                    self.emit(SIGNAL('projectFile'), itm.fileName())
-                elif itm.isMultiProjectFile():
-                    self.emit(SIGNAL('multiProjectFile'), itm.fileName())
-                elif itm.isIdlFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName())
-                elif itm.isResourcesFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName())
-                elif itm.isPixmapFile():
-                    self.emit(SIGNAL('pixmapFile'), itm.fileName())
-                elif itm.isSvgFile():
-                    self.emit(SIGNAL('svgFile'), itm.fileName())
-                else:
-                    type_ = mimetypes.guess_type(itm.fileName())[0]
-                    if type_ is None or type_.split("/")[0] == "text":
-                        self.emit(SIGNAL('sourceFile'), itm.fileName())
-                    else:
-                        QDesktopServices.openUrl(QUrl(itm.fileName()))
-            elif isinstance(itm, BrowserClassItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.classObject().lineno)
-            elif isinstance(itm, BrowserMethodItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.functionObject().lineno)
-            elif isinstance(itm, BrowserClassAttributeItem):
-                self.emit(SIGNAL('sourceFile'), itm.fileName(), 
-                    itm.attributeObject().lineno)
+                        if Utilities.mimetypes.isTextFile(itm.fileName()):
+                            self.sourceFile[str].emit(itm.fileName())
+                        else:
+                            QDesktopServices.openUrl(QUrl(itm.fileName()))
+                elif isinstance(itm, BrowserClassItem):
+                    self.sourceFile[str, int].emit(
+                        itm.fileName(), itm.classObject().lineno)
+                elif isinstance(itm, BrowserMethodItem):
+                    self.sourceFile[str, int].emit(
+                        itm.fileName(), itm.functionObject().lineno)
+                elif isinstance(itm, BrowserClassAttributeItem):
+                    self.sourceFile[str, int].emit(
+                        itm.fileName(), itm.attributeObject().lineno)
+            self._activating = False
         
     def _editPixmap(self):
         """
@@ -368,7 +445,7 @@ class Browser(QTreeView):
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
                 if itm.isPixmapFile():
-                    self.emit(SIGNAL('pixmapEditFile'), itm.fileName())
+                    self.pixmapEditFile.emit(itm.fileName())
         
     def _copyToClipboard(self):
         """
@@ -376,10 +453,10 @@ class Browser(QTreeView):
         """
         itm = self.model().item(self.currentIndex())
         try:
-            fn = unicode(itm.fileName())
+            fn = itm.fileName()
         except AttributeError:
             try:
-                fn = unicode(itm.dirName())
+                fn = itm.dirName()
             except AttributeError:
                 fn = ""
         
@@ -399,19 +476,19 @@ class Browser(QTreeView):
             pyfn = None
 
         if pyfn is not None:
-            self.emit(SIGNAL('unittestOpen'), pyfn)
+            self.unittestOpen.emit(pyfn)
         
     def __newToplevelDir(self):
         """
         Private slot to handle the New toplevel directory popup menu entry.
         """
-        dname = KQFileDialog.getExistingDirectory(\
+        dname = E5FileDialog.getExistingDirectory(
             None,
             QApplication.translate('Browser', "New toplevel directory"),
-            QString(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
-        if not dname.isEmpty():
-            dname = os.path.abspath(unicode(Utilities.toNativeSeparators(dname)))
+            "",
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
+        if dname:
+            dname = os.path.abspath(Utilities.toNativeSeparators(dname))
             self.__model.addTopLevelDir(dname)
         
     def __removeToplevel(self):
@@ -445,11 +522,8 @@ class Browser(QTreeView):
         index = self.currentIndex()
         searchDir = self.model().item(index).dirName()
         
-        findFilesDialog = e4App().getObject("FindFilesDialog")
-        findFilesDialog.setSearchDirectory(searchDir)
-        findFilesDialog.show()
-        findFilesDialog.raise_()
-        findFilesDialog.activateWindow()
+        e5App().getObject("UserInterface")\
+            .showFindFilesDialog(searchDir=searchDir)
         
     def __replaceInDirectory(self):
         """
@@ -458,15 +532,14 @@ class Browser(QTreeView):
         index = self.currentIndex()
         searchDir = self.model().item(index).dirName()
         
-        replaceFilesDialog = e4App().getObject("ReplaceFilesDialog")
-        replaceFilesDialog.setSearchDirectory(searchDir)
-        replaceFilesDialog.show()
-        replaceFilesDialog.raise_()
-        replaceFilesDialog.activateWindow()
+        e5App().getObject("UserInterface")\
+            .showReplaceFilesDialog(searchDir=searchDir)
         
-    def handleProgramChange(self,fn):
+    def handleProgramChange(self, fn):
         """
         Public slot to handle the programChange signal.
+        
+        @param fn file name (string)
         """
         self.__model.programChange(os.path.dirname(fn))
         
@@ -534,7 +607,7 @@ class Browser(QTreeView):
         categories = {}
         categories["sum"] = 0
         for typ in filter:
-            categories[unicode(typ)] = 0
+            categories[str(typ)] = 0
         
         indexes = self.selectedIndexes()
         for index in indexes:
@@ -543,7 +616,7 @@ class Browser(QTreeView):
                 for typ in filter:
                     if isinstance(itm, typ):
                         categories["sum"] += 1
-                        categories[unicode(typ)] += 1
+                        categories[str(typ)] += 1
         
         return categories
         
@@ -558,6 +631,8 @@ class Browser(QTreeView):
         Private method to open the configuration dialog.
         """
         if self.__embeddedBrowser == 1:
-            e4App().getObject("UserInterface").showPreferences("debuggerGeneralPage")
+            e5App().getObject("UserInterface")\
+                .showPreferences("debuggerGeneralPage")
         elif self.__embeddedBrowser == 2:
-            e4App().getObject("UserInterface").showPreferences("projectBrowserPage")
+            e5App().getObject("UserInterface")\
+                .showPreferences("projectBrowserPage")
