@@ -7,22 +7,23 @@
 Module implementing the browser sort filter proxy model.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QModelIndex
+from PyQt4.QtGui import QSortFilterProxyModel
 
 import Preferences
 
+
 class BrowserSortFilterProxyModel(QSortFilterProxyModel):
     """
     Class implementing the browser sort filter proxy model.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent object (QObject)
         """
-        QSortFilterProxyModel.__init__(self, parent)
+        super().__init__(parent)
         self.hideNonPublic = Preferences.getUI("BrowsersHideNonPublic")
         
     def sort(self, column, order):
@@ -34,7 +35,7 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         """
         self.__sortColumn = column
         self.__sortOrder = order
-        QSortFilterProxyModel.sort(self, column, order)
+        super().sort(column, order)
         
     def lessThan(self, left, right):
         """
@@ -48,11 +49,11 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         @param right index of right item (QModelIndex)
         @return true, if left is less than right (boolean)
         """
-        l = left.model() and left.model().item(left) or None
-        r = right.model() and right.model().item(right) or None
+        le = left.model() and left.model().item(left) or None
+        ri = right.model() and right.model().item(right) or None
         
-        if l and r:
-            return l.lessThan(r, self.__sortColumn, self.__sortOrder)
+        if le and ri:
+            return le.lessThan(ri, self.__sortColumn, self.__sortOrder)
         
         return False
         
@@ -69,7 +70,7 @@ class BrowserSortFilterProxyModel(QSortFilterProxyModel):
         sindex = self.mapToSource(index)
         return self.sourceModel().item(sindex)
     
-    def hasChildren(self, parent = QModelIndex()):
+    def hasChildren(self, parent=QModelIndex()):
         """
         Public method to check for the presence of child items.
         
