@@ -4,31 +4,33 @@
 #
 
 """
-Module implementing a dialog to compare two files and show the result side by side.
+Module implementing a dialog to compare two files and show the result side by
+side.
 """
 
-import os
-import sys
 import re
 from difflib import _mdiff, IS_CHARACTER_JUNK
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QTimer, QEvent, pyqtSlot
+from PyQt4.QtGui import QWidget, QColor, QFontMetrics, QBrush, QApplication, \
+    QTextCursor, QDialogButtonBox
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
-
-from E4Gui.E4Completers import E4FileCompleter
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
 import UI.PixmapCache
 
-from Ui_CompareDialog import Ui_CompareDialog
+from .Ui_CompareDialog import Ui_CompareDialog
 
 import Utilities
+import Preferences
 
-def sbsdiff(a, b, linenumberwidth = 4):
+
+def sbsdiff(a, b, linenumberwidth=4):
     """
-    Compare two sequences of lines; generate the delta for display side by side.
+    Compare two sequences of lines; generate the delta for display side by
+    side.
     
     @param a first sequence of lines (list of strings)
     @param b second sequence of lines (list of strings)
@@ -36,7 +38,8 @@ def sbsdiff(a, b, linenumberwidth = 4):
     @return a generator yielding tuples of differences. The tuple is composed
         of strings as follows.
         <ul>
-            <li>opcode -- one of e, d, i, r for equal, delete, insert, replace</li>
+            <li>opcode -- one of e, d, i, r for equal, delete, insert,
+                replace</li>
             <li>lineno a -- linenumber of sequence a</li>
             <li>line a -- line of sequence a</li>
             <li>lineno b -- linenumber of sequence b</li>
@@ -56,46 +59,49 @@ def sbsdiff(a, b, linenumberwidth = 4):
             .replace('\0^', "")\
             .replace('\1', "")
 
-    linenumberformat = "%%%dd" % linenumberwidth
+    linenumberformat = "{{0:{0:d}d}}".format(linenumberwidth)
     emptylineno = ' ' * linenumberwidth
     
-    for (ln1, l1), (ln2, l2), flag in _mdiff(a, b, None, None, IS_CHARACTER_JUNK):
+    for (ln1, l1), (ln2, l2), flag in _mdiff(a, b, None, None,
+                                             IS_CHARACTER_JUNK):
         if not flag:
-            yield ('e', str(linenumberformat % ln1), l1,
-                        str(linenumberformat % ln2), l2)
+            yield ('e', linenumberformat.format(ln1), l1,
+                   linenumberformat.format(ln2), l2)
             continue
         if ln2 == "" and l2 == "\n":
-            yield ('d', str(linenumberformat % ln1), removeMarkers(l1),
-                        emptylineno, '\n')
+            yield ('d', linenumberformat.format(ln1), removeMarkers(l1),
+                   emptylineno, '\n')
             continue
         if ln1 == "" and l1 == "\n":
             yield ('i', emptylineno, '\n',
-                        str(linenumberformat % ln2), removeMarkers(l2))
+                   linenumberformat.format(ln2), removeMarkers(l2))
             continue
-        yield ('r', str(linenumberformat % ln1), l1,
-                    str(linenumberformat % ln2), l2)
+        yield ('r', linenumberformat.format(ln1), l1,
+               linenumberformat.format(ln2), l2)
+
 
 class CompareDialog(QWidget, Ui_CompareDialog):
     """
-    Class implementing a dialog to compare two files and show the result side by side.
+    Class implementing a dialog to compare two files and show the result side
+    by side.
     """
-    def __init__(self, files = [], parent = None):
+    def __init__(self, files=[], parent=None):
         """
         Constructor
         
-        @param files list of files to compare and their label 
+        @param files list of files to compare and their label
             (list of two tuples of two strings)
         @param parent parent widget (QWidget)
         """
-        QWidget.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.file1Completer = E4FileCompleter(self.file1Edit)
-        self.file2Completer = E4FileCompleter(self.file2Edit)
+        self.file1Completer = E5FileCompleter(self.file1Edit)
+        self.file2Completer = E5FileCompleter(self.file2Edit)
         
-        self.diffButton = \
-            self.buttonBox.addButton(self.trUtf8("Compare"), QDialogButtonBox.ActionRole)
-        self.diffButton.setToolTip(\
+        self.diffButton = self.buttonBox.addButton(
+            self.trUtf8("Compare"), QDialogButtonBox.ActionRole)
+        self.diffButton.setToolTip(
             self.trUtf8("Press to perform the comparison of the two files"))
         self.diffButton.setEnabled(False)
         self.diffButton.setDefault(True)
@@ -105,10 +111,10 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
         self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow.png"))
         
-        self.totalLabel.setText(self.trUtf8('Total: %1').arg(0))
-        self.changedLabel.setText(self.trUtf8('Changed: %1').arg(0))
-        self.addedLabel.setText(self.trUtf8('Added: %1').arg(0))
-        self.deletedLabel.setText(self.trUtf8('Deleted: %1').arg(0))
+        self.totalLabel.setText(self.trUtf8('Total: {0}').format(0))
+        self.changedLabel.setText(self.trUtf8('Changed: {0}').format(0))
+        self.addedLabel.setText(self.trUtf8('Added: {0}').format(0))
+        self.deletedLabel.setText(self.trUtf8('Deleted: {0}').format(0))
         
         self.updateInterval = 20    # update every 20 lines
         
@@ -119,12 +125,11 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         
         self.on_synchronizeCheckBox_toggled(True)
         
-        if Utilities.isWindowsPlatform():
-            self.contents_1.setFontFamily("Lucida Console")
-            self.contents_2.setFontFamily("Lucida Console")
-        else:
-            self.contents_1.setFontFamily("Monospace")
-            self.contents_2.setFontFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.contents_1.setFontFamily(font.family())
+        self.contents_1.setFontPointSize(font.pointSize())
+        self.contents_2.setFontFamily(font.family())
+        self.contents_2.setFontPointSize(font.pointSize())
         self.fontHeight = QFontMetrics(self.contents_1.currentFont()).height()
         
         self.cNormalFormat = self.contents_1.currentCharFormat()
@@ -136,17 +141,11 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.cReplacedFormat.setBackground(QBrush(QColor(190, 190, 237)))
         
         # connect some of our widgets explicitly
-        self.connect(self.file1Edit, SIGNAL("textChanged(const QString &)"), 
-                     self.__fileChanged)
-        self.connect(self.file2Edit, SIGNAL("textChanged(const QString &)"), 
-                     self.__fileChanged)
-        self.connect(self.synchronizeCheckBox, SIGNAL("toggled(bool)"), 
-                     self.on_synchronizeCheckBox_toggled)
-        self.connect(self.vsb1, SIGNAL("valueChanged(int)"), self.__scrollBarMoved)
-        self.connect(self.vsb1, SIGNAL('valueChanged(int)'),
-            self.vsb2, SLOT('setValue(int)'))
-        self.connect(self.vsb2, SIGNAL('valueChanged(int)'),
-            self.vsb1, SLOT('setValue(int)'))
+        self.file1Edit.textChanged.connect(self.__fileChanged)
+        self.file2Edit.textChanged.connect(self.__fileChanged)
+        self.vsb1.valueChanged.connect(self.__scrollBarMoved)
+        self.vsb1.valueChanged.connect(self.vsb2.setValue)
+        self.vsb2.valueChanged.connect(self.vsb1.setValue)
         
         self.diffParas = []
         self.currentDiffPos = -1
@@ -165,17 +164,17 @@ class CompareDialog(QWidget, Ui_CompareDialog):
             self.file1Label.hide()
             self.file2Label.hide()
 
-    def show(self, filename = None):
+    def show(self, filename=None):
         """
         Public slot to show the dialog.
         
-        @param filename name of a file to use as the first file (string or QString)
+        @param filename name of a file to use as the first file (string)
         """
         if filename:
             self.file1Edit.setText(filename)
-        QWidget.show(self)
+        super().show()
         
-    def __appendText(self, pane, linenumber, line, format, interLine = False):
+    def __appendText(self, pane, linenumber, line, format, interLine=False):
         """
         Private method to append text to the end of the contents pane.
         
@@ -190,7 +189,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         pane.setTextCursor(tc)
         pane.setCurrentCharFormat(format)
         if interLine:
-            pane.insertPlainText("%s " % linenumber)
+            pane.insertPlainText("{0} ".format(linenumber))
             for txt in re.split(self.markerPattern, line):
                 if txt:
                     if txt.count('\1'):
@@ -206,7 +205,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
                     pane.setCurrentCharFormat(self.cNormalFormat)
                     pane.insertPlainText(txt)
         else:
-            pane.insertPlainText("%s %s" % (linenumber, line))
+            pane.insertPlainText("{0} {1}".format(linenumber, line))
 
     def on_buttonBox_clicked(self, button):
         """
@@ -217,35 +216,76 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         if button == self.diffButton:
             self.on_diffButton_clicked()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffButton_clicked(self):
         """
         Private slot to handle the Compare button press.
         """
-        filename1 = unicode(Utilities.toNativeSeparators(self.file1Edit.text()))
+        filename1 = Utilities.toNativeSeparators(self.file1Edit.text())
         try:
-            f1 = open(filename1, "rb")
+            f1 = open(filename1, "r", encoding="utf-8")
             lines1 = f1.readlines()
             f1.close()
         except IOError:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Compare Files"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be read.</p>""")
-                    .arg(filename1))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be read.</p>""")
+                .format(filename1))
             return
 
-        filename2 = unicode(Utilities.toNativeSeparators(self.file2Edit.text()))
+        filename2 = Utilities.toNativeSeparators(self.file2Edit.text())
         try:
-            f2 = open(filename2, "rb")
+            f2 = open(filename2, "r", encoding="utf-8")
             lines2 = f2.readlines()
             f2.close()
         except IOError:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Compare Files"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be read.</p>""")
-                    .arg(filename2))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be read.</p>""")
+                .format(filename2))
             return
         
+        self.__compare(lines1, lines2)
+        
+    def compare(self, lines1, lines2, name1="", name2=""):
+        """
+        Public method to compare two lists of text.
+        
+        @param lines1 text to compare against (string or list of strings)
+        @param lines2 text to compare (string or list of strings)
+        @keyparam name1 name to be shown for the first text (string)
+        @keyparam name2 name to be shown for the second text (string)
+        """
+        if name1 == "" or name2 == "":
+            self.filesGroup.hide()
+        else:
+            self.file1Button.hide()
+            self.file2Button.hide()
+            self.file1Edit.setText(name1)
+            self.file1Edit.setReadOnly(True)
+            self.file2Edit.setText(name2)
+            self.file2Edit.setReadOnly(True)
+        self.diffButton.setEnabled(False)
+        self.diffButton.hide()
+        
+        if isinstance(lines1, str):
+            lines1 = lines1.splitlines(True)
+        if isinstance(lines2, str):
+            lines2 = lines2.splitlines(True)
+        
+        self.__compare(lines1, lines2)
+        
+    def __compare(self, lines1, lines2):
+        """
+        Private method to compare two lists of text.
+        
+        @param lines1 text to compare against (list of strings)
+        @param lines2 text to compare (list of strings)
+        """
         self.contents_1.clear()
         self.contents_2.clear()
         
@@ -299,21 +339,27 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.vsb2.setValue(0)
         self.firstButton.setEnabled(False)
         self.upButton.setEnabled(False)
-        self.downButton.setEnabled(len(self.diffParas) > 0)
-        self.lastButton.setEnabled(len(self.diffParas) > 0)
+        self.downButton.setEnabled(
+            len(self.diffParas) > 0 and
+            (self.vsb1.isVisible() or self.vsb2.isVisible()))
+        self.lastButton.setEnabled(
+            len(self.diffParas) > 0 and
+            (self.vsb1.isVisible() or self.vsb2.isVisible()))
         
-        self.totalLabel.setText(self.trUtf8('Total: %1').arg(added + deleted + changed))
-        self.changedLabel.setText(self.trUtf8('Changed: %1').arg(changed))
-        self.addedLabel.setText(self.trUtf8('Added: %1').arg(added))
-        self.deletedLabel.setText(self.trUtf8('Deleted: %1').arg(deleted))
+        self.totalLabel.setText(self.trUtf8('Total: {0}')
+                                    .format(added + deleted + changed))
+        self.changedLabel.setText(self.trUtf8('Changed: {0}').format(changed))
+        self.addedLabel.setText(self.trUtf8('Added: {0}').format(added))
+        self.deletedLabel.setText(self.trUtf8('Deleted: {0}').format(deleted))
 
     def __moveTextToCurrentDiffPos(self):
         """
         Private slot to move the text display to the current diff position.
         """
-        value = (self.diffParas[self.currentDiffPos] - 1) * self.fontHeight
-        self.vsb1.setValue(value)
-        self.vsb2.setValue(value)
+        if 0 <= self.currentDiffPos < len(self.diffParas):
+            value = (self.diffParas[self.currentDiffPos] - 1) * self.fontHeight
+            self.vsb1.setValue(value)
+            self.vsb2.setValue(value)
     
     def __scrollBarMoved(self, value):
         """
@@ -339,7 +385,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
                     if tPos <= diffPos:
                         break
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_upButton_clicked(self):
         """
         Private slot to go to the previous difference.
@@ -347,7 +393,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.currentDiffPos -= 1
         self.__moveTextToCurrentDiffPos()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_downButton_clicked(self):
         """
         Private slot to go to the next difference.
@@ -355,7 +401,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.currentDiffPos += 1
         self.__moveTextToCurrentDiffPos()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_firstButton_clicked(self):
         """
         Private slot to go to the first difference.
@@ -363,7 +409,7 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.currentDiffPos = 0
         self.__moveTextToCurrentDiffPos()
     
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_lastButton_clicked(self):
         """
         Private slot to go to the last difference.
@@ -375,8 +421,8 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         """
         Private slot to enable/disable the Compare button.
         """
-        if self.file1Edit.text().isEmpty() or \
-           self.file2Edit.text().isEmpty():
+        if not self.file1Edit.text() or \
+           not self.file2Edit.text():
             self.diffButton.setEnabled(False)
         else:
             self.diffButton.setEnabled(True)
@@ -388,30 +434,30 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         @param lineEdit field for the display of the selected filename
                 (QLineEdit)
         """
-        filename = KQFileDialog.getOpenFileName(\
+        filename = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select file to compare"),
             lineEdit.text(),
-            QString())
+            "")
             
-        if not filename.isEmpty():
+        if filename:
             lineEdit.setText(Utilities.toNativeSeparators(filename))
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_file1Button_clicked(self):
         """
         Private slot to handle the file 1 file selection button press.
         """
         self.__selectFile(self.file1Edit)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_file2Button_clicked(self):
         """
         Private slot to handle the file 2 file selection button press.
         """
         self.__selectFile(self.file2Edit)
 
-    @pyqtSignature("bool")
+    @pyqtSlot(bool)
     def on_synchronizeCheckBox_toggled(self, sync):
         """
         Private slot to connect or disconnect the scrollbars of the displays.
@@ -420,29 +466,30 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         """
         if sync:
             self.hsb2.setValue(self.hsb1.value())
-            self.connect(self.hsb1, SIGNAL('valueChanged(int)'),
-                self.hsb2, SLOT('setValue(int)'))
-            self.connect(self.hsb2, SIGNAL('valueChanged(int)'),
-                self.hsb1, SLOT('setValue(int)'))
+            self.hsb1.valueChanged.connect(self.hsb2.setValue)
+            self.hsb2.valueChanged.connect(self.hsb1.setValue)
         else:
-            self.disconnect(self.hsb1, SIGNAL('valueChanged(int)'),
-                self.hsb2, SLOT('setValue(int)'))
-            self.disconnect(self.hsb2, SIGNAL('valueChanged(int)'),
-                self.hsb1, SLOT('setValue(int)'))
+            self.hsb1.valueChanged.disconnect(self.hsb2.setValue)
+            self.hsb2.valueChanged.disconnect(self.hsb1.setValue)
 
-class CompareWindow(KQMainWindow):
+
+class CompareWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, files = [], parent = None):
+    def __init__(self, files=[], parent=None):
         """
         Constructor
         
-        @param files list of files to compare and their label 
+        @param files list of files to compare and their label
             (list of two tuples of two strings)
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
+        
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
         self.cw = CompareDialog(files, self)
         self.cw.installEventFilter(self)
         size = self.cw.size()
@@ -461,4 +508,4 @@ class CompareWindow(KQMainWindow):
             QApplication.exit()
             return True
         
-        return False
\ No newline at end of file
+        return False
