@@ -9,7 +9,7 @@ Module implementing a dialog to confirm deletion of multiple files.
 
 from PyQt4.QtGui import QDialog, QDialogButtonBox
 
-from Ui_DeleteFilesConfirmationDialog import Ui_DeleteFilesConfirmationDialog
+from .Ui_DeleteFilesConfirmationDialog import Ui_DeleteFilesConfirmationDialog
 
 
 class DeleteFilesConfirmationDialog(QDialog, Ui_DeleteFilesConfirmationDialog):
@@ -21,14 +21,11 @@ class DeleteFilesConfirmationDialog(QDialog, Ui_DeleteFilesConfirmationDialog):
         Constructor
         
         @param parent parent of this dialog (QWidget)
-        @param caption window title for the dialog (string or QString)
-        @param message message to be shown (string or QString)
-        @param okLabel label for the OK button (string or QString)
-        @param cancelLabel label for the Cancel button (string or QString)
-        @param files list of filenames to be shown (list of strings or QStrings
-            or a QStringList)
+        @param caption window title for the dialog (string)
+        @param message message to be shown (string)
+        @param files list of filenames to be shown (list of strings)
         """
-        QDialog.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         self.setModal(True)
         
@@ -39,8 +36,7 @@ class DeleteFilesConfirmationDialog(QDialog, Ui_DeleteFilesConfirmationDialog):
         self.setWindowTitle(caption)
         self.message.setText(message)
         
-        for file_ in files:
-            self.filesList.addItem(file_)
+        self.filesList.addItems(files)
 
     def on_buttonBox_clicked(self, button):
         """
