@@ -8,24 +8,27 @@ Module implementing a dialog to compare two files.
 """
 
 import os
-import sys
 import time
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QFileInfo, QEvent, pyqtSlot
+from PyQt4.QtGui import QWidget, QColor, QBrush, QApplication, QTextCursor, \
+    QDialogButtonBox
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQMainWindow import KQMainWindow
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5MainWindow import E5MainWindow
 
-from E4Gui.E4Completers import E4FileCompleter
+from .Ui_DiffDialog import Ui_DiffDialog
 
-from Ui_DiffDialog import Ui_DiffDialog
 import Utilities
+import Preferences
 
 from difflib import SequenceMatcher
 
 # This function is copied from python 2.3 and slightly modified.
 # The header lines contain a tab after the filename.
+
+
 def unified_diff(a, b, fromfile='', tofile='', fromfiledate='',
                  tofiledate='', n=3, lineterm='\n'):
     """
@@ -79,13 +82,14 @@ def unified_diff(a, b, fromfile='', tofile='', fromfiledate='',
     @return a generator yielding lines of differences
     """
     started = False
-    for group in SequenceMatcher(None,a,b).get_grouped_opcodes(n):
+    for group in SequenceMatcher(None, a, b).get_grouped_opcodes(n):
         if not started:
-            yield '--- %s\t%s%s' % (fromfile, fromfiledate, lineterm)
-            yield '+++ %s\t%s%s' % (tofile, tofiledate, lineterm)
+            yield '--- {0}\t{1}{2}'.format(fromfile, fromfiledate, lineterm)
+            yield '+++ {0}\t{1}{2}'.format(tofile, tofiledate, lineterm)
             started = True
         i1, i2, j1, j2 = group[0][1], group[-1][2], group[0][3], group[-1][4]
-        yield "@@ -%d,%d +%d,%d @@%s" % (i1+1, i2-i1, j1+1, j2-j1, lineterm)
+        yield "@@ -{0:d},{1:d} +{2:d},{3:d} @@{4}".format(
+            i1 + 1, i2 - i1, j1 + 1, j2 - j1, lineterm)
         for tag, i1, i2, j1, j2 in group:
             if tag == 'equal':
                 for line in a[i1:i2]:
@@ -100,9 +104,11 @@ def unified_diff(a, b, fromfile='', tofile='', fromfiledate='',
 
 # This function is copied from python 2.3 and slightly modified.
 # The header lines contain a tab after the filename.
+
+
 def context_diff(a, b, fromfile='', tofile='',
                  fromfiledate='', tofiledate='', n=3, lineterm='\n'):
-    """
+    r"""
     Compare two sequences of lines; generate the delta as a context diff.
 
     Context diffs are a compact way of showing line changes and a few
@@ -127,7 +133,8 @@ def context_diff(a, b, fromfile='', tofile='',
     Example:
 
     <pre>
-    &gt;&gt;&gt; print ''.join(context_diff('one\ntwo\nthree\nfour\n'.splitlines(1),
+    &gt;&gt;&gt; print ''.join(
+    ...       context_diff('one\ntwo\nthree\nfour\n'.splitlines(1),
     ...       'zero\none\ntree\nfour\n'.splitlines(1), 'Original', 'Current',
     ...       'Sat Jan 26 23:30:50 1991', 'Fri Jun 06 10:22:46 2003')),
     *** Original Sat Jan 26 23:30:50 1991
@@ -155,20 +162,21 @@ def context_diff(a, b, fromfile='', tofile='',
     @param lineterm line termination string (string)
     @return a generator yielding lines of differences
     """
-
     started = False
-    prefixmap = {'insert':'+ ', 'delete':'- ', 'replace':'! ', 'equal':'  '}
-    for group in SequenceMatcher(None,a,b).get_grouped_opcodes(n):
+    prefixmap = {'insert': '+ ', 'delete': '- ', 'replace': '! ',
+                 'equal': '  '}
+    for group in SequenceMatcher(None, a, b).get_grouped_opcodes(n):
         if not started:
-            yield '*** %s\t%s%s' % (fromfile, fromfiledate, lineterm)
-            yield '--- %s\t%s%s' % (tofile, tofiledate, lineterm)
+            yield '*** {0}\t{1}{2}'.format(fromfile, fromfiledate, lineterm)
+            yield '--- {0}\t{1}{2}'.format(tofile, tofiledate, lineterm)
             started = True
 
-        yield '***************%s' % (lineterm,)
+        yield '***************{0}'.format(lineterm)
         if group[-1][2] - group[0][1] >= 2:
-            yield '*** %d,%d ****%s' % (group[0][1]+1, group[-1][2], lineterm)
+            yield '*** {0:d},{1:d} ****{2}'.format(
+                group[0][1] + 1, group[-1][2], lineterm)
         else:
-            yield '*** %d ****%s' % (group[-1][2], lineterm)
+            yield '*** {0:d} ****{1}'.format(group[-1][2], lineterm)
         visiblechanges = [e for e in group if e[0] in ('replace', 'delete')]
         if visiblechanges:
             for tag, i1, i2, _, _ in group:
@@ -177,9 +185,10 @@ def context_diff(a, b, fromfile='', tofile='',
                         yield prefixmap[tag] + line
 
         if group[-1][4] - group[0][3] >= 2:
-            yield '--- %d,%d ----%s' % (group[0][3]+1, group[-1][4], lineterm)
+            yield '--- {0:d},{1:d} ----{2}'.format(
+                group[0][3] + 1, group[-1][4], lineterm)
         else:
-            yield '--- %d ----%s' % (group[-1][4], lineterm)
+            yield '--- {0:d} ----{1}'.format(group[-1][4], lineterm)
         visiblechanges = [e for e in group if e[0] in ('replace', 'insert')]
         if visiblechanges:
             for tag, _, _, j1, j2 in group:
@@ -187,27 +196,31 @@ def context_diff(a, b, fromfile='', tofile='',
                     for line in b[j1:j2]:
                         yield prefixmap[tag] + line
 
+
 class DiffDialog(QWidget, Ui_DiffDialog):
     """
     Class implementing a dialog to compare two files.
     """
-    def __init__(self,parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
+        
+        @param parent reference to the parent widget (QWidget)
         """
-        QWidget.__init__(self,parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.file1Completer = E4FileCompleter(self.file1Edit)
-        self.file2Completer = E4FileCompleter(self.file2Edit)
+        self.file1Completer = E5FileCompleter(self.file1Edit)
+        self.file2Completer = E5FileCompleter(self.file2Edit)
         
-        self.diffButton = \
-            self.buttonBox.addButton(self.trUtf8("Compare"), QDialogButtonBox.ActionRole)
-        self.diffButton.setToolTip(\
+        self.diffButton = self.buttonBox.addButton(
+            self.trUtf8("Compare"), QDialogButtonBox.ActionRole)
+        self.diffButton.setToolTip(
             self.trUtf8("Press to perform the comparison of the two files"))
-        self.saveButton = \
-            self.buttonBox.addButton(self.trUtf8("Save"), QDialogButtonBox.ActionRole)
-        self.saveButton.setToolTip(self.trUtf8("Save the output to a patch file"))
+        self.saveButton = self.buttonBox.addButton(
+            self.trUtf8("Save"), QDialogButtonBox.ActionRole)
+        self.saveButton.setToolTip(
+            self.trUtf8("Save the output to a patch file"))
         self.diffButton.setEnabled(False)
         self.saveButton.setEnabled(False)
         self.diffButton.setDefault(True)
@@ -217,10 +230,9 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         
         self.updateInterval = 20    # update every 20 lines
         
-        if Utilities.isWindowsPlatform():
-            self.contents.setFontFamily("Lucida Console")
-        else:
-            self.contents.setFontFamily("Monospace")
+        font = Preferences.getEditorOtherFonts("MonospacedFont")
+        self.contents.setFontFamily(font.family())
+        self.contents.setFontPointSize(font.pointSize())
         
         self.cNormalFormat = self.contents.currentCharFormat()
         self.cAddedFormat = self.contents.currentCharFormat()
@@ -233,20 +245,18 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         self.cLineNoFormat.setBackground(QBrush(QColor(255, 220, 168)))
         
         # connect some of our widgets explicitly
-        self.connect(self.file1Edit, SIGNAL("textChanged(const QString &)"), 
-                     self.__fileChanged)
-        self.connect(self.file2Edit, SIGNAL("textChanged(const QString &)"), 
-                     self.__fileChanged)
+        self.file1Edit.textChanged.connect(self.__fileChanged)
+        self.file2Edit.textChanged.connect(self.__fileChanged)
         
-    def show(self, filename = None):
+    def show(self, filename=None):
         """
         Public slot to show the dialog.
         
-        @param filename name of a file to use as the first file (string or QString)
+        @param filename name of a file to use as the first file (string)
         """
         if filename:
             self.file1Edit.setText(filename)
-        QWidget.show(self)
+        super().show()
         
     def on_buttonBox_clicked(self, button):
         """
@@ -259,7 +269,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         elif button == self.saveButton:
             self.on_saveButton_clicked()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_saveButton_clicked(self):
         """
         Private slot to handle the Save button press.
@@ -269,100 +279,104 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         """
         dname, fname = Utilities.splitPath(self.filename2)
         if fname != '.':
-            fname = "%s.diff" % self.filename2
+            fname = "{0}.diff".format(self.filename2)
         else:
             fname = dname
             
-        selectedFilter = QString("")
-        fname = KQFileDialog.getSaveFileName(\
+        fname, selectedFilter = E5FileDialog.getSaveFileNameAndFilter(
             self,
             self.trUtf8("Save Diff"),
             fname,
             self.trUtf8("Patch Files (*.diff)"),
-            selectedFilter,
-            QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
+            None,
+            E5FileDialog.Options(E5FileDialog.DontConfirmOverwrite))
         
-        if fname.isEmpty():
+        if not fname:
             return
-            
+        
         ext = QFileInfo(fname).suffix()
-        if ext.isEmpty():
-            ex = selectedFilter.section('(*',1,1).section(')',0,0)
-            if not ex.isEmpty():
-                fname.append(ex)
+        if not ext:
+            ex = selectedFilter.split("(*")[1].split(")")[0]
+            if ex:
+                fname += ex
         if QFileInfo(fname).exists():
-            res = KQMessageBox.warning(self,
+            res = E5MessageBox.yesNo(
+                self,
                 self.trUtf8("Save Diff"),
-                self.trUtf8("<p>The patch file <b>%1</b> already exists.</p>")
-                    .arg(fname),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.Abort | \
-                    QMessageBox.Save),
-                QMessageBox.Abort)
-            if res != QMessageBox.Save:
+                self.trUtf8("<p>The patch file <b>{0}</b> already exists."
+                            " Overwrite it?</p>").format(fname),
+                icon=E5MessageBox.Warning)
+            if not res:
                 return
-        fname = unicode(Utilities.toNativeSeparators(fname))
+        fname = Utilities.toNativeSeparators(fname)
         
         try:
-            f = open(fname, "wb")
+            f = open(fname, "w", encoding="utf-8")
             txt = self.contents.toPlainText()
             try:
-                f.write(unicode(txt))
+                f.write(txt)
             except UnicodeError:
                 pass
             f.close()
-        except IOError, why:
-            KQMessageBox.critical(self, self.trUtf8('Save Diff'),
-                self.trUtf8('<p>The patch file <b>%1</b> could not be saved.<br />'
-                            'Reason: %2</p>')
-                    .arg(unicode(fname)).arg(str(why)))
+        except IOError as why:
+            E5MessageBox.critical(
+                self, self.trUtf8('Save Diff'),
+                self.trUtf8(
+                    '<p>The patch file <b>{0}</b> could not be saved.<br />'
+                    'Reason: {1}</p>').format(fname, str(why)))
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_diffButton_clicked(self):
         """
         Private slot to handle the Compare button press.
         """
-        self.filename1 = unicode(Utilities.toNativeSeparators(self.file1Edit.text()))
+        self.filename1 = Utilities.toNativeSeparators(self.file1Edit.text())
         try:
             filemtime1 = time.ctime(os.stat(self.filename1).st_mtime)
         except IOError:
             filemtime1 = ""
         try:
-            f1 = open(self.filename1, "rb")
+            f1 = open(self.filename1, "r", encoding="utf-8")
             lines1 = f1.readlines()
             f1.close()
         except IOError:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Compare Files"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be read.</p>""")
-                    .arg(self.filename1))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be read.</p>""")
+                .format(self.filename1))
             return
 
-        self.filename2 = unicode(Utilities.toNativeSeparators(self.file2Edit.text()))
+        self.filename2 = Utilities.toNativeSeparators(self.file2Edit.text())
         try:
             filemtime2 = time.ctime(os.stat(self.filename2).st_mtime)
         except IOError:
             filemtime2 = ""
         try:
-            f2 = open(self.filename2, "rb")
+            f2 = open(self.filename2, "r", encoding="utf-8")
             lines2 = f2.readlines()
             f2.close()
         except IOError:
-            KQMessageBox.critical(self,
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Compare Files"),
-                self.trUtf8("""<p>The file <b>%1</b> could not be read.</p>""")
-                    .arg(self.filename2))
+                self.trUtf8(
+                    """<p>The file <b>{0}</b> could not be read.</p>""")
+                .format(self.filename2))
             return
         
         self.contents.clear()
         self.saveButton.setEnabled(False)
         
         if self.unifiedRadioButton.isChecked():
-            self.__generateUnifiedDiff(lines1, lines2, self.filename1, self.filename2,
-                                filemtime1, filemtime2)
+            self.__generateUnifiedDiff(
+                lines1, lines2, self.filename1, self.filename2,
+                filemtime1, filemtime2)
         else:
-            self.__generateContextDiff(lines1, lines2, self.filename1, self.filename2,
-                                filemtime1, filemtime2)
+            self.__generateContextDiff(
+                lines1, lines2, self.filename1, self.filename2,
+                filemtime1, filemtime2)
         
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.Start)
@@ -375,7 +389,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         """
         Private method to append text to the end of the contents pane.
         
-        @param txt text to insert (QString)
+        @param txt text to insert (string)
         @param format text format to be used (QTextCharFormat)
         """
         tc = self.contents.textCursor()
@@ -385,7 +399,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         self.contents.insertPlainText(txt)
         
     def __generateUnifiedDiff(self, a, b, fromfile, tofile,
-                            fromfiledate, tofiledate):
+                              fromfiledate, tofiledate):
         """
         Private slot to generate a unified diff output.
         
@@ -398,7 +412,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         """
         paras = 0
         for line in unified_diff(a, b, fromfile, tofile,
-                            fromfiledate, tofiledate):
+                                 fromfiledate, tofiledate):
             if line.startswith('+') or line.startswith('>'):
                 format = self.cAddedFormat
             elif line.startswith('-') or line.startswith('<'):
@@ -413,10 +427,11 @@ class DiffDialog(QWidget, Ui_DiffDialog):
                 QApplication.processEvents()
             
         if paras == 0:
-            self.__appendText(self.trUtf8('There is no difference.'), self.cNormalFormat)
+            self.__appendText(
+                self.trUtf8('There is no difference.'), self.cNormalFormat)
 
     def __generateContextDiff(self, a, b, fromfile, tofile,
-                            fromfiledate, tofiledate):
+                              fromfiledate, tofiledate):
         """
         Private slot to generate a context diff output.
         
@@ -429,14 +444,15 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         """
         paras = 0
         for line in context_diff(a, b, fromfile, tofile,
-                            fromfiledate, tofiledate):
+                                 fromfiledate, tofiledate):
             if line.startswith('+ '):
                 format = self.cAddedFormat
             elif line.startswith('- '):
                 format = self.cRemovedFormat
             elif line.startswith('! '):
                 format = self.cReplacedFormat
-            elif (line.startswith('*** ') or line.startswith('--- ')) and paras > 1:
+            elif (line.startswith('*** ') or line.startswith('--- ')) and \
+                    paras > 1:
                 format = self.cLineNoFormat
             else:
                 format = self.cNormalFormat
@@ -446,14 +462,15 @@ class DiffDialog(QWidget, Ui_DiffDialog):
                 QApplication.processEvents()
             
         if paras == 0:
-            self.__appendText(self.trUtf8('There is no difference.'), self.cNormalFormat)
+            self.__appendText(
+                self.trUtf8('There is no difference.'), self.cNormalFormat)
 
     def __fileChanged(self):
         """
         Private slot to enable/disable the Compare button.
         """
-        if self.file1Edit.text().isEmpty() or \
-           self.file2Edit.text().isEmpty():
+        if not self.file1Edit.text() or \
+           not self.file2Edit.text():
             self.diffButton.setEnabled(False)
         else:
             self.diffButton.setEnabled(True)
@@ -465,40 +482,45 @@ class DiffDialog(QWidget, Ui_DiffDialog):
         @param lineEdit field for the display of the selected filename
                 (QLineEdit)
         """
-        filename = KQFileDialog.getOpenFileName(\
+        filename = E5FileDialog.getOpenFileName(
             self,
             self.trUtf8("Select file to compare"),
             lineEdit.text(),
-            QString())
+            "")
             
-        if not filename.isEmpty():
+        if filename:
             lineEdit.setText(Utilities.toNativeSeparators(filename))
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_file1Button_clicked(self):
         """
         Private slot to handle the file 1 file selection button press.
         """
         self.__selectFile(self.file1Edit)
 
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_file2Button_clicked(self):
         """
         Private slot to handle the file 2 file selection button press.
         """
         self.__selectFile(self.file2Edit)
 
-class DiffWindow(KQMainWindow):
+
+class DiffWindow(E5MainWindow):
     """
     Main window class for the standalone dialog.
     """
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         """
         Constructor
         
         @param parent reference to the parent widget (QWidget)
         """
-        KQMainWindow.__init__(self, parent)
+        super().__init__(parent)
+        
+        self.setStyle(Preferences.getUI("Style"),
+                      Preferences.getUI("StyleSheet"))
+        
         self.cw = DiffDialog(self)
         self.cw.installEventFilter(self)
         size = self.cw.size()
