@@ -10,56 +10,62 @@ Module implementing a dialog to search for text in files.
 import os
 import re
 
-import sys
+from PyQt4.QtCore import pyqtSignal, Qt, pyqtSlot
+from PyQt4.QtGui import QCursor, QDialog, QApplication, QMenu, \
+    QDialogButtonBox, QTreeWidgetItem
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from E5Gui.E5Application import e5App
+from E5Gui import E5MessageBox, E5FileDialog
 
-from KdeQt import KQFileDialog, KQMessageBox
-from KdeQt.KQApplication import e4App
-
-from Ui_FindFileDialog import Ui_FindFileDialog
+from .Ui_FindFileDialog import Ui_FindFileDialog
 
 import Utilities
 import Preferences
 
+
 class FindFileDialog(QDialog, Ui_FindFileDialog):
     """
     Class implementing a dialog to search for text in files.
     
-    The occurrences found are displayed in a QTreeWidget showing the filename, the 
-    linenumber and the found text. The file will be opened upon a double click onto 
-    the respective entry of the list.
+    The occurrences found are displayed in a QTreeWidget showing the filename,
+    the linenumber and the found text. The file will be opened upon a double
+    click onto the respective entry of the list.
     
-    @signal sourceFile(string, int, string, (int, int)) emitted to open a 
-        source file at a line
-    @signal designerFile(string) emitted to open a Qt-Designer file
+    @signal sourceFile(str, int, str, int, int) emitted to open a source file
+        at a line
+    @signal designerFile(str) emitted to open a Qt-Designer file
     """
-    lineRole    = Qt.UserRole + 1
-    startRole   = Qt.UserRole + 2
-    endRole     = Qt.UserRole + 3
-    replaceRole = Qt.UserRole + 4
-    md5Role     = Qt.UserRole + 5
+    sourceFile = pyqtSignal(str, int, str, int, int)
+    designerFile = pyqtSignal(str)
     
-    def __init__(self, project, replaceMode = False, parent=None):
+    lineRole = Qt.UserRole + 1
+    startRole = Qt.UserRole + 2
+    endRole = Qt.UserRole + 3
+    replaceRole = Qt.UserRole + 4
+    md5Role = Qt.UserRole + 5
+    
+    def __init__(self, project, replaceMode=False, parent=None):
         """
         Constructor
         
         @param project reference to the project object
+        @param replaceMode flag indicating the replace dialog mode (boolean)
         @param parent parent widget of this dialog (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         self.setWindowFlags(Qt.WindowFlags(Qt.Window))
         
         self.__replaceMode = replaceMode
         
         self.stopButton = \
-            self.buttonBox.addButton(self.trUtf8("Stop"), QDialogButtonBox.ActionRole)
+            self.buttonBox.addButton(self.trUtf8("Stop"),
+                                     QDialogButtonBox.ActionRole)
         self.stopButton.setEnabled(False)
         
         self.findButton = \
-            self.buttonBox.addButton(self.trUtf8("Find"), QDialogButtonBox.ActionRole)
+            self.buttonBox.addButton(self.trUtf8("Find"),
+                                     QDialogButtonBox.ActionRole)
         self.findButton.setEnabled(False)
         self.findButton.setDefault(True)
         
@@ -73,12 +79,15 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
         self.findProgressLabel.setMaximumWidth(550)
         
-        self.searchHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/SearchHistory").toStringList()
-        self.replaceHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/ReplaceHistory").toStringList()
-        self.dirHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/DirectoryHistory").toStringList()
+        self.searchHistory = Preferences.toList(
+            Preferences.Prefs.settings.value(
+                "FindFileDialog/SearchHistory"))
+        self.replaceHistory = Preferences.toList(
+            Preferences.Prefs.settings.value(
+                "FindFileDialog/ReplaceHistory"))
+        self.dirHistory = Preferences.toList(
+            Preferences.Prefs.settings.value(
+                "FindFileDialog/DirectoryHistory"))
         self.findtextCombo.addItems(self.searchHistory)
         self.replacetextCombo.addItems(self.replaceHistory)
         self.dirCombo.addItems(self.dirHistory)
@@ -98,8 +107,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             self.findList.setFont(font)
 
         # Qt Designer form files
-        self.filterForms = r'.*\.ui$|.*\.ui\.h$'
-        self.formsExt = ['*.ui', '*.ui.h']
+        self.filterForms = r'.*\.ui$'
+        self.formsExt = ['*.ui']
         
         # Corba interface files
         self.filterInterfaces = r'.*\.idl$'
@@ -114,51 +123,52 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.__populating = False
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"), 
-                     self.__contextMenuRequested)
+        self.customContextMenuRequested.connect(self.__contextMenuRequested)
         
-    def __createItem(self, file, line, text, start, end, replTxt = "", md5 = ""):
+    def __createItem(self, file, line, text, start, end, replTxt="", md5=""):
         """
         Private method to create an entry in the file list.
         
-        @param file filename of file (string or QString)
+        @param file filename of file (string)
         @param line line number (integer)
-        @param text text found (string or QString)
+        @param text text found (string)
         @param start start position of match (integer)
         @param end end position of match (integer)
-        @param replTxt text with replacements applied (string or QString)
-        @param md5 MD5 hash of the file (string or QString)
+        @param replTxt text with replacements applied (string)
+        @keyparam md5 MD5 hash of the file (string)
         """
         if self.__lastFileItem is None:
             # It's a new file
-            self.__lastFileItem = QTreeWidgetItem(self.findList, QStringList(file))
+            self.__lastFileItem = QTreeWidgetItem(self.findList, [file])
             self.__lastFileItem.setFirstColumnSpanned(True)
             self.__lastFileItem.setExpanded(True)
             if self.__replaceMode:
-                self.__lastFileItem.setFlags(self.__lastFileItem.flags() | \
+                self.__lastFileItem.setFlags(
+                    self.__lastFileItem.flags() |
                     Qt.ItemFlags(Qt.ItemIsUserCheckable | Qt.ItemIsTristate))
-                # Qt bug: 
-                # item is not user checkable if setFirstColumnSpanned is True (< 4.5.0)
-            self.__lastFileItem.setData(0, self.md5Role, QVariant(md5))
+                # Qt bug:
+                # item is not user checkable if setFirstColumnSpanned
+                # is True (< 4.5.0)
+            self.__lastFileItem.setData(0, self.md5Role, md5)
         
         itm = QTreeWidgetItem(self.__lastFileItem)
         itm.setTextAlignment(0,  Qt.AlignRight)
         itm.setData(0, Qt.DisplayRole, line)
         itm.setData(1, Qt.DisplayRole, text)
-        itm.setData(0, self.lineRole, QVariant(line))
-        itm.setData(0, self.startRole, QVariant(start))
-        itm.setData(0, self.endRole, QVariant(end))
-        itm.setData(0, self.replaceRole, QVariant(replTxt))
+        itm.setData(0, self.lineRole, line)
+        itm.setData(0, self.startRole, start)
+        itm.setData(0, self.endRole, end)
+        itm.setData(0, self.replaceRole, replTxt)
         if self.__replaceMode:
             itm.setFlags(itm.flags() | Qt.ItemFlags(Qt.ItemIsUserCheckable))
             itm.setCheckState(0, Qt.Checked)
             self.replaceButton.setEnabled(True)
         
-    def show(self, txt = ""):
+    def show(self, txt=""):
         """
         Overwritten method to enable/disable the project button.
         
-        @param txt text to be shown in the searchtext combo (string or QString)
+        @param txt text to be shown in the searchtext combo (string)
         """
         if self.project and self.project.isOpen():
             self.projectButton.setEnabled(True)
@@ -174,11 +184,12 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             self.findList.clear()
             self.replacetextCombo.setEditText("")
         
-        QDialog.show(self)
+        super().show()
         
     def on_findtextCombo_editTextChanged(self, text):
         """
-        Private slot to handle the editTextChanged signal of the find text combo.
+        Private slot to handle the editTextChanged signal of the find
+        text combo.
         
         @param text (ignored)
         """
@@ -186,7 +197,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
     def on_replacetextCombo_editTextChanged(self, text):
         """
-        Private slot to handle the editTextChanged signal of the replace text combo.
+        Private slot to handle the editTextChanged signal of the replace
+        text combo.
         
         @param text (ignored)
         """
@@ -194,35 +206,36 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
     def on_dirCombo_editTextChanged(self, text):
         """
-        Private slot to handle the textChanged signal of the directory combo box.
+        Private slot to handle the textChanged signal of the directory
+        combo box.
         
         @param text (ignored)
         """
         self.__enableFindButton()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_projectButton_clicked(self):
         """
         Private slot to handle the selection of the project radio button.
         """
         self.__enableFindButton()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_dirButton_clicked(self):
         """
         Private slot to handle the selection of the project radio button.
         """
         self.__enableFindButton()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_filterCheckBox_clicked(self):
         """
         Private slot to handle the selection of the file filter check box.
         """
         self.__enableFindButton()
         
-    @pyqtSignature("QString")
-    def on_filterEdit_textEdited(self, p0):
+    @pyqtSlot(str)
+    def on_filterEdit_textEdited(self, text):
         """
         Private slot to handle the textChanged signal of the file filter edit.
         
@@ -234,13 +247,14 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         Private slot called to enable the find button.
         """
-        if self.findtextCombo.currentText().isEmpty() or \
-           (self.__replaceMode and self.replacetextCombo.currentText().isEmpty()) or \
-           (self.dirButton.isChecked() and \
-            (self.dirCombo.currentText().isEmpty() or \
-             not os.path.exists(
-                os.path.abspath(unicode(self.dirCombo.currentText()))))) or \
-           (self.filterCheckBox.isChecked() and self.filterEdit.text().isEmpty()):
+        if self.findtextCombo.currentText() == "" or \
+           (self.__replaceMode and
+            self.replacetextCombo.currentText() == "") or \
+           (self.dirButton.isChecked() and
+            (self.dirCombo.currentText() == "" or
+             not os.path.exists(os.path.abspath(
+                self.dirCombo.currentText())))) or \
+           (self.filterCheckBox.isChecked() and self.filterEdit.text() == ""):
             self.findButton.setEnabled(False)
             self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         else:
@@ -277,32 +291,31 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         Private slot to handle the find button being pressed.
         """
-        if self.__replaceMode and not e4App().getObject("ViewManager").checkAllDirty():
+        if self.__replaceMode and \
+           not e5App().getObject("ViewManager").checkAllDirty():
             return
         
         self.__cancelSearch = False
-        self.stopButton.setEnabled(True)
-        self.stopButton.setDefault(True)
-        self.findButton.setEnabled(False)
         
         if self.filterCheckBox.isChecked():
-            fileFilter = unicode(self.filterEdit.text())
-            fileFilterList = ["^%s$" % filter.replace(".", "\.").replace("*", ".*") \
-                              for filter in fileFilter.split(";")]
+            fileFilter = self.filterEdit.text()
+            fileFilterList = \
+                ["^{0}$".format(filter.replace(".", "\.").replace("*", ".*"))
+                 for filter in fileFilter.split(";")]
             filterRe = re.compile("|".join(fileFilterList))
         
         if self.projectButton.isChecked():
             if self.filterCheckBox.isChecked():
-                files = [self.project.getRelativePath(file) \
-                         for file in \
-                         self.__getFileList(self.project.getProjectPath(), filterRe)]
+                files = [self.project.getRelativePath(file)
+                         for file in
+                         self.__getFileList(
+                             self.project.getProjectPath(), filterRe)]
             else:
                 files = []
                 if self.sourcesCheckBox.isChecked():
                     files += self.project.pdata["SOURCES"]
                 if self.formsCheckBox.isChecked():
-                    files += self.project.pdata["FORMS"] + \
-                              ['%s.h' % f for f in self.project.pdata["FORMS"]]
+                    files += self.project.pdata["FORMS"]
                 if self.interfacesCheckBox.isChecked():
                     files += self.project.pdata["INTERFACES"]
                 if self.resourcesCheckBox.isChecked():
@@ -312,8 +325,10 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 filters = []
                 if self.sourcesCheckBox.isChecked():
                     filters.extend(
-                        ["^%s$" % assoc.replace(".", "\.").replace("*", ".*") \
-                         for assoc in Preferences.getEditorLexerAssocs().keys() \
+                        ["^{0}$".format(
+                            assoc.replace(".", "\.").replace("*", ".*"))
+                         for assoc in list(
+                             Preferences.getEditorLexerAssocs().keys())
                          if assoc not in self.formsExt + self.interfacesExt])
                 if self.formsCheckBox.isChecked():
                     filters.append(self.filterForms)
@@ -324,9 +339,12 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 filterString = "|".join(filters)
                 filterRe = re.compile(filterString)
             files = self.__getFileList(
-                os.path.abspath(unicode(self.dirCombo.currentText())), filterRe)
+                os.path.abspath(self.dirCombo.currentText()),
+                filterRe)
         elif self.openFilesButton.isChecked():
-            files = e4App().getObject("ViewManager").getOpenFilenames()
+            vm = e5App().getObject("ViewManager")
+            vm.checkAllDirty()
+            files = vm.getOpenFilenames()
         
         self.findList.clear()
         QApplication.processEvents()
@@ -334,56 +352,67 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.findProgress.setMaximum(len(files))
         
         # retrieve the values
-        reg = self.regexpCheckBox.isChecked() 
+        reg = self.regexpCheckBox.isChecked()
         wo = self.wordCheckBox.isChecked()
         cs = self.caseCheckBox.isChecked()
-        ct = unicode(self.findtextCombo.currentText())
+        ct = self.findtextCombo.currentText()
         if reg:
             txt = ct
         else:
             txt = re.escape(ct)
         if wo:
-            txt = "\\b%s\\b" % txt
+            txt = "\\b{0}\\b".format(txt)
         flags = re.UNICODE | re.LOCALE
         if not cs:
             flags |= re.IGNORECASE
         try:
             search = re.compile(txt, flags)
-        except re.error, why:
-            QMessageBox.critical(None,
+        except re.error as why:
+            E5MessageBox.critical(
+                self,
                 self.trUtf8("Invalid search expression"),
                 self.trUtf8("""<p>The search expression is not valid.</p>"""
-                            """<p>Error: %1</p>""").arg(str(why)))
+                            """<p>Error: {0}</p>""").format(str(why)))
             self.stopButton.setEnabled(False)
             self.findButton.setEnabled(True)
             self.findButton.setDefault(True)
             return
-        
         # reset the findtextCombo
-        self.searchHistory.removeAll(ct)
-        self.searchHistory.prepend(ct)
+        if ct in self.searchHistory:
+            self.searchHistory.remove(ct)
+        self.searchHistory.insert(0, ct)
         self.findtextCombo.clear()
         self.findtextCombo.addItems(self.searchHistory)
-        Preferences.Prefs.settings.setValue("FindFileDialog/SearchHistory", 
-                                            self.searchHistory[:30])
+        Preferences.Prefs.settings.setValue(
+            "FindFileDialog/SearchHistory",
+            self.searchHistory[:30])
         
         if self.__replaceMode:
-            replTxt = unicode(self.replacetextCombo.currentText())
-            self.replaceHistory.removeAll(replTxt)
-            self.replaceHistory.prepend(replTxt)
+            replTxt = self.replacetextCombo.currentText()
+            if replTxt in self.replaceHistory:
+                self.replaceHistory.remove(replTxt)
+            self.replaceHistory.insert(0, replTxt)
             self.replacetextCombo.clear()
             self.replacetextCombo.addItems(self.replaceHistory)
-            Preferences.Prefs.settings.setValue("FindFileDialog/ReplaceHistory", 
-                                                self.replaceHistory[:30])
+            Preferences.Prefs.settings.setValue(
+                "FindFileDialog/ReplaceHistory",
+                self.replaceHistory[:30])
         
         if self.dirButton.isChecked():
             searchDir = self.dirCombo.currentText()
-            self.dirHistory.removeAll(searchDir)
+            if searchDir in self.dirHistory:
+                self.dirHistory.remove(searchDir)
             self.dirHistory.insert(0, searchDir)
             self.dirCombo.clear()
             self.dirCombo.addItems(self.dirHistory)
-            Preferences.Prefs.settings.setValue("FindFileDialog/DirectoryHistory", 
-                                                self.dirHistory[:30])
+            Preferences.Prefs.settings.setValue(
+                "FindFileDialog/DirectoryHistory",
+                self.dirHistory[:30])
+        
+        # set the button states
+        self.stopButton.setEnabled(True)
+        self.stopButton.setDefault(True)
+        self.findButton.setEnabled(False)
         
         # now go through all the files
         self.__populating = True
@@ -403,11 +432,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 fn = file
             # read the file and split it into textlines
             try:
-                f = open(fn, 'rb')
-                text, encoding, hash = Utilities.decodeWithHash(f.read())
+                text, encoding, hash = Utilities.readEncodedFileWithHash(fn)
                 lines = text.splitlines(True)
-                f.close()
-            except IOError:
+            except (UnicodeError, IOError):
                 progress += 1
                 self.findProgress.setValue(progress)
                 continue
@@ -429,17 +456,18 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         rline = ""
                     line = self.__stripEol(line)
                     if len(line) > 1024:
-                        line = "%s ..." % line[:1024]
+                        line = "{0} ...".format(line[:1024])
                     if self.__replaceMode:
                         if len(rline) > 1024:
-                            rline = "%s ..." % line[:1024]
-                        line = "- %s\n+ %s" % (
+                            rline = "{0} ...".format(line[:1024])
+                        line = "- {0}\n+ {1}".format(
                             line, self.__stripEol(rline))
-                    self.__createItem(file, count, line, start, end, rline, hash)
+                    self.__createItem(file, count, line, start, end,
+                                      rline, hash)
                     
                     if self.feelLikeCheckBox.isChecked():
-                        fn = os.path.join(self.project.ppath, unicode(file))
-                        self.emit(SIGNAL('sourceFile'), fn, count, "", (start, end))
+                        fn = os.path.join(self.project.ppath, file)
+                        self.sourceFile.emit(fn, count, "", start, end)
                         QApplication.processEvents()
                         breakSearch = True
                         break
@@ -449,10 +477,14 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             progress += 1
             self.findProgress.setValue(progress)
         
+        if not files:
+            self.findProgress.setMaximum(1)
+            self.findProgress.setValue(1)
+        
         self.findProgressLabel.setPath("")
         
         self.findList.setUpdatesEnabled(True)
-        self.findList.sortItems(self.findList.sortColumn(), 
+        self.findList.sortItems(self.findList.sortColumn(),
                                 self.findList.header().sortIndicatorOrder())
         self.findList.resizeColumnToContents(1)
         if self.__replaceMode:
@@ -469,7 +501,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
     def on_findList_itemDoubleClicked(self, itm, column):
         """
-        Private slot to handle the double click on a file item. 
+        Private slot to handle the double click on a file item.
         
         It emits the signal
         sourceFile or designerFile depending on the file extension.
@@ -479,9 +511,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         if itm.parent():
             file = itm.parent().text(0)
-            line = itm.data(0, self.lineRole).toInt()[0]
-            start = itm.data(0, self.startRole).toInt()[0]
-            end = itm.data(0, self.endRole).toInt()[0]
+            line = itm.data(0, self.lineRole)
+            start = itm.data(0, self.startRole)
+            end = itm.data(0, self.endRole)
         else:
             file = itm.text(0)
             line = 1
@@ -489,29 +521,26 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             end = 0
         
         if self.project:
-            fn = os.path.join(self.project.ppath, unicode(file))
+            fn = os.path.join(self.project.ppath, file)
         else:
-            fn = unicode(file)
+            fn = file
         if fn.endswith('.ui'):
-            self.emit(SIGNAL('designerFile'), fn)
-        elif fn.endswith('.ui.h'):
-            fn = os.path.splitext(unicode(file))[0]
-            self.emit(SIGNAL('designerFile'), fn)
+            self.designerFile.emit(fn)
         else:
-            self.emit(SIGNAL('sourceFile'), fn, line, "", (start, end))
+            self.sourceFile.emit(fn, line, "", start, end)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_dirSelectButton_clicked(self):
         """
         Private slot to display a directory selection dialog.
         """
-        directory = KQFileDialog.getExistingDirectory(\
+        directory = E5FileDialog.getExistingDirectory(
             self,
             self.trUtf8("Select directory"),
             self.dirCombo.currentText(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
             
-        if not directory.isEmpty():
+        if directory:
             self.dirCombo.setEditText(Utilities.toNativeSeparators(directory))
         
     def __getFileList(self, path, filterRe):
@@ -519,28 +548,35 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         Private method to get a list of files to search.
         
         @param path the root directory to search in (string)
-        @param filterRe regular expression defining the filter criteria (regexp object)
+        @param filterRe regular expression defining the filter
+            criteria (regexp object)
         @return list of files to be processed (list of strings)
         """
         path = os.path.abspath(path)
         files = []
         for dirname, _, names in os.walk(path):
-            files.extend([os.path.join(dirname, f) \
-                          for f in names \
+            files.extend([os.path.join(dirname, f)
+                          for f in names
                           if re.match(filterRe, f)]
-            )
+                         )
         return files
         
     def setSearchDirectory(self, searchDir):
         """
         Public slot to set the name of the directory to search in.
         
-        @param searchDir name of the directory to search in (string or QString)
+        @param searchDir name of the directory to search in (string)
         """
         self.dirButton.setChecked(True)
         self.dirCombo.setEditText(Utilities.toNativeSeparators(searchDir))
         
-    @pyqtSignature("")
+    def setOpenFiles(self):
+        """
+        Public slot to set the mode to search in open files.
+        """
+        self.openFilesButton.setChecked(True)
+        
+    @pyqtSlot()
     def on_replaceButton_clicked(self):
         """
         Private slot to perform the requested replace actions.
@@ -552,8 +588,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         for index in range(self.findList.topLevelItemCount()):
             itm = self.findList.topLevelItem(index)
             if itm.checkState(0) in [Qt.PartiallyChecked, Qt.Checked]:
-                file = unicode(itm.text(0))
-                origHash = itm.data(0, self.md5Role).toString()
+                file = itm.text(0)
+                origHash = itm.data(0, self.md5Role)
                 
                 self.findProgressLabel.setPath(file)
                 
@@ -564,16 +600,17 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 
                 # read the file and split it into textlines
                 try:
-                    f = open(fn, 'rb')
-                    text, encoding, hash = Utilities.decodeWithHash(f.read())
+                    text, encoding, hash = \
+                        Utilities.readEncodedFileWithHash(fn)
                     lines = text.splitlines(True)
-                    f.close()
-                except IOError, err:
-                    KQMessageBox.critical(self,
+                except (UnicodeError, IOError) as err:
+                    E5MessageBox.critical(
+                        self,
                         self.trUtf8("Replace in Files"),
-                        self.trUtf8("""<p>Could not read the file <b>%1</b>."""
-                                    """ Skipping it.</p><p>Reason: %2</p>""")\
-                            .arg(fn).arg(str(err))
+                        self.trUtf8(
+                            """<p>Could not read the file <b>{0}</b>."""
+                            """ Skipping it.</p><p>Reason: {1}</p>""")
+                        .format(fn, str(err))
                     )
                     progress += 1
                     self.findProgress.setValue(progress)
@@ -582,12 +619,14 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 # Check the original and the current hash. Skip the file,
                 # if hashes are different.
                 if origHash != hash:
-                    KQMessageBox.critical(self,
+                    E5MessageBox.critical(
+                        self,
                         self.trUtf8("Replace in Files"),
-                        self.trUtf8("""<p>The current and the original hash of the"""
-                                    """ file <b>%1</b> are different. Skipping it."""
-                                    """</p><p>Hash 1: %2</p><p>Hash 2: %3</p>""")\
-                            .arg(fn).arg(origHash).arg(hash)
+                        self.trUtf8(
+                            """<p>The current and the original hash of the"""
+                            """ file <b>{0}</b> are different. Skipping it."""
+                            """</p><p>Hash 1: {1}</p><p>Hash 2: {2}</p>""")
+                        .format(fn, origHash, hash)
                     )
                     progress += 1
                     self.findProgress.setValue(progress)
@@ -597,23 +636,22 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 for cindex in range(itm.childCount()):
                     citm = itm.child(cindex)
                     if citm.checkState(0) == Qt.Checked:
-                        line = citm.data(0, self.lineRole).toInt()[0]
-                        rline = citm.data(0, self.replaceRole).toString()
-                        lines[line - 1] = unicode(rline)
+                        line = citm.data(0, self.lineRole)
+                        rline = citm.data(0, self.replaceRole)
+                        lines[line - 1] = rline
                 
                 # write the file
                 txt = "".join(lines)
-                txt, encoding = Utilities.encode(txt, encoding)
                 try:
-                    f = open(fn, 'wb')
-                    f.write(txt)
-                    f.close()
-                except IOError, err:
-                    KQMessageBox.critical(self,
+                    Utilities.writeEncodedFile(fn, txt, encoding)
+                except (IOError, Utilities.CodingError, UnicodeError) as err:
+                    E5MessageBox.critical(
+                        self,
                         self.trUtf8("Replace in Files"),
-                        self.trUtf8("""<p>Could not save the file <b>%1</b>."""
-                                    """ Skipping it.</p><p>Reason: %2</p>""")\
-                            .arg(fn).arg(str(err))
+                        self.trUtf8(
+                            """<p>Could not save the file <b>{0}</b>."""
+                            """ Skipping it.</p><p>Reason: {1}</p>""")
+                        .format(fn, str(err))
                     )
             
             progress += 1
@@ -635,7 +673,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         menu = QMenu(self)
         
         menu.addAction(self.trUtf8("Open"), self.__openFile)
-        menu.addAction(self.trUtf8("Copy Path to Clipboard"), self.__copyToClipboard)
+        menu.addAction(self.trUtf8("Copy Path to Clipboard"),
+                       self.__copyToClipboard)
         
         menu.exec_(QCursor.pos())
         
