@@ -10,12 +10,14 @@ Module implementing a dialog to search for files.
 import os
 import sys
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import pyqtSignal, pyqtSlot
+from PyQt4.QtGui import QWidget, QHeaderView, QApplication, QDialogButtonBox, \
+    QTreeWidgetItem
 
-from E4Gui.E4Completers import E4DirCompleter
+from E5Gui.E5Completers import E5DirCompleter
+from E5Gui import E5FileDialog
 
-from Ui_FindFileNameDialog import Ui_FindFileNameDialog
+from .Ui_FindFileNameDialog import Ui_FindFileNameDialog
 from Utilities import direntries
 import Utilities
 
@@ -28,28 +30,31 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
     filename and the pathname. The file will be opened upon a double click
     onto the respective entry of the list.
     
-    @signal sourceFile(string) emitted to open a file in the editor
-    @signal designerFile(string) emitted to open a Qt-Designer file
+    @signal sourceFile(str) emitted to open a file in the editor
+    @signal designerFile(str) emitted to open a Qt-Designer file
     """
-    def __init__(self, project, parent = None):
+    sourceFile = pyqtSignal(str)
+    designerFile = pyqtSignal(str)
+    
+    def __init__(self, project, parent=None):
         """
         Constructor
         
         @param project reference to the project object
         @param parent parent widget of this dialog (QWidget)
         """
-        QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.searchDirCompleter = E4DirCompleter(self.searchDirEdit)
+        self.searchDirCompleter = E5DirCompleter(self.searchDirEdit)
         
         self.fileList.headerItem().setText(self.fileList.columnCount(), "")
         
-        self.stopButton = \
-            self.buttonBox.addButton(self.trUtf8("Stop"), QDialogButtonBox.ActionRole)
+        self.stopButton = self.buttonBox.addButton(
+            self.trUtf8("Stop"), QDialogButtonBox.ActionRole)
         self.stopButton.setToolTip(self.trUtf8("Press to stop the search"))
         self.stopButton.setEnabled(False)
-        self.buttonBox.button(QDialogButtonBox.Open).setToolTip(\
+        self.buttonBox.button(QDialogButtonBox.Open).setToolTip(
             self.trUtf8("Opens the selected file"))
         self.buttonBox.button(QDialogButtonBox.Open).setEnabled(False)
         
@@ -71,7 +76,7 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
     
     def __openFile(self, itm=None):
         """
-        Private slot to open a file. 
+        Private slot to open a file.
         
         It emits the signal sourceFile or designerFile depending on the
         file extension.
@@ -81,35 +86,35 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         if itm is None:
             itm = self.fileList.currentItem()
         if itm is not None:
-            fileName = unicode(itm.text(0))
-            filePath = unicode(itm.text(1))
+            fileName = itm.text(0)
+            filePath = itm.text(1)
             
             if fileName.endswith('.ui'):
-                self.emit(SIGNAL('designerFile'), os.path.join(filePath, fileName))
+                self.designerFile.emit(os.path.join(filePath, fileName))
             else:
-                self.emit(SIGNAL('sourceFile'), os.path.join(filePath, fileName))
+                self.sourceFile.emit(os.path.join(filePath, fileName))
 
     def __searchFile(self):
         """
         Private slot to handle the search.
         """
-        fileName = unicode(self.fileNameEdit.text())
+        fileName = self.fileNameEdit.text()
         if not fileName:
             self.fileList.clear()
             return
-        fileExt = unicode(self.fileExtEdit.text())
+        fileExt = self.fileExtEdit.text()
         if not fileExt and Utilities.isWindowsPlatform():
             self.fileList.clear()
             return
         
-        patternFormat = fileExt and "%s%s%s*" or "%s*%s%s"
-        fileNamePattern = patternFormat % (fileName, os.extsep,
-            fileExt and fileExt or '*')
+        patternFormat = fileExt and "{0}{1}{2}" or "{0}*{1}{2}"
+        fileNamePattern = patternFormat.format(
+            fileName, os.extsep, fileExt and fileExt or '*')
         
         searchPaths = []
         if self.searchDirCheckBox.isChecked() and \
-           not self.searchDirEdit.text().isEmpty():
-            searchPaths.append(unicode(self.searchDirEdit.text()))
+           self.searchDirEdit.text() != "":
+            searchPaths.append(self.searchDirEdit.text())
         if self.projectCheckBox.isChecked():
             searchPaths.append(self.project.ppath)
         if self.syspathCheckBox.isChecked():
@@ -124,19 +129,20 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         
         for path in searchPaths:
             if os.path.isdir(path):
-                files = direntries(path, True, fileNamePattern, False, self.checkStop)
+                files = direntries(path, True, fileNamePattern,
+                                   False, self.checkStop)
                 if files:
                     found = True
                     for file in files:
                         fp, fn = os.path.split(file)
-                        if locations.has_key(fn):
+                        if fn in locations:
                             if fp in locations[fn]:
                                 continue
                             else:
                                 locations[fn].append(fp)
                         else:
                             locations[fn] = [fp]
-                        QTreeWidgetItem(self.fileList, QStringList() << fn << fp)
+                        QTreeWidgetItem(self.fileList, [fn, fp])
                     QApplication.processEvents()
             
         del locations
@@ -166,7 +172,8 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         
     def on_fileExtEdit_textChanged(self, text):
         """
-        Private slot to handle the textChanged signal of the file extension edit.
+        Private slot to handle the textChanged signal of the file extension
+        edit.
         
         @param text (ignored)
         """
@@ -174,35 +181,38 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         
     def on_searchDirEdit_textChanged(self, text):
         """
-        Private slot to handle the textChanged signal of the search directory edit.
+        Private slot to handle the textChanged signal of the search directory
+        edit.
         
-        @param text (ignored)
+        @param text text of the search dir edit (string)
         """
-        self.searchDirCheckBox.setEnabled(not text.isEmpty())
+        self.searchDirCheckBox.setEnabled(text != "")
         if self.searchDirCheckBox.isChecked():
             self.__searchFile()
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_searchDirButton_clicked(self):
         """
-        Private slot to handle the clicked signal of the search directory selection button.
+        Private slot to handle the clicked signal of the search directory
+        selection button.
         """
-        searchDir = QFileDialog.getExistingDirectory(\
+        searchDir = E5FileDialog.getExistingDirectory(
             None,
             self.trUtf8("Select search directory"),
             self.searchDirEdit.text(),
-            QFileDialog.Options(QFileDialog.ShowDirsOnly))
+            E5FileDialog.Options(E5FileDialog.ShowDirsOnly))
         
-        if not searchDir.isEmpty():
+        if searchDir:
             self.searchDirEdit.setText(Utilities.toNativeSeparators(searchDir))
         
     def on_searchDirCheckBox_toggled(self, checked):
         """
-        Private slot to handle the toggled signal of the search directory checkbox.
+        Private slot to handle the toggled signal of the search directory
+        checkbox.
         
         @param checked flag indicating the state of the checkbox (boolean)
         """
-        if not self.searchDirEdit.text().isEmpty():
+        if self.searchDirEdit.text():
             self.__searchFile()
         
     def on_projectCheckBox_toggled(self, checked):
@@ -223,7 +233,7 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         
     def on_fileList_itemActivated(self, itm, column):
         """
-        Private slot to handle the double click on a file item. 
+        Private slot to handle the double click on a file item.
         
         It emits the signal sourceFile or designerFile depending on the
         file extension.
@@ -233,6 +243,7 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         """
         self.__openFile(itm)
         
+    @pyqtSlot(QTreeWidgetItem, QTreeWidgetItem)
     def on_fileList_currentItemChanged(self, current, previous):
         """
         Private slot handling a change of the current item.
@@ -240,7 +251,8 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         @param current current item (QTreeWidgetItem)
         @param previous prevoius current item (QTreeWidgetItem)
         """
-        self.buttonBox.button(QDialogButtonBox.Open).setEnabled(current is not None)
+        self.buttonBox.button(QDialogButtonBox.Open).setEnabled(
+            current is not None)
         
     def show(self):
         """
@@ -256,4 +268,4 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         self.fileNameEdit.selectAll()
         self.fileNameEdit.setFocus()
         
-        QWidget.show(self)
+        super().show()
