@@ -9,9 +9,9 @@ Module implementing a pixmap cache for icons.
 
 import os
 
-from PyQt4.QtCore import QStringList
 from PyQt4.QtGui import QPixmap, QIcon, QPainter
 
+
 class PixmapCache(object):
     """
     Class implementing a pixmap cache for icons.
@@ -21,7 +21,7 @@ class PixmapCache(object):
         Constructor
         """
         self.pixmapCache = {}
-        self.searchPath = QStringList()
+        self.searchPath = []
 
     def getPixmap(self, key):
         """
@@ -51,36 +51,42 @@ class PixmapCache(object):
         """
         Public method to add a path to the search path.
 
-        @param path path to add (QString)
+        @param path path to add (string)
         """
         if not path in self.searchPath:
             self.searchPath.append(path)
 
 pixCache = PixmapCache()
 
-def getPixmap(key, cache = pixCache):
+
+def getPixmap(key, cache=pixCache):
     """
     Module function to retrieve a pixmap.
 
     @param key name of the wanted pixmap (string)
+    @param cache reference to the pixmap cache object (PixmapCache)
     @return the requested pixmap (QPixmap)
     """
     return cache.getPixmap(key)
 
-def getIcon(key, cache = pixCache):
+
+def getIcon(key, cache=pixCache):
     """
     Module function to retrieve an icon.
 
     @param key name of the wanted icon (string)
+    @param cache reference to the pixmap cache object (PixmapCache)
     @return the requested icon (QIcon)
     """
     return QIcon(cache.getPixmap(key))
 
-def getSymlinkIcon(key, cache = pixCache):
+
+def getSymlinkIcon(key, cache=pixCache):
     """
     Module function to retrieve a symbolic link icon.
 
     @param key name of the wanted icon (string)
+    @param cache reference to the pixmap cache object (PixmapCache)
     @return the requested icon (QIcon)
     """
     pix1 = QPixmap(cache.getPixmap(key))
@@ -90,10 +96,12 @@ def getSymlinkIcon(key, cache = pixCache):
     painter.end()
     return QIcon(pix1)
 
-def addSearchPath(path, cache = pixCache):
+
+def addSearchPath(path, cache=pixCache):
     """
     Module function to add a path to the search path.
 
-    @param path path to add (QString)
+    @param path path to add (string)
+    @param cache reference to the pixmap cache object (PixmapCache)
     """
     cache.addSearchPath(path)
