@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a splashscreen for eric4.
+Module implementing a splashscreen for eric5.
 """
 
 import os.path
@@ -13,20 +13,22 @@ import logging
 from PyQt4.QtCore import Qt
 from PyQt4.QtGui import QApplication, QPixmap, QSplashScreen, QColor
 
-from eric4config import getConfig
+from eric5config import getConfig
+
 
 class SplashScreen(QSplashScreen):
     """
-    Class implementing a splashscreen for eric4.
+    Class implementing a splashscreen for eric5.
     """
     def __init__(self):
         """
         Constructor
         """
-        ericPic = QPixmap(os.path.join(getConfig('ericPixDir'), 'ericSplash.png'))
-        self.labelAlignment = \
-            Qt.Alignment(Qt.AlignBottom | Qt.AlignRight | Qt.AlignAbsolute)
-        QSplashScreen.__init__(self, ericPic)
+        ericPic = QPixmap(
+            os.path.join(getConfig('ericPixDir'), 'ericSplash.png'))
+        self.labelAlignment = Qt.Alignment(
+            Qt.AlignBottom | Qt.AlignRight | Qt.AlignAbsolute)
+        super().__init__(ericPic)
         self.show()
         QApplication.flush()
         
@@ -34,22 +36,23 @@ class SplashScreen(QSplashScreen):
         """
         Public method to show a message in the bottom part of the splashscreen.
         
-        @param msg message to be shown (string or QString)
+        @param msg message to be shown (string)
         """
-        logging.debug(unicode(msg))
-        QSplashScreen.showMessage(self, msg, self.labelAlignment, QColor(Qt.white))
+        logging.debug(msg)
+        super().showMessage(msg, self.labelAlignment, QColor(Qt.white))
         QApplication.processEvents()
         
     def clearMessage(self):
         """
         Public method to clear the message shown.
         """
-        QSplashScreen.clearMessage(self)
+        super().clearMessage()
         QApplication.processEvents()
 
+
 class NoneSplashScreen(object):
     """
-    Class implementing a "None" splashscreen for eric4.
+    Class implementing a "None" splashscreen for eric5.
     
     This class implements the same interface as the real splashscreen,
     but simply does nothing.
@@ -64,9 +67,9 @@ class NoneSplashScreen(object):
         """
         Public method to show a message in the bottom part of the splashscreen.
         
-        @param msg message to be shown (string or QString)
+        @param msg message to be shown (string)
         """
-        logging.debug(unicode(msg))
+        logging.debug(msg)
         
     def clearMessage(self):
         """
