@@ -7,6 +7,7 @@
 Module implementing base classes used by the various class browsers.
 """
 
+
 class _ClbrBase(object):
     """
     Class implementing the base of all class browser objects.
@@ -24,6 +25,16 @@ class _ClbrBase(object):
         self.name = name
         self.file = file
         self.lineno = lineno
+        self.endlineno = -1     # marker for "not set"
+        
+    def setEndLine(self, endLineNo):
+        """
+        Public method to set the ending line number.
+        
+        @param endLineNo number of the last line (integer)
+        """
+        self.endlineno = endLineNo
+
 
 class ClbrBase(_ClbrBase):
     """
@@ -71,8 +82,10 @@ class ClbrBase(_ClbrBase):
         
         @param attr Attribute object to be added (Attribute)
         """
-        if not self.globals.has_key(attr.name):
+        if attr.name not in self.globals:
             self.globals[attr.name] = attr
+        else:
+            self.globals[attr.name].addAssignment(attr.lineno)
         
     def _getglobal(self, name):
         """
@@ -92,8 +105,10 @@ class ClbrBase(_ClbrBase):
         
         @param attr Attribute object to be added (Attribute)
         """
-        if not self.attributes.has_key(attr.name):
+        if attr.name not in self.attributes:
             self.attributes[attr.name] = attr
+        else:
+            self.attributes[attr.name].addAssignment(attr.lineno)
         
     def _getattribute(self, name):
         """
@@ -115,7 +130,8 @@ class ClbrBase(_ClbrBase):
         @param _class Class object to be added (Class)
         """
         self.classes[name] = _class
-        
+
+
 class ClbrVisibilityMixinBase(object):
     """
     Class implementing the base class of all visibility mixins.
@@ -162,6 +178,7 @@ class ClbrVisibilityMixinBase(object):
         """
         self.visibility = 2
 
+
 class Attribute(_ClbrBase):
     """
     Class to represent an attribute.
@@ -176,6 +193,19 @@ class Attribute(_ClbrBase):
         @param lineno linenumber of the class definition
         """
         _ClbrBase.__init__(self, module, name, file, lineno)
+        
+        self.linenos = [lineno]
+    
+    def addAssignment(self, lineno):
+        """
+        Public method to add another assignment line number.
+        
+        @param lineno linenumber of the additional attribute assignment
+            (integer)
+        """
+        if lineno not in self.linenos:
+            self.linenos.append(lineno)
+
 
 class Class(ClbrBase):
     """
@@ -196,6 +226,7 @@ class Class(ClbrBase):
             super = []
         self.super = super
 
+
 class Module(ClbrBase):
     """
     Class to represent a module.
@@ -211,6 +242,7 @@ class Module(ClbrBase):
         """
         ClbrBase.__init__(self, module, name, file, lineno)
 
+
 class Function(ClbrBase):
     """
     Class to represent a function or method.
@@ -219,7 +251,7 @@ class Function(ClbrBase):
     Static = 1
     Class = 2
     
-    def __init__(self, module, name, file, lineno, signature = '', separator = ',',
+    def __init__(self, module, name, file, lineno, signature='', separator=',',
                  modifierType=General):
         """
         Constructor
@@ -236,6 +268,7 @@ class Function(ClbrBase):
         self.parameters = [e.strip() for e in signature.split(separator)]
         self.modifier = modifierType
 
+
 class Coding(ClbrBase):
     """
     Class to represent a source coding.
