@@ -25,51 +25,61 @@ PY_SOURCE = imp.PY_SOURCE
 PTL_SOURCE = 128
 RB_SOURCE = 129
 IDL_SOURCE = 130
+JS_SOURCE = 131
 
-SUPPORTED_TYPES = [PY_SOURCE, PTL_SOURCE, RB_SOURCE, IDL_SOURCE]
+SUPPORTED_TYPES = [PY_SOURCE, PTL_SOURCE, RB_SOURCE, IDL_SOURCE, JS_SOURCE]
 
 __extensions = {
-    "IDL"       : [".idl"],
-    "Python"    : [".py", ".pyw", ".ptl"],
-    "Ruby"      : [".rb"],
+    "IDL": [".idl"],
+    "Python": [".py", ".pyw", ".ptl"],  # currently not used
+    "Ruby": [".rb"],
+    "JavaScript": [".js"],
 }
 
-def readmodule(module, path=[], isPyFile = False):
-    '''
-    Read a source file and return a dictionary of classes, functions, modules, etc. .
+
+def readmodule(module, path=[], isPyFile=False):
+    """
+    Read a source file and return a dictionary of classes, functions, modules,
+    etc. .
     
-    The real work of parsing the source file is delegated to the individual file
-    parsers.
+    The real work of parsing the source file is delegated to the individual
+    file parsers.
 
     @param module name of the source file (string)
     @param path path the file should be searched in (list of strings)
+    @param isPyFile flag indicating a Python file (boolean)
     @return the resulting dictionary
-    '''
+    """
     ext = os.path.splitext(module)[1].lower()
     
     if ext in __extensions["IDL"]:
-        import idlclbr
+        from . import idlclbr
         dict = idlclbr.readmodule_ex(module, path)
         idlclbr._modules.clear()
     elif ext in __extensions["Ruby"]:
-        import rbclbr
+        from . import rbclbr
         dict = rbclbr.readmodule_ex(module, path)
         rbclbr._modules.clear()
+    elif ext in __extensions["JavaScript"]:
+        from . import jsclbr
+        dict = jsclbr.readmodule_ex(module, path)
+        jsclbr._modules.clear()
     elif ext in Preferences.getPython("PythonExtensions") or \
-         ext in Preferences.getPython("Python3Extensions") or \
-         isPyFile:
-        import pyclbr
-        dict = pyclbr.readmodule_ex(module, path, isPyFile = isPyFile)
+        ext in Preferences.getPython("Python3Extensions") or \
+            isPyFile:
+        from . import pyclbr
+        dict = pyclbr.readmodule_ex(module, path, isPyFile=isPyFile)
         pyclbr._modules.clear()
     else:
         # try Python if it is without extension
-        import pyclbr
+        from . import pyclbr
         dict = pyclbr.readmodule_ex(module, path)
         pyclbr._modules.clear()
     
     return dict
 
-def find_module(name, path, isPyFile = False):
+
+def find_module(name, path, isPyFile=False):
     """
     Module function to extend the Python module finding mechanism.
     
@@ -80,6 +90,7 @@ def find_module(name, path, isPyFile = False):
     
     @param name filename or modulename to search for (string)
     @param path search path (list of strings)
+    @param isPyFile flag indicating a Python file (boolean)
     @return tuple of the open file, pathname and description. Description
         is a tuple of file suffix, file mode and file type)
     @exception ImportError The file or module wasn't found.
@@ -100,6 +111,13 @@ def find_module(name, path, isPyFile = False):
                 return (open(pathname), pathname, (ext, 'r', IDL_SOURCE))
         raise ImportError
     
+    elif ext in __extensions["JavaScript"]:
+        for p in path:      # only search in path
+            pathname = os.path.join(p, name)
+            if os.path.exists(pathname):
+                return (open(pathname), pathname, (ext, 'r', JS_SOURCE))
+        raise ImportError
+    
     elif ext == '.ptl':
         for p in path:      # only search in path
             pathname = os.path.join(p, name)
@@ -109,15 +127,14 @@ def find_module(name, path, isPyFile = False):
     
     if name.lower().endswith('.py'):
         name = name[:-3]
-    if type(name) == type(u""):
-        name = name.encode('utf-8')
     
     try:
         return imp.find_module(name, path)
     except ImportError:
-        if name.lower().endswith(tuple(Preferences.getPython("PythonExtensions") + \
-                                       Preferences.getPython("Python3Extensions"))) or \
-           isPyFile:
+        if name.lower().endswith(
+                tuple(Preferences.getPython("PythonExtensions") +
+                      Preferences.getPython("Python3Extensions"))) or \
+                isPyFile:
             for p in path:      # search in path
                 pathname = os.path.join(p, name)
                 if os.path.exists(pathname):
