@@ -4,25 +4,26 @@
 #
 
 """
-Parse a CORBA IDL file and retrieve modules, interfaces, methods and attributes.
+Parse a CORBA IDL file and retrieve modules, interfaces, methods and
+attributes.
 
-Parse enough of a CORBA IDL file to recognize module, interface and method definitions
-and to find out the superclasses of an interface as well as its attributes.
+Parse enough of a CORBA IDL file to recognize module, interface and method
+definitions and to find out the superclasses of an interface as well as its
+attributes.
 
 It is based on the Python class browser found in this package.
 """
 
-import sys
-import os
 import re
 
 import Utilities
 import Utilities.ClassBrowsers as ClassBrowsers
-import ClbrBaseClasses
+from . import ClbrBaseClasses
 
 SUPPORTED_TYPES = [ClassBrowsers.IDL_SOURCE]
     
-_getnext = re.compile(r"""
+_getnext = re.compile(
+r"""
     (?P<String>
         " [^"\\\n]* (?: \\. [^"\\\n]*)* "
     )
@@ -39,7 +40,7 @@ _getnext = re.compile(r"""
         (?: oneway [ \t]+ )?
         (?: [a-zA-Z0-9_:]+ | void ) [ \t]*
         (?P<MethodName> [a-zA-Z_] [a-zA-Z0-9_]* )
-        [ \t]* 
+        [ \t]*
         \(
         (?P<MethodSignature> [^)]*? )
         \);
@@ -82,15 +83,16 @@ _getnext = re.compile(r"""
 |   (?P<End>
         [ \t]* } [ \t]* ;
     )
-""", re.VERBOSE | re.DOTALL | re.MULTILINE).search
+""", re.VERBOSE | re.DOTALL | re.MULTILINE).search      # __IGNORE_WARNING__
 
 # function to replace comments
-_commentsub = re.compile(r"""//[^\n]*\n|//[^\n]*$""").sub   
+_commentsub = re.compile(r"""//[^\n]*\n|//[^\n]*$""").sub
 # function to normalize whitespace
-_normalize = re.compile(r"""[ \t]{2,}""").sub               
+_normalize = re.compile(r"""[ \t]{2,}""").sub
 
 _modules = {}                           # cache of modules we've seen
 
+
 class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
     Mixin class implementing the notion of visibility.
@@ -101,6 +103,7 @@ class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
         """
         self.setPublic()
 
+
 class Module(ClbrBaseClasses.Module, VisibilityMixin):
     """
     Class to represent a CORBA IDL module.
@@ -117,6 +120,7 @@ class Module(ClbrBaseClasses.Module, VisibilityMixin):
         ClbrBaseClasses.Module.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Interface(ClbrBaseClasses.Class, VisibilityMixin):
     """
     Class to represent a CORBA IDL interface.
@@ -134,11 +138,13 @@ class Interface(ClbrBaseClasses.Class, VisibilityMixin):
         ClbrBaseClasses.Class.__init__(self, module, name, super, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Function(ClbrBaseClasses.Function, VisibilityMixin):
     """
     Class to represent a CORBA IDL function.
     """
-    def __init__(self, module, name, file, lineno, signature = '', separator = ','):
+    def __init__(self, module, name, file, lineno, signature='',
+                 separator=','):
         """
         Constructor
         
@@ -149,10 +155,11 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         @param signature parameterlist of the method
         @param separator string separating the parameters
         """
-        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno, 
+        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno,
                                           signature, separator)
         VisibilityMixin.__init__(self)
 
+
 class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
     """
     Class to represent a CORBA IDL attribute.
@@ -169,19 +176,22 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         ClbrBaseClasses.Attribute.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 def readmodule_ex(module, path=[]):
-    '''
-    Read a CORBA IDL file and return a dictionary of classes, functions and modules.
+    """
+    Read a CORBA IDL file and return a dictionary of classes, functions and
+    modules.
 
     @param module name of the CORBA IDL file (string)
     @param path path the file should be searched in (list of strings)
     @return the resulting dictionary
-    '''
-
+    """
+    global _modules
+    
     dict = {}
     dict_counts = {}
 
-    if _modules.has_key(module):
+    if module in _modules:
         # we've seen this file before...
         return _modules[module]
 
@@ -189,21 +199,28 @@ def readmodule_ex(module, path=[]):
     f = None
     fullpath = list(path)
     f, file, (suff, mode, type) = ClassBrowsers.find_module(module, fullpath)
+    if f:
+        f.close()
     if type not in SUPPORTED_TYPES:
         # not CORBA IDL source, can't do anything with this module
-        f.close()
         _modules[module] = dict
         return dict
 
     _modules[module] = dict
-    classstack = [] # stack of (class, indent) pairs
+    classstack = []  # stack of (class, indent) pairs
     indent = 0
-    src = Utilities.decode(f.read())[0]
-    f.close()
+    try:
+        src = Utilities.readEncodedFile(file)[0]
+    except (UnicodeError, IOError):
+        # can't do anything with this module
+        _modules[module] = dict
+        return dict
 
     lineno, last_lineno_pos = 1, 0
+    lastGlobalEntry = None
+    cur_obj = None
     i = 0
-    while 1:
+    while True:
         m = _getnext(src, i)
         if not m:
             break
@@ -221,28 +238,42 @@ def readmodule_ex(module, path=[]):
             last_lineno_pos = start
             # close all interfaces/modules indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             if classstack:
                 # it's an interface/module method
                 cur_class = classstack[-1][0]
-                if isinstance(cur_class, Interface) or isinstance(cur_class, Module):
+                if isinstance(cur_class, Interface) or \
+                        isinstance(cur_class, Module):
                     # it's a method
                     f = Function(None, meth_name,
                                  file, lineno, meth_sig)
                     cur_class._addmethod(meth_name, f)
                 # else it's a nested def
+                else:
+                    f = None
             else:
                 # it's a function
                 f = Function(module, meth_name,
                              file, lineno, meth_sig)
-                if dict_counts.has_key(meth_name):
+                if meth_name in dict_counts:
                     dict_counts[meth_name] += 1
-                    meth_name = "%s_%d" % (meth_name, dict_counts[meth_name])
+                    meth_name = "{0}_{1:d}".format(
+                        meth_name, dict_counts[meth_name])
                 else:
                     dict_counts[meth_name] = 0
                 dict[meth_name] = f
-            classstack.append((f, thisindent)) # Marker for nested fns
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = f
+            if cur_obj and isinstance(cur_obj, Function):
+                cur_obj.setEndLine(lineno - 1)
+            cur_obj = f
+            classstack.append((f, thisindent))  # Marker for nested fns
 
         elif m.start("String") >= 0:
             pass
@@ -256,7 +287,10 @@ def readmodule_ex(module, path=[]):
             indent += 1
             # close all interfaces/modules indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
@@ -268,12 +302,19 @@ def readmodule_ex(module, path=[]):
                 inherit = [_commentsub('', inherit)]
             # remember this interface
             cur_class = Interface(module, class_name, inherit,
-                              file, lineno)
+                                  file, lineno)
             if not classstack:
                 dict[class_name] = cur_class
             else:
                 cls = classstack[-1][0]
                 cls._addclass(class_name, cur_class)
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = cur_class
+            if cur_obj and isinstance(cur_obj, Function):
+                cur_obj.setEndLine(lineno - 1)
+            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Module") >= 0:
@@ -282,7 +323,10 @@ def readmodule_ex(module, path=[]):
             indent += 1
             # close all interfaces/modules indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
@@ -291,6 +335,12 @@ def readmodule_ex(module, path=[]):
             cur_class = Module(module, module_name, file, lineno)
             if not classstack:
                 dict[module_name] = cur_class
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = cur_class
+            if cur_obj and isinstance(cur_obj, Function):
+                cur_obj.setEndLine(lineno - 1)
+            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Attribute") >= 0:
@@ -311,6 +361,9 @@ def readmodule_ex(module, path=[]):
                     break
                 else:
                     index -= 1
+                    if lastGlobalEntry:
+                        lastGlobalEntry.setEndLine(lineno - 1)
+                    lastGlobalEntry = None
 
         elif m.start("Begin") >= 0:
             # a begin of a block we are not interested in
