@@ -14,19 +14,20 @@ This is module is based on pyclbr found in the Python 2.2.2 distribution.
 
 
 import sys
-import os
 import imp
 import re
 
 import Utilities
 import Utilities.ClassBrowsers as ClassBrowsers
-import ClbrBaseClasses
+from . import ClbrBaseClasses
+from functools import reduce
 
 TABWIDTH = 4
 
 SUPPORTED_TYPES = [ClassBrowsers.PY_SOURCE, ClassBrowsers.PTL_SOURCE]
     
-_getnext = re.compile(r"""
+_getnext = re.compile(
+r"""
     (?P<String>
        \""" [^"\\]* (?:
                         (?: \\. | "(?!"") )
@@ -62,7 +63,7 @@ _getnext = re.compile(r"""
         ^
         (?P<MethodIndent> [ \t]* )
         def [ \t]+
-        (?P<MethodName> [a-zA-Z_] \w* )
+        (?P<MethodName> \w+ )
         (?: [ \t]* \[ (?: plain | html ) \] )?
         [ \t]* \(
         (?P<MethodSignature> (?: [^)] | \)[ \t]*,? )*? )
@@ -73,7 +74,7 @@ _getnext = re.compile(r"""
         ^
         (?P<ClassIndent> [ \t]* )
         class [ \t]+
-        (?P<ClassName> [a-zA-Z_] \w* )
+        (?P<ClassName> \w+ )
         [ \t]*
         (?P<ClassSupers> \( [^)]* \) )?
         [ \t]* :
@@ -83,14 +84,14 @@ _getnext = re.compile(r"""
         ^
         (?P<AttributeIndent> [ \t]* )
         self [ \t]* \. [ \t]*
-        (?P<AttributeName> [a-zA-Z_] \w* )
+        (?P<AttributeName> \w+ )
         [ \t]* =
     )
 
 |   (?P<Variable>
         ^
         (?P<VariableIndent> [ \t]* )
-        (?P<VariableName> [a-zA-Z_] \w* )
+        (?P<VariableName> \w+ )
         [ \t]* =
     )
 
@@ -103,12 +104,13 @@ _getnext = re.compile(r"""
 |   (?P<CodingLine>
         ^ \# \s* [*_-]* \s* coding[:=] \s* (?P<Coding> [-\w_.]+ ) \s* [*_-]* $
     )
-""", re.VERBOSE | re.DOTALL | re.MULTILINE).search
+""", re.VERBOSE | re.DOTALL | re.MULTILINE).search      # __IGNORE_WARNING__
 
 _commentsub = re.compile(r"""#[^\n]*\n|#[^\n]*$""").sub
 
 _modules = {}                           # cache of modules we've seen
 
+
 class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
     Mixin class implementing the notion of visibility.
@@ -124,6 +126,7 @@ class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
         else:
             self.setPublic()
 
+
 class Class(ClbrBaseClasses.Class, VisibilityMixin):
     """
     Class to represent a Python class.
@@ -141,11 +144,12 @@ class Class(ClbrBaseClasses.Class, VisibilityMixin):
         ClbrBaseClasses.Class.__init__(self, module, name, super, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Function(ClbrBaseClasses.Function, VisibilityMixin):
     """
     Class to represent a Python function.
     """
-    def __init__(self, module, name, file, lineno, signature = '', separator = ',',
+    def __init__(self, module, name, file, lineno, signature='', separator=',',
                  modifierType=ClbrBaseClasses.Function.General):
         """
         Constructor
@@ -158,10 +162,11 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         @param separator string separating the parameters
         @param modifierType type of the function
         """
-        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno, 
+        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno,
                                           signature, separator, modifierType)
         VisibilityMixin.__init__(self)
 
+
 class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
     """
     Class to represent a class attribute.
@@ -178,6 +183,7 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         ClbrBaseClasses.Attribute.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Publics(object):
     """
     Class to represent the list of public identifiers.
@@ -195,11 +201,12 @@ class Publics(object):
         self.name = '__all__'
         self.file = file
         self.lineno = lineno
-        self.identifiers = [e.replace('"','').replace("'","").strip() \
+        self.identifiers = [e.replace('"', '').replace("'", "").strip()
                             for e in idents.split(',')]
     
-def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
-    '''
+
+def readmodule_ex(module, path=[], inpackage=False, isPyFile=False):
+    """
     Read a module file and return a dictionary of classes.
 
     Search for MODULE in PATH and sys.path, read and parse the
@@ -209,13 +216,15 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
     @param module name of the module file (string)
     @param path path the module should be searched in (list of strings)
     @param inpackage flag indicating a module inside a package is scanned
+    @param isPyFile flag indicating a Python file (boolean)
     @return the resulting dictionary
-    '''
-
+    """
+    global _modules
+    
     dict = {}
     dict_counts = {}
 
-    if _modules.has_key(module):
+    if module in _modules:
         # we've seen this module before...
         return _modules[module]
     if module in sys.builtin_module_names:
@@ -228,7 +237,7 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
     if inpackage:
         try:
             f, file, (suff, mode, type) = \
-                    ClassBrowsers.find_module(module, path)
+                ClassBrowsers.find_module(module, path)
         except ImportError:
             f = None
     if f is None:
@@ -242,27 +251,34 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
         _modules[module] = dict
         path = [file] + path
         f, file, (suff, mode, type) = \
-                        ClassBrowsers.find_module('__init__', [file])
+            ClassBrowsers.find_module('__init__', [file])
+    if f:
+        f.close()
     if type not in SUPPORTED_TYPES:
         # not Python source, can't do anything with this module
-        f.close()
         _modules[module] = dict
         return dict
 
     _modules[module] = dict
-    classstack = [] # stack of (class, indent) pairs
-    conditionalsstack = [] # stack of indents of conditional defines
+    classstack = []  # stack of (class, indent) pairs
+    conditionalsstack = []  # stack of indents of conditional defines
     deltastack = []
     deltaindent = 0
     deltaindentcalculated = 0
-    src = Utilities.decode(f.read())[0]
-    f.close()
+    try:
+        src = Utilities.readEncodedFile(file)[0]
+    except (UnicodeError, IOError):
+        # can't do anything with this module
+        _modules[module] = dict
+        return dict
 
     lineno, last_lineno_pos = 1, 0
+    lastGlobalEntry = None
+    cur_obj = None
     i = 0
     modifierType = ClbrBaseClasses.Function.General
     modifierIndent = -1
-    while 1:
+    while True:
         m = _getnext(src, i)
         if not m:
             break
@@ -295,19 +311,22 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                 if thisindent > conditionalsstack[-1]:
                     if not deltaindentcalculated:
                         deltastack.append(thisindent - conditionalsstack[-1])
-                        deltaindent = reduce(lambda x,y: x+y, deltastack)
+                        deltaindent = reduce(lambda x, y:  x + y, deltastack)
                         deltaindentcalculated = 1
                     thisindent -= deltaindent
                 else:
                     while conditionalsstack and \
-                          conditionalsstack[-1] >= thisindent:
+                            conditionalsstack[-1] >= thisindent:
                         del conditionalsstack[-1]
                         if deltastack:
                             del deltastack[-1]
                     deltaindentcalculated = 0
             # close all classes indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             if classstack:
                 # it's a class method
@@ -321,13 +340,21 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                 # it's a function
                 f = Function(module, meth_name,
                              file, lineno, meth_sig, modifierType=modifier)
-                if dict_counts.has_key(meth_name):
+                if meth_name in dict_counts:
                     dict_counts[meth_name] += 1
-                    meth_name = "%s_%d" % (meth_name, dict_counts[meth_name])
+                    meth_name = "{0}_{1:d}".format(
+                        meth_name, dict_counts[meth_name])
                 else:
                     dict_counts[meth_name] = 0
                 dict[meth_name] = f
-            classstack.append((f, thisindent)) # Marker for nested fns
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = f
+            if cur_obj and isinstance(cur_obj, Function):
+                cur_obj.setEndLine(lineno - 1)
+            cur_obj = f
+            classstack.append((f, thisindent))  # Marker for nested fns
             
             # reset the modifier settings
             modifierType = ClbrBaseClasses.Function.General
@@ -341,7 +368,10 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             thisindent = _indent(m.group("ClassIndent"))
             # close all classes indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
@@ -354,7 +384,7 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                 names = []
                 for n in inherit.split(','):
                     n = n.strip()
-                    if dict.has_key(n):
+                    if n in dict:
                         # we know this super class
                         n = dict[n]
                     else:
@@ -367,9 +397,9 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                             # module for class
                             m = c[-2]
                             c = c[-1]
-                            if _modules.has_key(m):
+                            if m in _modules:
                                 d = _modules[m]
-                                if d.has_key(c):
+                                if c in d:
                                     n = d[c]
                     names.append(n)
                 inherit = names
@@ -377,14 +407,19 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             cur_class = Class(module, class_name, inherit,
                               file, lineno)
             if not classstack:
-                if dict_counts.has_key(class_name):
+                if class_name in dict_counts:
                     dict_counts[class_name] += 1
-                    class_name = "%s_%d" % (class_name, dict_counts[class_name])
+                    class_name = "{0}_{1:d}".format(
+                        class_name, dict_counts[class_name])
                 else:
                     dict_counts[class_name] = 0
                 dict[class_name] = cur_class
             else:
                 classstack[-1][0]._addclass(class_name, cur_class)
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Attribute") >= 0:
@@ -394,7 +429,8 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             while index >= -len(classstack):
                 if classstack[index][0] is not None and \
                    not isinstance(classstack[index][0], Function):
-                    attr = Attribute(module, m.group("AttributeName"), file, lineno)
+                    attr = Attribute(
+                        module, m.group("AttributeName"), file, lineno)
                     classstack[index][0]._addattribute(attr)
                     break
                 else:
@@ -407,11 +443,14 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             last_lineno_pos = start
             if thisindent == 0:
                 # global variable
-                if not dict.has_key("@@Globals@@"):
-                    dict["@@Globals@@"] = \
-                        ClbrBaseClasses.ClbrBase(module, "Globals", file, lineno)
+                if "@@Globals@@" not in dict:
+                    dict["@@Globals@@"] = ClbrBaseClasses.ClbrBase(
+                        module, "Globals", file, lineno)
                 dict["@@Globals@@"]._addglobal(
                     Attribute(module, variable_name, file, lineno))
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = None
             else:
                 index = -1
                 while index >= -len(classstack):
@@ -434,7 +473,7 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             # a conditional function/method definition
             thisindent = _indent(m.group("ConditionalDefineIndent"))
             while conditionalsstack and \
-                  conditionalsstack[-1] >= thisindent:
+                    conditionalsstack[-1] >= thisindent:
                 del conditionalsstack[-1]
                 if deltastack:
                     del deltastack[-1]
@@ -446,16 +485,17 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             coding = m.group("Coding")
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
-            if not dict.has_key("@@Coding@@"):
-                dict["@@Coding@@"] = ClbrBaseClasses.Coding(module, file, lineno, coding)
+            if "@@Coding@@" not in dict:
+                dict["@@Coding@@"] = ClbrBaseClasses.Coding(
+                    module, file, lineno, coding)
         
         else:
             assert 0, "regexp _getnext found something unexpected"
 
-    if dict.has_key('__all__'):
+    if '__all__' in dict:
         # set visibility of all top level elements
         pubs = dict['__all__']
-        for key in dict.keys():
+        for key in list(list(dict.keys())):
             if key == '__all__' or key.startswith("@@"):
                 continue
             if key in pubs.identifiers:
@@ -466,6 +506,7 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
     
     return dict
 
+
 def _indent(ws):
     """
     Module function to return the indentation depth.
