@@ -12,17 +12,16 @@ and to find out the superclasses of a class as well as its attributes.
 It is based on the Python class browser found in this package.
 """
 
-import sys
-import os
 import re
 
 import Utilities
 import Utilities.ClassBrowsers as ClassBrowsers
-import ClbrBaseClasses
+from . import ClbrBaseClasses
 
 SUPPORTED_TYPES = [ClassBrowsers.RB_SOURCE]
     
-_getnext = re.compile(r"""
+_getnext = re.compile(
+r"""
     (?P<String>
         =begin .*? =end
     
@@ -49,14 +48,15 @@ _getnext = re.compile(r"""
         (?P<MethodIndent> [ \t]* )
         def [ \t]+
         (?:
-            (?P<MethodName2> [a-zA-Z0-9_]+ (?: \. | :: ) [a-zA-Z_] [a-zA-Z0-9_?!=]* )
+            (?P<MethodName2> [a-zA-Z0-9_]+ (?: \. | :: )
+            [a-zA-Z_] [a-zA-Z0-9_?!=]* )
         |
             (?P<MethodName> [a-zA-Z_] [a-zA-Z0-9_?!=]* )
         |
             (?P<MethodName3> [^( \t]{1,3} )
         )
-        [ \t]* 
-        (?: 
+        [ \t]*
+        (?:
             \( (?P<MethodSignature> (?: [^)] | \)[ \t]*,? )*? ) \)
         )?
         [ \t]*
@@ -72,7 +72,7 @@ _getnext = re.compile(r"""
             [ \t]*
             (?P<ClassSupers> < [ \t]* [A-Z] [a-zA-Z0-9_:]* )?
         |
-            [ \t]* << [ \t]* 
+            [ \t]* << [ \t]*
             (?P<ClassName2> [a-zA-Z_] [a-zA-Z0-9_:]* )
         )
         [ \t]*
@@ -102,11 +102,13 @@ _getnext = re.compile(r"""
         (?:
             (?P<AccessControlType> private | public | protected ) [^_]
         |
-            (?P<AccessControlType2> private_class_method | public_class_method )
+            (?P<AccessControlType2>
+            private_class_method | public_class_method )
         )
         \(?
         [ \t]*
-        (?P<AccessControlList> (?: : [a-zA-Z0-9_]+ , \s* )* (?: : [a-zA-Z0-9_]+ )+ )?
+        (?P<AccessControlList> (?: : [a-zA-Z0-9_]+ , \s* )*
+        (?: : [a-zA-Z0-9_]+ )+ )?
         [ \t]*
         \)?
     )
@@ -121,11 +123,12 @@ _getnext = re.compile(r"""
 |   (?P<Attr>
         ^
         (?P<AttrIndent> [ \t]* )
-        attr 
+        attr
         (?P<AttrType> (?: _accessor | _reader | _writer ) )?
         \(?
         [ \t]*
-        (?P<AttrList> (?: : [a-zA-Z0-9_]+ , \s* )* (?: : [a-zA-Z0-9_]+ | true | false )+ )
+        (?P<AttrList> (?: : [a-zA-Z0-9_]+ , \s* )*
+        (?: : [a-zA-Z0-9_]+ | true | false )+ )
         [ \t]*
         \)?
     )
@@ -133,7 +136,8 @@ _getnext = re.compile(r"""
 |   (?P<Begin>
             ^
             [ \t]*
-            (?: def | if | unless | case | while | until | for | begin ) \b [^_]
+            (?: def | if | unless | case | while | until | for | begin )
+            \b [^_]
         |
             [ \t]* do [ \t]* (?: \| .*? \| )? [ \t]* $
     )
@@ -152,12 +156,13 @@ _getnext = re.compile(r"""
             end \b [^_]
         )
     )
-""", re.VERBOSE | re.DOTALL | re.MULTILINE).search
+""", re.VERBOSE | re.DOTALL | re.MULTILINE).search      # __IGNORE_WARNING__
 
 _commentsub = re.compile(r"""#[^\n]*\n|#[^\n]*$""").sub
 
 _modules = {}                           # cache of modules we've seen
 
+
 class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
     """
     Mixin class implementing the notion of visibility.
@@ -168,6 +173,7 @@ class VisibilityMixin(ClbrBaseClasses.ClbrVisibilityMixinBase):
         """
         self.setPublic()
 
+
 class Class(ClbrBaseClasses.Class, VisibilityMixin):
     """
     Class to represent a Ruby class.
@@ -185,6 +191,7 @@ class Class(ClbrBaseClasses.Class, VisibilityMixin):
         ClbrBaseClasses.Class.__init__(self, module, name, super, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Module(ClbrBaseClasses.Module, VisibilityMixin):
     """
     Class to represent a Ruby module.
@@ -201,11 +208,13 @@ class Module(ClbrBaseClasses.Module, VisibilityMixin):
         ClbrBaseClasses.Module.__init__(self, module, name, file, lineno)
         VisibilityMixin.__init__(self)
 
+
 class Function(ClbrBaseClasses.Function, VisibilityMixin):
     """
     Class to represent a Ruby function.
     """
-    def __init__(self, module, name, file, lineno, signature = '', separator = ','):
+    def __init__(self, module, name, file, lineno, signature='',
+                 separator=','):
         """
         Constructor
         
@@ -216,10 +225,11 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         @param signature parameterlist of the method
         @param separator string separating the parameters
         """
-        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno, 
+        ClbrBaseClasses.Function.__init__(self, module, name, file, lineno,
                                           signature, separator)
         VisibilityMixin.__init__(self)
 
+
 class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
     """
     Class to represent a class or module attribute.
@@ -237,19 +247,21 @@ class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
         VisibilityMixin.__init__(self)
         self.setPrivate()
 
+
 def readmodule_ex(module, path=[]):
-    '''
+    """
     Read a Ruby file and return a dictionary of classes, functions and modules.
 
     @param module name of the Ruby file (string)
     @param path path the file should be searched in (list of strings)
     @return the resulting dictionary
-    '''
-
+    """
+    global _modules
+    
     dict = {}
     dict_counts = {}
 
-    if _modules.has_key(module):
+    if module in _modules:
         # we've seen this file before...
         return _modules[module]
 
@@ -257,22 +269,29 @@ def readmodule_ex(module, path=[]):
     f = None
     fullpath = list(path)
     f, file, (suff, mode, type) = ClassBrowsers.find_module(module, fullpath)
+    if f:
+        f.close()
     if type not in SUPPORTED_TYPES:
         # not Ruby source, can't do anything with this module
-        f.close()
         _modules[module] = dict
         return dict
 
     _modules[module] = dict
-    classstack = [] # stack of (class, indent) pairs
+    classstack = []  # stack of (class, indent) pairs
     acstack = []    # stack of (access control, indent) pairs
     indent = 0
-    src = Utilities.decode(f.read())[0]
-    f.close()
+    try:
+        src = Utilities.readEncodedFile(file)[0]
+    except (UnicodeError, IOError):
+        # can't do anything with this module
+        _modules[module] = dict
+        return dict
 
     lineno, last_lineno_pos = 1, 0
+    cur_obj = None
+    lastGlobalEntry = None
     i = 0
-    while 1:
+    while True:
         m = _getnext(src, i)
         if not m:
             break
@@ -283,8 +302,8 @@ def readmodule_ex(module, path=[]):
             thisindent = indent
             indent += 1
             meth_name = m.group("MethodName") or \
-                        m.group("MethodName2") or \
-                        m.group("MethodName3")
+                m.group("MethodName2") or \
+                m.group("MethodName3")
             meth_sig = m.group("MethodSignature")
             meth_sig = meth_sig and meth_sig.replace('\\\n', '') or ''
             meth_sig = _commentsub('', meth_sig)
@@ -296,15 +315,19 @@ def readmodule_ex(module, path=[]):
                 meth_name = meth_name[6:]
             # close all classes/modules indented at least as much
             while classstack and \
-                  classstack[-1][1] >= thisindent:
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             while acstack and \
-                  acstack[-1][1] >= thisindent:
+                    acstack[-1][1] >= thisindent:
                 del acstack[-1]
             if classstack:
                 # it's a class/module method
                 cur_class = classstack[-1][0]
-                if isinstance(cur_class, Class) or isinstance(cur_class, Module):
+                if isinstance(cur_class, Class) or \
+                        isinstance(cur_class, Module):
                     # it's a method
                     f = Function(None, meth_name,
                                  file, lineno, meth_sig)
@@ -325,13 +348,21 @@ def readmodule_ex(module, path=[]):
                 # it's a function
                 f = Function(module, meth_name,
                              file, lineno, meth_sig)
-                if dict_counts.has_key(meth_name):
+                if meth_name in dict_counts:
                     dict_counts[meth_name] += 1
-                    meth_name = "%s_%d" % (meth_name, dict_counts[meth_name])
+                    meth_name = "{0}_{1:d}".format(
+                        meth_name, dict_counts[meth_name])
                 else:
                     dict_counts[meth_name] = 0
                 dict[meth_name] = f
-            classstack.append((f, thisindent)) # Marker for nested fns
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = f
+            if cur_obj and isinstance(cur_obj, Function):
+                cur_obj.setEndLine(lineno - 1)
+            cur_obj = f
+            classstack.append((f, thisindent))  # Marker for nested fns
 
         elif m.start("String") >= 0:
             pass
@@ -346,12 +377,15 @@ def readmodule_ex(module, path=[]):
             # we found a class definition
             thisindent = indent
             indent += 1
-            # close all classes/modules indented at least as much
-            while classstack and \
-                  classstack[-1][1] >= thisindent:
-                del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
+            # close all classes/modules indented at least as much
+            while classstack and \
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
+                del classstack[-1]
             class_name = m.group("ClassName") or m.group("ClassName2")
             inherit = m.group("ClassSupers")
             if inherit:
@@ -362,55 +396,70 @@ def readmodule_ex(module, path=[]):
             cur_class = Class(module, class_name, inherit,
                               file, lineno)
             if not classstack:
-                if dict.has_key(class_name):
+                if class_name in dict:
                     cur_class = dict[class_name]
                 else:
                     dict[class_name] = cur_class
             else:
                 cls = classstack[-1][0]
-                if cls.classes.has_key(class_name):
+                if class_name in cls.classes:
                     cur_class = cls.classes[class_name]
                 elif cls.name == class_name or class_name == "self":
                     cur_class = cls
                 else:
                     cls._addclass(class_name, cur_class)
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = cur_class
+            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
             while acstack and \
-                  acstack[-1][1] >= thisindent:
+                    acstack[-1][1] >= thisindent:
                 del acstack[-1]
-            acstack.append(["public", thisindent])  # default access control is 'public'
+            acstack.append(["public", thisindent])  # default access control
+                                                    # is 'public'
 
         elif m.start("Module") >= 0:
             # we found a module definition
             thisindent = indent
             indent += 1
-            # close all classes/modules indented at least as much
-            while classstack and \
-                  classstack[-1][1] >= thisindent:
-                del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
+            # close all classes/modules indented at least as much
+            while classstack and \
+                    classstack[-1][1] >= thisindent:
+                if classstack[-1][0] is not None:
+                    # record the end line
+                    classstack[-1][0].setEndLine(lineno - 1)
+                del classstack[-1]
             module_name = m.group("ModuleName")
             # remember this class
             cur_class = Module(module, module_name, file, lineno)
             if not classstack:
-                if dict.has_key(module_name):
+                if module_name in dict:
                     cur_class = dict[module_name]
                 else:
                     dict[module_name] = cur_class
             else:
                 cls = classstack[-1][0]
-                if cls.classes.has_key(module_name):
+                if module_name in cls.classes:
                     cur_class = cls.classes[module_name]
                 elif cls.name == module_name:
                     cur_class = cls
                 else:
                     cls._addclass(module_name, cur_class)
+            if not classstack:
+                if lastGlobalEntry:
+                    lastGlobalEntry.setEndLine(lineno - 1)
+                lastGlobalEntry = cur_class
+            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
             while acstack and \
-                  acstack[-1][1] >= thisindent:
+                    acstack[-1][1] >= thisindent:
                 del acstack[-1]
-            acstack.append(["public", thisindent])  # default access control is 'public'
+            acstack.append(["public", thisindent])  # default access control
+                                                    # is 'public'
 
         elif m.start("AccessControl") >= 0:
             aclist = m.group("AccessControlList")
@@ -419,7 +468,7 @@ def readmodule_ex(module, path=[]):
                 while index >= -len(acstack):
                     if acstack[index][1] < indent:
                         actype = m.group("AccessControlType") or \
-                                 m.group("AccessControlType2").split('_')[0]
+                            m.group("AccessControlType2").split('_')[0]
                         acstack[index][0] = actype.lower()
                         break
                     else:
@@ -432,10 +481,10 @@ def readmodule_ex(module, path=[]):
                        not classstack[index][1] >= indent:
                         parent = classstack[index][0]
                         actype = m.group("AccessControlType") or \
-                                 m.group("AccessControlType2").split('_')[0]
+                            m.group("AccessControlType2").split('_')[0]
                         actype = actype.lower()
                         for name in aclist.split(","):
-                            name = name.strip()[1:]     # get rid of leading ':'
+                            name = name.strip()[1:]   # get rid of leading ':'
                             acmeth = parent._getmethod(name)
                             if acmeth is None:
                                 continue
@@ -457,11 +506,15 @@ def readmodule_ex(module, path=[]):
                 if classstack[index][0] is not None and \
                    not isinstance(classstack[index][0], Function) and \
                    not classstack[index][1] >= indent:
-                    attr = Attribute(module, m.group("AttributeName"), file, lineno)
+                    attr = Attribute(
+                        module, m.group("AttributeName"), file, lineno)
                     classstack[index][0]._addattribute(attr)
                     break
                 else:
                     index -= 1
+                    if lastGlobalEntry:
+                        lastGlobalEntry.setEndLine(lineno - 1)
+                    lastGlobalEntry = None
 
         elif m.start("Attr") >= 0:
             lineno = lineno + src.count('\n', last_lineno_pos, start)
@@ -477,9 +530,9 @@ def readmodule_ex(module, path=[]):
                         if not nv:
                             break
                         name = nv[0].strip()[1:]    # get rid of leading ':'
-                        attr = parent._getattribute("@"+name) or \
-                               parent._getattribute("@@"+name) or \
-                               Attribute(module, "@"+name, file, lineno)
+                        attr = parent._getattribute("@" + name) or \
+                            parent._getattribute("@@" + name) or \
+                            Attribute(module, "@" + name, file, lineno)
                         if len(nv) == 1 or nv[1].strip() == "false":
                             attr.setProtected()
                         elif nv[1].strip() == "true":
@@ -488,10 +541,10 @@ def readmodule_ex(module, path=[]):
                     else:
                         access = m.group("AttrType")
                         for name in m.group("AttrList").split(","):
-                            name = name.strip()[1:]     # get rid of leading ':'
-                            attr = parent._getattribute("@"+name) or \
-                                   parent._getattribute("@@"+name) or \
-                                   Attribute(module, "@"+name, file, lineno)
+                            name = name.strip()[1:]   # get rid of leading ':'
+                            attr = parent._getattribute("@" + name) or \
+                                parent._getattribute("@@" + name) or \
+                                Attribute(module, "@" + name, file, lineno)
                             if access == "_accessor":
                                 attr.setPublic()
                             elif access == "_reader" or access == "_writer":
@@ -527,8 +580,9 @@ def readmodule_ex(module, path=[]):
             coding = m.group("Coding")
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
-            if not dict.has_key("@@Coding@@"):
-                dict["@@Coding@@"] = ClbrBaseClasses.Coding(module, file, lineno, coding)
+            if "@@Coding@@" not in dict:
+                dict["@@Coding@@"] = ClbrBaseClasses.Coding(
+                    module, file, lineno, coding)
 
         else:
             assert 0, "regexp _getnext found something unexpected"
