@@ -7,16 +7,14 @@
 Module implementing the VCS command options dialog.
 """
 
-import sys
+from PyQt4.QtGui import QDialog
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-
-from Ui_CommandOptionsDialog import Ui_vcsCommandOptionsDialog
+from .Ui_CommandOptionsDialog import Ui_VcsCommandOptionsDialog
 
 import Utilities
 
-class vcsCommandOptionsDialog(QDialog, Ui_vcsCommandOptionsDialog):
+
+class VcsCommandOptionsDialog(QDialog, Ui_VcsCommandOptionsDialog):
     """
     Class implementing the VCS command options dialog.
     """
@@ -27,7 +25,7 @@ class vcsCommandOptionsDialog(QDialog, Ui_vcsCommandOptionsDialog):
         @param vcs reference to the vcs object
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
         if Utilities.isWindowsPlatform():
@@ -51,19 +49,20 @@ class vcsCommandOptionsDialog(QDialog, Ui_vcsCommandOptionsDialog):
         
         # modify the what's this help
         for widget in [self.globalEdit, self.commitEdit, self.checkoutEdit,
-                  self.updateEdit, self.addEdit, self.removeEdit,
-                  self.diffEdit, self.logEdit, self.historyEdit,
-                  self.statusEdit, self.tagEdit, self.exportEdit]:
+                       self.updateEdit, self.addEdit, self.removeEdit,
+                       self.diffEdit, self.logEdit, self.historyEdit,
+                       self.statusEdit, self.tagEdit, self.exportEdit]:
             t = widget.whatsThis()
-            if not t.isEmpty():
-                t = t.append(Utilities.getPercentReplacementHelp())
+            if t:
+                t += Utilities.getPercentReplacementHelp()
                 widget.setWhatsThis(t)
         
     def getOptions(self):
         """
         Public method used to retrieve the entered options.
         
-        @return dictionary of strings giving the options for each supported vcs command
+        @return dictionary of strings giving the options for each supported
+            vcs command
         """
         opt = {}
         opt['global'] = Utilities.parseOptionString(self.globalEdit.text())
