@@ -12,35 +12,34 @@ import os
 from PyQt4.QtCore import QObject
 from PyQt4.QtGui import QDialog
 
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Application import e5App
 
 from UI.DeleteFilesConfirmationDialog import DeleteFilesConfirmationDialog
 
 from Project.ProjectBrowserModel import ProjectBrowserSimpleDirectoryItem, \
     ProjectBrowserFileItem, ProjectBrowserDirectoryItem
 
-from RepositoryInfoDialog import VcsRepositoryInfoDialog
-
 import Preferences
 
+
 class VcsProjectBrowserHelper(QObject):
     """
     Class implementing the base class of the VCS project browser helper.
     """
-    def __init__(self, vcsObject, browserObject, projectObject, isTranslationsBrowser,
-        parent = None, name = None):
+    def __init__(self, vcsObject, browserObject, projectObject,
+                 isTranslationsBrowser, parent=None, name=None):
         """
         Constructor
         
         @param vcsObject reference to the vcs object
         @param browserObject reference to the project browser object
         @param projectObject reference to the project object
-        @param isTranslationsBrowser flag indicating, the helper is requested for the
-            translations browser (this needs some special treatment)
+        @param isTranslationsBrowser flag indicating, the helper is requested
+            for the translations browser (this needs some special treatment)
         @param parent parent widget (QWidget)
-        @param name name of this object (string or QString)
+        @param name name of this object (string)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         
@@ -49,9 +48,11 @@ class VcsProjectBrowserHelper(QObject):
         self.isTranslationsBrowser = isTranslationsBrowser
         self.project = projectObject
     
-    def addVCSMenus(self, mainMenu, multiMenu, backMenu, dirMenu, dirMultiMenu):
+    def addVCSMenus(self, mainMenu, multiMenu, backMenu, dirMenu,
+                    dirMultiMenu):
         """
-        Public method to add the VCS entries to the various project browser menus.
+        Public method to add the VCS entries to the various project browser
+        menus.
         
         @param mainMenu reference to the main menu (QPopupMenu)
         @param multiMenu reference to the multiple selection menu (QPopupMenu)
@@ -68,59 +69,67 @@ class VcsProjectBrowserHelper(QObject):
     
     def showContextMenu(self, menu, standardItems):
         """
-        Slot called before the context menu is shown. 
+        Slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the file status.
         
         @param menu reference to the menu to be shown
-        @param standardItems array of standard items that need activation/deactivation
-            depending on the overall VCS status
+        @param standardItems array of standard items that need
+            activation/deactivation depending on the overall VCS status
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
     
     def showContextMenuMulti(self, menu, standardItems):
         """
-        Slot called before the context menu (multiple selections) is shown. 
+        Slot called before the context menu (multiple selections) is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the files status.
         
         @param menu reference to the menu to be shown
-        @param standardItems array of standard items that need activation/deactivation
-            depending on the overall VCS status
+        @param standardItems array of standard items that need
+            activation/deactivation depending on the overall VCS status
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
     
     def showContextMenuDir(self, menu, standardItems):
         """
-        Slot called before the context menu is shown. 
+        Slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
         
         @param menu reference to the menu to be shown
-        @param standardItems array of standard items that need activation/deactivation
-            depending on the overall VCS status
+        @param standardItems array of standard items that
+            need activation/deactivation depending on the overall VCS status
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
     
     def showContextMenuDirMulti(self, menu, standardItems):
         """
-        Slot called before the context menu is shown. 
+        Slot called before the context menu is shown.
         
-        It enables/disables the VCS menu entries depending on the overall 
+        It enables/disables the VCS menu entries depending on the overall
         VCS status and the directory status.
         
         @param menu reference to the menu to be shown
-        @param standardItems array of standard items that need activation/deactivation
-            depending on the overall VCS status
+        @param standardItems array of standard items that need
+            activation/deactivation depending on the overall VCS status
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
 
-    ############################################################################
+    ###########################################################################
     ## General menu handling methods below
-    ############################################################################
+    ###########################################################################
     
     def _VCSUpdate(self):
         """
@@ -128,19 +137,20 @@ class VcsProjectBrowserHelper(QObject):
         VCS repository.
         """
         if self.isTranslationsBrowser:
-            names = [unicode(itm.dirName()) \
-                for itm in self.browser.getSelectedItems(\
-                    [ProjectBrowserSimpleDirectoryItem])]
+            names = [itm.dirName()
+                     for itm in self.browser.getSelectedItems(
+                         [ProjectBrowserSimpleDirectoryItem])]
             if not names:
-                names = [unicode(itm.fileName()) \
-                    for itm in self.browser.getSelectedItems([ProjectBrowserFileItem])]
+                names = [itm.fileName()
+                         for itm in self.browser.getSelectedItems(
+                             [ProjectBrowserFileItem])]
         else:
             names = []
             for itm in self.browser.getSelectedItems():
                 try:
-                    name = unicode(itm.fileName())
+                    name = itm.fileName()
                 except AttributeError:
-                    name = unicode(itm.dirName())
+                    name = itm.dirName()
                 names.append(name)
         self.vcs.vcsUpdate(names)
         
@@ -150,42 +160,44 @@ class VcsProjectBrowserHelper(QObject):
         VCS repository.
         """
         if self.isTranslationsBrowser:
-            names = [unicode(itm.dirName()) \
-                for itm in self.browser.getSelectedItems(\
-                    [ProjectBrowserSimpleDirectoryItem])]
+            names = [itm.dirName()
+                     for itm in self.browser.getSelectedItems(
+                         [ProjectBrowserSimpleDirectoryItem])]
             if not names:
-                names = [unicode(itm.fileName()) \
-                    for itm in self.browser.getSelectedItems([ProjectBrowserFileItem])]
+                names = [itm.fileName()
+                         for itm in self.browser.getSelectedItems(
+                             [ProjectBrowserFileItem])]
         else:
             names = []
             for itm in self.browser.getSelectedItems():
                 try:
-                    name = unicode(itm.fileName())
+                    name = itm.fileName()
                 except AttributeError:
-                    name = unicode(itm.dirName())
+                    name = itm.dirName()
                 names.append(name)
         if Preferences.getVCS("AutoSaveFiles"):
-            vm = e4App().getObject("ViewManager")
+            vm = e5App().getObject("ViewManager")
             for name in names:
                 vm.saveEditor(name)
         self.vcs.vcsCommit(names, '')
         
     def _VCSAdd(self):
         """
-        Protected slot called by the context menu to add the selected file to the
-        VCS repository.
+        Protected slot called by the context menu to add the selected file to
+        the VCS repository.
         """
         if self.isTranslationsBrowser:
-            items = self.browser.getSelectedItems([ProjectBrowserSimpleDirectoryItem])
+            items = self.browser.getSelectedItems(
+                [ProjectBrowserSimpleDirectoryItem])
             if items:
-                names = [unicode(itm.dirName()) for itm in items]
+                names = [itm.dirName() for itm in items]
                 qnames = []
             else:
                 items = self.browser.getSelectedItems([ProjectBrowserFileItem])
                 names = []
                 qnames = []
                 for itm in items:
-                    name = unicode(itm.fileName())
+                    name = itm.fileName()
                     if name.endswith('.qm'):
                         qnames.append(name)
                     else:
@@ -194,9 +206,9 @@ class VcsProjectBrowserHelper(QObject):
             names = []
             for itm in self.browser.getSelectedItems():
                 try:
-                    name = unicode(itm.fileName())
+                    name = itm.fileName()
                 except AttributeError:
-                    name = unicode(itm.dirName())
+                    name = itm.dirName()
                 names.append(name)
             qnames = []
         
@@ -228,13 +240,12 @@ class VcsProjectBrowserHelper(QObject):
         It is used to add the selected
         directory tree to the VCS repository.
         """
-        items = self.browser.getSelectedItems()
         names = []
         for itm in self.browser.getSelectedItems():
             try:
-                name = unicode(itm.fileName())
+                name = itm.fileName()
             except AttributeError:
-                name = unicode(itm.dirName())
+                name = itm.dirName()
             names.append(name)
         self.vcs.vcsAddTree(names)
         for fn in names:
@@ -242,38 +253,44 @@ class VcsProjectBrowserHelper(QObject):
         
     def _VCSRemove(self):
         """
-        Protected slot called by the context menu to remove the selected file from the
-        VCS repository.
+        Protected slot called by the context menu to remove the selected file
+        from the VCS repository.
         """
         if self.isTranslationsBrowser:
-            items = self.browser.getSelectedItems([ProjectBrowserSimpleDirectoryItem])
+            items = self.browser.getSelectedItems(
+                [ProjectBrowserSimpleDirectoryItem])
             if items:
                 return      # not supported
             
             isRemoveDirs = False
             items = self.browser.getSelectedItems([ProjectBrowserFileItem])
-            names = [unicode(itm.fileName()) for itm in items]
+            names = [itm.fileName() for itm in items]
             
-            dlg = DeleteFilesConfirmationDialog(self.parent(),
+            dlg = DeleteFilesConfirmationDialog(
+                self.parent(),
                 self.trUtf8("Remove from repository (and disk)"),
-                self.trUtf8("Do you really want to remove these translation files from"
+                self.trUtf8(
+                    "Do you really want to remove these translation files from"
                     " the repository (and disk)?"),
                 names)
         else:
             items = self.browser.getSelectedItems()
             isRemoveDirs = len(items) == \
-                self.browser.getSelectedItemsCount(\
-                [ProjectBrowserSimpleDirectoryItem, ProjectBrowserDirectoryItem])
+                self.browser.getSelectedItemsCount(
+                    [ProjectBrowserSimpleDirectoryItem,
+                     ProjectBrowserDirectoryItem])
             if isRemoveDirs:
-                names = [unicode(itm.dirName()) for itm in items]
+                names = [itm.dirName() for itm in items]
             else:
-                names = [unicode(itm.fileName()) for itm in items]
-            files = [self.browser.project.getRelativePath(name) \
-                for name in names]
+                names = [itm.fileName() for itm in items]
+            files = [self.browser.project.getRelativePath(name)
+                     for name in names]
             
-            dlg = DeleteFilesConfirmationDialog(self.parent(),
+            dlg = DeleteFilesConfirmationDialog(
+                self.parent(),
                 self.trUtf8("Remove from repository (and disk)"),
-                self.trUtf8("Do you really want to remove these files/directories"
+                self.trUtf8(
+                    "Do you really want to remove these files/directories"
                     " from the repository (and disk)?"),
                 files)
         
@@ -281,19 +298,21 @@ class VcsProjectBrowserHelper(QObject):
             status = self.vcs.vcsRemove(names)
             if status:
                 if isRemoveDirs:
-                    self.browser._removeDir() # remove directories from Project
+                    self.browser._removeDir()  # remove directories from
+                                               # Project
                 else:
-                    self.browser._removeFile() # remove file(s) from project
+                    self.browser._removeFile()  # remove file(s) from project
         
     def _VCSLog(self):
         """
-        Protected slot called by the context menu to show the VCS log of a file/directory.
+        Protected slot called by the context menu to show the VCS log of a
+        file/directory.
         """
         itm = self.browser.currentItem()
         try:
-            fn = unicode(itm.fileName())
+            fn = itm.fileName()
         except AttributeError:
-            fn = unicode(itm.dirName())
+            fn = itm.dirName()
         self.vcs.vcsLog(fn)
         
     def _VCSDiff(self):
@@ -304,9 +323,9 @@ class VcsProjectBrowserHelper(QObject):
         names = []
         for itm in self.browser.getSelectedItems():
             try:
-                name = unicode(itm.fileName())
+                name = itm.fileName()
             except AttributeError:
-                name = unicode(itm.dirName())
+                name = itm.dirName()
             names.append(name)
         self.vcs.vcsDiff(names)
         
@@ -315,50 +334,54 @@ class VcsProjectBrowserHelper(QObject):
         Protected slot called by the context menu to show the status of a file.
         """
         if self.isTranslationsBrowser:
-            items = self.browser.getSelectedItems([ProjectBrowserSimpleDirectoryItem])
+            items = self.browser.getSelectedItems(
+                [ProjectBrowserSimpleDirectoryItem])
             if items:
-                names = [unicode(itm.dirName()) for itm in items]
+                names = [itm.dirName() for itm in items]
             else:
                 items = self.browser.getSelectedItems([ProjectBrowserFileItem])
-                names = [unicode(itm.fileName()) for itm in items]
+                names = [itm.fileName() for itm in items]
         else:
             names = []
             for itm in self.browser.getSelectedItems():
                 try:
-                    name = unicode(itm.fileName())
+                    name = itm.fileName()
                 except AttributeError:
-                    name = unicode(itm.dirName())
+                    name = itm.dirName()
                 names.append(name)
         self.vcs.vcsStatus(names)
 
     def _VCSRevert(self):
         """
-        Protected slot called by the context menu to revert changes made to a file.
+        Protected slot called by the context menu to revert changes made to a
+        file.
         """
         names = []
         for itm in self.browser.getSelectedItems():
             try:
-                name = unicode(itm.fileName())
+                name = itm.fileName()
             except AttributeError:
-                name = unicode(itm.dirName())
+                name = itm.dirName()
             names.append(name)
         self.vcs.vcsRevert(names)
 
     def _VCSMerge(self):
         """
-        Protected slot called by the context menu to merge changes into to a file.
+        Protected slot called by the context menu to merge changes into to a
+        file.
         """
         itm = self.browser.currentItem()
         try:
-            name = unicode(itm.fileName())
+            name = itm.fileName()
         except AttributeError:
-            name = unicode(itm.dirName())
+            name = itm.dirName()
         self.vcs.vcsMerge(name)
     
     def _VCSInfoDisplay(self):
         """
         Protected slot called to show some vcs information.
         """
+        from .RepositoryInfoDialog import VcsRepositoryInfoDialog
         info = self.vcs.vcsRepositoryInfos(self.project.ppath)
         dlg = VcsRepositoryInfoDialog(None, info)
         dlg.exec_()
@@ -367,6 +390,7 @@ class VcsProjectBrowserHelper(QObject):
         """
         Protected method to update the VCS status of an item.
         
-        @param name filename or directoryname of the item to be updated (string)
+        @param name filename or directoryname of the item to be updated
+            (string)
         """
         self.project.getModel().updateVCSStatus(name)
