@@ -8,39 +8,33 @@ Module implementing the base class of the VCS project helper.
 """
 
 import os
-import sys
 import shutil
 import copy
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QDir, QFileInfo, QObject
+from PyQt4.QtGui import QDialog, QInputDialog
 
-from KdeQt import KQMessageBox, KQInputDialog
-from KdeQt.KQApplication import e4App
+from E5Gui.E5Action import E5Action
+from E5Gui import E5MessageBox
+from E5Gui.E5Application import e5App
 
-import VCS
-from CommandOptionsDialog import vcsCommandOptionsDialog
-from RepositoryInfoDialog import VcsRepositoryInfoDialog
-
-from E4Gui.E4Action import E4Action
-
-import Utilities
 import Preferences
 
+
 class VcsProjectHelper(QObject):
     """
     Class implementing the base class of the VCS project helper.
     """
-    def __init__(self, vcsObject, projectObject, parent = None, name = None):
+    def __init__(self, vcsObject, projectObject, parent=None, name=None):
         """
         Constructor
         
         @param vcsObject reference to the vcs object
         @param projectObject reference to the project object
         @param parent parent widget (QWidget)
-        @param name name of this object (string or QString)
+        @param name name of this object (string)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         
@@ -67,20 +61,25 @@ class VcsProjectHelper(QObject):
         """
         Public method to generate the action objects.
         """
-        self.vcsNewAct = E4Action(self.trUtf8('New from repository'),
-                self.trUtf8('&New from repository...'), 0, 0, self, 'vcs_new')
+        self.vcsNewAct = E5Action(
+            self.trUtf8('New from repository'),
+            self.trUtf8('&New from repository...'),
+            0, 0, self, 'vcs_new')
         self.vcsNewAct.setStatusTip(self.trUtf8(
             'Create a new project from the VCS repository'
         ))
         self.vcsNewAct.setWhatsThis(self.trUtf8(
             """<b>New from repository</b>"""
-            """<p>This creates a new local project from the VCS repository.</p>"""
+            """<p>This creates a new local project from the VCS"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsNewAct, SIGNAL('triggered()'), self._vcsCheckout)
+        self.vcsNewAct.triggered[()].connect(self._vcsCheckout)
         self.actions.append(self.vcsNewAct)
         
-        self.vcsExportAct = E4Action(self.trUtf8('Export from repository'), 
-                self.trUtf8('&Export from repository...'), 0, 0, self, 'vcs_export')
+        self.vcsExportAct = E5Action(
+            self.trUtf8('Export from repository'),
+            self.trUtf8('&Export from repository...'),
+            0, 0, self, 'vcs_export')
         self.vcsExportAct.setStatusTip(self.trUtf8(
             'Export a project from the repository'
         ))
@@ -88,19 +87,22 @@ class VcsProjectHelper(QObject):
             """<b>Export from repository</b>"""
             """<p>This exports a project from the repository.</p>"""
         ))
-        self.connect(self.vcsExportAct, SIGNAL('triggered()'), self._vcsExport)
+        self.vcsExportAct.triggered[()].connect(self._vcsExport)
         self.actions.append(self.vcsExportAct)
         
-        self.vcsAddAct = E4Action(self.trUtf8('Add to repository'),
-                self.trUtf8('&Add to repository...'), 0, 0, self, 'vcs_add')
+        self.vcsAddAct = E5Action(
+            self.trUtf8('Add to repository'),
+            self.trUtf8('&Add to repository...'),
+            0, 0, self, 'vcs_add')
         self.vcsAddAct.setStatusTip(self.trUtf8(
             'Add the local project to the VCS repository'
         ))
         self.vcsAddAct.setWhatsThis(self.trUtf8(
             """<b>Add to repository</b>"""
-            """<p>This adds (imports) the local project to the VCS repository.</p>"""
+            """<p>This adds (imports) the local project to the VCS"""
+            """ repository.</p>"""
         ))
-        self.connect(self.vcsAddAct, SIGNAL('triggered()'), self._vcsImport)
+        self.vcsAddAct.triggered[()].connect(self._vcsImport)
         self.actions.append(self.vcsAddAct)
     
     def initMenu(self, menu):
@@ -124,7 +126,7 @@ class VcsProjectHelper(QObject):
         if self.vcsAddAct:
             self.vcsAddAct.setEnabled(self.project.isOpen())
 
-    def _vcsCheckout(self, export = False):
+    def _vcsCheckout(self, export=False):
         """
         Protected slot used to create a local project from the repository.
         
@@ -134,18 +136,17 @@ class VcsProjectHelper(QObject):
         if not self.project.checkDirty():
             return
         
-        vcsSystemsDict = e4App().getObject("PluginManager")\
+        vcsSystemsDict = e5App().getObject("PluginManager")\
             .getPluginDisplayStrings("version_control")
         if not vcsSystemsDict:
             # no version control system found
             return
         
-        vcsSystemsDisplay = QStringList()
-        keys = vcsSystemsDict.keys()
-        keys.sort()
+        vcsSystemsDisplay = []
+        keys = sorted(vcsSystemsDict.keys())
         for key in keys:
             vcsSystemsDisplay.append(vcsSystemsDict[key])
-        vcsSelected, ok = KQInputDialog.getItem(\
+        vcsSelected, ok = QInputDialog.getItem(
             None,
             self.trUtf8("New Project"),
             self.trUtf8("Select version control system for the project"),
@@ -153,7 +154,7 @@ class VcsProjectHelper(QObject):
             0, False)
         if not ok:
             return
-        for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
+        for vcsSystem, vcsSystemDisplay in list(vcsSystemsDict.items()):
             if vcsSystemDisplay == vcsSelected:
                 break
         
@@ -169,15 +170,18 @@ class VcsProjectHelper(QObject):
                 self.project.pdata["VCS"] = [vcsSystem]
                 self.project.vcs = self.project.initVCS(vcsSystem)
                 # edit VCS command options
-                vcores = KQMessageBox.question(None,
-                    self.trUtf8("New Project"),
-                    self.trUtf8("""Would you like to edit the VCS command options?"""),
-                    QMessageBox.StandardButtons(\
-                        QMessageBox.No | \
-                        QMessageBox.Yes),
-                    QMessageBox.No)
-                if vcores == QMessageBox.Yes:
-                    codlg = vcsCommandOptionsDialog(self.project.vcs)
+                if self.project.vcs.vcsSupportCommandOptions():
+                    vcores = E5MessageBox.yesNo(
+                        self.parent(),
+                        self.tr("New Project"),
+                        self.tr(
+                            """Would you like to edit the VCS command"""
+                            """ options?"""))
+                else:
+                    vcores = False
+                if vcores:
+                    from .CommandOptionsDialog import VcsCommandOptionsDialog
+                    codlg = VcsCommandOptionsDialog(self.project.vcs)
                     if codlg.exec_() == QDialog.Accepted:
                         self.project.vcs.vcsSetOptions(codlg.getOptions())
                 
@@ -186,10 +190,12 @@ class VcsProjectHelper(QObject):
                     try:
                         os.makedirs(projectdir)
                     except EnvironmentError:
-                        KQMessageBox.critical(None,
+                        E5MessageBox.critical(
+                            self.parent(),
                             self.trUtf8("Create project directory"),
-                            self.trUtf8("<p>The project directory <b>%1</b> could not"
-                                " be created.</p>").arg(projectdir))
+                            self.trUtf8(
+                                "<p>The project directory <b>{0}</b> could not"
+                                " be created.</p>").format(projectdir))
                         self.project.pdata["VCS"] = ['None']
                         self.project.vcs = self.project.initVCS()
                         return
@@ -199,78 +205,84 @@ class VcsProjectHelper(QObject):
                 if export:
                     ok = self.project.vcs.vcsExport(vcsDataDict, projectdir)
                 else:
-                    ok = self.project.vcs.vcsCheckout(vcsDataDict, projectdir, False)
+                    ok = self.project.vcs.vcsCheckout(vcsDataDict, projectdir,
+                                                      False)
                 if ok:
                     projectdir = os.path.normpath(projectdir)
-                    filters = QStringList() << "*.e4p" << "*.e4pz" << "*.e3p" << "*.e3pz"
+                    filters = ["*.e4p"]
                     d = QDir(projectdir)
                     plist = d.entryInfoList(filters)
                     if len(plist):
                         if len(plist) == 1:
-                            self.project.openProject(plist[0].absoluteFilePath())
-                            self.project.emit(SIGNAL('newProject'))
+                            self.project.openProject(
+                                plist[0].absoluteFilePath())
+                            self.project.newProject.emit()
                         else:
                             pfilenamelist = d.entryList(filters)
-                            pfilename, ok = KQInputDialog.getItem(
+                            pfilename, ok = QInputDialog.getItem(
                                 None,
                                 self.trUtf8("New project from repository"),
                                 self.trUtf8("Select a project file to open."),
                                 pfilenamelist, 0, False)
                             if ok:
-                                self.project.openProject(\
+                                self.project.openProject(
                                     QFileInfo(d, pfilename).absoluteFilePath())
-                                self.project.emit(SIGNAL('newProject'))
+                                self.project.newProject.emit()
                         if export:
                             self.project.pdata["VCS"] = ['None']
                             self.project.vcs = self.project.initVCS()
                             self.project.setDirty(True)
                             self.project.saveProject()
                     else:
-                        res = KQMessageBox.question(None,
+                        res = E5MessageBox.yesNo(
+                            self.parent(),
                             self.trUtf8("New project from repository"),
-                            self.trUtf8("The project retrieved from the repository"
+                            self.trUtf8(
+                                "The project retrieved from the repository"
                                 " does not contain an eric project file"
-                                " (*.e4p *.e4pz *.e3p *.e3pz)."
-                                " Create it?"),
-                            QMessageBox.StandardButtons(\
-                                QMessageBox.No | \
-                                QMessageBox.Yes),
-                            QMessageBox.Yes)
-                        if res == QMessageBox.Yes:
+                                " (*.e4p). Create it?"),
+                            yesDefault=True)
+                        if res:
                             self.project.ppath = projectdir
                             self.project.opened = True
                             
-                            from Project.PropertiesDialog import PropertiesDialog
+                            from Project.PropertiesDialog import \
+                                PropertiesDialog
                             dlg = PropertiesDialog(self.project, False)
                             if dlg.exec_() == QDialog.Accepted:
                                 dlg.storeData()
                                 self.project.initFileTypes()
                                 self.project.setDirty(True)
                                 try:
-                                    ms = os.path.join(self.project.ppath, 
-                                                      self.project.pdata["MAINSCRIPT"][0])
+                                    ms = os.path.join(
+                                        self.project.ppath,
+                                        self.project.pdata["MAINSCRIPT"][0])
                                     if os.path.exists(ms):
                                         self.project.appendFile(ms)
                                 except IndexError:
                                     ms = ""
                                 self.project.newProjectAddFiles(ms)
+                                self.project.createProjectManagementDir()
                                 self.project.saveProject()
                                 self.project.openProject(self.project.pfile)
                                 if not export:
-                                    res = KQMessageBox.question(None,
-                                        self.trUtf8("New project from repository"),
-                                        self.trUtf8("Shall the project file be added to"
-                                            " the repository?"),
-                                        QMessageBox.StandardButtons(\
-                                            QMessageBox.No | \
-                                            QMessageBox.Yes),
-                                        QMessageBox.Yes)
-                                    if res == QMessageBox.Yes:
-                                        self.project.vcs.vcsAdd(self.project.pfile)
+                                    res = E5MessageBox.yesNo(
+                                        self.parent(),
+                                        self.trUtf8(
+                                            "New project from repository"),
+                                        self.trUtf8(
+                                            "Shall the project file be added"
+                                            " to the repository?"),
+                                        yesDefault=True)
+                                    if res:
+                                        self.project.vcs.vcsAdd(
+                                            self.project.pfile)
                 else:
-                    KQMessageBox.critical(None,
+                    E5MessageBox.critical(
+                        self.parent(),
                         self.trUtf8("New project from repository"),
-                        self.trUtf8("""The project could not be retrieved from"""
+                        self.trUtf8(
+                            """The project could not be retrieved from"""
                             """ the repository."""))
                     self.project.pdata["VCS"] = ['None']
                     self.project.vcs = self.project.initVCS()
@@ -288,14 +300,14 @@ class VcsProjectHelper(QObject):
         """
         Protected slot used to import the local project into the repository.
         
-        <b>NOTE</b>: 
+        <b>NOTE</b>:
             This does not necessarily make the local project a vcs controlled
-            project. You may have to checkout the project from the repository in 
-            order to accomplish that.
+            project. You may have to checkout the project from the repository
+            in order to accomplish that.
         """
         def revertChanges():
             """
-            Local function do revert the changes made to the project object.
+            Local function to revert the changes made to the project object.
             """
             self.project.pdata["VCS"] = pdata_vcs[:]
             self.project.pdata["VCSOPTIONS"] = copy.deepcopy(pdata_vcsoptions)
@@ -312,18 +324,17 @@ class VcsProjectHelper(QObject):
         pdata_vcsother = copy.deepcopy(self.project.pdata["VCSOTHERDATA"])
         vcs = self.project.vcs
         vcsHelper = self.project.vcsProjectHelper
-        vcsSystemsDict = e4App().getObject("PluginManager")\
+        vcsSystemsDict = e5App().getObject("PluginManager")\
             .getPluginDisplayStrings("version_control")
         if not vcsSystemsDict:
             # no version control system found
             return
         
-        vcsSystemsDisplay = QStringList()
-        keys = vcsSystemsDict.keys()
-        keys.sort()
+        vcsSystemsDisplay = []
+        keys = sorted(list(vcsSystemsDict.keys()))
         for key in keys:
             vcsSystemsDisplay.append(vcsSystemsDict[key])
-        vcsSelected, ok = KQInputDialog.getItem(\
+        vcsSelected, ok = QInputDialog.getItem(
             None,
             self.trUtf8("Import Project"),
             self.trUtf8("Select version control system for the project"),
@@ -331,45 +342,47 @@ class VcsProjectHelper(QObject):
             0, False)
         if not ok:
             return
-        vcsSystem = None
-        for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
+        for vcsSystem, vcsSystemDisplay in list(vcsSystemsDict.items()):
             if vcsSystemDisplay == vcsSelected:
                 break
         
-        if vcsSystem:
-            self.project.pdata["VCS"] = [vcsSystem]
-            self.project.vcs = self.project.initVCS(vcsSystem)
-            if self.project.vcs is not None:
-                vcsdlg = self.project.vcs.vcsOptionsDialog(self.project, self.project.name, 1)
-                if vcsdlg.exec_() == QDialog.Accepted:
-                    vcsDataDict = vcsdlg.getData()
-                    # edit VCS command options
-                    vcores = KQMessageBox.question(None,
-                        self.trUtf8("Import Project"),
-                        self.trUtf8("""Would you like to edit the VCS command options?"""),
-                        QMessageBox.StandardButtons(\
-                            QMessageBox.No | \
-                            QMessageBox.Yes),
-                        QMessageBox.No)
-                    if vcores == QMessageBox.Yes:
-                        codlg = vcsCommandOptionsDialog(self.project.vcs)
-                        if codlg.exec_() == QDialog.Accepted:
-                            self.project.vcs.vcsSetOptions(codlg.getOptions())
-                    self.project.setDirty(True)
-                    self.project.vcs.vcsSetDataFromDict(vcsDataDict)
-                    self.project.saveProject()
-                    isVcsControlled = \
-                        self.project.vcs.vcsImport(vcsDataDict, self.project.ppath)[0]
-                    if isVcsControlled:
-                        # reopen the project
-                        self.project.openProject(self.project.pfile)
-                    else:
-                        # revert the changes to the local project 
-                        # because the project dir is not a VCS directory
-                        revertChanges()
+        self.project.pdata["VCS"] = [vcsSystem]
+        self.project.vcs = self.project.initVCS(vcsSystem)
+        if self.project.vcs is not None:
+            vcsdlg = self.project.vcs.vcsOptionsDialog(self.project,
+                                                       self.project.name, 1)
+            if vcsdlg.exec_() == QDialog.Accepted:
+                vcsDataDict = vcsdlg.getData()
+                # edit VCS command options
+                if self.project.vcs.vcsSupportCommandOptions():
+                    vcores = E5MessageBox.yesNo(
+                        self.parent(),
+                        self.tr("Import Project"),
+                        self.tr(
+                            """Would you like to edit the VCS command"""
+                            """ options?"""))
                 else:
-                    # revert the changes because user cancelled
+                    vcores = False
+                if vcores:
+                    from .CommandOptionsDialog import VcsCommandOptionsDialog
+                    codlg = VcsCommandOptionsDialog(self.project.vcs)
+                    if codlg.exec_() == QDialog.Accepted:
+                        self.project.vcs.vcsSetOptions(codlg.getOptions())
+                self.project.setDirty(True)
+                self.project.vcs.vcsSetDataFromDict(vcsDataDict)
+                self.project.saveProject()
+                isVcsControlled = self.project.vcs.vcsImport(
+                    vcsDataDict, self.project.ppath)[0]
+                if isVcsControlled:
+                    # reopen the project
+                    self.project.openProject(self.project.pfile)
+                else:
+                    # revert the changes to the local project
+                    # because the project dir is not a VCS directory
                     revertChanges()
+            else:
+                # revert the changes because user cancelled
+                revertChanges()
 
     def _vcsUpdate(self):
         """
@@ -377,19 +390,18 @@ class VcsProjectHelper(QObject):
         """
         shouldReopen = self.vcs.vcsUpdate(self.project.ppath)
         if shouldReopen:
-            res = KQMessageBox.information(None,
+            res = E5MessageBox.yesNo(
+                self.parent(),
                 self.trUtf8("Update"),
                 self.trUtf8("""The project should be reread. Do this now?"""),
-                QMessageBox.StandardButtons(\
-                    QMessageBox.No | \
-                    QMessageBox.Yes),
-                QMessageBox.Yes)
-            if res == QMessageBox.Yes:
+                yesDefault=True)
+            if res:
                 self.project.reopenProject()
         
     def _vcsCommit(self):
         """
-        Protected slot used to commit changes to the local project to the repository.
+        Protected slot used to commit changes to the local project to the
+        repository.
         """
         if Preferences.getVCS("AutoSaveProject"):
             self.project.saveProject()
@@ -404,15 +416,13 @@ class VcsProjectHelper(QObject):
         Depending on the parameters set in the vcs object the project
         may be removed from the local disk as well.
         """
-        res = KQMessageBox.warning(None,
+        res = E5MessageBox.yesNo(
+            self.parent(),
             self.trUtf8("Remove project from repository"),
-            self.trUtf8("Dou you really want to remove this project from"
-                " the repository (and disk)?"),
-            QMessageBox.StandardButtons(\
-                QMessageBox.No | \
-                QMessageBox.Yes),
-            QMessageBox.No)
-        if res == QMessageBox.Yes:
+            self.trUtf8(
+                "Dou you really want to remove this project from"
+                " the repository (and disk)?"))
+        if res:
             self.vcs.vcsRemove(self.project.ppath, True)
             self._vcsCommit()
             if not os.path.exists(self.project.pfile):
@@ -425,10 +435,12 @@ class VcsProjectHelper(QObject):
         """
         Protected slot to edit the VCS command options.
         """
-        codlg = vcsCommandOptionsDialog(self.vcs)
-        if codlg.exec_() == QDialog.Accepted:
-            self.vcs.vcsSetOptions(codlg.getOptions())
-            self.project.setDirty(True)
+        if self.vcs.vcsSupportCommandOptions():
+            from .CommandOptionsDialog import VcsCommandOptionsDialog
+            codlg = VcsCommandOptionsDialog(self.vcs)
+            if codlg.exec_() == QDialog.Accepted:
+                self.vcs.vcsSetOptions(codlg.getOptions())
+                self.project.setDirty(True)
         
     def _vcsLog(self):
         """
@@ -438,7 +450,8 @@ class VcsProjectHelper(QObject):
         
     def _vcsDiff(self):
         """
-        Protected slot used to show the difference of the local project to the repository.
+        Protected slot used to show the difference of the local project to
+        the repository.
         """
         self.vcs.vcsDiff(self.project.ppath)
         
@@ -464,11 +477,20 @@ class VcsProjectHelper(QObject):
         """
         Protected slot used to switch the local project to another tag/branch.
         """
-        self.vcs.vcsSwitch(self.project.ppath)
+        shouldReopen = self.vcs.vcsSwitch(self.project.ppath)
+        if shouldReopen:
+            res = E5MessageBox.yesNo(
+                self.parent(),
+                self.trUtf8("Switch"),
+                self.trUtf8("""The project should be reread. Do this now?"""),
+                yesDefault=True)
+            if res:
+                self.project.reopenProject()
         
     def _vcsMerge(self):
         """
-        Protected slot used to merge changes of a tag/revision into the local project.
+        Protected slot used to merge changes of a tag/revision into the local
+        project.
         """
         self.vcs.vcsMerge(self.project.ppath)
         
@@ -488,6 +510,7 @@ class VcsProjectHelper(QObject):
         """
         Protected slot called to show some vcs information.
         """
+        from .RepositoryInfoDialog import VcsRepositoryInfoDialog
         info = self.vcs.vcsRepositoryInfos(self.project.ppath)
         dlg = VcsRepositoryInfoDialog(None, info)
         dlg.exec_()
