@@ -4,21 +4,22 @@
 #
 
 """
-Module implementing a LED to indicate the status of the VCS status monitor thread.
+Module implementing a LED to indicate the status of the VCS status monitor
+thread.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import Qt
+from PyQt4.QtGui import QColor, QInputDialog, QMenu
 
-from KdeQt import KQInputDialog
-
-from E4Gui.E4Led import E4Led, E4LedRectangular
+from E5Gui.E5Led import E5Led, E5LedRectangular
 
 import Preferences
 
-class StatusMonitorLed(E4Led):
+
+class StatusMonitorLed(E5Led):
     """
-    Class implementing a LED to indicate the status of the VCS status monitor thread.
+    Class implementing a LED to indicate the status of the VCS status monitor
+    thread.
     """
     def __init__(self, project, parent):
         """
@@ -27,76 +28,78 @@ class StatusMonitorLed(E4Led):
         @param project reference to the project object (Project.Project)
         @param parent reference to the parent object (QWidget)
         """
-        E4Led.__init__(self, parent, shape = E4LedRectangular, rectRatio = 1.0)
+        E5Led.__init__(self, parent, shape=E5LedRectangular, rectRatio=1.0)
         
         self.project = project
         self.vcsMonitorLedColors = {
-            "off"       : QColor(Qt.lightGray),
-            "ok"        : QColor(Qt.green),
-            "nok"       : QColor(Qt.red),
-            "op"        : QColor(Qt.yellow),
-            "send"      : QColor(Qt.blue), 
-            "wait"      : QColor(Qt.cyan), 
-            "timeout"   : QColor(Qt.darkRed)
+            "off": QColor(Qt.lightGray),
+            "ok": QColor(Qt.green),
+            "nok": QColor(Qt.red),
+            "op": QColor(Qt.yellow),
+            "send": QColor(Qt.blue),
+            "wait": QColor(Qt.cyan),
+            "timeout": QColor(Qt.darkRed)
         }
         self.__on = False
         
         self.setWhatsThis(self.trUtf8(
             """<p>This LED indicates the operating"""
             """ status of the VCS monitor thread (off = monitoring off,"""
-            """ green = monitoring on and ok, red = monitoring on, but not ok,"""
-            """ yellow = checking VCS status). A status description is given"""
-            """ in the tooltip.</p>"""
+            """ green = monitoring on and ok, red = monitoring on, but"""
+            """ not ok, yellow = checking VCS status). A status description"""
+            """ is given in the tooltip.</p>"""
         ))
-        self.setToolTip(\
+        self.setToolTip(
             self.trUtf8("Repository status checking is switched off")
         )
         self.setColor(self.vcsMonitorLedColors["off"])
         
         # define a context menu
         self.__menu = QMenu(self)
-        self.__checkAct = \
-            self.__menu.addAction(self.trUtf8("Check status"), self.__checkStatus)
-        self.__intervalAct = \
-            self.__menu.addAction(self.trUtf8("Set interval..."), self.__setInterval)
+        self.__checkAct = self.__menu.addAction(
+            self.trUtf8("Check status"), self.__checkStatus)
+        self.__intervalAct = self.__menu.addAction(
+            self.trUtf8("Set interval..."), self.__setInterval)
         self.__menu.addSeparator()
-        self.__onAct  = \
-            self.__menu.addAction(self.trUtf8("Switch on"), self.__switchOn)
-        self.__offAct = \
-            self.__menu.addAction(self.trUtf8("Switch off"), self.__switchOff)
+        self.__onAct = self.__menu.addAction(
+            self.trUtf8("Switch on"), self.__switchOn)
+        self.__offAct = self.__menu.addAction(
+            self.trUtf8("Switch off"), self.__switchOff)
         self.__checkActions()
         
         # connect signals to our slots
         self.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"),
-                     self._showContextMenu)
-        self.connect(self.project, SIGNAL('vcsStatusMonitorStatus(QString, QString)'),
-                     self.__projectVcsMonitorStatus)
+        self.customContextMenuRequested.connect(self._showContextMenu)
+        self.project.vcsStatusMonitorStatus.connect(
+            self.__projectVcsMonitorStatus)
     
     def __checkActions(self):
         """
         Private method to set the enabled status of the context menu actions.
         """
         if self.project.pudata["VCSSTATUSMONITORINTERVAL"]:
-            vcsStatusMonitorInterval = self.project.pudata["VCSSTATUSMONITORINTERVAL"][0]
+            vcsStatusMonitorInterval = \
+                self.project.pudata["VCSSTATUSMONITORINTERVAL"][0]
         else:
-            vcsStatusMonitorInterval = Preferences.getVCS("StatusMonitorInterval")
+            vcsStatusMonitorInterval = \
+                Preferences.getVCS("StatusMonitorInterval")
         self.__checkAct.setEnabled(self.__on)
         self.__intervalAct.setEnabled(self.__on)
-        self.__onAct.setEnabled((not self.__on) and vcsStatusMonitorInterval > 0)
+        self.__onAct.setEnabled(
+            (not self.__on) and vcsStatusMonitorInterval > 0)
         self.__offAct.setEnabled(self.__on)
         
     def __projectVcsMonitorStatus(self, status, statusMsg):
         """
         Private method to receive the status monitor status.
         
-        @param status status of the monitoring thread (QString, ok, nok or off)
-        @param statusMsg explanotory text for the signaled status (QString)
+        @param status status of the monitoring thread (string, ok, nok or off)
+        @param statusMsg explanotory text for the signaled status (string)
         """
-        self.setColor(self.vcsMonitorLedColors[unicode(status)])
+        self.setColor(self.vcsMonitorLedColors[status])
         self.setToolTip(statusMsg)
         
-        self.__on = unicode(status) != 'off'
+        self.__on = status != 'off'
     
     def _showContextMenu(self, coord):
         """
@@ -120,11 +123,11 @@ class StatusMonitorLed(E4Led):
         """
         Private slot to change the status check interval.
         """
-        interval,  ok = KQInputDialog.getInt(\
+        interval,  ok = QInputDialog.getInt(
             None,
             self.trUtf8("VCS Status Monitor"),
             self.trUtf8("Enter monitor interval [s]"),
-            self.project.getStatusMonitorInterval(), 
+            self.project.getStatusMonitorInterval(),
             0, 3600, 1)
         if ok:
             self.project.setStatusMonitorInterval(interval)
