@@ -7,42 +7,42 @@
 Module implementing the VCS status monitor thread base class.
 """
 
-import os
+from PyQt4.QtCore import QThread, QMutex, QWaitCondition, pyqtSignal
 
-from PyQt4.QtCore import QThread, QMutex, QMutexLocker, QWaitCondition, \
-    QString, QStringList, SIGNAL
-
-from KdeQt.KQApplication import e4App
 
 class VcsStatusMonitorThread(QThread):
     """
     Class implementing the VCS status monitor thread base class.
     
-    @signal vcsStatusMonitorData(QStringList) emitted to update the VCS status
-    @signal vcsStatusMonitorStatus(QString, QString) emitted to signal the status of the
-        monitoring thread (ok, nok, op) and a status message
+    @signal vcsStatusMonitorData(list of str) emitted to update the VCS status
+    @signal vcsStatusMonitorStatus(str, str) emitted to signal the status of
+        the monitoring thread (ok, nok, op) and a status message
     """
-    def __init__(self, interval, projectDir, vcs, parent = None):
+    vcsStatusMonitorData = pyqtSignal(list)
+    vcsStatusMonitorStatus = pyqtSignal(str, str)
+    
+    def __init__(self, interval, project, vcs, parent=None):
         """
         Constructor
         
         @param interval new interval in seconds (integer)
-        @param projectDir project directory to monitor (string or QString)
+        @param project reference to the project object (Project)
         @param vcs reference to the version control object
         @param parent reference to the parent object (QObject)
         """
-        QThread.__init__(self, parent)
+        super().__init__(parent)
         self.setObjectName("VcsStatusMonitorThread")
         
         self.setTerminationEnabled(True)
         
-        self.projectDir = QString(projectDir)
+        self.projectDir = project.getProjectPath()
+        self.project = project
         self.vcs = vcs
         
         self.interval = interval
         self.autoUpdate = False
         
-        self.statusList = QStringList()
+        self.statusList = []
         self.reportedStates = {}
         self.shouldUpdate = False
         
@@ -56,48 +56,45 @@ class VcsStatusMonitorThread(QThread):
         """
         while not self.__stopIt:
             # perform the checking task
-            self.statusList.clear()
-            self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), 
-                      QString("wait"), self.trUtf8("Waiting for lock"))
+            self.statusList = []
+            self.vcsStatusMonitorStatus.emit(
+                "wait", self.trUtf8("Waiting for lock"))
             try:
                 locked = self.vcs.vcsExecutionMutex.tryLock(5000)
             except TypeError:
                 locked = self.vcs.vcsExecutionMutex.tryLock()
             if locked:
                 try:
-                    self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), 
-                              QString("op"), self.trUtf8("Checking repository status"))
+                    self.vcsStatusMonitorStatus.emit(
+                        "op", self.trUtf8("Checking repository status"))
                     res, statusMsg = self._performMonitor()
                 finally:
                     self.vcs.vcsExecutionMutex.unlock()
                 if res:
-                    status = QString("ok")
+                    status = "ok"
                 else:
-                    status = QString("nok")
-                self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), 
-                          QString("send"), self.trUtf8("Sending data"))
-                self.emit(SIGNAL("vcsStatusMonitorData(QStringList)"), 
-                          QStringList(self.statusList))
-                self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), 
-                          status, statusMsg)
+                    status = "nok"
+                self.vcsStatusMonitorStatus.emit(
+                    "send", self.trUtf8("Sending data"))
+                self.vcsStatusMonitorData.emit(self.statusList)
+                self.vcsStatusMonitorStatus.emit(status, statusMsg)
             else:
-                self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), 
-                          QString("timeout"), self.trUtf8("Timed out waiting for lock"))
+                self.vcsStatusMonitorStatus.emit(
+                    "timeout", self.trUtf8("Timed out waiting for lock"))
             
             if self.autoUpdate and self.shouldUpdate:
-                try:
-                    self.vcs.vcsUpdate(self.projectDir, True)
-                    continue    # check again
-                except TypeError:
-                    pass    # compatibility for older VCS plugins
+                self.vcs.vcsUpdate(self.projectDir, True)
+                continue    # check again
                 self.shouldUpdate = False
             
             # wait until interval has expired checking for a stop condition
             self.monitorMutex.lock()
             if not self.__stopIt:
-                self.monitorCondition.wait(self.monitorMutex, self.interval * 1000)
+                self.monitorCondition.wait(
+                    self.monitorMutex, self.interval * 1000)
             self.monitorMutex.unlock()
         
+        self._shutdown()
         self.exit()
     
     def setInterval(self, interval):
@@ -159,10 +156,9 @@ class VcsStatusMonitorThread(QThread):
         """
         Public method to clear the cached VCS state of a file/directory.
         
-        @param name name of the entry to be cleared (QString or string)
+        @param name name of the entry to be cleared (string)
         """
-        project = e4App().getObject("Project")
-        key = project.getRelativePath(unicode(name))
+        key = self.project.getRelativePath(name)
         try:
             del self.reportedStates[key]
         except KeyError:
@@ -172,10 +168,10 @@ class VcsStatusMonitorThread(QThread):
         """
         Protected method implementing the real monitoring action.
         
-        This method must be overridden and populate the statusList member variable
-        with a list of strings giving the status in the first column and the
-        path relative to the project directory starting with the third column.
-        The allowed status flags are:
+        This method must be overridden and populate the statusList member
+        variable with a list of strings giving the status in the first column
+        and the path relative to the project directory starting with the
+        third column. The allowed status flags are:
         <ul>
             <li>"A" path was added but not yet comitted</li>
             <li>"M" path has local changes</li>
@@ -186,7 +182,17 @@ class VcsStatusMonitorThread(QThread):
             <li>" " path is back at normal</li>
         </ul>
         
-        @return tuple of flag indicating successful operation (boolean) and 
-            a status message in case of non successful operation (QString)
+        @ireturn tuple of flag indicating successful operation (boolean) and
+            a status message in case of non successful operation (string)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
+    
+    def _shutdown(self):
+        """
+        Protected method performing shutdown actions.
+        
+        The default implementation does nothing.
+        """
+        pass
