@@ -4,32 +4,38 @@
 #
 
 """
-Module implementing an abstract base class to be subclassed by all specific 
+Module implementing an abstract base class to be subclassed by all specific
 VCS interfaces.
 """
 
 import os
 
 from PyQt4.QtCore import QObject, QThread, QMutex, QProcess, \
-    QString, QStringList, SIGNAL, Qt
+    Qt, pyqtSignal
 from PyQt4.QtGui import QApplication
 
-from KdeQt import KQMessageBox
+from E5Gui import E5MessageBox
 
 import Preferences
 
+
 class VersionControl(QObject):
     """
-    Class implementing an abstract base class to be subclassed by all specific 
+    Class implementing an abstract base class to be subclassed by all specific
     VCS interfaces.
     
     It defines the vcs interface to be implemented by subclasses
     and the common methods.
     
-    @signal vcsStatusMonitorData(QStringList) emitted to update the VCS status
-    @signal vcsStatusMonitorStatus(QString, QString) emitted to signal the status of the
-        monitoring thread (ok, nok, op, off) and a status message
+    @signal vcsStatusMonitorData(list of str) emitted to update the VCS status
+    @signal vcsStatusMonitorStatus(str, str) emitted to signal the status of
+        the monitoring thread (ok, nok, op, off) and a status message
+    @signal vcsStatusChanged() emitted to indicate a change of the overall
+        VCS status
     """
+    vcsStatusMonitorData = pyqtSignal(list)
+    vcsStatusMonitorStatus = pyqtSignal(str, str)
+    vcsStatusChanged = pyqtSignal()
     
     canBeCommitted = 1  # Indicates that a file/directory is in the vcs.
     canBeAdded = 2      # Indicates that a file/directory is not in vcs.
@@ -39,24 +45,24 @@ class VersionControl(QObject):
         Constructor
         
         @param parent parent widget (QWidget)
-        @param name name of this object (string or QString)
+        @param name name of this object (string)
         """
-        QObject.__init__(self, parent)
+        super().__init__(parent)
         if name:
             self.setObjectName(name)
         self.defaultOptions = {
-            'global' : [''],
-            'commit' : [''],
-            'checkout' : [''],
-            'update' : [''],
-            'add' : [''],
-            'remove' : [''],
-            'diff' : [''],
-            'log' : [''],
-            'history' : [''],
-            'status' : [''],
-            'tag' : [''],
-            'export' : ['']
+            'global': [''],
+            'commit': [''],
+            'checkout': [''],
+            'update': [''],
+            'add': [''],
+            'remove': [''],
+            'diff': [''],
+            'log': [''],
+            'history': [''],
+            'status': [''],
+            'tag': [''],
+            'export': ['']
         }
         self.interestingDataKeys = []
         self.options = {}
@@ -70,6 +76,9 @@ class VersionControl(QObject):
     def vcsShutdown(self):
         """
         Public method used to shutdown the vcs interface.
+        
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -77,57 +86,61 @@ class VersionControl(QObject):
         """
         Public method used to test for the presence of the vcs.
         
-        It must return a bool to indicate the existance and a QString giving
-        an error message in case of failure.
-        
-        @exception RuntimeError not implemented
+        @ireturn tuple of flag indicating the existence and a string
+            giving an error message in case of failure
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsInit(self, vcsDir, noDialog = False):
+    def vcsInit(self, vcsDir, noDialog=False):
         """
         Public method used to initialize the vcs.
         
-        It must return a boolean to indicate an execution without errors.
-        
         @param vcsDir name of the VCS directory (string)
         @param noDialog flag indicating quiet operations (boolean)
-        @exception RuntimeError not implemented
+        @ireturn flag indicating success (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
     def vcsConvertProject(self, vcsDataDict, project):
         """
-        Public method to convert an uncontrolled project to a version controlled project.
+        Public method to convert an uncontrolled project to a version
+        controlled project.
         
         @param vcsDataDict dictionary of data required for the conversion
         @param project reference to the project object
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsImport(self, vcsDataDict, projectDir, noDialog = False):
+    def vcsImport(self, vcsDataDict, projectDir, noDialog=False):
         """
         Public method used to import the project into the vcs.
         
         @param vcsDataDict dictionary of data required for the import
         @param projectDir project directory (string)
         @param noDialog flag indicating quiet operations
-        @return flag indicating an execution without errors (boolean)
+        @ireturn flag indicating an execution without errors (boolean)
             and a flag indicating the version controll status (boolean)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsCheckout(self, vcsDataDict, projectDir, noDialog = False):
+    def vcsCheckout(self, vcsDataDict, projectDir, noDialog=False):
         """
         Public method used to check the project out of the vcs.
         
         @param vcsDataDict dictionary of data required for the checkout
         @param projectDir project directory to create (string)
         @param noDialog flag indicating quiet operations
-        @return flag indicating an execution without errors (boolean)
-        @exception RuntimeError not implemented
+        @ireturn flag indicating an execution without errors (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -135,64 +148,61 @@ class VersionControl(QObject):
         """
         Public method used to export a directory from the vcs.
         
-        It must return a boolean to indicate an execution without errors.
-        
         @param vcsDataDict dictionary of data required for the export
         @param projectDir project directory to create (string)
-        @return flag indicating an execution without errors (boolean)
-        @exception RuntimeError not implemented
+        @ireturn flag indicating an execution without errors (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsCommit(self, name, message, noDialog = False):
+    def vcsCommit(self, name, message, noDialog=False):
         """
-        Public method used to make the change of a file/directory permanent in the vcs.
-        
-        It must return a boolean to indicate an execution without errors.
+        Public method used to make the change of a file/directory permanent in
+        the vcs.
         
         @param name file/directory name to be committed (string)
         @param message message for this operation (string)
-        @param noDialog flag indicating quiet operations
-        @exception RuntimeError not implemented
+        @param noDialog flag indicating quiet operations (boolean)
+        @ireturn flag indicating success (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsUpdate(self, name, noDialog = False):
+    def vcsUpdate(self, name, noDialog=False):
         """
         Public method used to update a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to be updated (string)
         @param noDialog flag indicating quiet operations (boolean)
-        @return flag indicating, that the update contained an add
+        @ireturn flag indicating, that the update contained an add
             or delete (boolean)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsAdd(self, name, isDir = False, noDialog = False):
+    def vcsAdd(self, name, isDir=False, noDialog=False):
         """
         Public method used to add a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to be added (string)
         @param isDir flag indicating name is a directory (boolean)
         @param noDialog flag indicating quiet operations (boolean)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsAddBinary(self, name, isDir = False):
+    def vcsAddBinary(self, name, isDir=False):
         """
         Public method used to add a file/directory in binary mode in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to be added (string)
         @param isDir flag indicating name is a directory (boolean)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -200,27 +210,26 @@ class VersionControl(QObject):
         """
         Public method to add a directory tree rooted at path in the vcs.
         
-        It must not return anything.
-        
         @param path root directory of the tree to be added (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsRemove(self, name, project = False, noDialog = False):
+    def vcsRemove(self, name, project=False, noDialog=False):
         """
         Public method used to add a file/directory in the vcs.
         
-        It must return a flag indicating successfull operation
-        
         @param name file/directory name to be removed (string)
         @param project flag indicating deletion of a project tree (boolean)
         @param noDialog flag indicating quiet operations
-        @exception RuntimeError not implemented
+        @ireturn flag indicating success (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsMove(self, name, project, target = None, noDialog = False):
+    def vcsMove(self, name, project, target=None, noDialog=False):
         """
         Public method used to move a file/directory.
         
@@ -228,8 +237,9 @@ class VersionControl(QObject):
         @param project reference to the project object
         @param target new name of the file/directory (string)
         @param noDialog flag indicating quiet operations
-        @return flag indicating successfull operation (boolean)
-        @exception RuntimeError not implemented
+        @ireturn flag indicating successfull operation (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -237,10 +247,9 @@ class VersionControl(QObject):
         """
         Public method used to view the log of a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to show the log for (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -248,10 +257,9 @@ class VersionControl(QObject):
         """
         Public method used to view the diff of a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to be diffed (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -259,10 +267,9 @@ class VersionControl(QObject):
         """
         Public method used to view the history of a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to show the history for (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -270,10 +277,9 @@ class VersionControl(QObject):
         """
         Public method used to view the status of a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to show the status for (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -281,10 +287,9 @@ class VersionControl(QObject):
         """
         Public method used to set the tag of a file/directory in the vcs.
         
-        It must not return anything.
-        
         @param name file/directory name to be tagged (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -292,10 +297,9 @@ class VersionControl(QObject):
         """
         Public method used to revert changes made to a file/directory.
         
-        It must not return anything.
-        
         @param name file/directory name to be reverted (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -303,10 +307,11 @@ class VersionControl(QObject):
         """
         Public method used to switch a directory to a different tag/branch.
         
-        It must not return anything.
-        
         @param name directory name to be switched (string)
-        @exception RuntimeError not implemented
+        @ireturn flag indicating, that the switch contained an add
+            or delete (boolean)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -314,10 +319,9 @@ class VersionControl(QObject):
         """
         Public method used to merge a tag/branch into the local project.
         
-        It must not return anything.
-        
         @param name file/directory name to be merged (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -326,21 +330,24 @@ class VersionControl(QObject):
         Public method used to get the registered state of a file in the vcs.
         
         @param name filename to check (string)
-        @return a combination of canBeCommited and canBeAdded or
+        @ireturn a combination of canBeCommited and canBeAdded or
             0 in order to signal an error
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
     def vcsAllRegisteredStates(self, names, dname):
         """
-        Public method used to get the registered states of a number of files in the vcs.
+        Public method used to get the registered states of a number of files
+        in the vcs.
         
         @param names dictionary with all filenames to be checked as keys
         @param dname directory to check in (string)
-        @return the received dictionary completed with a combination of 
+        @ireturn the received dictionary completed with a combination of
             canBeCommited and canBeAdded or None in order to signal an error
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -348,8 +355,9 @@ class VersionControl(QObject):
         """
         Public method returning the name of the vcs.
         
-        @return name of the vcs (string)
-        @exception RuntimeError not implemented
+        @ireturn name of the vcs (string)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -358,7 +366,8 @@ class VersionControl(QObject):
         Public method used to cleanup the local copy.
         
         @param name directory name to be cleaned up (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -367,26 +376,33 @@ class VersionControl(QObject):
         Public method used to execute arbitrary vcs commands.
         
         @param name directory name of the working directory (string)
-        @exception RuntimeError not implemented
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsOptionsDialog(self, project, archive, editable = False, parent = None):
+    def vcsOptionsDialog(self, project, archive, editable=False, parent=None):
         """
         Public method to get a dialog to enter repository info.
         
         @param project reference to the project object
         @param archive name of the project in the repository (string)
-        @param editable flag indicating that the project name is editable (boolean)
+        @param editable flag indicating that the project name is editable
+            (boolean)
         @param parent parent widget (QWidget)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsNewProjectOptionsDialog(self, parent = None):
+    def vcsNewProjectOptionsDialog(self, parent=None):
         """
-        Public method to get a dialog to enter repository info for getting a new project.
+        Public method to get a dialog to enter repository info for getting a
+        new project.
         
         @param parent parent widget (QWidget)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -395,19 +411,25 @@ class VersionControl(QObject):
         Public method to retrieve information about the repository.
         
         @param ppath local path to get the repository infos (string)
-        @return string with ready formated info for display (QString)
+        @ireturn string with ready formated info for display (string)
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
-    def vcsGetProjectBrowserHelper(self, browser, project, isTranslationsBrowser = False):
+    def vcsGetProjectBrowserHelper(self, browser, project,
+                                   isTranslationsBrowser=False):
         """
-        Public method to instanciate a helper object for the different project browsers.
+        Public method to instanciate a helper object for the different
+        project browsers.
         
         @param browser reference to the project browser object
         @param project reference to the project object
-        @param isTranslationsBrowser flag indicating, the helper is requested for the
-            translations browser (this needs some special treatment)
-        @return the project browser helper object
+        @param isTranslationsBrowser flag indicating, the helper is requested
+            for the translations browser (this needs some special treatment)
+        @ireturn the project browser helper object
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
         
@@ -416,7 +438,9 @@ class VersionControl(QObject):
         Public method to instanciate a helper object for the project.
         
         @param project reference to the project object
-        @return the project helper object
+        @ireturn the project helper object
+        @exception RuntimeError to indicate that this method must be
+            implemented by a subclass
         """
         raise RuntimeError('Not implemented')
     
@@ -441,6 +465,15 @@ class VersionControl(QObject):
         """
         pass
         
+    def vcsSupportCommandOptions(self):
+        """
+        Public method to signal the support of user settable command options.
+        
+        @return flag indicating the support  of user settable command options
+            (boolean)
+        """
+        return True
+    
     def vcsDefaultOptions(self):
         """
         Public method used to retrieve the default options for the vcs.
@@ -448,7 +481,8 @@ class VersionControl(QObject):
         @return a dictionary with the vcs operations as key and
             the respective options as values. The key 'global' must contain
             the global options. The other keys must be 'commit', 'update',
-            'add', 'remove', 'diff', 'log', 'history', 'tag', 'status' and 'export'.
+            'add', 'remove', 'diff', 'log', 'history', 'tag', 'status' and
+            'export'.
         """
         return self.defaultOptions
         
@@ -459,11 +493,12 @@ class VersionControl(QObject):
         @param options a dictionary of option strings with keys as
                 defined by the default options
         """
-        for key in options.keys():
-            try:
-                self.options[key] = options[key]
-            except KeyError:
-                pass
+        if self.vcsSupportCommandOptions():
+            for key in options:
+                try:
+                    self.options[key] = options[key]
+                except KeyError:
+                    pass
         
     def vcsGetOptions(self):
         """
@@ -472,7 +507,10 @@ class VersionControl(QObject):
         @return a dictionary of option strings that can be passed to
             vcsSetOptions.
         """
-        return self.options
+        if self.vcsSupportCommandOptions():
+            return self.options
+        else:
+            return self.defaultOptions
         
     def vcsSetOtherData(self, data):
         """
@@ -480,7 +518,7 @@ class VersionControl(QObject):
         
         @param data a dictionary of vcs specific data
         """
-        for key in data.keys():
+        for key in data:
             try:
                 self.otherData[key] = data[key]
             except KeyError:
@@ -511,24 +549,25 @@ class VersionControl(QObject):
         @param dict dictionary to pick entries from
         """
         for key in self.interestingDataKeys:
-            if dict.has_key(key):
+            if key in dict:
                 self.otherData[key] = dict[key]
         
     #####################################################################
     ## below are some utility methods
     #####################################################################
     
-    def startSynchronizedProcess(self, proc, program, arguments, workingDir = None):
+    def startSynchronizedProcess(self, proc, program, arguments,
+                                 workingDir=None):
         """
-        Public method to start a synchroneous process
+        Public method to start a synchroneous process.
         
         This method starts a process and waits
         for its end while still serving the Qt event loop.
         
         @param proc process to start (QProcess)
-        @param program path of the executable to start (string or QString)
-        @param arguments list of arguments for the process (QStringList)
-        @param workingDir working directory for the process (string or QString)
+        @param program path of the executable to start (string)
+        @param arguments list of arguments for the process (list of strings)
+        @param workingDir working directory for the process (string)
         @return flag indicating normal exit (boolean)
         """
         if proc is None:
@@ -537,21 +576,23 @@ class VersionControl(QObject):
         if workingDir:
             proc.setWorkingDirectory(workingDir)
         proc.start(program, arguments)
-        procStarted = proc.waitForStarted()
+        procStarted = proc.waitForStarted(5000)
         if not procStarted:
-            KQMessageBox.critical(None,
+            E5MessageBox.critical(
+                None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
-                    'The process %1 could not be started. '
+                    'The process {0} could not be started. '
                     'Ensure, that it is in the search path.'
-                ).arg(program))
+                ).format(program))
             return False
         else:
             while proc.state() == QProcess.Running:
                 QApplication.processEvents()
                 QThread.msleep(300)
                 QApplication.processEvents()
-            return (proc.exitStatus() == QProcess.NormalExit) and (proc.exitCode() == 0)
+            return (proc.exitStatus() == QProcess.NormalExit) and \
+                (proc.exitCode() == 0)
         
     def splitPath(self, name):
         """
@@ -560,48 +601,46 @@ class VersionControl(QObject):
         @param name path name (string)
         @return a tuple of 2 strings (dirname, filename).
         """
-        fi = unicode(name)
-        if os.path.isdir(fi):
-            dn = os.path.abspath(fi)
+        if os.path.isdir(name):
+            dn = os.path.abspath(name)
             fn = "."
         else:
-            dn, fn = os.path.split(fi)
+            dn, fn = os.path.split(name)
         return (dn, fn)
     
     def splitPathList(self, names):
         """
-        Public method splitting the list of names into a common directory part and 
-        a file list.
+        Public method splitting the list of names into a common directory part
+        and a file list.
         
         @param names list of paths (list of strings)
         @return a tuple of string and list of strings (dirname, filenamelist)
         """
-        li = [unicode(n) for n in names]
-        dname = os.path.commonprefix(li)
+        dname = os.path.commonprefix(names)
         if dname:
             if not dname.endswith(os.sep):
                 dname = os.path.dirname(dname) + os.sep
-            fnames = [n.replace(dname, '') for n in li]
+            fnames = [n.replace(dname, '') for n in names]
             dname = os.path.dirname(dname)
             return (dname, fnames)
         else:
-            return ("/", li)
+            return ("/", names)
 
     def addArguments(self, args, argslist):
         """
-        Protected method to add an argument list to the already present arguments.
+        Protected method to add an argument list to the already present
+        arguments.
         
-        @param args current arguments list (QStringList)
-        @param argslist list of arguments (list of strings or list of QStrings or
-            a QStringList)
+        @param args current arguments list (list of strings)
+        @param argslist list of arguments (list of strings)
         """
         for arg in argslist:
-            if unicode(arg) != '':
+            if arg != '':
                 args.append(arg)
     
-    ############################################################################
+    ###########################################################################
     ## VCS status monitor thread related methods
-    ############################################################################
+    ###########################################################################
     
     def __statusMonitorStatus(self, status, statusMsg):
         """
@@ -609,10 +648,10 @@ class VersionControl(QObject):
         
         It simply reemits the received status.
         
-        @param status status of the monitoring thread (QString, ok, nok or off)
-        @param statusMsg explanotory text for the signaled status (QString)
+        @param status status of the monitoring thread (string, ok, nok or off)
+        @param statusMsg explanotory text for the signaled status (string)
         """
-        self.emit(SIGNAL("vcsStatusMonitorStatus(QString, QString)"), status, statusMsg)
+        self.vcsStatusMonitorStatus.emit(status, statusMsg)
         QApplication.flush()
 
     def __statusMonitorData(self, statusList):
@@ -621,9 +660,9 @@ class VersionControl(QObject):
         
         It simply reemits the received status list.
         
-        @param statusList list of status records (QStringList)
+        @param statusList list of status records (list of strings)
         """
-        self.emit(SIGNAL("vcsStatusMonitorData(QStringList)"), statusList)
+        self.vcsStatusMonitorData.emit(statusList)
         QApplication.flush()
 
     def startStatusMonitor(self, project):
@@ -634,19 +673,19 @@ class VersionControl(QObject):
         @return reference to the monitor thread (QThread)
         """
         if project.pudata["VCSSTATUSMONITORINTERVAL"]:
-            vcsStatusMonitorInterval = project.pudata["VCSSTATUSMONITORINTERVAL"][0]
+            vcsStatusMonitorInterval = project.pudata[
+                "VCSSTATUSMONITORINTERVAL"][0]
         else:
-            vcsStatusMonitorInterval = Preferences.getVCS("StatusMonitorInterval")
+            vcsStatusMonitorInterval = Preferences.getVCS(
+                "StatusMonitorInterval")
         if vcsStatusMonitorInterval > 0:
-            self.statusMonitorThread = \
-                self._createStatusMonitorThread(vcsStatusMonitorInterval, project)
+            self.statusMonitorThread = self._createStatusMonitorThread(
+                vcsStatusMonitorInterval, project)
             if self.statusMonitorThread is not None:
-                self.connect(self.statusMonitorThread, 
-                             SIGNAL("vcsStatusMonitorData(QStringList)"),
-                             self.__statusMonitorData, Qt.QueuedConnection)
-                self.connect(self.statusMonitorThread, 
-                             SIGNAL("vcsStatusMonitorStatus(QString, QString)"),
-                             self.__statusMonitorStatus, Qt.QueuedConnection)
+                self.statusMonitorThread.vcsStatusMonitorData.connect(
+                    self.__statusMonitorData, Qt.QueuedConnection)
+                self.statusMonitorThread.vcsStatusMonitorStatus.connect(
+                    self.__statusMonitorStatus, Qt.QueuedConnection)
                 self.statusMonitorThread.setAutoUpdate(
                     Preferences.getVCS("AutoUpdate"))
                 self.statusMonitorThread.start()
@@ -659,12 +698,10 @@ class VersionControl(QObject):
         Public method to stop the VCS status monitor thread.
         """
         if self.statusMonitorThread is not None:
-            self.__statusMonitorData(QStringList("--RESET--"))
-            self.disconnect(self.statusMonitorThread, 
-                SIGNAL("vcsStatusMonitorData(QStringList)"),
+            self.__statusMonitorData(["--RESET--"])
+            self.statusMonitorThread.vcsStatusMonitorData.disconnect(
                 self.__statusMonitorData)
-            self.disconnect(self.statusMonitorThread, 
-                SIGNAL("vcsStatusMonitorStatus(QString, QString)"),
+            self.statusMonitorThread.vcsStatusMonitorStatus.disconnect(
                 self.__statusMonitorStatus)
             self.statusMonitorThread.stop()
             self.statusMonitorThread.wait(10000)
@@ -672,7 +709,8 @@ class VersionControl(QObject):
                 self.statusMonitorThread.terminate()
                 self.statusMonitorThread.wait(10000)
             self.statusMonitorThread = None
-            self.__statusMonitorStatus(QString("off"), 
+            self.__statusMonitorStatus(
+                "off",
                 self.trUtf8("Repository status checking is switched off"))
     
     def setStatusMonitorInterval(self, interval, project):
@@ -725,6 +763,8 @@ class VersionControl(QObject):
         """
         Public method to wake up the VCS status monitor thread.
         """
+        self.vcsStatusChanged.emit()
+        
         if self.statusMonitorThread is not None:
             self.statusMonitorThread.checkStatus()
     
@@ -732,19 +772,21 @@ class VersionControl(QObject):
         """
         Public method to clear the cached VCS state of a file/directory.
         
-        @param name name of the entry to be cleared (QString or string)
+        @param name name of the entry to be cleared (string)
         """
         if self.statusMonitorThread is not None:
             self.statusMonitorThread.clearCachedState(name)
         
     def _createStatusMonitorThread(self, interval, project):
         """
-        Protected method to create an instance of the VCS status monitor thread.
+        Protected method to create an instance of the VCS status monitor
+        thread.
         
-        Note: This method should be overwritten in subclasses in order to support
-        VCS status monitoring.
+        Note: This method should be overwritten in subclasses in order to
+        support VCS status monitoring.
         
-        @param interval check interval for the monitor thread in seconds (integer)
+        @param interval check interval for the monitor thread in seconds
+            (integer)
         @param project reference to the project object
         @return reference to the monitor thread (QThread)
         """
