@@ -7,34 +7,34 @@
 Module implementing a configuration dialog for the bookmarked files menu.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QFileInfo, Qt, pyqtSlot
+from PyQt4.QtGui import QListWidgetItem, QColor, QDialog
 
-from KdeQt import KQFileDialog
+from E5Gui.E5Completers import E5FileCompleter
+from E5Gui import E5FileDialog
 
-from E4Gui.E4Completers import E4FileCompleter
-
-from Ui_BookmarkedFilesDialog import Ui_BookmarkedFilesDialog
+from .Ui_BookmarkedFilesDialog import Ui_BookmarkedFilesDialog
 
 import Utilities
 
+
 class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
     """
     Class implementing a configuration dialog for the bookmarked files menu.
     """
-    def __init__(self, bookmarks, parent = None):
+    def __init__(self, bookmarks, parent=None):
         """
         Constructor
         
-        @param bookmarks list of bookmarked files (QStringList)
+        @param bookmarks list of bookmarked files (list of strings)
         @param parent parent widget (QWidget)
         """
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
         self.setupUi(self)
         
-        self.fileCompleter = E4FileCompleter(self.fileEdit)
+        self.fileCompleter = E5FileCompleter(self.fileEdit)
         
-        self.bookmarks = QStringList(bookmarks)
+        self.bookmarks = bookmarks[:]
         for bookmark in self.bookmarks:
             itm = QListWidgetItem(bookmark, self.filesList)
             if not QFileInfo(bookmark).exists():
@@ -47,10 +47,11 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         """
         Private slot to handle the textChanged signal of the file edit.
         
-        @param txt the text of the file edit (QString)
+        @param txt the text of the file edit (string)
         """
-        self.addButton.setEnabled(not txt.isEmpty())
-        self.changeButton.setEnabled(not txt.isEmpty() and \
+        self.addButton.setEnabled(txt != "")
+        self.changeButton.setEnabled(
+            txt != "" and
             self.filesList.currentRow() != -1)
         
     def on_filesList_currentRowChanged(self, row):
@@ -75,13 +76,13 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
             bookmark = self.bookmarks[row]
             self.fileEdit.setText(bookmark)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_addButton_clicked(self):
         """
         Private slot to add a new entry.
         """
         bookmark = self.fileEdit.text()
-        if not bookmark.isEmpty():
+        if bookmark:
             bookmark = Utilities.toNativeSeparators(bookmark)
             itm = QListWidgetItem(bookmark, self.filesList)
             if not QFileInfo(bookmark).exists():
@@ -91,7 +92,7 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         row = self.filesList.currentRow()
         self.on_filesList_currentRowChanged(row)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_changeButton_clicked(self):
         """
         Private slot to change an entry.
@@ -107,7 +108,7 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         else:
             itm.setBackgroundColor(QColor())
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_deleteButton_clicked(self):
         """
         Private slot to delete the selected entry.
@@ -119,7 +120,7 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         row = self.filesList.currentRow()
         self.on_filesList_currentRowChanged(row)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_downButton_clicked(self):
         """
         Private slot to move an entry down in the list.
@@ -140,7 +141,7 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
         else:
             self.downButton.setEnabled(True)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_upButton_clicked(self):
         """
         Private slot to move an entry up in the list.
@@ -160,21 +161,21 @@ class BookmarkedFilesDialog(QDialog, Ui_BookmarkedFilesDialog):
             self.upButton.setEnabled(True)
         self.downButton.setEnabled(True)
         
-    @pyqtSignature("")
+    @pyqtSlot()
     def on_fileButton_clicked(self):
         """
         Private slot to handle the file selection via a file selection dialog.
         """
-        bookmark = KQFileDialog.getOpenFileName()
-        if not bookmark.isEmpty():
+        bookmark = E5FileDialog.getOpenFileName()
+        if bookmark:
             bookmark = Utilities.toNativeSeparators(bookmark)
             self.fileEdit.setText(bookmark)
         
     def getBookmarkedFiles(self):
         """
-        Public method to retrieve the tools list. 
+        Public method to retrieve the tools list.
         
-        @return a list of filenames (QStringList)
+        @return a list of filenames (list of strings)
         """
         return self.bookmarks
         
